CustomizationSpecManager

Struct CustomizationSpecManager 

pub struct CustomizationSpecManager { /* private fields */ }
The CustomizationSpecManager managed object is used to manage customization specifications stored on the VirtualCenter server.

Implementations

Source

impl CustomizationSpecManager

pub fn new(client: Arc<dyn VimClient>, mo_id: &str) -> Self

pub async fn check_customization_resources(&self, guest_os: &str) -> Result<()>

Deprecated as of vSphere 9.0, and there is no replacement for it.

Validate that required resources are available on the server to customize a particular guest operating system.

These would include sysprep for Windows and the debugfs and changefs volume editors for Linux guests.

Required privileges: System.View

Parameters:
guest_os

Short name from the guest OS descriptor list describing the OS we intend to customize.

Errors:

MissingLinuxCustResources:

MissingWindowsCustResources:

UncustomizableGuest:

pub async fn create_customization_spec( &self, item: &CustomizationSpecItem, ) -> Result<()>

Creates a new specification.

Required privileges: VirtualMachine.Provisioning.ModifyCustSpecs

Parameters:
item
Errors:

AlreadyExists:

CannotDecryptPasswords:

pub async fn delete_customization_spec(&self, name: &str) -> Result<()>

Deletes a specification.

Required privileges: VirtualMachine.Provisioning.ModifyCustSpecs

Parameters:
name
Errors:

NotFound:

pub async fn duplicate_customization_spec( &self, name: &str, new_name: &str, ) -> Result<()>

Duplicates a specification.

Required privileges: VirtualMachine.Provisioning.ModifyCustSpecs

Parameters:
name
new_name
Errors:

NotFound:

AlreadyExists:

pub async fn does_customization_spec_exist(&self, name: &str) -> Result<bool>

Whether or not a specification exists.

Required privileges: VirtualMachine.Provisioning.ReadCustSpecs

Parameters:
name
pub async fn get_customization_spec( &self, name: &str, ) -> Result<CustomizationSpecItem>

Obtains a specification for the given name.

Required privileges: VirtualMachine.Provisioning.ReadCustSpecs

Parameters:
name

Unique name identifying the requested customization specification.

Errors:

NotFound:

pub async fn is_guest_os_customizable(&self, guest_id: &str) -> Result<bool>

Whether or not the guest OS is customizable.

Since: vSphere API Release 9.0.0.0

Required privileges: System.View

Parameters:
guest_id

Short name from the guest OS descriptor list describing the OS we intend to check.

pub async fn overwrite_customization_spec( &self, item: &CustomizationSpecItem, ) -> Result<()>

Overwrites an existing specification, possibly after retrieving (by using ‘get’) and editing it.

If, based on the item’s changeVersion value, the overwrite process detects that the specification has changed since its retrieval, then the API uses the SpecModified exception to warn clients that they might overwrite another client’s change.

Required privileges: VirtualMachine.Provisioning.ModifyCustSpecs

Parameters:
item
Errors:

NotFound:

ConcurrentAccess:

CannotDecryptPasswords:

pub async fn rename_customization_spec( &self, name: &str, new_name: &str, ) -> Result<()>

Renames a specification.

Required privileges: VirtualMachine.Provisioning.ModifyCustSpecs

Parameters:
name
new_name
Errors:

NotFound:

AlreadyExists:

pub async fn customization_spec_item_to_xml( &self, item: &CustomizationSpecItem, ) -> Result<String>

Converts a specification item to XML text

Required privileges: System.View

Parameters:
item
pub async fn xml_to_customization_spec_item( &self, spec_item_xml: &str, ) -> Result<CustomizationSpecItem>

Converts an XML string to a specification item

Required privileges: System.View

Parameters:
spec_item_xml
Errors:

Failure

pub async fn encryption_key(&self) -> Result<Option<Vec<i8>>>

Gets a binary public encryption key that can be used to encrypt passwords in stored specifications.

Required privileges: System.View

pub async fn info(&self) -> Result<Option<Vec<CustomizationSpecInfo>>>

Gets a list of information on available specifications.

Required privileges: VirtualMachine.Provisioning.ReadCustSpecs