HostVirtualNicManager

Struct HostVirtualNicManager 

pub struct HostVirtualNicManager { /* private fields */ }
The VirtualNicManager managed object describes the special Virtual NIC configuration of the host.

Implementations

Source

impl HostVirtualNicManager

pub fn new(client: Arc<dyn VimClient>, mo_id: &str) -> Self

pub async fn deselect_vnic_for_nic_type( &self, nic_type: &str, device: &str, ) -> Result<()>

Deselect the VirtualNic to be a special type.

Required privileges: Host.Config.Network

Parameters:
nic_type

The type of VirtualNic that would be deselected

device

The device that uniquely identifies the VirtualNic.

Errors:

InvalidArgument: if nicType is invalid, device represents a nonexistent or invalid VirtualNic, or the VirtualNic is not selected

HostConfigFault: for any other failure.

pub async fn query_net_config( &self, nic_type: &str, ) -> Result<Option<VirtualNicManagerNetConfig>>

Get the NetConfig for the specified nicType

Required privileges: System.Read

Parameters:
nic_type

The HostVirtualNicManagerNicType_enum

Errors:

InvalidArgument: if nicType is invalid

HostConfigFault: for any other failure.

pub async fn select_vnic_for_nic_type( &self, nic_type: &str, device: &str, ) -> Result<()>

Select the NicType of the VirtualNic.

Selecting a device automatically deselects the previous selection if VirtualNicManagerNetConfig.multiSelectAllowed is false for the specified nicType. Else, the device is added to the list of selected nics.

Required privileges: Host.Config.Network

Parameters:
nic_type

The type of VirtualNic that would be selected

device

The device that uniquely identifies the VirtualNic.

Errors:

InvalidArgument: if nicType is invalid, or device represents a nonexistent or invalid VirtualNic

HostConfigFault: for any other failure.

pub async fn set_custom_value(&self, key: &str, value: &str) -> Result<()>

Assigns a value to a custom field.

The setCustomValue method requires whichever updatePrivilege is defined as one of the CustomFieldDef.fieldInstancePrivileges for the CustomFieldDef whose value is being changed.

Parameters:
key

The name of the field whose value is to be updated.

value

Value to be assigned to the custom field.

pub async fn available_field(&self) -> Result<Option<Vec<CustomFieldDef>>>

List of custom field definitions that are valid for the object’s type.

The fields are sorted by CustomFieldDef.name.

Required privileges: System.View

pub async fn info(&self) -> Result<HostVirtualNicManagerInfo>

Network configuration.

pub async fn value(&self) -> Result<Option<Vec<Box<dyn CustomFieldValueTrait>>>>

List of custom field values.

Each value uses a key to associate an instance of a CustomFieldStringValue with a custom field definition.

Required privileges: System.View