pub struct ManagedObjectView { /* private fields */ }Expand description
ManagedObjectView is the base class for view objects that provide access to a set of ManagedEntity objects.
ManagedObjectView defines a view list; the list contains references to objects in the view. To create a view use the ViewManager methods.
Implementations