StorageQueryManager

Struct StorageQueryManager 

pub struct StorageQueryManager { /* private fields */ }
This managed object is used to query vCenter Server’s storage system entities.

Implementations

Source

impl StorageQueryManager

pub fn new(client: Arc<dyn VimClient>, mo_id: &str) -> Self

pub async fn query_hosts_with_attached_lun( &self, lun_uuid: &str, ) -> Result<Option<Vec<ManagedObjectReference>>>

Query the set of all hosts which have the specified lun attached.

Requires Host.Config.Storage privilege on the hosts which have the lun in attached state.

Required privileges: System.Read

Parameters:
lun_uuid

The UUID of the ScsiLun device.

Returns:

HostSystem The set of hosts which have the specified lun attached. No values are returned if there are no hosts with the specified lun in attached state.

Refers instances of HostSystem.