VsanUpdateManager

Struct VsanUpdateManager 

pub struct VsanUpdateManager { /* private fields */ }
Generic engine that can install VIBs onto ESX (optimized for vSAN clusters) using either rolling installs or one-shot.

In addition to VIBs, it can also install firmware updates for select hardware. The Managed Entity can be accessed through MOID of vsan-update-manager, through vSAN service at ESXi host side.

Implementations

Source

impl VsanUpdateManager

pub fn new(client: Arc<dyn VimClient>, mo_id: &str) -> Self

pub async fn vsan_vib_install_task( &self, cluster: Option<&ManagedObjectReference>, vib_specs: Option<&[VsanVibSpec]>, scan_results: Option<&[VsanVibScanResult]>, firmware_specs: Option<&[VsanHclFirmwareUpdateSpec]>, maintenance_spec: Option<&HostMaintenanceSpec>, rolling: Option<bool>, no_sig_check: Option<bool>, ) -> Result<ManagedObjectReference>

Deprecated as of vSphere API 8.0.

Takes a list of VIBs, firmwares, and installs those VIBs/FWs on the hosts referenced in the VIB/FW specs.

If a scan has previously been performed, the results can be passed in. If not provided, a scan is done implicitly. Install may require ESX maintenance mode, and reboots, depending on the VIB to be installed and the state of the host. Any firmware update will always require maintenance mode and a host reboot.

Parameters:
cluster

Optional cluster this scan is happening in reference to.

Required privileges: Host.Config.Storage Host.Config.Settings

Refers instance of ComputeResource.

vib_specs

List of VIB specs to installed (context is always a single host)

scan_results

List of VIB scan results obtained from VsanVibScan()

firmware_specs

List of Firmware spec to be installed (context is always a single host and vmhba)

maintenance_spec

Maintenance spec to pass to EnterMaintenanceMode_Task() In case of non-rolling installs, no other vSAN action than ‘noAction’ is allowed.

rolling

True (default) means a 1-host-at-a-time rolling install will be performed.

no_sig_check

Skip signature checking, should not be used outside of fully trusted test environments. Default: False

Returns:

Refers instance of Task.

Errors:

Failure

pub async fn vsan_vib_install_preflight_check( &self, cluster: Option<&ManagedObjectReference>, ) -> Result<VsanVibInstallPreflightStatus>

Performs pre-flight checks for a VIB install.

Details of checks performed are documented in the result structure.

Parameters:
cluster

Cluster for which to perform preflight check

Required privileges: System.Read

Refers instance of ComputeResource.

Returns:

Preflight check results

Errors:

Failure

pub async fn vsan_vib_scan( &self, cluster: Option<&ManagedObjectReference>, vib_specs: &[VsanVibSpec], ) -> Result<Option<Vec<VsanVibScanResult>>>

Takes a list of VIBs and a list of hosts, and determines which VIBs would be installed, what the requirements are (e.g.

maintenance mode, reboot) and which existing VIBs (if any) they are overriding. Doesn’t perform any actual install, but instead just provides information on “what if”.

Parameters:
cluster

Optional cluster this scan is happening in reference to.

Required privileges: System.Read

Refers instance of ComputeResource.

vib_specs

List of VIB specs to check (one entry per host)

Returns:

List of VIBs that would be installed. Each such result is for a single host, single VIB.

Errors:

Failure