pub enum ArrayUpdateOperationEnum {
Add,
Remove,
Edit,
Other_(String),
}Expand description
This list specifies the type of operation being performed on the array.
Possible values:
-
add: indicates an addition to the array. -
remove: indicates the removal of an element in the array.In this case the key field must contain the key of the element to be removed.
-
edit: indicates changes to an element in the array.
Variants
Implementations