pub enum AutoStartActionEnum {
None,
SystemDefault,
PowerOn,
PowerOff,
GuestShutdown,
Suspend,
Other_(String),
}Expand description
Possible values:
-
none: No action is taken for this virtual machine.This virtual machine is not a part of the auto-start sequence. This can be used for both auto-start and auto-start settings.
-
systemDefault: The default system action is taken for this virtual machine when it is next in the auto-start order.This can be used for both auto-start and auto-start settings.
-
powerOn: This virtual machine is powered on when it is next in the auto-start order. -
powerOff: This virtual machine is powered off when it is next in the auto-stop order.This is the default stopAction.
-
guestShutdown: The guest operating system for a virtual machine is shut down when that virtual machine in next in the auto-stop order. -
suspend: This virtual machine is suspended when it is next in the auto-stop order.
Variants
None
SystemDefault
PowerOn
PowerOff
GuestShutdown
Suspend
Other_(String)
This variant handles values not known at compile time.
Implementations