pub enum ClusterInfraUpdateHaConfigInfoRemediationTypeEnum {
QuarantineMode,
MaintenanceMode,
Other_(String),
}Expand description
Possible values:
QuarantineMode: With this behavior configured, a degraded host will be recommended to be placed in Quarantine Mode.MaintenanceMode: With this behavior configured, a degraded host will be recommended to be placed in Maintenance Mode.
Variants
QuarantineMode
MaintenanceMode
Other_(String)
This variant handles values not known at compile time.
Implementations