ClusterPowerStatusEnum

Enum ClusterPowerStatusEnum 

pub enum ClusterPowerStatusEnum {
Show 20 variants ClusterPoweredOn, HaDisabled, SupportedVMsPoweredOff, VcVmPoweredOff, VsanMemberShipUpdateDisabled, VsanDomPauseAllCcPsSet, HostsInMm, HostsPoweredOff, ClusterPoweredOff, HostsOutOfMm, VsanMemberShipUpdateEnabled, VsanDomPauseAllCcPsUnset, VcVmPoweredOn, SupportedVMsPoweredOn, HaEnabled, InfraVMsRecorded, HostsInfraVMsPoweredoff, HostsInfraVMsPoweredon, ClusterPowerStatusUnknown, Other_(String),
}
Defines the detailed cluster wide power action.

Possible values:

  • clusterPoweredOn: indicate the cluster is in running state.
  • haDisabled: vSphere HA is disabled.
  • supportedVMsPoweredOff: the supported system VMs are powered off.
  • vcVMPoweredOff: power off the VC VM if the VC VM is on vSAN.
  • vsanMemberShipUpdateDisabled: vSAN membership updates is disabled.
  • vsanDOMPauseAllCCPsSet: DOMPauseAllCCPs is set.
  • hostsInMM: all hosts are in maintenance mode.
  • hostsPoweredOff: power-off operations have been triggered on all hosts.
  • clusterPoweredOff: indicate the cluster is in shutdown state.
  • hostsOutOfMM: all hosts are out of maintenance mode.
  • vsanMemberShipUpdateEnabled: vSAN membership updates is enabled.
  • vsanDOMPauseAllCCPsUnset: DOMPauseAllCCPs is unset.
  • vcVMPoweredOn: power on the VC VMs if it the VC VM is on vSAN.
  • supportedVMsPoweredOn: the supported system VMs are powered on.
  • haEnabled: vSphere HA is enabled.
  • infraVMsRecorded
  • hostsInfraVMsPoweredoff
  • hostsInfraVMsPoweredon
  • ClusterPowerStatus_Unknown: represent the value when the lower version client cannot recognize the enum value.

Variants



ClusterPoweredOn



HaDisabled



SupportedVMsPoweredOff



VcVmPoweredOff



VsanMemberShipUpdateDisabled



VsanDomPauseAllCcPsSet



HostsInMm



HostsPoweredOff



ClusterPoweredOff



HostsOutOfMm



VsanMemberShipUpdateEnabled



VsanDomPauseAllCcPsUnset



VcVmPoweredOn



SupportedVMsPoweredOn



HaEnabled



InfraVMsRecorded



HostsInfraVMsPoweredoff



HostsInfraVMsPoweredon



ClusterPowerStatusUnknown



Other_(String)

This variant handles values not known at compile time.

Implementations

Source

impl ClusterPowerStatusEnum

pub fn as_str(&self) -> &str

pub fn from_str(s: &str) -> Self