pub enum CustomizationSysprepRebootOptionEnum {
Reboot,
Noreboot,
Shutdown,
Other_(String),
}Expand description
A enum constant specifying what should be done to the guest vm after running sysprep.
Possible values:
-
reboot: Reboot the machine after running sysprep.This will cause values specified in the sysprep.xml to be applied immediately.
-
noreboot: Take no action.Leave the guest os running after running sysprep. This option can be used to look at values for debugging purposes after running sysprep.
-
shutdown: Shutdown the machine after running sysprep.This puts the vm in a sealed state.
How to access
VirtualMachine::check_customization_spec(spec).options?→CustomizationWinOptions.reboot?VirtualMachine::customize_vm_task(spec).options?→CustomizationWinOptions.reboot?VirtualMachine::clone_vm_task(spec).customization?.options?→CustomizationWinOptions.reboot?ClusterComputeResource::place_vm(placement_spec).clone_spec?.customization?.options?→CustomizationWinOptions.reboot?VirtualMachineGuestCustomizationManager::customize_guest_task(spec).options?→CustomizationWinOptions.reboot?CustomizationSpecManager::create_customization_spec(item).spec.options?→CustomizationWinOptions.reboot?CustomizationSpecManager::get_customization_spec().spec.options?→CustomizationWinOptions.reboot?CustomizationSpecManager::overwrite_customization_spec(item).spec.options?→CustomizationWinOptions.reboot?CustomizationSpecManager::customization_spec_item_to_xml(item).spec.options?→CustomizationWinOptions.reboot?CustomizationSpecManager::xml_to_customization_spec_item().spec.options?→CustomizationWinOptions.reboot?
(10 of 12 paths)
Variants
Implementations