pub enum HostConfigChangeOperationEnum {
Add,
Remove,
Edit,
Ignore,
Other_(String),
}Expand description
This list indicates the operation that should be performed for an entity.
Possible values:
-
add: Indicates the addition of an entity to the configuration. -
remove: Indicates the removal of an entity from the configuration. -
edit: Indicates changes on the entity.The entity must exist or a NotFound error will be thrown.
-
ignore: Indicates that an entity will be ignored: it won’t be added when it doesn’t exist, or removed/changed when it exists.
Variants
Implementations