pub enum HostLicensableResourceKeyEnum {
NumCpuPackages,
NumCpuCores,
MemorySize,
MemoryForVms,
NumVmsStarted,
NumVmsStarting,
VsanCapacity,
Other_(String),
}Expand description
Identifiers of currently supported resources.
Possible values:
-
numCpuPackages: Number of CPU packages on this host. -
numCpuCores: Number of licensable CPU cores/compute-units on this host. -
memorySize: Total size of memory installed on this host, measured in kilobytes. -
memoryForVms: Total size of memory configured for VMs on this host, measured in kilobytes. -
numVmsStarted: Number of VMs already running on this host. -
numVmsStarting: Number of VMs that are currently powering-on, immigrating, etc. -
vsanCapacity: vSAN capacity in TiB on this host.Since: vSphere API Release 8.0.3.0
Variants
NumCpuPackages
NumCpuCores
MemorySize
MemoryForVms
NumVmsStarted
NumVmsStarting
VsanCapacity
Other_(String)
This variant handles values not known at compile time.
Implementations