pub enum HostPtpConfigDeviceTypeEnum {
None,
VirtualNic,
PciPassthruNic,
Other_(String),
}Expand description
PTP capable network device type.
Possible values:
-
none: No device. -
virtualNic: Virtual network adapter. -
pciPassthruNic: A network PCI device capable of PTP hardware timestamping, enabled for passthru.See HostPciPassthruSystem for information on PCI devices enabled for passthru available on the host.
Since: vSphere API Release 7.0.3.0
Variants
None
VirtualNic
PciPassthruNic
Other_(String)
This variant handles values not known at compile time.
Implementations