pub enum HttpNfcLeaseStateEnum {
Initializing,
Ready,
Done,
Error,
Other_(String),
}Expand description
List of possible states of a lease.
Possible values:
initializing: When the lease is being initialized.ready: When the lease is ready and disks may be transferred.done: When the import/export session is completed, and the lease is no longer held.error: When an error has occurred.
How to access
HttpNfcLease::state
Variants
Implementations