pub enum LicenseFeatureInfoStateEnum {
Enabled,
Disabled,
Optional,
Other_(String),
}Expand description
Describes the state of the feature.
Possible values:
-
enabled: The current edition license has implicitly enabled this additional feature. -
disabled: The current edition license does not allow this additional feature. -
optional: The current edition license allows this additional feature.The LicenseManager.EnableFeature and LicenseManager.DisableFeature methods can be used to enable or disable this feature.
How to access
LicenseManager::feature_info.state?LicenseManager::query_supported_features().state?LicenseManager::query_license_source_availability().feature.state?LicenseManager::query_license_usage().feature_info?[*].state?
Variants
Implementations