pub enum LicenseManagerLicenseKeyEnum {
Show 18 variants
EsxFull,
EsxVmtn,
EsxExpress,
San,
Iscsi,
Nas,
Vsmp,
Backup,
Vc,
VcExpress,
EsxHost,
GsxHost,
ServerHost,
DrsPower,
Vmotion,
Drs,
Das,
Other_(String),
}Expand description
Deprecated as of VI API 2.5, use LicenseManager.QueryLicenseSourceAvailability to obtain an array of LicenseAvailabilityInfo data objects.
Licensed features have unique keys to identify them.
Possible values:
-
esxFull: The edition license for the ESX Server, Standard edition.This is a per CPU package license.
-
esxVmtn: The edition license for the ESX server, VMTN edition.This is a per CPU package license.
-
esxExpress: The edition license for the ESX server, Starter edition.This is a per CPU package license.
-
san: Enable use of SAN.This is a per CPU package license.
-
iscsi: Enable use of iSCSI.This is a per CPU package license.
-
nas: Enable use of NAS.This is a per CPU package license.
-
vsmp: Enable up to 4-way VSMP feature.This is a per CPU package license.
-
backup: Enable ESX Server consolidated backup feature.This is a per CPU package license.
-
vc: The edition license for a VirtualCenter server, full edition.This license is independent of the number of CPU packages for the VirtualCenter host.
-
vcExpress: The edition license for a VirtualCenter server, starter edition.This license limits the number of hosts (esxHost or serverHost) that can be managed by the VirtualCenter product.
-
esxHost: Enable VirtualCenter ESX Server host management functionality.This is a per ESX server CPU package license.
-
gsxHost: Enable VirtualCenter GSX Server host management functionality.This is a per GSX server CPU package license.
-
serverHost: Enable VirtualCenter VMware server host management functionality.This is a per VMware server CPU package license.
-
drsPower: Enable VirtualCenter DRS Power Management Functionality.This is a per CPU package
-
vmotion: Enable VMotion.This is a per ESX server CPU package license.
-
drs: Enable VirtualCenter Distributed Resource Scheduler.This is a per ESX server CPU package license.
-
das: Enable VirtualCenter HA.This is a per ESX server CPU package license.
Variants
EsxFull
EsxVmtn
EsxExpress
San
Iscsi
Nas
Vsmp
Backup
Vc
VcExpress
EsxHost
GsxHost
ServerHost
DrsPower
Vmotion
Drs
Das
Other_(String)
This variant handles values not known at compile time.
Implementations