pub enum PbmBuiltinGenericTypeEnum {
VmwRange,
VmwSet,
Other_(String),
}Expand description
The PbmBuiltinGenericType_enum enumerated type defines the list of builtin generic datatypes.
See PbmCapabilityGenericTypeInfo.PbmCapabilityGenericTypeInfo.genericTypeName.
A generic datatype indicates how to interpret a collection of values of a specific datatype (PbmCapabilityTypeInfo.typeName).
Possible values:
-
VMW_RANGE: Indicates a full or partial range of values (PbmCapabilityRange).A full range specifies both
minandmaxvalues. A partial range specifies one or the other,minormax. -
VMW_SET: Indicates a single value or a discrete set of values (PbmCapabilityDiscreteSet).
Variants
Implementations