pub enum ThirdPartyLicenseAssignmentFailedReasonEnum {
LicenseAssignmentFailed,
ModuleNotInstalled,
Other_(String),
}Expand description
Possible values:
licenseAssignmentFailed: A general failure has occurred during assigning license to the 3rd party modulemoduleNotInstalled: The 3rd party module we are trying to license is not installed.
Variants
LicenseAssignmentFailed
ModuleNotInstalled
Other_(String)
This variant handles values not known at compile time.
Implementations