pub enum UpgradePolicyEnum {
Manual,
UpgradeAtPowerCycle,
Other_(String),
}Expand description
The policy setting used to determine when tools are auto-upgraded for a virtual machine
Possible values:
-
manual: No auto-upgrades for tools will be performed for this virtual machine.Users must manually invoke the UpgradeTools operation to update the tools.
-
upgradeAtPowerCycle: When the virtual machine is power-cycled, the system checks for a newer version of tools when the VM comes back up.If it is available, a tools upgrade is automatically performed on the virtual machine and it is rebooted if necessary.
Variants
Implementations