pub enum VimVsanLifecyclePreCheckTypeEnum {
SupportedWitnessVersion,
VirtualWitnessHost,
SharedWitnessHost,
PreCheckTypeUnknown,
Other_(String),
}Expand description
The lifecycle check types required by lifecycle manager/vLCM.
Possible values:
supportedWitnessVersion: Check to cover that the witness host software version is 7.0 or higher.virtualWitnessHost: Check to cover that the witness host is a virtual host and not a physical host.sharedWitnessHost: Check to cover that the witness host is not shared.PreCheckType_unknown: Unknown precheck type.
Variants
SupportedWitnessVersion
VirtualWitnessHost
PreCheckTypeUnknown
Other_(String)
This variant handles values not known at compile time.
Implementations