pub enum VirtualDiskRuleSpecRuleTypeEnum {
Affinity,
AntiAffinity,
Disabled,
Other_(String),
}Expand description
Rule type determines how the virtual disks in a vm can be grouped together.
Possible values:
affinity: Virtual disks in the list are grouped together and placed on the same data store.antiAffinity: Virtual disks in the list are placed on different data stores.disabled: SDRS will be disabled for the disks in the list.
Variants
Affinity
AntiAffinity
Disabled
Other_(String)
This variant handles values not known at compile time.
Implementations