pub enum VirtualMachineToolsInstallTypeEnum {
GuestToolsTypeUnknown,
GuestToolsTypeMsi,
GuestToolsTypeTar,
GuestToolsTypeOsp,
GuestToolsTypeOpenVmTools,
Other_(String),
}Expand description
The installation type of tools in the VM.
Possible values:
-
guestToolsTypeUnknown: Installation type is not known.Most likely tools have been installed by OSPs or open-vm-tools, but a version that does not report its install type or an install type that we do not recognize.
-
guestToolsTypeMSI: MSI is the installation type used for VMware Tools on Windows. -
guestToolsTypeTar: Tools have been installed by the tar installer. -
guestToolsTypeOSP: OSPs are RPM or Debian packages tailored for the OS in the VM.See http://packages.vmware.com
-
guestToolsTypeOpenVMTools: open-vm-tools are the open-source version of VMware Tools, may have been packaged by the OS vendor.
Variants
GuestToolsTypeUnknown
GuestToolsTypeMsi
GuestToolsTypeTar
GuestToolsTypeOsp
GuestToolsTypeOpenVmTools
Other_(String)
This variant handles values not known at compile time.
Implementations