pub enum VsanControllerTypeEnum {
NvMe,
Scsi,
VsanControllerTypeUnknown,
Other_(String),
}Expand description
Enumeration indicates the vSAN disk controller type.
Possible values:
NVMe: The controller is an NVMe controller.SCSI: The controller is a SCSI controller.VsanControllerType_Unknown: Represent the value when the lower version client cannot recognize the enum value.
Variants
NvMe
Scsi
VsanControllerTypeUnknown
Other_(String)
This variant handles values not known at compile time.
Implementations