pub enum VsanDiskTypeEnum {
DiskGroup,
StoragePool,
DirectDisk,
VsanDiskTypeUnknown,
Other_(String),
}Expand description
vSAN disk types.
Possible values:
diskGroup: Represents disk belonging to disk group model.storagePool: Represents disk belonging to storage pool model.directDisk: Represents disk belonging to vSAN direct disks.VsanDiskType_Unknown: Represents the value when lower version client cannot recognize the enum value.
Variants
DiskGroup
StoragePool
DirectDisk
VsanDiskTypeUnknown
Other_(String)
This variant handles values not known at compile time.
Implementations