AgencyConfigInfo

Struct AgencyConfigInfo 

pub struct AgencyConfigInfo {
Show 17 fields pub agent_config: Option<Vec<AgentConfigInfo>>, pub scope: Option<Box<dyn AgencyScopeTrait>>, pub manually_mark_agent_vm_available_after_provisioning: Option<bool>, pub manually_mark_agent_vm_available_after_power_on: Option<bool>, pub optimized_deployment_enabled: Option<bool>, pub agent_name: Option<String>, pub agency_name: Option<String>, pub use_uuid_vm_name: Option<bool>, pub manually_provisioned: Option<bool>, pub manually_monitored: Option<bool>, pub bypass_vum_enabled: Option<bool>, pub agent_vm_network: Option<Vec<ManagedObjectReference>>, pub agent_vm_datastore: Option<Vec<ManagedObjectReference>>, pub prefer_host_configuration: Option<bool>, pub ip_pool: Option<IpPool>, pub resource_pools: Option<Vec<AgencyVmResourcePool>>, pub folders: Option<Vec<AgencyVmFolder>>,
}
Deprecated as of vSphere 9.0. Please refer to vLCM APIs.

This is the configuration of an Agency.

It determines on which compute resources to deploy the agents, which VIB to install, which OVF package to install, and how to configure these items by setting the OVF environment properties.

This structure may be used only with operations rendered under /eam.

How to access

  • Agency::config
  • Agency::query_config()
  • Agency::update(config)
  • EsxAgentManager::create_agency(agency_config_info)

Fields

agent_config: Option<Vec<AgentConfigInfo>>

A list of AgentConfigInfos for hosts covered by this Agency.

When provisioning a new agent to a host, vSphere ESX Agent Manager tries to find, from left to right in the array, a match for an AgentConfigInfo and stops searching at the first one that it finds. If AgencyConfigInfoEx.vmPlacementPolicy is set, the array needs to contain only a single agent config. In that case the agent config is not bound to a specific host, but to the whole cluster.

scope: Option<Box<dyn AgencyScopeTrait>>

The scope of the Agency.

manually_mark_agent_vm_available_after_provisioning: Option<bool>

If set to true, the client of this agency must manually mark the agent as ready after the agent virtual machine has been provisioned.

This is useful if the client of this solution performs some extra reconfiguration of the agent virtual machine before it is powered on.

See also Agent.MarkAsAvailable.

manually_mark_agent_vm_available_after_power_on: Option<bool>

If set to true, the client of this agency must manually mark the agent as ready after the agent virtual machine has been powered on.

In this case, DRS will not regard the agent virtual machine as ready until the client has marked the agent as ready.

See also Agent.MarkAsAvailable.

optimized_deployment_enabled: Option<bool>

If set to true, ESX Agent Manager will use vSphere Linked Clones to speed up the deployment of agent virtual machines.

Using linked clones implies that the agent virtual machines cannot use Storage vMotion to move to another vSphere datastore. If set to false, ESX Agent Manager will use Full VM Cloning. If unset default is true.

agent_name: Option<String>

An optional name to use when naming agent virtual machines.

For example, if set to “example-agent”, each agent virtual machine will be named “example-agent (1)”, “example-agent (2)”, and so on. The maximum length of agentName is 70 characters.

agency_name: Option<String>

Name of the agency.

Must be set when creating the agency.

use_uuid_vm_name: Option<bool>

Property agentName is required if this property is set to true.

If set to true, ESX Agent Manager will name virtual machines with UUID suffix. For example, “example-agent-UUID”. In this case, the maximum length of agentName is 43 characters.

If not set or is set to false, virtual machines will not contain UUID in their name.

manually_provisioned: Option<bool>

Deprecated use automatically provisioned VMs and register hooks to have control post provisioning and power on.

Set to true if agent VMs are manually provisioned.

If unset, defaults to false.

manually_monitored: Option<bool>

Deprecated use automatically provisioned VMs and register hooks to have control post provisioning and power on.

Set to true if agent VMs are manually monitored.

If unset, defaults to false. This can only be set to true if AgencyConfigInfo.manuallyProvisioned is set to true.

bypass_vum_enabled: Option<bool>

Deprecated vUM is no more consulted so this property has no sense anymore.

Set to true will install VIBs directly on the hosts even if VMware Update Manager is installed.

If unset, defaults to false.

agent_vm_network: Option<Vec<ManagedObjectReference>>

Specifies the networks which to be configured on the agent VMs.

This property is only applicable for pinned to host VMs - i.e. (AgencyConfigInfoEx.vmPlacementPolicy) is not set.

If not set or AgencyConfigInfo.preferHostConfiguration is set to true, the default host agent VM network (configured through vim.host.EsxAgentHostManager) is used, otherwise the first network from the array that is present on the host is used.

At most one of AgencyConfigInfo.agentVmNetwork and AgencyConfigInfoEx.vmNetworkMapping needs to be set.

Refers instances of Network.

agent_vm_datastore: Option<Vec<ManagedObjectReference>>

The datastores used to configure the storage on the agent VMs.

This property is required if AgencyConfigInfoEx.vmPlacementPolicy is set and AgencyConfigInfoEx.datastoreSelectionPolicy is not set. In that case the first element from the list is used.

If not set or AgencyConfigInfo.preferHostConfiguration is set to true and AgencyConfigInfoEx.vmPlacementPolicy is not set, the default host agent VM datastore (configured through vim.host.EsxAgentHostManager) is used, otherwise the first datastore from the array that is present on the host is used.

If AgencyConfigInfoEx.vmPlacementPolicy is set at most one of AgencyConfigInfo.agentVmDatastore and AgencyConfigInfoEx.datastoreSelectionPolicy needs to be set. If AgencyConfigInfoEx.vmPlacementPolicy is not set AgencyConfigInfoEx.datastoreSelectionPolicy takes precedence over AgencyConfigInfo.agentVmDatastore .

Refers instances of Datastore.

prefer_host_configuration: Option<bool>

If set to true the default agent VM datastore and network will take precedence over AgencyConfigInfo.agentVmNetwork and AgencyConfigInfo.agentVmDatastore when configuring the agent VMs.

This property is not used if AgencyConfigInfoEx.vmPlacementPolicy is set.

ip_pool: Option<IpPool>

Deprecated that is a custom configuration that should be setup by the agency owner. One way is to use AgencyConfigInfo.manuallyMarkAgentVmAvailableAfterPowerOn or AgencyConfigInfo.manuallyMarkAgentVmAvailableAfterProvisioning hooks.

If set, a property with id “ip” and value an IP from the pool is added to the vApp configuration of the deployed VMs.

resource_pools: Option<Vec<AgencyVmResourcePool>>

Defines the resource pools where VMs to be deployed.

If specified, the VMs for every compute resouce in the scope will be deployed to its corresponding resource pool. If not specified, the agent VMs for each compute resource will be deployed under top level nested resource pool created for the agent VMs. If unable to create a nested resource pool, the root resource pool of the compute resource will be used.

folders: Option<Vec<AgencyVmFolder>>

Defines the folders where VMs to be deployed.

If specified, the VMs for every compute resouce in the scope will be deployed to its corresponding folder. The link is made between the compute resource parent and the datacenter the folder belongs to AgencyVMFolder.datacenterId. If not specified, the agent VMs for each compute resource will be deployed in top level folder created in each datacenter for the agent VMs.