AgentVibMatchingRule

Struct AgentVibMatchingRule 

pub struct AgentVibMatchingRule {
    pub vib_name_regex: String,
    pub vib_version_regex: String,
}
Deprecated vIB matching rules are no longer supported by EAM. Same overlaps with VIB dependency requirements which reside in each VIB’s metadata.

Specifies regular expressions for Vib name and version.

This structure may be used only with operations rendered under /eam.

How to access

  • Agent::config.vib_matching_rules?[*]
  • Agency::config.agent_config?[*].vib_matching_rules?[*]
  • Agent::agent_query_config().vib_matching_rules?[*]
  • Agency::query_config().agent_config?[*].vib_matching_rules?[*]
  • Agency::update(config).agent_config?[*].vib_matching_rules?[*]
  • EsxAgentManager::create_agency(agency_config_info).agent_config?[*].vib_matching_rules?[*]

Fields

vib_name_regex: String

Vib name regular expression.

vib_version_regex: String

Vib version regular expression.