pub struct AndAlarmExpression {
pub expression: Vec<Box<dyn AlarmExpressionTrait>>,
}Expand description
A data object type that links multiple alarm expressions with AND operators.
How to access
AlarmManager::default_expression→AndAlarmExpressionAlarm::reconfigure_alarm(spec).expression→AndAlarmExpressionAlarmManager::create_alarm(spec).expression→AndAlarmExpression
Fields
expression: Vec<Box<dyn AlarmExpressionTrait>>List of alarm expressions that define the overall status of the alarm.
- The state of the alarm expression is gray if all subexpressions are gray. Otherwise, gray subexpressions are ignored.
- The state is red if all subexpressions are red.
- Otherwise, the state is yellow if all subexpressions are red or yellow.
- Otherwise, the state of the alarm expression is green.