pub struct ApplyHostProfileConfigurationResult {
pub start_time: String,
pub complete_time: String,
pub host: ManagedObjectReference,
pub status: String,
pub errors: Option<Vec<MethodFault>>,
}Expand description
The ApplyHostProfileConfigurationResult data object contains the remediation results for a host: the time that the remediation happens, the status, the errors, and optinal compliance result after reboot.
How to access
HostSystem::remediation_result
Fields
start_time: StringTime that the host config apply starts.
complete_time: StringTime that the host config apply completes.
host: ManagedObjectReferenceHost to be remediated.
Refers instance of HostSystem.
status: StringStatus of the remediation.
See ApplyHostProfileConfigurationResultStatus_enum for valid values.
errors: Option<Vec<MethodFault>>If status is fail, this property contains
a list of status error message objects.