BaseConfigInfo

Struct BaseConfigInfo 

pub struct BaseConfigInfo {
    pub id: Id,
    pub name: String,
    pub create_time: String,
    pub keep_after_delete_vm: Option<bool>,
    pub relocation_disabled: Option<bool>,
    pub native_snapshot_supported: Option<bool>,
    pub changed_block_tracking_enabled: Option<bool>,
    pub backing: Box<dyn BaseConfigInfoBackingInfoTrait>,
    pub metadata: Option<Vec<KeyValue>>,
    pub vclock: Option<VslmVClockInfo>,
    pub iofilter: Option<Vec<String>>,
}
This data object type contains the basic configuration for a virtual storage object or a virtual storage object snapshot.

Fields

id: Id

ID of this object.

name: String

Descriptive name of this object.

create_time: String

The date and time this object was created.

keep_after_delete_vm: Option<bool>

Choice of the deletion behavior of this virtual storage object.

If not set, the default value is false.

relocation_disabled: Option<bool>

Is virtual storage object relocation disabled.

If not set, the default value is false.

native_snapshot_supported: Option<bool>

Is virtual storage object supports native snapshot.

If not set, the default value is false.

changed_block_tracking_enabled: Option<bool>

If Virtua storage object has changed block tracking enabled.

If not set, the default value is false.

backing: Box<dyn BaseConfigInfoBackingInfoTrait>

Backing of this object.

metadata: Option<Vec<KeyValue>>

Metadata associated with the FCD if available.

Since: vSphere API Release 7.0.2.0

vclock: Option<VslmVClockInfo>

VClock associated with the fcd when the operation completed.

The files is unset if the operation is a retrieve.

Since: vSphere API Release 7.0.2.0

iofilter: Option<Vec<String>>

IDs of the IO Filters associated with the virtual disk.

See IoFilterInfo.id. The client cannot modify this information on a virtual machine.