pub struct BoolOption {
pub option_type_: OptionType,
pub supported: bool,
pub default_value: bool,
}Expand description
The BoolOption data object type describes if an option is supported (“true”) and if the option is set to “true” or “false” by default.
How to access
ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.device_change?[*].device.device_info?→OptionDef.option_type→BoolOptionClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.device_change?[*].device.device_info?→OptionDef.option_type→BoolOptionClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.device_change?[*].device.device_info?→OptionDef.option_type→BoolOptionClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device.device_info?→OptionDef.option_type→BoolOptionClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_groups?.device_group?[*].device_info?→OptionDef.option_type→BoolOptionAlarmManager::description.state_operator[*]→OptionDef.option_type→BoolOptionAlarmManager::description.metric_operator[*]→OptionDef.option_type→BoolOptionAlarmManager::description.host_system_connection_state[*]→OptionDef.option_type→BoolOptionAlarmManager::description.virtual_machine_power_state[*]→OptionDef.option_type→BoolOptionAlarmManager::description.datastore_connection_state[*]→OptionDef.option_type→BoolOption
(10 of 100 paths)
Fields
option_type_: OptionTypesupported: boolThe flag to indicate whether or not the option is supported.
default_value: boolThe default value for the option.