ClusterAgentHostInPartialMaintenanceMode

Struct ClusterAgentHostInPartialMaintenanceMode 

pub struct ClusterAgentHostInPartialMaintenanceMode {
    pub cluster_agent_vm_issue_: ClusterAgentVmIssue,
}
An agent virtual machine operation cannot be executed on host, because the host is in partial maintenance mode that blocks the virtual machine operation.

This is not a remediable issue. To remediate, take the host ouf of partial maintenance mode.

This structure may be used only with operations rendered under /eam.

Since: vEAM API 8.3

Fields

cluster_agent_vm_issue_: ClusterAgentVmIssue