pub struct ClusterAgentVmProtected {
pub cluster_agent_vm_issue_: ClusterAgentVmIssue,
}Expand description
An agent virtual machine is protected from modifications (example: HA recovery).
This is an active remediable issue. To remediate, vSphere ESX Agent Manager modifies the virtual machine.
This structure may be used only with operations rendered under /eam.
Since: vEAM API 9.0
Fields
cluster_agent_vm_issue_: ClusterAgentVmIssueTrait Implementations
Sourceimpl AgencyIssueTrait for ClusterAgentVmProtected
impl AgencyIssueTrait for ClusterAgentVmProtected
Sourcefn get_agency_issue(&self) -> &AgencyIssue
fn get_agency_issue(&self) -> &AgencyIssue
Get a reference to the AgencyIssue parent struct
Sourcefn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
fn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
Get a mutable reference to the AgencyIssue parent struct
Sourceimpl ClusterAgentAgentIssueTrait for ClusterAgentVmProtected
impl ClusterAgentAgentIssueTrait for ClusterAgentVmProtected
Sourcefn get_cluster_agent_agent_issue(&self) -> &ClusterAgentAgentIssue
fn get_cluster_agent_agent_issue(&self) -> &ClusterAgentAgentIssue
Get a reference to the ClusterAgentAgentIssue parent struct
Sourcefn get_cluster_agent_agent_issue_mut(&mut self) -> &mut ClusterAgentAgentIssue
fn get_cluster_agent_agent_issue_mut(&mut self) -> &mut ClusterAgentAgentIssue
Get a mutable reference to the ClusterAgentAgentIssue parent struct
Sourceimpl ClusterAgentVmIssueTrait for ClusterAgentVmProtected
impl ClusterAgentVmIssueTrait for ClusterAgentVmProtected
Sourcefn get_cluster_agent_vm_issue(&self) -> &ClusterAgentVmIssue
fn get_cluster_agent_vm_issue(&self) -> &ClusterAgentVmIssue
Get a reference to the ClusterAgentVmIssue parent struct
Sourcefn get_cluster_agent_vm_issue_mut(&mut self) -> &mut ClusterAgentVmIssue
fn get_cluster_agent_vm_issue_mut(&mut self) -> &mut ClusterAgentVmIssue
Get a mutable reference to the ClusterAgentVmIssue parent struct
Sourceimpl Debug for ClusterAgentVmProtected
impl Debug for ClusterAgentVmProtected
Sourceimpl Deref for ClusterAgentVmProtected
impl Deref for ClusterAgentVmProtected
Sourceimpl DerefMut for ClusterAgentVmProtected
impl DerefMut for ClusterAgentVmProtected
Sourceimpl IssueTrait for ClusterAgentVmProtected
impl IssueTrait for ClusterAgentVmProtected
Sourceimpl VimObjectTrait for ClusterAgentVmProtected
impl VimObjectTrait for ClusterAgentVmProtected
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
impl DataObjectTrait for ClusterAgentVmProtected