ClusterComputeResourceHostEvacuationInfo

Struct ClusterComputeResourceHostEvacuationInfo 

pub struct ClusterComputeResourceHostEvacuationInfo {
    pub host: ManagedObjectReference,
    pub action: Option<Vec<Box<dyn OptionValueTrait>>>,
}
This data object describes what evacuation actions should be made for a given host.

Since: vSphere API Release 8.0.3.0

How to access

  • ClusterComputeResource::cluster_enter_maintenance_mode(info).host_evac_info?[*]

Fields

host: ManagedObjectReference

Candidate host to be put into maintenance mode.

Refers instance of HostSystem.

action: Option<Vec<Box<dyn OptionValueTrait>>>

Specifies the list of required actions.

Depending on the specified option values passed, additional actions such as ones related to evacuation of specific objects, additional memory reservation or allowing/disallowing certain groups of operations may be taken when entering the desired flavor of maintenance mode. The list of supported options and values may vary based on the version of the ESXi host and Virtual Center.

If unset, a default list of actions will be assumed based on the selected flavor of maintenance mode as specified by the ClusterComputeResourceMaintenanceInfo.partialMMId field. See HostPartialMaintenanceModeId_enum for further information about individual flavors.