ClusterConfigInfoEx

Struct ClusterConfigInfoEx 

pub struct ClusterConfigInfoEx {
Show 18 fields pub compute_resource_config_info_: ComputeResourceConfigInfo, pub system_v_ms_config: Option<ClusterSystemVMsConfigInfo>, pub das_config: ClusterDasConfigInfo, pub das_vm_config: Option<Vec<ClusterDasVmConfigInfo>>, pub drs_config: ClusterDrsConfigInfo, pub drs_vm_config: Option<Vec<ClusterDrsVmConfigInfo>>, pub rule: Option<Vec<Box<dyn ClusterRuleInfoTrait>>>, pub orchestration: Option<ClusterOrchestrationInfo>, pub vm_orchestration: Option<Vec<ClusterVmOrchestrationInfo>>, pub dpm_config_info: Option<ClusterDpmConfigInfo>, pub dpm_host_config: Option<Vec<ClusterDpmHostConfigInfo>>, pub vsan_config_info: Option<Box<dyn VsanClusterConfigInfoTrait>>, pub vsan_host_config: Option<Vec<Box<dyn VsanHostConfigInfoTrait>>>, pub group: Option<Vec<Box<dyn ClusterGroupInfoTrait>>>, pub infra_update_ha_config: Option<ClusterInfraUpdateHaConfigInfo>, pub proactive_drs_config: Option<ClusterProactiveDrsConfigInfo>, pub crypto_config: Option<ClusterCryptoConfigInfo>, pub vsan_core_config: Option<VsanClusterCoreConfig>,
}
The ClusterConfigInfoEx data object describes a complete cluster configuration.

For information about configuring a cluster, see ClusterConfigSpecEx.

How to access

  • ComputeResource::configuration_ex→ClusterConfigInfoEx
  • ClusterComputeResource::configuration_ex→ClusterConfigInfoEx

Fields

compute_resource_config_info_: ComputeResourceConfigInfosystem_v_ms_config: Option<ClusterSystemVMsConfigInfo>

Deprecated as of vSphere 9.0 with no replacement. In a future release of vSphere, the vCLS functionality will be disabled, vCLS system VMs will be deleted, and vCLS APIs will be removed.

Configuration for vCLS system VMs deployment.

Since: vSphere API Release 7.0.3.0

das_config: ClusterDasConfigInfo

Cluster-wide configuration of the vSphere HA service.

das_vm_config: Option<Vec<ClusterDasVmConfigInfo>>

List of virtual machine configurations for the vSphere HA service.

Each entry applies to one virtual machine.

If a virtual machine is not specified in this array, the service uses the default settings for that virtual machine.

drs_config: ClusterDrsConfigInfo

Cluster-wide configuration of the VMware DRS service.

drs_vm_config: Option<Vec<ClusterDrsVmConfigInfo>>

List of virtual machine configurations for the VMware DRS service.

Each entry applies to one virtual machine.

If a virtual machine is not specified in this array, the service uses the default settings for that virtual machine.

rule: Option<Vec<Box<dyn ClusterRuleInfoTrait>>>

Cluster-wide rules.

orchestration: Option<ClusterOrchestrationInfo>

Cluster-wide configuration of VM orchestration.

vm_orchestration: Option<Vec<ClusterVmOrchestrationInfo>>

List of virtual machine configurations that apply during cluster wide VM orchestration.

Each entry applies to one virtual machine.

If a virtual machine is not specified in this array, the service uses the default settings for that virtual machine.

dpm_config_info: Option<ClusterDpmConfigInfo>

Cluster-wide configuration of the VMware DPM service.

dpm_host_config: Option<Vec<ClusterDpmHostConfigInfo>>

List of host configurations for the VMware DPM service.

Each entry applies to one host.

If a host is not specified in this array, the service uses the cluster default settings for that host.

vsan_config_info: Option<Box<dyn VsanClusterConfigInfoTrait>>

Cluster-wide configuration of the VMware VSAN service.

vsan_host_config: Option<Vec<Box<dyn VsanHostConfigInfoTrait>>>

List of host configurations for the VMware VSAN service.

Each entry applies to one host.

If a host is not specified in this array, the service uses the cluster default settings for that host.

group: Option<Vec<Box<dyn ClusterGroupInfoTrait>>>

Cluster-wide groups.

infra_update_ha_config: Option<ClusterInfraUpdateHaConfigInfo>

Cluster-wide configuration of the VMware InfraUpdateHA service.

proactive_drs_config: Option<ClusterProactiveDrsConfigInfo>

Cluster-wide configuration of the ProactiveDRS service.

crypto_config: Option<ClusterCryptoConfigInfo>

Cluster-wide configuration of the encryption mode.

vsan_core_config: Option<VsanClusterCoreConfig>

vSAN first-class settings that will be configured together with vSAN enablement.

Since: vSphere API Release 9.0.0.0