ClusterFtVmHostRuleInfo

Struct ClusterFtVmHostRuleInfo 

pub struct ClusterFtVmHostRuleInfo {
    pub cluster_rule_info_: ClusterRuleInfo,
    pub vm_group_name: String,
    pub host_group_name: Option<Vec<String>>,
}
An ClusterFtVmHostRuleInfo object provides control of the placement of virtual machines across two host groups.

The virtual machines and hosts referenced by an FT VM-Host rule must be in the same cluster.

An FT VM-Host rule identifies the following groups.

  • A virtual machine group name (ClusterVmGroup).
  • An array of two host groups (ClusterHostGroup).

ClusterFtVmHostRuleInfo stores only the names of the relevant virtual machine and host groups. The group contents are stored in the virtual machine and host group objects.

When employing this rule, take care to ensure that the specified host groups have sufficient resources to support the requirements of all VMs specified.

Since: vSphere API Release 8.0.3.0

How to access

  • StoragePod::pod_storage_drs_entry.storage_drs_config.pod_config.rule?[*]→ClusterFtVmHostRuleInfo
  • ComputeResource::configuration_ex→ClusterConfigInfoEx.rule?[*]→ClusterFtVmHostRuleInfo
  • ClusterComputeResource::configuration.rule?[*]→ClusterFtVmHostRuleInfo
  • ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.rule?[*]→ClusterFtVmHostRuleInfo
  • Folder::create_cluster(spec).rules_spec?[*].info?→ClusterFtVmHostRuleInfo
  • Folder::create_cluster_ex(spec).rules_spec?[*].info?→ClusterFtVmHostRuleInfo
  • Folder::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.rules_spec?[*].info?→ClusterFtVmHostRuleInfo
  • Folder::batch_add_hosts_to_cluster_task(comp_res_spec)→ClusterConfigSpecEx.rules_spec?[*].info?→ClusterFtVmHostRuleInfo
  • Folder::batch_add_standalone_hosts_task(comp_res_spec)→ClusterConfigSpecEx.rules_spec?[*].info?→ClusterFtVmHostRuleInfo
  • StoragePod::create_cluster(spec).rules_spec?[*].info?→ClusterFtVmHostRuleInfo

(10 of 24 paths)

Fields

cluster_rule_info_: ClusterRuleInfovm_group_name: String

Virtual machine group name (ClusterVmGroup.ClusterGroupInfo.name).

The named virtual machine group may have zero or more VMs. A virtual machine in this group may be a normal virtual machine or a fault tolerant primary virtual machine; it cannot be a fault tolerant secondary virtual machine.

Control of FT secondary virtual machines is implied by the presence of the primary FT virtual machine.

A virtual machine in this group should not be referenced in any other FT VM-Host rule or VM-Host rule ClusterVmHostRuleInfo.

host_group_name: Option<Vec<String>>

Array of two Host Groups (ClusterHostGroup).

The hostGroup array must have two host groups. Each host group in the hostGroup array will have a set of hosts. For each Fault Tolerance primary VM that is part of VmGroup, the primary and secondary VMs would be placed on hosts that are not part of the same host group.

The members of each host group should be disjoint from the members of all other host group specified.