ClusterHostPowerAction

Struct ClusterHostPowerAction 

pub struct ClusterHostPowerAction {
    pub cluster_action_: ClusterAction,
    pub operation_type: HostPowerOperationTypeEnum,
    pub power_consumption_watt: Option<i32>,
    pub cpu_capacity_m_hz: Option<i32>,
    pub mem_capacity_mb: Option<i32>,
}
Describes a single host power action.

How to access

  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→ClusterHostPowerAction
  • StoragePod::pod_storage_drs_entry.action_history?[*].action→ClusterHostPowerAction
  • ClusterComputeResource::action_history.action→ClusterHostPowerAction
  • ClusterComputeResource::recommendation.action?[*]→ClusterHostPowerAction
  • Datastore::datastore_enter_maintenance_mode().recommendations?[*].action?[*]→ClusterHostPowerAction
  • ClusterComputeResource::cluster_enter_maintenance_mode().recommendations?[*].action?[*]→ClusterHostPowerAction
  • ClusterComputeResource::place_vm().recommendations?[*].action?[*]→ClusterHostPowerAction
  • StorageResourceManager::recommend_datastores().recommendations?[*].action?[*]→ClusterHostPowerAction

Fields

cluster_action_: ClusterActionoperation_type: HostPowerOperationTypeEnum

Specify whether the action is power on or power off

power_consumption_watt: Option<i32>

Estimated power consumption of the host.

In case of power-on, this is the projected increase in the cluster’s power consumption. In case of power off, this is the projected decrease in the cluster’s power consumption

cpu_capacity_m_hz: Option<i32>

CPU capacity of the host in units of MHz.

In case of power-on action, this is the projected increase in the cluster’s CPU capacity. In case of power off, this is the projected decrease in the cluster’s CPU capacity.

mem_capacity_mb: Option<i32>

Memory capacity of the host in units of MM.

In case of power-on action, this is the projected increase in the cluster’s memory capacity. In case of power off, this is the projected decrease in the cluster’s memory capacity.