ClusterProfileConfigServiceCreateSpec

Struct ClusterProfileConfigServiceCreateSpec 

pub struct ClusterProfileConfigServiceCreateSpec {
    pub cluster_profile_config_spec_: ClusterProfileConfigSpec,
    pub service_type: Option<Vec<String>>,
}
DataObject which allows reconfiguration of a profile based on services that will be available on the cluster.

How to access

  • HostProfileManager::create_profile(create_spec)→ClusterProfileConfigServiceCreateSpec
  • ProfileManager::create_profile(create_spec)→ClusterProfileConfigServiceCreateSpec
  • ClusterProfile::update_cluster_profile(config)→ClusterProfileConfigServiceCreateSpec
  • ClusterProfileManager::create_profile(create_spec)→ClusterProfileConfigServiceCreateSpec

Fields

cluster_profile_config_spec_: ClusterProfileConfigSpecservice_type: Option<Vec<String>>

Type of the service for which the ClusterProfile is being requested.

If more than one service is specified, the created ClusterProfile will cater for all the services. Possible values are specified by ClusterProfileServiceType_enum. If unset, clear the compliance expressions on the profile.