CnsBlockBackingDetails

Struct CnsBlockBackingDetails 

pub struct CnsBlockBackingDetails {
    pub cns_backing_object_details_: CnsBackingObjectDetails,
    pub backing_disk_id: Option<String>,
    pub backing_disk_url_path: Option<String>,
    pub backing_disk_path: Option<String>,
    pub backing_disk_object_id: Option<String>,
    pub used_capacity_in_mb: Option<i64>,
    pub aggregated_snapshot_capacity_in_mb: Option<i64>,
}
Details for a block type backing for container volume.

This class will be used as input at the time of volume creation and will also be returned as part of query result to give more information about a container volume.

Note: In future, for block volumes the disk format, like thin, lazy-zeroed- thick, eager-zeroed-thick, will be made a part of storage policy. Until then, for block volumes, only the thin type of provisioning will be supported.

This structure may be used only with operations rendered under /vsan.

How to access

  • CnsVolumeManager::cns_create_volume(create_specs).backing_object_details→CnsBlockBackingDetails
  • CnsVolumeManager::cns_query_volume().volumes?[*].backing_object_details?→CnsBlockBackingDetails

Fields

cns_backing_object_details_: CnsBackingObjectDetailsbacking_disk_id: Option<String>

At the time of creation this field would identify the existing disk that should be used to back the container volume.

This field is optional and when this and backingDiskPath are not specified, a new disk will be created to back the volume.

When this filed is present, capacityInMb and storage policy fields will be ignored.

backing_disk_url_path: Option<String>

At the time of creation this field would identify the URL path to an existing disk that should be used to back the container volume.

This field should be set in create request when the client wants to register an existing disk as a CNS block volume. If this disk is already registered as CNS block volume, then the server will throw CnsAlreadyRegisteredFault CNS fault with the CNS volume ID set.

This field is optional and when this and backingDiskId are not specified, a new disk will be created to back the volume.

When this field is present, capacityInMb and storage policy fields will be ignored.

Note that this field will not be set in the query API result. But in future release of CNS, it may be set.

This field must be in the following format: Format: https://<vc_ip>/folder/<vm_vmdk_path>?dcPath=<datacenterPath>& dsName=<datastoreName>

Ex: https://10.192.255.221/folder/34a9c05d-5f03-e254-e692-02004479cb91/ vm2_1.vmdk?dcPath=/Folder-1/Datacenter-1&dsName=vsanDatastore

This is for a 34a9c05d-5f03-e254-e692-02004479cb91/vm2_1.vmdk file under datacenter “Datacenter-1” with path “/Folder-1/Datacenter-1” and datastore “vsanDatastore”.

backing_disk_path: Option<String>

This is file path of the volume.

It’s different from backingDiskUrlPath. backingDiskUrlPath is accessible from a web browser, while backingDiskPath is accessible by the file system.

This field is set only in result of query.

backing_disk_object_id: Option<String>

This is the id generated by underlying object storage, such as vsan/vvol.

This field is set only in result of query.

used_capacity_in_mb: Option<i64>

This is the rolled up used capacity of the FCD and its snapshots.

Set to -1 if unknown.

aggregated_snapshot_capacity_in_mb: Option<i64>

This is the rolled up allocated space of the volume’s snapshots.

Set to -1 if unknown.