CnsKubernetesEntityReference

Struct CnsKubernetesEntityReference 

pub struct CnsKubernetesEntityReference {
    pub entity_type: String,
    pub entity_name: String,
    pub namespace: Option<String>,
    pub cluster_id: Option<String>,
}
Data object that represents a Kubernetes entity reference both within the Kubernetes cluster and across nested clusters.

Example for within Kubernetes cluster - A PVC referring a PV within the same kubernetes cluster. Example for across nested cluster - A PVC in supervisor cluster used by a PV in guest cluster.

This structure may be used only with operations rendered under /vsan.

How to access

  • CnsVolumeManager::cns_create_volume(create_specs).metadata?.entity_metadata?[*]→CnsKubernetesEntityMetadata.referred_entity?[*]
  • CnsVolumeManager::cns_update_volume_metadata(update_specs).metadata.entity_metadata?[*]→CnsKubernetesEntityMetadata.referred_entity?[*]
  • CnsVolumeManager::cns_query_volume().volumes?[*].metadata?.entity_metadata?[*]→CnsKubernetesEntityMetadata.referred_entity?[*]

Fields

entity_type: String

Represents the type of entity in Kubernetes.

See CnsKubernetesEntityType_enum for supported types.

entity_name: String

Represents the name of entity.

namespace: Option<String>

Namespace in Kubernetes the entity belongs to, if applicable.

Namespace must not be set for entity of type persistent volume and must be set for entities of type persistent volume claim and pod.

cluster_id: Option<String>

Represents the Kubernetes cluster the entity belongs to.

If unset, the server will interpret that this referred entity is in the same Kubernetes cluster as the CnsKubernetesEntityMetadata.entityType.

The clusterId should be one of the cluster in CnsVolumeMetadata.containerClusterArray