pub struct CnsSnapshotCreateSpec {
pub volume_id: CnsVolumeId,
pub description: String,
}Expand description
Specifications for snapshot creation operation.
Create snapshot with given description.
This structure may be used only with operations rendered under /vsan.
How to access
CnsVolumeManager::cns_create_snapshots(snapshot_specs)
Fields
volume_id: CnsVolumeIdUnique identifier for the volume.
description: StringUser description of this snapshot.
CNS server does not enforce uniqueness of snapshot description