pub struct CnsVolumeAttachDetachSpec {
pub volume_id: CnsVolumeId,
pub vm: ManagedObjectReference,
}Expand description
Data object for specifications for volume attach/detach operations.
This structure may be used only with operations rendered under /vsan.
How to access
CnsVolumeManager::cns_attach_volume(attach_specs)CnsVolumeManager::cns_detach_volume(detach_specs)
Fields
volume_id: CnsVolumeIdUnique identifier and datastore information for the volume.
vm: ManagedObjectReferenceVirtualMachine to which this volume needs to be attached to.
Refers instance of VirtualMachine.