CnsVolumeExtendSpec

Struct CnsVolumeExtendSpec 

pub struct CnsVolumeExtendSpec {
    pub volume_id: CnsVolumeId,
    pub capacity_in_mb: i64,
}
Specifications for volume extend operation.

Extend operation is called to extend volume’s capacity. The new non-negative capacity should be specified in MB.

Extend operation should be called by providing at least one ExtendSpec. If an array of empty spec is passed, the operation will fail.

This structure may be used only with operations rendered under /vsan.

How to access

  • CnsVolumeManager::cns_extend_volume(extend_specs)

Fields

volume_id: CnsVolumeId

Unique identifier for the volume.

capacity_in_mb: i64

New capacityInMb for the volume.