pub struct CreateTaskAction {
pub task_type_id: String,
pub cancelable: bool,
}Expand description
This data object type specifies the type of task to be created when this action is triggered.
How to access
ScheduledTask::reconfigure_scheduled_task(spec).action→CreateTaskActionScheduledTaskManager::create_scheduled_task(spec).action→CreateTaskActionScheduledTaskManager::create_object_scheduled_task(spec).action→CreateTaskActionAlarm::reconfigure_alarm(spec).action?→AlarmTriggeringAction.action→CreateTaskActionAlarmManager::create_alarm(spec).action?→AlarmTriggeringAction.action→CreateTaskAction
Fields
task_type_id: StringExtension registered task type identifier for type of task being created.
cancelable: boolWhether the task should be cancelable.