pub struct CryptoManagerKmipCryptoKeyStatus {
pub key_id: CryptoKeyId,
pub key_available: Option<bool>,
pub reason: Option<String>,
pub key_info: Option<Box<dyn CryptoManagerKmipCryptoKeyStatusKeyInfoTrait>>,
pub encrypted_v_ms: Option<Vec<ManagedObjectReference>>,
pub affected_hosts: Option<Vec<ManagedObjectReference>>,
pub referenced_by_tags: Option<Vec<String>>,
}Expand description
Fields
key_id: CryptoKeyIdCrypto key Id
key_available: Option<bool>If the key is available for crypto operation
reason: Option<String>The reason for key not available, valid when keyAvailable is false.
CryptoManagerKmipCryptoKeyStatusKeyUnavailableReason_enum lists the set of supported values.
key_info: Option<Box<dyn CryptoManagerKmipCryptoKeyStatusKeyInfoTrait>>The key info of the wrapped key.
If key is not a wrapped, then it will unset.
Since: vSphere API Release 9.0.0.0
encrypted_v_ms: Option<Vec<ManagedObjectReference>>The list of VMs which use that key
Refers instances of VirtualMachine.
affected_hosts: Option<Vec<ManagedObjectReference>>The lists of hosts which use that key as host key
Refers instances of HostSystem.
The identifier list for the 3rd party who are using the key