CustomizationAdapterMapping

Struct CustomizationAdapterMapping 

pub struct CustomizationAdapterMapping {
    pub mac_address: Option<String>,
    pub adapter: CustomizationIpSettings,
}
Data object type to associate a virtual network adapter with its IP settings.

How to access

  • VirtualMachine::check_customization_spec(spec).nic_setting_map?[*]
  • VirtualMachine::customize_vm_task(spec).nic_setting_map?[*]
  • VirtualMachine::clone_vm_task(spec).customization?.nic_setting_map?[*]
  • ClusterComputeResource::place_vm(placement_spec).clone_spec?.customization?.nic_setting_map?[*]
  • VirtualMachineGuestCustomizationManager::customize_guest_task(spec).nic_setting_map?[*]
  • CustomizationSpecManager::create_customization_spec(item).spec.nic_setting_map?[*]
  • CustomizationSpecManager::get_customization_spec().spec.nic_setting_map?[*]
  • CustomizationSpecManager::overwrite_customization_spec(item).spec.nic_setting_map?[*]
  • CustomizationSpecManager::customization_spec_item_to_xml(item).spec.nic_setting_map?[*]
  • CustomizationSpecManager::xml_to_customization_spec_item().spec.nic_setting_map?[*]

(10 of 12 paths)

Fields

mac_address: Option<String>

The MAC address of a network adapter being customized.

The client cannot change this value because the guest operating system has no control over the MAC address of a virtual network adapter.

This property is optional. If it is not included, the customization process maps the settings from the list of AdapterMappings.IPSettings in the Specification.nicSettingMap to the virtual machine’s network adapters, in PCI slot order. The first virtual network adapter on the PCI bus is assigned nicSettingMap[0].IPSettings, the second adapter is assigned nicSettingMap[1].IPSettings, and so on.

In vSphere 7.0 series, the MAC addresses must be specified in the ascending order of pciSlotNumber, otherwise a MAC address mismatch error will be reported. For further details, see the https://kb.vmware.com/s/article/87648

adapter: CustomizationIpSettings

The IP settings for the associated virtual network adapter.