CustomizationGlobalIpSettings

Struct CustomizationGlobalIpSettings 

pub struct CustomizationGlobalIpSettings {
    pub dns_suffix_list: Option<Vec<String>>,
    pub dns_server_list: Option<Vec<String>>,
}
A collection of global IP settings for a virtual network adapter.

In Linux, DNS server settings are global. The settings can either be statically set or supplied by a DHCP server.

How to access

  • VirtualMachine::check_customization_spec(spec).global_ip_settings
  • VirtualMachine::customize_vm_task(spec).global_ip_settings
  • VirtualMachine::clone_vm_task(spec).customization?.global_ip_settings
  • ClusterComputeResource::place_vm(placement_spec).clone_spec?.customization?.global_ip_settings
  • VirtualMachineGuestCustomizationManager::customize_guest_task(spec).global_ip_settings
  • CustomizationSpecManager::create_customization_spec(item).spec.global_ip_settings
  • CustomizationSpecManager::get_customization_spec().spec.global_ip_settings
  • CustomizationSpecManager::overwrite_customization_spec(item).spec.global_ip_settings
  • CustomizationSpecManager::customization_spec_item_to_xml(item).spec.global_ip_settings
  • CustomizationSpecManager::xml_to_customization_spec_item().spec.global_ip_settings

(10 of 12 paths)

Fields

dns_suffix_list: Option<Vec<String>>

List of name resolution suffixes for the virtual network adapter.

This list applies to both Windows and Linux guest customization. For Linux, this setting is global, whereas in Windows, this setting is listed on a per-adapter basis, even though the setting is global in Windows.

dns_server_list: Option<Vec<String>>

List of DNS servers, for a virtual network adapter with a static IP address.

If this list is empty, then the guest operating system is expected to use a DHCP server to get its DNS server settings. These settings configure the virtual machine to use the specified DNS servers. These DNS server settings are listed in order of preference.