CustomizationGuiUnattended

Struct CustomizationGuiUnattended 

pub struct CustomizationGuiUnattended {
    pub password: Option<CustomizationPassword>,
    pub time_zone: i32,
    pub auto_logon: bool,
    pub auto_logon_count: i32,
}
The GuiUnattended type maps to the GuiUnattended key in the sysprep.xml answer file.

These values are plugged directly into the sysprep.xml file that VirtualCenter stores on the target virtual disk. For more detailed information, see <a href=“https://technet.microsoft.com/en-us/library/cc771830(v=ws.10).aspx“target=”_blank“>Performing Unattended Installations.

How to access

  • VirtualMachine::check_customization_spec(spec).identity→CustomizationSysprep.gui_unattended
  • VirtualMachine::customize_vm_task(spec).identity→CustomizationSysprep.gui_unattended
  • VirtualMachine::clone_vm_task(spec).customization?.identity→CustomizationSysprep.gui_unattended
  • ClusterComputeResource::place_vm(placement_spec).clone_spec?.customization?.identity→CustomizationSysprep.gui_unattended
  • VirtualMachineGuestCustomizationManager::customize_guest_task(spec).identity→CustomizationSysprep.gui_unattended
  • CustomizationSpecManager::create_customization_spec(item).spec.identity→CustomizationSysprep.gui_unattended
  • CustomizationSpecManager::get_customization_spec().spec.identity→CustomizationSysprep.gui_unattended
  • CustomizationSpecManager::overwrite_customization_spec(item).spec.identity→CustomizationSysprep.gui_unattended
  • CustomizationSpecManager::customization_spec_item_to_xml(item).spec.identity→CustomizationSysprep.gui_unattended
  • CustomizationSpecManager::xml_to_customization_spec_item().spec.identity→CustomizationSysprep.gui_unattended

(10 of 12 paths)

Fields

password: Option<CustomizationPassword>

The new administrator password for the machine.

To specify that the password should be set to blank (that is, no password), set the password value to NULL. Because of encryption, “” is NOT a valid value.

If password is set to blank and CustomizationGuiUnattended.autoLogon is set, the guest customization will fail.

If the XML file is generated by the VirtualCenter Customization Wizard, then the password is encrypted. Otherwise, the client should set the plainText attribute to true, so that the customization process does not attempt to decrypt the string.

time_zone: i32

The time zone index for the virtual machine.

Numbers correspond to time zones listed at <a href=“https://support.microsoft.com/en-us/help/973627/microsoft-time-zone-index-values“target=”_blank“>Microsoft Time Zone Index Values.

auto_logon: bool

Flag to determine whether or not the machine automatically logs on as Administrator.

See also the password property.

If the AutoLogon flag is set, CustomizationGuiUnattended.password must not be blank or the guest customization will fail.

auto_logon_count: i32

If the AutoLogon flag is set, then the AutoLogonCount property specifies the number of times the machine should automatically log on as Administrator.

Generally it should be 1, but if your setup requires a number of reboots, you may want to increase it. This number may be determined by the list of commands executed by the GuiRunOnce command.