pub struct DatacenterBasicConnectInfo {
pub hostname: Option<String>,
pub error: Option<MethodFault>,
pub server_ip: Option<String>,
pub num_vm: Option<i32>,
pub num_powered_on_vm: Option<i32>,
pub host_product_info: Option<AboutInfo>,
pub hardware_vendor: Option<String>,
pub hardware_model: Option<String>,
}Expand description
BasicConnectInfo consists of essential information about the host.
This is a subset of HostConnectInfo and contains the information which is relevant when it comes to dealing with a set of hosts.
How to access
Datacenter::batch_query_connect_info()
Fields
hostname: Option<String>Target host.
error: Option<MethodFault>Error encountered while querying the host.
See Datacenter.QueryConnectionInfo for the list of exceptions which can be represented here.
server_ip: Option<String>IP address of the VirtualCenter already managing this host, if any.
num_vm: Option<i32>Specifies the number of VMs on the host.
num_powered_on_vm: Option<i32>Specifies the number of powered-on VMs on the host.
host_product_info: Option<AboutInfo>Information about the software running on the host.
hardware_vendor: Option<String>Hardware vendor identification.
hardware_model: Option<String>System model identification.