DpuStatusInfo

Struct DpuStatusInfo 

pub struct DpuStatusInfo {
    pub host_hardware_element_info_: HostHardwareElementInfo,
    pub dpu_id: String,
    pub fru: Option<HostFru>,
    pub sensors: Option<Vec<DpuStatusInfoOperationalInfo>>,
}
Data object describing the operational status of various DPU elements.

Since: vSphere API Release 8.0.0.1

How to access

  • HostSystem::runtime.health_system_runtime?.hardware_status_info?.dpu_status_info?[*]
  • HostSystem::runtime.health_system_runtime?.hardware_status_info?.memory_status_info?[*]→DpuStatusInfo
  • HostSystem::runtime.health_system_runtime?.hardware_status_info?.cpu_status_info?[*]→DpuStatusInfo
  • HostSystem::summary.runtime?.health_system_runtime?.hardware_status_info?.dpu_status_info?[*]
  • HostSystem::summary.runtime?.health_system_runtime?.hardware_status_info?.memory_status_info?[*]→DpuStatusInfo
  • HostHealthStatusSystem::runtime.hardware_status_info?.dpu_status_info?[*]
  • HostHealthStatusSystem::runtime.hardware_status_info?.memory_status_info?[*]→DpuStatusInfo
  • HostHealthStatusSystem::runtime.hardware_status_info?.cpu_status_info?[*]→DpuStatusInfo
  • Datacenter::query_connection_info().host.runtime?.health_system_runtime?.hardware_status_info?.dpu_status_info?[*]
  • Datacenter::query_connection_info_via_spec().host.runtime?.health_system_runtime?.hardware_status_info?.dpu_status_info?[*]

(10 of 18 paths)

Fields

host_hardware_element_info_: HostHardwareElementInfodpu_id: String

Uniquely identify this DPU.

Should be the VMware identifier which can be composed from pci and other identifying elements.

fru: Option<HostFru>

The FRU this sensor monitors, if any.

sensors: Option<Vec<DpuStatusInfoOperationalInfo>>