DvsSecurityPolicy

Struct DvsSecurityPolicy 

pub struct DvsSecurityPolicy {
    pub inheritable_policy_: InheritablePolicy,
    pub allow_promiscuous: Option<BoolPolicy>,
    pub mac_changes: Option<BoolPolicy>,
    pub forged_transmits: Option<BoolPolicy>,
}
This data object type describes security policy governing ports.

How to access

  • DistributedVirtualPortgroup::config.default_port_config?→VMwareDvsPortSetting.security_policy?
  • VmwareDistributedVirtualSwitch::config.default_port_config→VMwareDvsPortSetting.security_policy?
  • DistributedVirtualSwitch::config.default_port_config→VMwareDvsPortSetting.security_policy?
  • DistributedVirtualPortgroup::reconfigure_dv_portgroup_task(spec).default_port_config?→VMwareDvsPortSetting.security_policy?
  • VmwareDistributedVirtualSwitch::create_dv_portgroup_task(spec).default_port_config?→VMwareDvsPortSetting.security_policy?
  • VmwareDistributedVirtualSwitch::add_dv_portgroup_task(spec).default_port_config?→VMwareDvsPortSetting.security_policy?
  • VmwareDistributedVirtualSwitch::reconfigure_dvs_task(spec).default_port_config?→VMwareDvsPortSetting.security_policy?
  • VmwareDistributedVirtualSwitch::reconfigure_dv_port_task(port).setting?→VMwareDvsPortSetting.security_policy?
  • Folder::create_dvs_task(spec).config_spec.default_port_config?→VMwareDvsPortSetting.security_policy?
  • StoragePod::create_dvs_task(spec).config_spec.default_port_config?→VMwareDvsPortSetting.security_policy?

(10 of 22 paths)

Fields

inheritable_policy_: InheritablePolicyallow_promiscuous: Option<BoolPolicy>

The flag to indicate whether or not all traffic is seen on the port.

mac_changes: Option<BoolPolicy>

The flag to indicate whether or not the Media Access Control (MAC) address can be changed.

forged_transmits: Option<BoolPolicy>

The flag to indicate whether or not the virtual network adapter should be allowed to send network traffic with a different MAC address than that of the virtual network adapter.