DvsSummary

Struct DvsSummary 

pub struct DvsSummary {
    pub name: String,
    pub uuid: String,
    pub num_ports: i32,
    pub product_info: Option<DistributedVirtualSwitchProductSpec>,
    pub host_member: Option<Vec<ManagedObjectReference>>,
    pub vm: Option<Vec<ManagedObjectReference>>,
    pub host: Option<Vec<ManagedObjectReference>>,
    pub portgroup_name: Option<Vec<String>>,
    pub description: Option<String>,
    pub contact: Option<DvsContactInfo>,
    pub num_hosts: Option<i32>,
}
Summary of the distributed switch configuration.

How to access

  • VmwareDistributedVirtualSwitch::summary
  • DistributedVirtualSwitch::summary

Fields

name: String

The name of the switch.

uuid: String

The generated UUID of the switch.

num_ports: i32

Current number of ports, not including conflict ports.

product_info: Option<DistributedVirtualSwitchProductSpec>

The product information for the implementation of the switch.

host_member: Option<Vec<ManagedObjectReference>>

The names of the hosts that join the switch.

Refers instances of HostSystem.

vm: Option<Vec<ManagedObjectReference>>

The Virtual Machines with Virtual NICs that connect to the switch.

In releases after vSphere API 5.0, vSphere Servers might not generate property collector update notifications for this property. To obtain the latest value of the property, you can use PropertyCollector methods RetrievePropertiesEx or WaitForUpdatesEx. If you use the PropertyCollector.WaitForUpdatesEx method, specify an empty string for the version parameter. Since this property is on a DataObject, an update returned by WaitForUpdatesEx may contain values for this property when some other property on the DataObject changes. If this update is a result of a call to WaitForUpdatesEx with a non-empty version parameter, the value for this property may not be current.

Refers instances of VirtualMachine.

host: Option<Vec<ManagedObjectReference>>

The hosts with Virtual NICs that connect to the switch.

Refers instances of HostSystem.

portgroup_name: Option<Vec<String>>

The names of the portgroups that are defined on the switch.

description: Option<String>

A description string of the switch.

contact: Option<DvsContactInfo>

The human operator contact information.

num_hosts: Option<i32>

The number of hosts in the switch.

The value of this property is not affected by the privileges granted to the current user.