DvsVmVnicResourcePoolConfigSpec

Struct DvsVmVnicResourcePoolConfigSpec 

pub struct DvsVmVnicResourcePoolConfigSpec {
    pub operation: String,
    pub key: Option<String>,
    pub config_version: Option<String>,
    pub allocation_info: Option<DvsVmVnicResourceAllocation>,
    pub name: Option<String>,
    pub description: Option<String>,
}
The configuration specification data object to update the resource configuration for a virtual NIC network resource pool.

How to access

  • VmwareDistributedVirtualSwitch::dvs_reconfigure_vm_vnic_network_resource_pool_task(config_spec)
  • DistributedVirtualSwitch::dvs_reconfigure_vm_vnic_network_resource_pool_task(config_spec)

Fields

operation: String

The type of operation on the virtual NIC network resource pool Possible value can be of ConfigSpecOperation_enum

key: Option<String>

The key of the network resource pool.

The property is ignored for add operations.

config_version: Option<String>

The configVersion is a unique identifier for a given version of the configuration.

Each change to the configuration will update this value. This is typically implemented as a non-decreasing count or a time-stamp. However, a client should always treat this as an opaque string.

If specified when updating the resource configuration, the changes will only be applied if the current configVersion matches the specified configVersion. This field can be used to guard against updates that that may have occurred between the time when configVersion was read and when it is applied.

allocation_info: Option<DvsVmVnicResourceAllocation>

The resource allocation for the virtual NIC network resource pool.

name: Option<String>

The name for the virtual NIC network resource pool.

The property is required for Add operations.

description: Option<String>

The description for the virtual NIC network resource pool.