pub struct EntityBackup {}Expand description
EntityBackup is an abstract data object that contains the related entity backup and restore elements for virtual distributed switches and virtual distributed portgroups.
See the following elements:
- EntityBackupConfig
- EntityImportType_enum
- EntityType_enum