ExtManagedEntityInfo

Struct ExtManagedEntityInfo 

pub struct ExtManagedEntityInfo {
    pub type: String,
    pub small_icon_url: Option<String>,
    pub icon_url: Option<String>,
    pub description: Option<String>,
}
This data object contains information about entities managed by this extension.

The data can be used by clients to show extra information about managed virtual machines or vApps, such as a custom icon and a description of the entity.

How to access

  • ExtensionManager::extension_list.managed_entity_info?[*]
  • ExtensionManager::find_extension().managed_entity_info?[*]
  • ExtensionManager::register_extension(extension).managed_entity_info?[*]
  • ExtensionManager::update_extension(extension).managed_entity_info?[*]

Fields

type: String

Managed entity type, as defined by the extension.

This matches the type field in the configuration about a virtual machine or vApp.

small_icon_url: Option<String>

The URL to a 16x16 pixel icon in PNG format for entities of this type managed by this extension.

The design of the icon should allow for the possibility of it being badged with the power state of the entity by the vSphere client. If you do not provide this icon, the icon at iconUrl, if found, is scaled down to 16x16 pixels.

icon_url: Option<String>

The URL to an icon in PNG format that is no larger than 256x256 pixels.

This icon will be scaled to 16x16, 32x32, 64x64, and 128x128 if needed. The icon is shown for all entities of this type managed by this extension.

description: Option<String>

Description of this managed entity type.

This is typically displayed by clients, and should provide users with information about the function of entities of this type.