ExtendedElementDescription

Struct ExtendedElementDescription 

pub struct ExtendedElementDescription {
    pub element_description_: ElementDescription,
    pub message_catalog_key_prefix: String,
    pub message_arg: Option<Vec<KeyAnyValue>>,
}
How to access

  • ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.device_change?[*].device.device_info?→ExtendedElementDescription
  • ClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.device_change?[*].device.device_info?→ExtendedElementDescription
  • ClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.device_change?[*].device.device_info?→ExtendedElementDescription
  • ClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device.device_info?→ExtendedElementDescription
  • ClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_groups?.device_group?[*].device_info?→ExtendedElementDescription
  • AlarmManager::description.state_operator[*]→ExtendedElementDescription
  • AlarmManager::description.metric_operator[*]→ExtendedElementDescription
  • AlarmManager::description.host_system_connection_state[*]→ExtendedElementDescription
  • AlarmManager::description.virtual_machine_power_state[*]→ExtendedElementDescription
  • AlarmManager::description.datastore_connection_state[*]→ExtendedElementDescription

(10 of 100 paths)

Fields

element_description_: ElementDescriptionmessage_catalog_key_prefix: String

Key to the localized message string in the catalog.

If the localized string contains parameters, values to the parameters will be provided in #messageArg. E.g: If the message in the catalog is “IP address is {address}”, value for “address” will be provided by #messageArg. Both summary and label in ElementDescription will have a corresponding entry in the message catalog with the keys <messageCatalogKeyPrefix>.summary and <messageCatalogKeyPrefix>.label respectively. ElementDescription.summary and ElementDescription.label will contain the strings in server locale.

message_arg: Option<Vec<KeyAnyValue>>

Provides named arguments that can be used to localize the message in the catalog.