FaultDomainInfo

Struct FaultDomainInfo 

pub struct FaultDomainInfo {
    pub fault_domain_id_: FaultDomainId,
    pub name: Option<String>,
    pub description: Option<String>,
    pub storage_array_id: Option<String>,
    pub children: Option<Vec<Box<dyn FaultDomainIdTrait>>>,
    pub provider: Option<ManagedObjectReference>,
}
Information about a Fault Domain.

This structure may be used only with operations rendered under /sms.

How to access

  • ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.perfsvc_config?.profile?→VirtualMachineDefinedProfileSpec.replication_spec?.replication_group_id.fault_domain_id→FaultDomainInfo
  • ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.iscsi_config?→VsanIscsiTargetServiceSpec.home_object_storage_policy?→VirtualMachineDefinedProfileSpec.replication_spec?.replication_group_id.fault_domain_id→FaultDomainInfo
  • ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.profile?[*]→VirtualMachineDefinedProfileSpec.replication_spec?.replication_group_id.fault_domain_id→FaultDomainInfo
  • ClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.profile?[*]→VirtualMachineDefinedProfileSpec.replication_spec?.replication_group_id.fault_domain_id→FaultDomainInfo
  • ClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.profile?[*]→VirtualMachineDefinedProfileSpec.replication_spec?.replication_group_id.fault_domain_id→FaultDomainInfo
  • ClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.vm_profile?[*]→VirtualMachineDefinedProfileSpec.replication_spec?.replication_group_id.fault_domain_id→FaultDomainInfo
  • ClusterComputeResource::recommendation.action?[*]→StoragePlacementAction.relocate_spec.profile?[*]→VirtualMachineDefinedProfileSpec.replication_spec?.replication_group_id.fault_domain_id→FaultDomainInfo
  • Folder::create_vm_task(config).vm_profile?[*]→VirtualMachineDefinedProfileSpec.replication_spec?.replication_group_id.fault_domain_id→FaultDomainInfo
  • Folder::create_vm_task(config).device_change?[*].profile?[*]→VirtualMachineDefinedProfileSpec.replication_spec?.replication_group_id.fault_domain_id→FaultDomainInfo
  • Folder::create_cluster_ex(spec).vsan_config?→VsanConfigInfoEx.perfsvc_config?.profile?→VirtualMachineDefinedProfileSpec.replication_spec?.replication_group_id.fault_domain_id→FaultDomainInfo

(10 of 100 paths)

Fields

fault_domain_id_: FaultDomainIdname: Option<String>

Name of the fault domain, if not specified, the id will be used in place of the name.

Name need not be unique.

description: Option<String>

Description - could be a localized string.

storage_array_id: Option<String>

Identifier of the Storage Array that this Fault Domain belongs to.

A Fault Domain and all its children should report same FaultDomainInfo.storageArrayId. It can be left unspecified. If not specified, vSphere will not support High Availability feature for this Fault Domain. When specified, vSphere will treat the the currently active VASA provider for StorageArray as the active VASA provider for this Fault Domain and its children. Changing High Availability support choice for a Fault Domain intermittently, by sometimes specifying the storageArrayId and sometimes not, will cause unexpected result and might cause VP to be in ‘syncError’ state in vSphere.

children: Option<Vec<Box<dyn FaultDomainIdTrait>>>

List of children, the entries in the array should always be FaultDomainId and not FaultDomainInfo.

The 2016 vSphere release will not support nested Fault Domains. The field FaultDomainInfo#children is ignored by vSphere 2016 release.

provider: Option<ManagedObjectReference>

VASA provider that is actively managing this fault domain

Refers instance of SmsProvider.