pub struct FileLockInfoResult {
pub lock_info: Option<Vec<FileLockInfo>>,
pub fault: Option<MethodFault>,
}Expand description
Fields
lock_info: Option<Vec<FileLockInfo>>FileLockInfo entries populated based on results fetched from host.
If a single path is provided result should contain a single entry. For a generic VM name potentially multiple entries could be fetched and populated. Refer to FileManager.QueryFileLockInfo for more details.
fault: Option<MethodFault>Trait Implementations
Sourceimpl Debug for FileLockInfoResult
impl Debug for FileLockInfoResult
Sourceimpl Deserialize for FileLockInfoResult
impl Deserialize for FileLockInfoResult
Sourceimpl VimObjectTrait for FileLockInfoResult
impl VimObjectTrait for FileLockInfoResult
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
impl DataObjectTrait for FileLockInfoResult