pub struct GuestPosixFileAttributes {
pub guest_file_attributes_: GuestFileAttributes,
pub owner_id: Option<i32>,
pub group_id: Option<i32>,
pub permissions: Option<i64>,
}Expand description
Different attributes for Posix guest file.
How to access
GuestFileManager::change_file_attributes_in_guest(file_attributes)→GuestPosixFileAttributesGuestFileManager::initiate_file_transfer_to_guest(file_attributes)→GuestPosixFileAttributesGuestFileManager::initiate_file_transfer_from_guest().attributes→GuestPosixFileAttributesGuestFileManager::list_files_in_guest().files?[*].attributes→GuestPosixFileAttributes
Fields
guest_file_attributes_: GuestFileAttributesowner_id: Option<i32>The owner ID.
If this property is not specified when passing a GuestPosixFileAttributes object to GuestFileManager.InitiateFileTransferToGuest, the default value will be the owner Id of the user who invoked the file transfer operation.
group_id: Option<i32>The group ID.
If this property is not specified when passing a GuestPosixFileAttributes object to GuestFileManager.InitiateFileTransferToGuest, the default value will be the group Id of the user who invoked the file transfer operation.
permissions: Option<i64>The file permissions.
When creating a file with GuestFileManager.InitiateFileTransferToGuest, these are in chmod(2) format. When reporting on existing files, these are in stat(2) format. If this property is not specified when passing a GuestPosixFileAttributes object to GuestFileManager.InitiateFileTransferToGuest, the file will be created with 0644 permissions.