HbrManagerReplicationVmInfo

Struct HbrManagerReplicationVmInfo 

pub struct HbrManagerReplicationVmInfo {
    pub state: String,
    pub progress_info: Option<ReplicationVmProgressInfo>,
    pub image_id: Option<String>,
    pub last_error: Option<MethodFault>,
}
This data object represents the essential information about the state of a given replicated VirtualMachine.

Fields

state: String

A string representing the current ReplicationVmState_enum of the virtual machine.

progress_info: Option<ReplicationVmProgressInfo>

Progress stats for the current operation.

Never present if the state is not “syncing” or “active”. If not present while in one of these states, the host is still gathering initial operation statistics (progress can be assumed to be 0).

image_id: Option<String>

An optional imageId that identifies the instance being created, this is the imagId string that is passed to HbrManager.HbrCreateInstance_Task or HbrManager.HbrStartOfflineInstance_Task

last_error: Option<MethodFault>

A MethodFault representing the last replication specific error that the VirtualMachine encountered during a create instance operation.

The successful creation of an instance will clear any error.