HostAuthenticationInfo

Struct HostAuthenticationInfo 

pub struct HostAuthenticationInfo {
    pub principal: String,
    pub owner_tag: String,
    pub ssl_certificates: Option<Vec<String>>,
}
Authentication information for a host managed by a vCenter Server or a vCenter extension to login into other hosts without username/password authentication.

Since: vSphere API Release 9.0.0.0

How to access

  • HostSystem::config.authentication_data?[*]

Fields

principal: String

The principal used for the login session

owner_tag: String

The tag associated with this registration.

Owner tags allow multiple entities to register the same certificate without interfering with each other on the life cycle of the certificate with their unique tags. Each solution must use a unique tag to identify itself.

ssl_certificates: Option<Vec<String>>

Specify the PEM-encoded SSL certificate to register on the host.