pub struct HostDhcpServiceSpec {
pub virtual_switch: String,
pub default_lease_duration: i32,
pub lease_begin_ip: String,
pub lease_end_ip: String,
pub max_lease_duration: i32,
pub unlimited_lease: bool,
pub ip_subnet_addr: String,
pub ip_subnet_mask: String,
}Expand description
How to access
HostSystem::config.network?.dhcp?[*].specHostNetworkSystem::network_config.dhcp?[*].specHostNetworkSystem::network_info.dhcp?[*].specHostNetworkSystem::update_network_config(config).dhcp?[*].specHostProfileManager::apply_host_config_task(config_spec).network?.dhcp?[*].specHostProfileManager::generate_config_task_list(config_spec).network?.dhcp?[*].specHostProfileManager::generate_host_profile_task_list_task(config_spec).network?.dhcp?[*].specHostProfile::execute_host_profile().config_spec?.network?.dhcp?[*].specHostProfileManager::generate_config_task_list().config_spec?.network?.dhcp?[*].spec
Fields
virtual_switch: StringThe name of the virtual switch to which DHCP service is connected.
default_lease_duration: i32The default DHCP lease duration (minutes).
lease_begin_ip: StringThe start of the IP address range served by the DHCP service.
lease_end_ip: StringThe end of the IP address range served by the DHCP service.
max_lease_duration: i32The maximum DHCP lease duration (minutes).
unlimited_lease: boolA flag to indicate whether or not unlimited DHCP lease durations are allowed.
ip_subnet_addr: StringSubnet served by DHCP service.
ip_subnet_mask: StringSubnet mask of network served by DHCP service.