pub struct HostDiskPartitionSpec {
pub partition_format: Option<String>,
pub chs: Option<HostDiskDimensionsChs>,
pub total_sectors: Option<i64>,
pub partition: Option<Vec<HostDiskPartitionAttributes>>,
pub sector_size: Option<i32>,
}Expand description
This data object type describes the disk partition table specification used to configure the partitions on a disk.
This data object represents the fundamental data needed to specify a partition table.
How to access
HostStorageSystem::extend_vffs(spec)HostStorageSystem::update_disk_partitions(spec)HostDatastoreSystem::create_vmfs_datastore(spec).partitionHostDatastoreSystem::expand_vmfs_datastore(spec).partitionHostDatastoreSystem::extend_vmfs_datastore(spec).partitionHostDiagnosticSystem::create_diagnostic_partition(spec).partitionHostStorageSystem::compute_disk_partition_info().specHostStorageSystem::compute_disk_partition_info_for_resize().specHostStorageSystem::format_vffs(create_spec).partition?HostDiagnosticSystem::query_partition_create_desc().spec.partition
(10 of 20 paths)
Fields
partition_format: Option<String>Partition format type on the disk.
chs: Option<HostDiskDimensionsChs>Disk dimensions expressed as cylinder, head, sector (CHS) coordinates.
total_sectors: Option<i64>Disk dimensions expressed as a total number of sectors.
For sector size, see the HostDiskPartitionSpec.sectorSize field.
partition: Option<Vec<HostDiskPartitionAttributes>>List of partitions on the disk.
sector_size: Option<i32>The sector size in bytes.
The typical values are 512 and 4096. If unset, the value should be considered 512.
Since: vSphere API Release 9.0.0.0