pub struct HostFirewallRule {
pub port: i32,
pub end_port: Option<i32>,
pub direction: HostFirewallRuleDirectionEnum,
pub port_type: Option<HostFirewallRulePortTypeEnum>,
pub protocol: String,
}Expand description
This data object type describes a port (or range of ports), identified by port number(s), direction and protocol.
It is used as a convenient way for users to express what ports they want to permit through the firewall.
How to access
HostSystem::config.firewall?.ruleset?[*].rule[*]HostFirewallSystem::firewall_info.ruleset?[*].rule[*]
Fields
port: i32The port number.
end_port: Option<i32>For a port range, the ending port number.
direction: HostFirewallRuleDirectionEnumThe port direction.
port_type: Option<HostFirewallRulePortTypeEnum>The port type.
protocol: StringThe port protocol.
Valid values are defined by the HostFirewallRuleProtocol_enum enumeration.