pub struct HostFirewallRuleset {
pub key: String,
pub label: String,
pub required: bool,
pub rule: Vec<HostFirewallRule>,
pub service: Option<String>,
pub enabled: bool,
pub allowed_hosts: Option<HostFirewallRulesetIpList>,
pub user_controllable: Option<bool>,
pub ip_list_user_configurable: Option<bool>,
}Expand description
Data object that describes a single network ruleset that can be allowed or blocked by the firewall using the HostFirewallSystem object.
How to access
HostSystem::config.firewall?.ruleset?[*]HostFirewallSystem::firewall_info.ruleset?[*]
Fields
key: StringBrief identifier for the ruleset.
label: StringDisplay label for the ruleset.
required: boolFlag indicating whether the ruleset is required and cannot be disabled.
rule: Vec<HostFirewallRule>List of rules within the ruleset.
service: Option<String>Managed service (if any) that uses this ruleset.
Must be one of the services listed in HostServiceInfo.service.
enabled: boolFlag indicating whether the ruleset is enabled.
If the ruleset is enabled, all ports specified in the ruleset are opened by the firewall.
allowed_hosts: Option<HostFirewallRulesetIpList>List of ipaddress to allow access to the service
user_controllable: Option<bool>Flag indicating whether user can enable/disable the firewall ruleset.
Since: vSphere API Release 8.0.2.0
ip_list_user_configurable: Option<bool>Flag indicating whether user can modify the allowed IP list of the firewall ruleset.
Since: vSphere API Release 8.0.2.0