HostInternetScsiHbaIpCapabilities

Struct HostInternetScsiHbaIpCapabilities 

pub struct HostInternetScsiHbaIpCapabilities {
Show 20 fields pub address_settable: bool, pub ip_configuration_method_settable: bool, pub subnet_mask_settable: bool, pub default_gateway_settable: bool, pub primary_dns_server_address_settable: bool, pub alternate_dns_server_address_settable: bool, pub ipv_6_supported: Option<bool>, pub arp_redirect_settable: Option<bool>, pub mtu_settable: Option<bool>, pub host_name_as_target_address: Option<bool>, pub name_alias_settable: Option<bool>, pub ipv_4_enable_settable: Option<bool>, pub ipv_6_enable_settable: Option<bool>, pub ipv_6_prefix_length_settable: Option<bool>, pub ipv_6_prefix_length: Option<i32>, pub ipv_6_dhcp_configuration_settable: Option<bool>, pub ipv_6_link_local_auto_configuration_settable: Option<bool>, pub ipv_6_router_advertisement_configuration_settable: Option<bool>, pub ipv_6_default_gateway_settable: Option<bool>, pub ipv_6_max_static_addresses_supported: Option<i32>,
}
The IP Capabilities for the host bus adapter

How to access

  • HostSystem::config.storage_device?.host_bus_adapter?[*]→HostInternetScsiHba.ip_capabilities
  • HostStorageSystem::storage_device_info.host_bus_adapter?[*]→HostInternetScsiHba.ip_capabilities
  • HostProfileManager::apply_host_config_task(config_spec).storage_device?.host_bus_adapter?[*]→HostInternetScsiHba.ip_capabilities
  • HostProfileManager::generate_config_task_list(config_spec).storage_device?.host_bus_adapter?[*]→HostInternetScsiHba.ip_capabilities
  • HostProfileManager::generate_host_profile_task_list_task(config_spec).storage_device?.host_bus_adapter?[*]→HostInternetScsiHba.ip_capabilities
  • HostProfile::execute_host_profile().config_spec?.storage_device?.host_bus_adapter?[*]→HostInternetScsiHba.ip_capabilities
  • HostProfileManager::generate_config_task_list().config_spec?.storage_device?.host_bus_adapter?[*]→HostInternetScsiHba.ip_capabilities

Fields

address_settable: bool

True if the host bus adapter supports setting its IPv4 address.

ip_configuration_method_settable: bool

True if the host bus adapter supports DHCPv4.

subnet_mask_settable: bool

True if the host bus adapter supports setting its IPv4 subnet mask.

default_gateway_settable: bool

True if the host bus adapter supports setting its IPv4 gateway.

primary_dns_server_address_settable: bool

True if the host bus adapter supports setting its primary DNS.

alternate_dns_server_address_settable: bool

True if the host bus adapter supports setting its secondary DNS.

ipv_6_supported: Option<bool>

True if the host bus adapter supports the use of IPv6 addresses

arp_redirect_settable: Option<bool>

True if the host bus adapter supports setting its ARP Redirect value

mtu_settable: Option<bool>

True if the host bus adapter supports setting its MTU, (for Jumbo Frames, etc)

host_name_as_target_address: Option<bool>

True if the discovery and static targets can be configured with a host name as opposed to an IP address.

name_alias_settable: Option<bool>

True if the host bus adapter supports setting its name and alias

ipv_4_enable_settable: Option<bool>

True if IPv4 addresssing can be enabled or disabled on the host bus adapter.

ipv_6_enable_settable: Option<bool>

True if IPv6 addresssing can be enabled or disabled on the host bus adapter.

ipv_6_prefix_length_settable: Option<bool>

True if the Host bus adapter supports setting IPv6 Prefix Length.

ipv_6_prefix_length: Option<i32>

Provides the value that user should be using if host bus adapter does not support changing of prefix length.

ipv_6_dhcp_configuration_settable: Option<bool>

True if the Host bus adapter supports DHCPv6 configuration.

ipv_6_link_local_auto_configuration_settable: Option<bool>

True if the Host bus adapter supports setting configuration of its IPv6 link local address User can specify link local static address if link local auto configuration is set to false.

link local address usually starts with fe80: and has prefix 64.

ipv_6_router_advertisement_configuration_settable: Option<bool>

True if the Host bus adapter supports router advertisement configuration method.

Note: Currently Qlogic adapter does not support plumbing of any user specified static address if router advertisement method is enabled.

ipv_6_default_gateway_settable: Option<bool>

True if the Host bus adapter supports setting its IPv6 default gateway.

ipv_6_max_static_addresses_supported: Option<i32>

The maximum number of supported IPv6 static addresses on the host bus adapter that user can set.