pub struct HostLowLevelProvisioningManagerSnapshotLayoutSpec {
pub id: i32,
pub src_filename: String,
pub dst_filename: String,
pub disk: Option<Vec<HostLowLevelProvisioningManagerDiskLayoutSpec>>,
}Expand description
File layout spec of a snapshot, including path to the vmsn file of the snapshot and the layout of virtual disks when the snapshot was taken.
Fields
id: i32The unique identifier of the snapshot
src_filename: StringName of the source snapshot file in datastore path.
dst_filename: StringName of the destination snapshot file in datastore path.
disk: Option<Vec<HostLowLevelProvisioningManagerDiskLayoutSpec>>Layout of each virtual disk of the virtual machine when the snapshot was taken.