HostLowLevelProvisioningManagerVmMigrationStatus

Struct HostLowLevelProvisioningManagerVmMigrationStatus 

pub struct HostLowLevelProvisioningManagerVmMigrationStatus {
    pub migration_id: i64,
    pub type: String,
    pub source: bool,
    pub considered_successful: bool,
}
The status of a virtual machine migration operation.

Fields

migration_id: i64

Unique identifier for this operation, currently it’s unique within one virtual center instance.

type: String

Manner in which the migration process is performed.

The set of possible values is described in HostVMotionManagerVMotionType_enum.

source: bool

Whether the virtual machine is the source of the migration.

For disk only migration, the value is always true.

considered_successful: bool

Whether the operation is considered successful.

A migration operation is considered successful if its switch over phase has completed successfully.

More specifically, for an in-progress migration, it is considered successful if it has had a sucessful switch over, otherwise it is considered unsuccessful. Likewise, the status of a completed migration operation is also based on the switch over completion status.

The difference between a completed vs. in-progress migration with the same consideredSuccessful property is that in the former case the server is able to complete the clean up process thus leaves nothing for the recovery process to clean up.