HostNvmeDiscoveryLogEntry

Struct HostNvmeDiscoveryLogEntry 

pub struct HostNvmeDiscoveryLogEntry {
    pub subnqn: String,
    pub subsystem_type: String,
    pub subsystem_port_id: i32,
    pub controller_id: i32,
    pub admin_queue_max_size: i32,
    pub transport_parameters: Box<dyn HostNvmeTransportParametersTrait>,
    pub transport_requirements: String,
    pub connected: bool,
}
This data object represents a single entry in the Discovery Log returned by a Discovery controller.

How to access

  • HostStorageSystem::discover_nvme_controllers().entry?[*]

Fields

subnqn: String

NVME Qualified name of the discovered subsystem.

Corresponds to the SUBNQN field in the Discovery Log Page Entry as specified by the NVME over Fabrics spec.

subsystem_type: String

NVM Subsystem type.

Corresponds to the SUBTYPE field in the Discovery Log Page Entry as specified by the NVME over Fabrics spec. The set of supported values is described in HostNvmeDiscoveryLogSubsystemType_enum.

subsystem_port_id: i32

NVM subsystem port ID.

Corresponds to the PORTID field in the Discovery Log Page Entry as specified by the NVME over Fabrics spec. For an overview, see:

  • “NVM Express over Fabrics 1.0”, Section 1.5.2, NVM Subsystem
controller_id: i32

NVME Controller ID within the NVM subsystem.

Corresponds to the CNTLID field in the Discovery Log Page Entry as specified by the NVME over Fabrics spec. In the static controller model, this field may be set to a specific controller ID which can be used to connect to that particular controller. It could also be set to 0xFFFE (65534 in decimal), in which case the controller ID will be allocated when a connection is established. In the dynamic controller model, this field shall be set to 0xFFFF (65535 in decimal). Note that this is different from the controllerNumber HostNvmeController.controllerNumber, which is the unique identifier of the NVMe controller within the entire host and is allocated only after a connection is established.

admin_queue_max_size: i32

The maximum size of the Admin Submission Queue.

Corresponds to the ASQSZ field in the Discovery Log Page Entry as specified by the NVME over Fabrics spec. This applies to all controllers within the NVM Subsystem. When establishing a connection, the value of HostNvmeConnectSpec.adminQueueSize may not exceed this value.

transport_parameters: Box<dyn HostNvmeTransportParametersTrait>

Transport specific parameters necessary to establish a connection.

Different types of fabrics transports and different means to specify a connection target may be supported. The transport specific parameters object is constructed based on the data in the Transport Type (TRTYPE), Address Family (ADRFAM), Transport Service Identifier (TRSVCID), Transport Address (TRADDR) and Transport Specific Address Subtype (TSAS) fields in the Discovery Log Page Entry as specified by the NVME over Fabrics spec. When connecting to the controller represented by this Discovery Log Page Entry, the transport specific parameters can be passed directly as HostNvmeSpec.transportParameters.

transport_requirements: String

The requirements for NVME Transport.

Corresponds to the TREQ field in the Discovery Log Page Entry as specified by the NVME over Fabrics spec The set of possible values is described in HostNvmeDiscoveryLogTransportRequirements_enum

connected: bool

Indicates whether the controller represented by this Discovery Log Page Entry is already connected to the adapter through which the discovery is initiated.