pub struct HostNvmeSpec {
pub hba_name: String,
pub transport_parameters: Box<dyn HostNvmeTransportParametersTrait>,
}Expand description
Specifies the main parameters needed when connecting to an NVMe over Fabrics controller or Discovery Service.
Fields
hba_name: StringThe device name of the NVME over Fabrics host bus adapter.
transport_parameters: Box<dyn HostNvmeTransportParametersTrait>Transport specific information necessary to connect to the controller.