HostOpaqueSwitch

Struct HostOpaqueSwitch 

pub struct HostOpaqueSwitch {
    pub dynamic_property: Option<Vec<DynamicProperty>>,
    pub key: String,
    pub name: Option<String>,
    pub pnic: Option<Vec<String>>,
    pub pnic_zone: Option<Vec<HostOpaqueSwitchPhysicalNicZone>>,
    pub status: Option<String>,
    pub vtep: Option<Vec<HostVirtualNic>>,
    pub extra_config: Option<Vec<Box<dyn OptionValueTrait>>>,
    pub feature_capability: Option<Vec<HostFeatureCapability>>,
}
The OpaqueSwitch contains basic information about virtual switches that are managed by a management plane outside of vSphere.

How to access

  • HostSystem::config.network?.opaque_switch?[*]
  • HostNetworkSystem::network_info.opaque_switch?[*]

Fields

dynamic_property: Option<Vec<DynamicProperty>>

Set of dynamic properties.

This property is optional because only the properties of an object that are unknown to a client will be part of this set. This property is not readonly just in case we want to send such properties from a client in the future.

key: String

The opaque switch ID.

name: Option<String>

The opaque switch name.

pnic: Option<Vec<String>>

The set of physical network adapters associated with this switch.

pnic_zone: Option<Vec<HostOpaqueSwitchPhysicalNicZone>>

The IDs of networking zones associated with this switch.

status: Option<String>

Opaque switch status.

See OpaqueSwitchState for valid values.

vtep: Option<Vec<HostVirtualNic>>

List of VTEPs associated with this switch.

extra_config: Option<Vec<Box<dyn OptionValueTrait>>>

Extra NSX specific properties for opaque switch.

feature_capability: Option<Vec<HostFeatureCapability>>

Array of host specific feature capabilities that the switch has.