pub struct HostPartialMaintenanceModeRuntimeInfo {
pub key: String,
pub host_status: String,
}Expand description
This data object contains information about the runtime status of a partial maintenance mode.
Since: vSphere API Release 8.0.3.0
How to access
HostSystem::runtime.partial_maintenance_mode?[*]HostSystem::summary.runtime?.partial_maintenance_mode?[*]HostSystem::query_host_connection_info().host.runtime?.partial_maintenance_mode?[*]Datacenter::query_connection_info().host.runtime?.partial_maintenance_mode?[*]Datacenter::query_connection_info_via_spec().host.runtime?.partial_maintenance_mode?[*]
Fields
key: StringThe unique identifier of the partial maintenance mode.
The values of the identifiers for the most common kinds of partial maintenance modes are enumerated in HostPartialMaintenanceModeId_enum.
host_status: StringThe current runtime status for the particular partial maintenance mode.
The list of supported values is specified in HostPartialMaintenanceModeStatus_enum.