pub struct HostPlacedVirtualNicIdentifier {
pub vm: ManagedObjectReference,
pub vnic_key: String,
pub reservation: Option<i32>,
}Expand description
This data type describes the Virtual Machine and Virtual NIC to identify virtual adapters placed on a physical NIC
How to access
HostSystem::runtime.network_runtime_info?.network_resource_runtime?.pnic_resource_info[*].placed_virtual_nics?[*]HostSystem::summary.runtime?.network_runtime_info?.network_resource_runtime?.pnic_resource_info[*].placed_virtual_nics?[*]HostSystem::query_host_connection_info().host.runtime?.network_runtime_info?.network_resource_runtime?.pnic_resource_info[*].placed_virtual_nics?[*]Datacenter::query_connection_info().host.runtime?.network_runtime_info?.network_resource_runtime?.pnic_resource_info[*].placed_virtual_nics?[*]Datacenter::query_connection_info_via_spec().host.runtime?.network_runtime_info?.network_resource_runtime?.pnic_resource_info[*].placed_virtual_nics?[*]
Fields
vm: ManagedObjectReferenceThe Virtual Machine
Refers instance of VirtualMachine.
vnic_key: StringThe virtual NIC key
reservation: Option<i32>The virtual NIC reservation