HostSpbmHashInfo

Struct HostSpbmHashInfo 

pub struct HostSpbmHashInfo {
    pub policy_info_hash: String,
    pub datastore_info_hash: String,
}
A structure enclosing the computed policy info hash and the datastore info hash values.

They are used by SPBM to verify whether the policy info or datastore info needs to be refreshed on this host.

This structure may be used only with operations rendered under /vsan.

Fields

policy_info_hash: String

Hash computed from all the policy definitions on the host.

datastore_info_hash: String

Hash computed from all the datastore info on the host.