HostSubSpecification

Struct HostSubSpecification 

pub struct HostSubSpecification {
    pub name: String,
    pub created_time: String,
    pub data: Option<Vec<i8>>,
    pub binary_data: Option<Vec<u8>>,
}
Host sub specification data are the data used when create a virtual device, and/or configure the virtual device and its related host services.

A typical example of host sub specification data is the DVS host view specification, which is used when create DVS host view on an ESXi host and configure the virtual switch on the host. The introduction of this type of data is for improving the availability of the ESXi host management. For example, when the VirtualCenter server is not available, an ESXi host will have enough information to reconfigure DVS host view properly when the ESXi host is booted from stateless or stateless caching. Host sub specification data are data for VMware internal data structure used in virtual device creation and configuration. They are different to AnswerFile which are from public knowledge domain or the public API of VMware ESXi host services. When the host sub specification data for a single feature are stored in multiple host sub specification data objects, it is the responsibility of the host specification source in this feature to guarantee the completeness and consistency of these host sub specification objects.

How to access

  • HostSpecificationManager::update_host_sub_specification(host_sub_spec)
  • HostSpecificationManager::retrieve_host_specification().sub_specs?[*]
  • HostSpecificationManager::update_host_specification(host_spec).sub_specs?[*]

Fields

name: String

The full name of the host sub specification.

The format of this member variable is: CompanyName_ProductName_SubSpecName. Thus, name conflict is avoided by containing the company name, product name, and sub specification name in this full name.

created_time: String

Time at which the host sub specification was created.

data: Option<Vec<i8>>

The host sub specification data

binary_data: Option<Vec<u8>>

The host sub specification data in Binary for wire efficiency.