pub struct HostSystemSwapConfiguration {
pub option: Option<Vec<Box<dyn HostSystemSwapConfigurationSystemSwapOptionTrait>>>,
}Expand description
Information and specification for control of the system swap configuration on the current host.
How to access
HostSystem::config.system_swap_configuration?HostSystem::update_system_swap_configuration(sys_swap_config)
Fields
option: Option<Vec<Box<dyn HostSystemSwapConfigurationSystemSwapOptionTrait>>>The currently enabled options.
When this property contains only one value and this value is HostSystemSwapConfigurationDisabledOption,
this indicates that the system swap is disabled.
If the HostSystemSwapConfigurationDisabledOption option is
used together with some other option in call to HostSystem.UpdateSystemSwapConfiguration, a
InvalidArgument is thrown.
It is not allowed to have duplicate values in this array. If so a
InvalidArgument is thrown.