pub struct HostSystemSwapConfigurationHostLocalSwapOption {
pub host_system_swap_configuration_system_swap_option_: HostSystemSwapConfigurationSystemSwapOption,
}Expand description
Use option to indicate that the datastore configured for host local swap may be used for system swap.
How to access
HostSystem::config.system_swap_configuration?.option?[*]→HostSystemSwapConfigurationHostLocalSwapOptionHostSystem::update_system_swap_configuration(sys_swap_config).option?[*]→HostSystemSwapConfigurationHostLocalSwapOption
Fields
host_system_swap_configuration_system_swap_option_: HostSystemSwapConfigurationSystemSwapOptionTrait Implementations
Sourceimpl HostSystemSwapConfigurationSystemSwapOptionTrait for HostSystemSwapConfigurationHostLocalSwapOption
impl HostSystemSwapConfigurationSystemSwapOptionTrait for HostSystemSwapConfigurationHostLocalSwapOption
Sourcefn get_host_system_swap_configuration_system_swap_option(
&self,
) -> &HostSystemSwapConfigurationSystemSwapOption
fn get_host_system_swap_configuration_system_swap_option( &self, ) -> &HostSystemSwapConfigurationSystemSwapOption
Get a reference to the HostSystemSwapConfigurationSystemSwapOption parent struct
Sourcefn get_host_system_swap_configuration_system_swap_option_mut(
&mut self,
) -> &mut HostSystemSwapConfigurationSystemSwapOption
fn get_host_system_swap_configuration_system_swap_option_mut( &mut self, ) -> &mut HostSystemSwapConfigurationSystemSwapOption
Get a mutable reference to the HostSystemSwapConfigurationSystemSwapOption parent struct
Sourceimpl VimObjectTrait for HostSystemSwapConfigurationHostLocalSwapOption
impl VimObjectTrait for HostSystemSwapConfigurationHostLocalSwapOption
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
impl DataObjectTrait for HostSystemSwapConfigurationHostLocalSwapOption