pub struct HostTpmCommandEventDetails {
pub host_tpm_event_details_: HostTpmEventDetails,
pub command_line: String,
}Expand description
Details of an Trusted Platform Module (TPM) event recording options entered manually on the command line prompt at boot time.
How to access
HostSystem::query_tpm_attestation_report().tpm_events[*].event_details→HostTpmCommandEventDetails
Fields
host_tpm_event_details_: HostTpmEventDetailscommand_line: StringBoot options as entered on the command line prompt at boot time.