pub struct HostTpmEventDetails {
pub data_hash: Vec<i8>,
pub data_hash_method: Option<String>,
}Expand description
This is a base data object for describing an event generated by Trusted Platform Module (TPM).
It contains parameters common to all TPM event types.
How to access
HostSystem::query_tpm_attestation_report().tpm_events[*].event_details
Fields
data_hash: Vec<i8>Value of the Platform Configuration Register (PCR) for this event.
data_hash_method: Option<String>Method in which the digest hash is calculated.
The set of possible values is described in HostDigestInfoDigestMethodType_enum.