HostUnresolvedVmfsVolumeResolveStatus

Struct HostUnresolvedVmfsVolumeResolveStatus 

pub struct HostUnresolvedVmfsVolumeResolveStatus {
    pub resolvable: bool,
    pub incomplete_extents: Option<bool>,
    pub multiple_copies: Option<bool>,
}
Data object that describes the resolvability of a volume.

How to access

  • HostDatastoreSystem::query_unresolved_vmfs_volumes().resolve_status
  • HostStorageSystem::query_unresolved_vmfs_volume().resolve_status

Fields

resolvable: bool

Can this volume be resolved? There may be other reasons a volume cannot be resolved other than the fact that it is incomplete.

This boolean will authoritatively indicate if the server can resolve this volume.

incomplete_extents: Option<bool>

Is the list of extents for the volume a partial list? A volume can only be resignatured if all extents composing that volume are available.

Hence, a volume with a partial extent list cannot be resignatured.

In cases where this information is not known for a volume, this property will be unset.

multiple_copies: Option<bool>

Are there multiple copies of extents for this volume? If any extent of the volume has multiple copies then the extents to be resolved must be explicitly specified when resolving this volume.

In cases where this information is not known for a volume, this property will be unset.