HostVirtualNicConnection

Struct HostVirtualNicConnection 

pub struct HostVirtualNicConnection {
    pub portgroup: Option<String>,
    pub dv_port: Option<DistributedVirtualSwitchPortConnection>,
    pub op_network: Option<HostVirtualNicOpaqueNetworkSpec>,
}
DataObject which provides a level of indirection when identifying VirtualNics during configuration.

This dataObject lets users specify a VirtualNic in terms of the portgroup/Dv Port the Virtual NIC is connected to. This is useful in cases where VirtualNic will be created as part of a configuration operation and the created VirtualNic is referred to in some other part of configuration. e.g: for configuring VMotion

How to access

  • HostNetworkSystem::console_ip_route_config→HostIpRouteConfigSpec.gateway_device_connection?
  • HostNetworkSystem::console_ip_route_config→HostIpRouteConfigSpec.ip_v_6_gateway_device_connection?
  • HostNetworkSystem::dns_config→HostDnsConfigSpec.virtual_nic_connection?
  • HostNetworkSystem::dns_config→HostDnsConfigSpec.virtual_nic_connection_v_6?
  • HostNetworkSystem::ip_route_config→HostIpRouteConfigSpec.gateway_device_connection?
  • ClusterComputeResource::configure_hci_task(host_inputs).host_vmk_nics?[*].nic_spec.ip_route_spec?.ip_route_config?→HostIpRouteConfigSpec.gateway_device_connection?
  • ClusterComputeResource::configure_hci_task(host_inputs).host_vmk_nics?[*].nic_spec.ip_route_spec?.ip_route_config?→HostIpRouteConfigSpec.ip_v_6_gateway_device_connection?
  • ClusterComputeResource::extend_hci_task(host_inputs).host_vmk_nics?[*].nic_spec.ip_route_spec?.ip_route_config?→HostIpRouteConfigSpec.gateway_device_connection?
  • ClusterComputeResource::extend_hci_task(host_inputs).host_vmk_nics?[*].nic_spec.ip_route_spec?.ip_route_config?→HostIpRouteConfigSpec.ip_v_6_gateway_device_connection?
  • HostProfileManager::apply_host_config_task(config_spec).nic_type_selection?[*].vnic

(10 of 100 paths)

Fields

portgroup: Option<String>

Name of the portgroup to which the virtual nic is connected to.

If this parameter is set, use a virtual nic connected to a legacy portgroup.

dv_port: Option<DistributedVirtualSwitchPortConnection>

Identifier for the DistributedVirtualPort.

If the virtual nic is to be connected to a DVS, #dvPort will be set instead of #portgroup

op_network: Option<HostVirtualNicOpaqueNetworkSpec>

Identifier for the opaqueNetworkSpec virtual nic connected to.

If the virtual nic is to be connected to a logicSwitch, #opNetwork will be set instead of #portgroup and #dvPort