HostVirtualNicSpec

Struct HostVirtualNicSpec 

pub struct HostVirtualNicSpec {
Show 14 fields pub dynamic_property: Option<Vec<DynamicProperty>>, pub ip: Option<Box<dyn HostIpConfigTrait>>, pub mac: Option<String>, pub distributed_virtual_port: Option<DistributedVirtualSwitchPortConnection>, pub portgroup: Option<String>, pub mtu: Option<i32>, pub tso_enabled: Option<bool>, pub net_stack_instance_key: Option<String>, pub opaque_network: Option<HostVirtualNicOpaqueNetworkSpec>, pub external_id: Option<String>, pub pinned_pnic: Option<String>, pub ip_route_spec: Option<HostVirtualNicIpRouteSpec>, pub system_owned: Option<bool>, pub dpu_id: Option<String>,
}
The HostVirtualNicSpec data object describes the HostVirtualNic configuration containing both the configured properties on a virtual NIC and identification information.

How to access

  • HostSystem::config.network?.vnic?[*].spec
  • HostSystem::config.network?.console_vnic?[*].spec
  • HostSystem::config.network?.opaque_switch?[*].vtep?[*].spec
  • HostSystem::config.vmotion?.net_config?.candidate_vnic?[*].spec
  • HostSystem::config.virtual_nic_manager_info?.net_config?[*].candidate_vnic?[*].spec
  • HostNetworkSystem::network_config.vnic?[*].spec?
  • HostNetworkSystem::network_config.console_vnic?[*].spec?
  • HostNetworkSystem::network_info.vnic?[*].spec
  • HostNetworkSystem::network_info.console_vnic?[*].spec
  • HostVMotionSystem::net_config.candidate_vnic?[*].spec

(10 of 34 paths)

Fields

dynamic_property: Option<Vec<DynamicProperty>>

Set of dynamic properties.

This property is optional because only the properties of an object that are unknown to a client will be part of this set. This property is not readonly just in case we want to send such properties from a client in the future.

ip: Option<Box<dyn HostIpConfigTrait>>

IP configuration on the virtual network adapter.

mac: Option<String>

Media access control (MAC) address of the virtual network adapter.

distributed_virtual_port: Option<DistributedVirtualSwitchPortConnection>

DistributedVirtualPort or DistributedVirtualPortgroup connection.

To specify a port connection, set DistributedVirtualSwitchPortConnection.switchUuid and DistributedVirtualSwitchPortConnection.portKey properties. To specify a portgroup connection, set DistributedVirtualSwitchPortConnection.switchUuid and DistributedVirtualSwitchPortConnection.portgroupKey properties.

When reconfiguring a virtual NIC, this property indicates the new portgroup to which the virtual NIC should connect. You can specify this property only if you do not specify HostVirtualNicSpec.distributedVirtualPort and HostVirtualNicSpec.opaqueNetwork

portgroup: Option<String>

Portgroup (HostPortGroup) to which the virtual NIC is connected.

When reconfiguring a virtual NIC, this property indicates the new portgroup to which the virtual NIC should connect. You can specify this property only if you do not specify HostVirtualNicSpec.distributedVirtualPort and HostVirtualNicSpec.opaqueNetwork

mtu: Option<i32>

Maximum transmission unit for packets size in bytes for the virtual NIC.

If not specified, the Server will use the system default value.

tso_enabled: Option<bool>

Flag enabling or disabling TCP segmentation offset for a virtual NIC.

If not specified, a default value of true will be used.

net_stack_instance_key: Option<String>

The NetStackInstance that the virtual NIC uses, the value of this property is default to be defaultTcpipStack

opaque_network: Option<HostVirtualNicOpaqueNetworkSpec>

Opaque network (HostOpaqueNetworkInfo) to which the virtual NIC is connected.

When reconfiguring a virtual NIC, this property indicates the specification of opaque network to which the virtual NIC should connect. You can specify this property only if you do not specify HostVirtualNicSpec.distributedVirtualPort and HostVirtualNicSpec.portgroup.

external_id: Option<String>

An ID assigned to the vmkernel adapter by external management plane.

The value and format of this property is determined by external management plane, and vSphere doesn’t do any validation. It’s also up to external management plane to set, unset or maintain this property.

This property is applicable only when HostVirtualNicSpec.opaqueNetwork property is set, otherwise it’s value is ignored.

pinned_pnic: Option<String>

The physical nic to which the vmkernel adapter is pinned.

Setting this value ensures that the virtual NIC will access external network only via the the specified physical NIC.

This property is applicable only when HostVirtualNicSpec.opaqueNetwork property is set. If the vmkernel adapter is connected to a portgroup or dvPort, then such pinning can be achieved by configuring correct teaming policy on the portgroup or dvPort or dvPortgroup that is connected to virtual NIC.

ip_route_spec: Option<HostVirtualNicIpRouteSpec>

The ip route configuration used by the vmkernel adapter.

This attribute allows the vmkernel adapter to specify its own default gateway.

system_owned: Option<bool>

Deprecated as of vSphere API 9, use HostVirtualNic.owner instead.

Set to true when the vmkernel adapter is configured by other system indirectly other than by the user directly.

dpu_id: Option<String>

The identifier of the DPU hosting the vmknic.

If vmknic is on ESX host, dpuId will be unset.

Since: vSphere API Release 8.0.0.1