pub struct HostVmciAccessManagerAccessSpec {
pub vm: ManagedObjectReference,
pub services: Option<Vec<String>>,
pub mode: String,
}Expand description
The AccessSpec data object declares an update to the service access granted to a VM.
The given list of services will either be granted in addition to existing services, replace the existing service or be revoked depending on the mode specified. In case of a revoke, an empty or non-existing service list indicates that all granted services should be revoked.
Fields
vm: ManagedObjectReferenceRefers instance of VirtualMachine.
services: Option<Vec<String>>mode: StringTrait Implementations
Sourceimpl VimObjectTrait for HostVmciAccessManagerAccessSpec
impl VimObjectTrait for HostVmciAccessManagerAccessSpec
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
impl DataObjectTrait for HostVmciAccessManagerAccessSpec