HttpNfcLeaseDeviceUrl

Struct HttpNfcLeaseDeviceUrl 

pub struct HttpNfcLeaseDeviceUrl {
    pub key: String,
    pub import_key: String,
    pub url: String,
    pub ssl_thumbprint: String,
    pub ssl_certificate: Option<String>,
    pub disk: Option<bool>,
    pub target_id: Option<String>,
    pub datastore_key: Option<String>,
    pub file_size: Option<i64>,
}
Provides a mapping from logical device IDs to upload/download URLs.

For export, a single device id is returned based on the object identifiers for the objects.

For import, two device ids are returned. One based on the object names used in the ImportSpec, and one based on the object identifiers for the created objects. This is immutable and would match the id if an ExportLease is latter created.

How to access

  • HttpNfcLease::info.device_url?[*]

Fields

key: String

The immutable identifier for the device.

This is set for both import/export leases.

import_key: String

Identifies the device based on the names in an ImportSpec.

This is only set for import leases.

url: String

The URL to use to upload/download the device content.

The returned url contains either an IP address, a hostname or a “*”. If a “*” is returned the client must substitutes the “*” with the hostname or IP address used when connecting to the server. For example if the client connected to “someHost” and the device url returned is:

 http:// *:somePort/somePath

the client must substitute the “*” with “someHost” before use. The resulting url would be:

 http://someHost:somePort/somePath

The server cannot return a valid hostname or IP address when the client connects via a NAT, a proxy, or when the server is multihomed.

ssl_thumbprint: String

SSL thumbprint for the host the URL refers to.

Empty if no SSL thumbprint is available or needed.

ssl_certificate: Option<String>

PEM encoded SSL Certificate of the host

Since: vSphere API Release 9.0.0.0

disk: Option<bool>

Optional value to specify if the attached file is a disk in vmdk format.

target_id: Option<String>

Id for this target.

This only used for multi-POSTing, where a single HTTP POST is applied to multiple targets.

datastore_key: Option<String>

Key for the datastore this disk is on.

This is used to look up hosts which can be used to multi-POST disk contents, in the host map of the lease.

file_size: Option<i64>

Specifies the size of the file backing for this device.

This property is only set for non-disk file backings.