IncompatibleHostVersion

Struct IncompatibleHostVersion 

pub struct IncompatibleHostVersion {
    pub vm_not_deployed_: VmNotDeployed,
}
Deprecated as of vSphere 9.0. Please refer to vLCM APIs.

An agent virtual machine is expected to be deployed on a host, but the agent could not be deployed because it was incompatible with the host.

This is an active remediable issue. To remediate, vSphere ESX Agent Manager redeployes the agent. However, the problem is likely to persist until either the host or the solution has been upgraded, so that the agent will become compatible with the host.

This structure may be used only with operations rendered under /eam.

Fields

vm_not_deployed_: VmNotDeployed