IntegrityAgencyCannotDeleteSoftware

Struct IntegrityAgencyCannotDeleteSoftware 

pub struct IntegrityAgencyCannotDeleteSoftware {
    pub integrity_agency_vum_issue_: IntegrityAgencyVumIssue,
}
Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs.

Cannot remove the Baseline associated with an Agency from VUM.

This is an active remediable issue. To remediate, vSphere ESX Agent Manager retries the delete operation. Note: In future this issue will denote also the removal of the Agency software (VIBs) from VUM software depot once VUM provides an API for that.

This structure may be used only with operations rendered under /eam.

Fields

integrity_agency_vum_issue_: IntegrityAgencyVumIssue