pub struct IscsiMigrationDependency {
pub migration_allowed: bool,
pub disallow_reason: Option<IscsiStatus>,
pub dependency: Option<Vec<IscsiDependencyEntity>>,
}Expand description
Provides migration dependency information for a given Physical NIC.
Lists all the iSCSI and networking resources impacted if migration of a given Physical NIC is to take place.
How to access
IscsiManager::query_migration_dependencies()
Fields
migration_allowed: boolIndicates whether migration can be safely performed If migrationAllowed is False, the disallowReason will contain the specific condition that makes the migration attempt unsafe.
disallow_reason: Option<IscsiStatus>Reasons for not allowing migration.
Unset if migrationAllowed is true.
dependency: Option<Vec<IscsiDependencyEntity>>Details of all the resources affected by migration.