pub struct LicenseAvailabilityInfo {
pub feature: LicenseFeatureInfo,
pub total: i32,
pub available: i32,
}Expand description
Deprecated as of vSphere API 4.0, this is not used by the system.
Describes how many licenses of a particular feature is provided by the licensing source.
How to access
LicenseManager::query_license_source_availability()
Fields
feature: LicenseFeatureInfoDescribes the feature.
total: i32Total number of licenses for this given type that are installed on the source.
available: i32The number of licenses that have not yet been reserved on the source.