pub struct LifecycleFaultDomainDetails {
pub is_preferred_fault_domain: Option<bool>,
pub name: Option<String>,
pub hosts: Option<Vec<ManagedObjectReference>>,
}Expand description
vSAN stretched cluster fault domain details required by lifecycle manager/vLCM.
This structure may be used only with operations rendered under /vsan.
How to access
VsanVcClusterConfigSystem::run_lifecycle_check().config_details.fault_domains_details?[*]
Fields
is_preferred_fault_domain: Option<bool>Whether this is the preferred fault domain.
name: Option<String>The fault domain name.
Optional when hosts are fault domains.
hosts: Option<Vec<ManagedObjectReference>>The list of hosts in the fault domain.
Refers instances of HostSystem.