pub struct LongOption {
pub option_type_: OptionType,
pub min: i64,
pub max: i64,
pub default_value: i64,
}Expand description
The LongOption data object type is used to define the minimum, maximum, and default values for a 64-bit long option.
How to access
ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.device_change?[*].device.device_info?→OptionDef.option_type→LongOptionClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.device_change?[*].device.device_info?→OptionDef.option_type→LongOptionClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.device_change?[*].device.device_info?→OptionDef.option_type→LongOptionClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device.device_info?→OptionDef.option_type→LongOptionClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_groups?.device_group?[*].device_info?→OptionDef.option_type→LongOptionAlarmManager::description.state_operator[*]→OptionDef.option_type→LongOptionAlarmManager::description.metric_operator[*]→OptionDef.option_type→LongOptionAlarmManager::description.host_system_connection_state[*]→OptionDef.option_type→LongOptionAlarmManager::description.virtual_machine_power_state[*]→OptionDef.option_type→LongOptionAlarmManager::description.datastore_connection_state[*]→OptionDef.option_type→LongOption
(10 of 100 paths)
Fields
option_type_: OptionTypemin: i64The minimum value.
max: i64The maximum value.
default_value: i64The default value.