pub struct MethodAction {
pub name: String,
pub argument: Option<Vec<MethodActionArgument>>,
}Expand description
This data object type defines an operation and its arguments, invoked on a particular entity.
How to access
ScheduledTask::reconfigure_scheduled_task(spec).action→MethodActionScheduledTaskManager::create_scheduled_task(spec).action→MethodActionScheduledTaskManager::create_object_scheduled_task(spec).action→MethodActionAlarm::reconfigure_alarm(spec).action?→AlarmTriggeringAction.action→MethodActionAlarmManager::create_alarm(spec).action?→AlarmTriggeringAction.action→MethodAction
Fields
name: StringName of the operation.
argument: Option<Vec<MethodActionArgument>>An array consisting of the arguments for the operation.