pub struct MissingProperty {
pub path: String,
pub fault: MethodFault,
}Expand description
Used for reporting properties for which values could not be retrieved.
How to access
PropertyCollector::retrieve_properties().missing_set?[*]VsanMassCollector::vsan_retrieve_properties().missing_set?[*]PropertyCollector::continue_retrieve_properties_ex().objects[*].missing_set?[*]PropertyCollector::retrieve_properties_ex().objects[*].missing_set?[*]PropertyCollector::check_for_updates().filter_set?[*].object_set?[*].missing_set?[*]PropertyCollector::wait_for_updates().filter_set?[*].object_set?[*].missing_set?[*]
(6 of 7 paths)
Fields
path: StringProperty for which a value could not be retrieved
fault: MethodFaultFault describing the failure to retrieve the property value.
The possible faults for missing properties are:
- SystemError if there was some unknown problem reading the value
- SecurityError if the logged in session did not have permission to read the value