MonthlyByWeekdayTaskScheduler

Struct MonthlyByWeekdayTaskScheduler 

pub struct MonthlyByWeekdayTaskScheduler {
    pub monthly_task_scheduler_: MonthlyTaskScheduler,
    pub offset: WeekOfMonthEnum,
    pub weekday: DayOfWeekEnum,
}
The MonthlyByWeekdayTaskScheduler data object sets the time for monthly task execution.

You identify a single day for task execution by specifying the week of the month and day of the week, and you complete the schedule by setting the inherited properties for the hour and minute.

By default, the scheduler executes the task on the specified day every month. If you set the interval to a value greater than 1, the task will execute at the specified monthly interval. (For example, an interval of 2 will cause the task to execute on the specified day, hour, and minute every 2 months.)

How to access

  • ScheduledTask::reconfigure_scheduled_task(spec).scheduler→MonthlyByWeekdayTaskScheduler
  • ScheduledTaskManager::create_scheduled_task(spec).scheduler→MonthlyByWeekdayTaskScheduler
  • ScheduledTaskManager::create_object_scheduled_task(spec).scheduler→MonthlyByWeekdayTaskScheduler

Fields

monthly_task_scheduler_: MonthlyTaskScheduleroffset: WeekOfMonthEnum

The week in the month during which the scheduled task is to run.

weekday: DayOfWeekEnum

The day in the week when the scheduled task is to run.