pub struct NegatableExpression {
pub negate: Option<bool>,
}Expand description
The base class for any type of setting or configuration to which negation can be applied.
When used in a configuration information object: if NegatableExpression.negate is true, then ~(objectValue) will be used for the configuration. If false, then objectValue will be used as it is.
Fields
negate: Option<bool>Whether the configuration needs to be negated or not.