NodeDeploymentSpec

Struct NodeDeploymentSpec 

pub struct NodeDeploymentSpec {
    pub esx_host: Option<ManagedObjectReference>,
    pub datastore: Option<ManagedObjectReference>,
    pub public_network_port_group: Option<ManagedObjectReference>,
    pub cluster_network_port_group: Option<ManagedObjectReference>,
    pub folder: ManagedObjectReference,
    pub resource_pool: Option<ManagedObjectReference>,
    pub management_vc: Option<ServiceLocator>,
    pub node_name: String,
    pub ip_settings: CustomizationIpSettings,
}
The NodeDeploymentSpec class defines location specification of the nodes the VCHA Cluster along with Management vCenter Server information that manages node VM.

How to access

  • FailoverClusterConfigurator::create_witness_node_task(witness_deployment_spec)
  • FailoverClusterConfigurator::deploy_vcha_task(deployment_spec).witness_deployment_spec

Fields

esx_host: Option<ManagedObjectReference>

ESX host on which the VM is to be deployed.

For behavior when an esxHost is not specified,

See also VirtualMachineRelocateSpec.host.

Refers instance of HostSystem.

datastore: Option<ManagedObjectReference>

Datastore used for deploying the VM.

For behavior when a datastore is not specified,

See also VirtualMachineRelocateSpec.datastore.

Refers instance of Datastore.

public_network_port_group: Option<ManagedObjectReference>

Name of the portgroup that is associated with the public IP address where clients connect to vCenter Server.

If a portgroup is not specified same portgroup present on source is used to deploy the VM with an assumption that portgroup is present on destination.

Refers instance of Network.

cluster_network_port_group: Option<ManagedObjectReference>

Name of the portgroup that is associated with the VCHA Cluster IP address where clients connect to vCenter Server.

If a portgroup is not specified same portgroup present on source is used to deploy the VM with an assumption that portgroup is present on destination.

Refers instance of Network.

folder: ManagedObjectReference

Folder in which the VM is to be created.

Refers instance of Folder.

resource_pool: Option<ManagedObjectReference>

ResourcePool that will be used to deploy this node.

If the ResourcePool is not specified, the root resource pool for the host will be used.

Refers instance of ResourcePool.

management_vc: Option<ServiceLocator>

Management vCenter Server managing this VM.

If the managementVc is not specified, managementVc specified as part of SourceNodeSpec is used.

node_name: String

nodeName here refers to a name that will be assigned to the VM to which this node will be deployed to.

ip_settings: CustomizationIpSettings

VCHA Cluster network configuration of the node.

All cluster communication (state replication, heartbeat, cluster messages) happens over this network.