pub struct NsxHostVNicProfile {
pub apply_profile_: ApplyProfile,
pub key: String,
pub ip_config: IpAddressProfile,
}Expand description
The NsxHostVNicProfile data object is the base object for host Virtual NIC connected to NSX logic switch subprofiles.
If a profile plug-in defines additional policies or subprofiles, use the ApplyProfile.policy or ApplyProfile.property list to access the configuration data.
How to access
HostProfile::validation_failure_info.apply_profile?.network?.nsx_host_nic?[*]HostProfile::config→HostProfileConfigInfo.apply_profile?.network?.nsx_host_nic?[*]Profile::config→HostProfileConfigInfo.apply_profile?.network?.nsx_host_nic?[*]ClusterProfile::config→HostProfileConfigInfo.apply_profile?.network?.nsx_host_nic?[*]HostProfileManager::create_default_profile()→NsxHostVNicProfileHostProfileManager::composite_host_profile_task(to_be_merged).network?.nsx_host_nic?[*]HostProfileManager::composite_host_profile_task(to_be_replaced_with).network?.nsx_host_nic?[*]HostProfileManager::composite_host_profile_task(to_be_deleted).network?.nsx_host_nic?[*]HostProfileManager::composite_host_profile_task(enable_status_to_be_copied).network?.nsx_host_nic?[*]HostProfile::update_host_profile(config)→HostProfileCompleteConfigSpec.apply_profile?.network?.nsx_host_nic?[*]
(10 of 25 paths)
Fields
apply_profile_: ApplyProfilekey: StringLinkable identifier.
ip_config: IpAddressProfileIP address for the Virtual NIC belonging to a logic switch.