NvdimmHealthInfo

Struct NvdimmHealthInfo 

pub struct NvdimmHealthInfo {
    pub health_status: String,
    pub health_information: String,
    pub state_flag_info: Option<Vec<String>>,
    pub dimm_temperature: i32,
    pub dimm_temperature_threshold: i32,
    pub spare_blocks_percentage: i32,
    pub spare_block_threshold: i32,
    pub dimm_lifespan_percentage: i32,
    pub es_temperature: Option<i32>,
    pub es_temperature_threshold: Option<i32>,
    pub es_lifespan_percentage: Option<i32>,
}
\brief NVDIMM health information

How to access

  • HostNvdimmSystem::nvdimm_system_info.dimm_info?[*].health_info

Fields

health_status: String

Device health status.

health_information: String

Health status description.

state_flag_info: Option<Vec<String>>

State flag information.

This information is the cumulation of state flags of all the NVDIMM region state flags. It must be one or more of NvdimmNvdimmHealthInfoState_enum

dimm_temperature: i32

Current Nvdimm temperature in degree Celsius.

dimm_temperature_threshold: i32

Nvdimm temperature threshold.

Default value is 0, indicating threshold has not reached, if set to 1, reached threshold limit.

spare_blocks_percentage: i32

Percentage of spare capavity as a percentage of factory configured space (valid range 0 to 100)

spare_block_threshold: i32

Spare block threshold.

Default value is 0, indicating threshold has not reached, if set to 1, reached threshold limit.

dimm_lifespan_percentage: i32

Lifespan of Nvdimm as percentage.

100% = Warranted life span has reached.

es_temperature: Option<i32>

Energy source current temperature in degree Celsius.

Default value is 0, indicating there is no energy source for these nvdimms.

es_temperature_threshold: Option<i32>

Energy source temperature threshold.

Default value is 0, indicating threshold has not reached, if set to 1, reached threshold limit.

es_lifespan_percentage: Option<i32>

Lifespan of Energy source as percentage.

100% = Warranted life span has reached. Default value is 0, indicating there is no energy source.