pub struct OptionType {
pub value_is_readonly: Option<bool>,
}Expand description
The base data object type for all options.
How to access
StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.device_change?[*].device.device_info?→OptionDef.option_typeStoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StorageMigrationAction.relocate_spec.device_change?[*].device.device_info?→OptionDef.option_typeStoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→PlacementAction.relocate_spec?.device_change?[*].device.device_info?→OptionDef.option_typeStoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device.device_info?→OptionDef.option_typeStoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.device_groups?.device_group?[*].device_info?→OptionDef.option_typeClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.device_change?[*].device.device_info?→OptionDef.option_typeClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.device_change?[*].device.device_info?→OptionDef.option_typeClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.device_change?[*].device.device_info?→OptionDef.option_typeClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device.device_info?→OptionDef.option_typeClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_groups?.device_group?[*].device_info?→OptionDef.option_type
(10 of 100 paths)
Fields
value_is_readonly: Option<bool>The flag to indicate whether or not a user can modify a value belonging to this option type.
If the flag is not set, the value can be modified.