OrphanedAgency

Struct OrphanedAgency 

pub struct OrphanedAgency {
    pub agency_issue_: AgencyIssue,
}
Deprecated eAM no longer raises this issue. If agecny is getting orphaned EAM simply destroys it.

The solution that created the agency is no longer registered with the vCenter server.

This is an active remediable issue. To remediate, vSphere ESX Agent Manager undeploys and removes the agency.

This structure may be used only with operations rendered under /eam.

Fields

agency_issue_: AgencyIssue