pub struct PbmCapabilityNamespaceInfo {
pub version: String,
pub namespace: String,
pub info: Option<PbmExtendedElementDescription>,
}Expand description
Name space information for the capability metadata schema.
NOTE: Name spaces are required to be globally unique across resource types. A same vendor can register multiple name spaces for same resource type or for different resource type, but the schema namespace URL must be unique for each of these cases. A CapabilityMetadata object is uniquely identified based on the namespace it belongs to and it’s unique identifier within that namespace.
This structure may be used only with operations rendered under /pbm.
How to access
PbmProfileProfileManager::pbm_fetch_capability_schema().namespace_infoPbmProfileProfileManager::pbm_fetch_vendor_info().vendor_namespace_info[*].namespace_info
Fields
version: StringSchema version
namespace: StringSchema namespace.
info: Option<PbmExtendedElementDescription>Trait Implementations
Sourceimpl Debug for PbmCapabilityNamespaceInfo
impl Debug for PbmCapabilityNamespaceInfo
Sourceimpl VimObjectTrait for PbmCapabilityNamespaceInfo
impl VimObjectTrait for PbmCapabilityNamespaceInfo
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
impl DataObjectTrait for PbmCapabilityNamespaceInfo