pub struct PbmCapabilityProfileCreateSpec {
pub name: String,
pub description: Option<String>,
pub category: Option<String>,
pub resource_type: PbmProfileResourceType,
pub constraints: Box<dyn PbmCapabilityConstraintsTrait>,
}Expand description
The PbmCapabilityProfileCreateSpec describes storage requirements.
Use this data object to create a PbmCapabilityProfile.
This structure may be used only with operations rendered under /pbm.
How to access
PbmPlacementSolver::pbm_check_compatibility_with_spec(profile_spec)PbmPlacementSolver::pbm_query_matching_hub_with_spec(create_spec)PbmProfileProfileManager::pbm_create(create_spec)
Fields
name: StringName of the capability based profile to be created.
The maximum length of the name is 80 characters.
description: Option<String>Text description associated with the profile.
category: Option<String>Category specifies the type of policy to be created.
This can be REQUIREMENT from PbmProfileCategoryEnum_enum or null when creating a storage policy. And it can be DATA_SERVICE_POLICY from PbmProfileCategoryEnum_enum when creating a data service policy. RESOURCE from PbmProfileCategoryEnum_enum is not allowed as resource profile is created by the system.
resource_type: PbmProfileResourceTypeDeprecated as of vSphere API 6.5.
Specifies the type of resource to which the profile applies.
The only legal value is STORAGE - deprecated.
constraints: Box<dyn PbmCapabilityConstraintsTrait>Set of subprofiles that define the storage requirements.
A subprofile corresponds to a rule set in the vSphere Web Client.