pub struct PbmCapabilityTimeSpan {
pub value: i32,
pub unit: String,
}Expand description
The PbmCapabilityTimeSpan data object defines a time value and time unit, for example 10 hours or 5 minutes.
See PbmBuiltinType_enum.VMW_TIMESPAN.
This structure may be used only with operations rendered under /pbm.
Fields
value: i32Time value.
Must be a positive integer.
unit: StringUnit value for time.
The string value must correspond to one of the PbmCapabilityTimeUnitType_enum values.