pub struct PbmDataServiceToPoliciesMap {
pub data_service_policy: PbmProfileId,
pub parent_storage_policies: Option<Vec<PbmProfileId>>,
pub fault: Option<MethodFault>,
}Expand description
DataServiceToProfilesMap maps the data service policy to the parent storage policies if referred.
This is returned from the API call
ProfileManager#queryParentStoragePolicies(ProfileId[])
This structure may be used only with operations rendered under /pbm.
Fields
data_service_policy: PbmProfileIdDenotes a Data Service Policy Id.
parent_storage_policies: Option<Vec<PbmProfileId>>Storage Policies that refer to the Data Service Policy given by PbmDataServiceToPoliciesMap.dataServicePolicy.
fault: Option<MethodFault>The fault is set in case of error conditions and this property will have the reason.