PbmRollupComplianceResult

Struct PbmRollupComplianceResult 

pub struct PbmRollupComplianceResult {
    pub oldest_check_time: String,
    pub entity: PbmServerObjectRef,
    pub overall_compliance_status: String,
    pub overall_compliance_task_status: Option<String>,
    pub result: Option<Vec<PbmComplianceResult>>,
    pub error_cause: Option<Vec<MethodFault>>,
    pub profile_mismatch: bool,
}
The PbmRollupComplianceResult data object identifies the virtual machine for which rollup compliance was checked, and it contains the overall status and a list of compliance result objects.

This structure may be used only with operations rendered under /pbm.

How to access

  • PbmComplianceManager::pbm_check_rollup_compliance()
  • PbmComplianceManager::pbm_fetch_rollup_compliance_result()

Fields

oldest_check_time: String

Indicates the earliest time that compliance was checked for any of the entities in the rollup compliance check.

The compliance check time for a single entity is represented in the PbmComplianceResult.PbmComplianceResult.checkTime property. If the PbmComplianceResult.checkTime property is unset for any of the objects in the results array, the oldestCheckTime property will be unset.

entity: PbmServerObjectRef

Virtual machine for which the rollup compliance was checked.

overall_compliance_status: String

Overall compliance status of the virtual machine and its virtual disks.

overallComplianceStatus is a string value that corresponds to one of the PbmComplianceResult.PbmComplianceResult.complianceStatus values.

The overall compliance status is determined by the following rules, applied in the order listed:

  • If all the entities are compliant, the overall status is compliant.
  • Else if any entity’s status is outOfDate, the overall status is outOfDate.
  • Else if any entity’s status is nonCompliant, the overall status is nonCompliant.
  • Else if any entity’s status is unknown, the overall status is unknown.
  • Else if any entity’s status is notApplicable, the overall status is notApplicable.
overall_compliance_task_status: Option<String>

Overall compliance task status of the virtual machine and its virtual disks.

overallComplianceTaskStatus is a string value that corresponds to one of the PbmComplianceResult. PbmComplianceResult.complianceTaskStatus values.

result: Option<Vec<PbmComplianceResult>>

Individual compliance results that make up the rollup.

error_cause: Option<Vec<MethodFault>>

This property is set if the overall compliance task fails with some error.

This property indicates the causes of error. If there are multiple failures, it stores these failure in this array.

profile_mismatch: bool

Deprecated as of vSphere 2016, use PbmRollupComplianceResult.overallComplianceStatus to know if profile mismatch has occurred. If overallComplianceStatus value is outOfDate, it means profileMismatch has occurred.

True if and only if PbmComplianceResult.

PbmComplianceResult.mismatch is true for at least one entity in the rollup compliance check.