PersonalityAgencyInvalidDepot

Struct PersonalityAgencyInvalidDepot 

pub struct PersonalityAgencyInvalidDepot {
    pub personality_agency_depot_issue_: PersonalityAgencyDepotIssue,
}
Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs.

The offline depot has missing or invalid metadata to be usable by Personality Manager.

This structure may be used only with operations rendered under /eam.

Fields

personality_agency_depot_issue_: PersonalityAgencyDepotIssue