pub struct PersonalityAgentAwaitingPmRemediation {
pub personality_agent_pm_issue_: PersonalityAgentPmIssue,
}Expand description
Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs.
The agent workflow is blocked until its’ required solutions are re-mediated externally in Personality Manager.
This issue is only passively remediable. The desired state has to be applied in PM by an user.
This structure may be used only with operations rendered under /eam.
Fields
personality_agent_pm_issue_: PersonalityAgentPmIssueTrait Implementations
Sourceimpl AgencyIssueTrait for PersonalityAgentAwaitingPmRemediation
impl AgencyIssueTrait for PersonalityAgentAwaitingPmRemediation
Sourcefn get_agency_issue(&self) -> &AgencyIssue
fn get_agency_issue(&self) -> &AgencyIssue
Get a reference to the AgencyIssue parent struct
Sourcefn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
fn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
Get a mutable reference to the AgencyIssue parent struct
Sourceimpl AgentIssueTrait for PersonalityAgentAwaitingPmRemediation
impl AgentIssueTrait for PersonalityAgentAwaitingPmRemediation
Sourcefn get_agent_issue(&self) -> &AgentIssue
fn get_agent_issue(&self) -> &AgentIssue
Get a reference to the AgentIssue parent struct
Sourcefn get_agent_issue_mut(&mut self) -> &mut AgentIssue
fn get_agent_issue_mut(&mut self) -> &mut AgentIssue
Get a mutable reference to the AgentIssue parent struct
Sourceimpl PersonalityAgentPmIssueTrait for PersonalityAgentAwaitingPmRemediation
impl PersonalityAgentPmIssueTrait for PersonalityAgentAwaitingPmRemediation
Sourcefn get_personality_agent_pm_issue(&self) -> &PersonalityAgentPmIssue
fn get_personality_agent_pm_issue(&self) -> &PersonalityAgentPmIssue
Get a reference to the PersonalityAgentPmIssue parent struct
Sourcefn get_personality_agent_pm_issue_mut(&mut self) -> &mut PersonalityAgentPmIssue
fn get_personality_agent_pm_issue_mut(&mut self) -> &mut PersonalityAgentPmIssue
Get a mutable reference to the PersonalityAgentPmIssue parent struct
Sourceimpl VimObjectTrait for PersonalityAgentAwaitingPmRemediation
impl VimObjectTrait for PersonalityAgentAwaitingPmRemediation
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
impl DataObjectTrait for PersonalityAgentAwaitingPmRemediation