PersonalityAgentPmIssue

Struct PersonalityAgentPmIssue 

pub struct PersonalityAgentPmIssue {
    pub agent_issue_: AgentIssue,
}
Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs.

Base class for all issues which occurred during EAM communication with Personality Manager.

This structure may be used only with operations rendered under /eam.

Fields

agent_issue_: AgentIssue