PhysicalNicLinkInfo

Struct PhysicalNicLinkInfo 

pub struct PhysicalNicLinkInfo {
    pub speed_mb: i32,
    pub duplex: bool,
}
The PhysicalNicLinkInfo data object describes the link speed and the type of duplex communication.

The link speed indicates the bit rate in megabits per second. The duplex boolean indicates if the link is capable of full-duplex or half-duplex communication.

How to access

  • HostSystem::config.network?.pnic?[*].link_speed?
  • HostSystem::config.network?.pnic?[*].valid_link_specification?[*]
  • HostSystem::config.network?.pnic?[*].spec.link_speed?
  • HostSystem::config.sriov_device_pool?[*]→HostSriovNetworkDevicePoolInfo.pnic?[*].link_speed?
  • HostSystem::config.sriov_device_pool?[*]→HostSriovNetworkDevicePoolInfo.pnic?[*].valid_link_specification?[*]
  • HostNetworkSystem::network_info.pnic?[*].link_speed?
  • HostNetworkSystem::network_info.pnic?[*].valid_link_specification?[*]
  • HostNetworkSystem::network_config.pnic?[*].spec.link_speed?
  • HostNetworkSystem::network_info.pnic?[*].spec.link_speed?
  • HostPciPassthruSystem::sriov_device_pool_info→HostSriovNetworkDevicePoolInfo.pnic?[*].link_speed?

(10 of 29 paths)

Fields

speed_mb: i32

Bit rate on the link.

duplex: bool

Flag to indicate whether or not the link is capable of full-duplex (“true”) or only half-duplex (“false”).