pub struct ProfileApplyProfileElement {
pub apply_profile_: ApplyProfile,
pub key: String,
}Expand description
DataObject which represents an ApplyProfile element.
An ApplyProfile element is an ApplyProfile for a set of host configuration settings which may be instanced. For example, there may be multiple virtual switch instances represented by individual ApplyProfileElement DataObjects.
How to access
HostProfileManager::create_default_profile()→ProfileApplyProfileElement
Fields
apply_profile_: ApplyProfilekey: StringThe linkable identifier.