pub struct ProfileDeferredPolicyOptionParameter {
pub input_path: ProfilePropertyPath,
pub parameter: Option<Vec<KeyAnyValue>>,
}Expand description
The ProfileDeferredPolicyOptionParameter data object contains information about a single deferred parameter for host configuration.
- The Server verifies deferred parameter data when it calls the HostProfile.HostProfile.ExecuteHostProfile method.
- The client supplies deferred parameter data for host configuration when it calls the HostProfileManager.HostProfileManager.ApplyHostConfig_Task method.
- The vCenter Server stores deferred parameter data in answer files (AnswerFile.AnswerFile.userInput).
How to access
HostProfile::execute_host_profile(deferred_param)HostProfileManager::apply_host_config_task(user_input)HostProfile::execute_host_profile().require_input?[*]HostProfileManager::retrieve_answer_file().user_input?[*]HostProfileManager::retrieve_answer_file_for_profile().user_input?[*]HostProfileManager::generate_host_config_task_spec_task(hosts_info).customizations?.user_input?[*]HostProfileManager::retrieve_host_customizations().customizations?.user_input?[*]
(7 of 9 paths)
Fields
input_path: ProfilePropertyPathComplete path to the PolicyOption that defines the parameters.
parameter: Option<Vec<KeyAnyValue>>List that contains values for the policy parameters.
During parameter verification, this property is unspecified if the client has not provided the values for this parameter. See ProfileExecuteResult.ProfileExecuteResult.requireInput.