pub struct ProfileSimpleExpression {
pub profile_expression_: ProfileExpression,
pub expression_type: String,
pub parameter: Option<Vec<KeyAnyValue>>,
}Expand description
DataObject represents a pre-defined expression
How to access
HostProfile::config→HostProfileConfigInfo.default_comply_profile?.expression[*]→ProfileSimpleExpressionHostProfile::config→HostProfileConfigInfo.custom_comply_profile?.expression[*]→ProfileSimpleExpressionHostProfile::config→ClusterProfileConfigInfo.comply_profile?.expression[*]→ProfileSimpleExpressionProfile::config→HostProfileConfigInfo.default_comply_profile?.expression[*]→ProfileSimpleExpressionProfile::config→HostProfileConfigInfo.custom_comply_profile?.expression[*]→ProfileSimpleExpressionProfile::config→ClusterProfileConfigInfo.comply_profile?.expression[*]→ProfileSimpleExpressionClusterProfile::config→HostProfileConfigInfo.default_comply_profile?.expression[*]→ProfileSimpleExpressionClusterProfile::config→HostProfileConfigInfo.custom_comply_profile?.expression[*]→ProfileSimpleExpressionClusterProfile::config→ClusterProfileConfigInfo.comply_profile?.expression[*]→ProfileSimpleExpressionHostProfile::update_host_profile(config)→HostProfileCompleteConfigSpec.custom_comply_profile?.expression[*]→ProfileSimpleExpression
(10 of 25 paths)
Fields
profile_expression_: ProfileExpressionexpression_type: StringType of the simple expression to instantiate.
The expressionType should be derived from the available expressions as listed in the metadata.
parameter: Option<Vec<KeyAnyValue>>The parameters for the expressionType.
The list of parameters needed for a simple expression can be obtained from the metadata.