QueryPointInTimeReplicaParam

Struct QueryPointInTimeReplicaParam 

pub struct QueryPointInTimeReplicaParam {
    pub replica_time_query_param: Option<ReplicaQueryIntervalParam>,
    pub pit_name: Option<String>,
    pub tags: Option<Vec<String>>,
    pub prefer_details: Option<bool>,
}
Describes the search criteria for the PiT query.

If none of the fields is set, or if the number of PiT replicas is too large, VASA provider can return QueryPointInTimeReplicaSummaryResult.

This structure may be used only with operations rendered under /sms.

How to access

  • VasaProvider::query_point_in_time_replica(query_param)

Fields

replica_time_query_param: Option<ReplicaQueryIntervalParam>

Specifies the replica time span that vSphere is interested in.

pit_name: Option<String>

Only the replicas that match the given name are requested.

A regexp according to http://www.w3.org/TR/xmlschema-2/#regexs.

tags: Option<Vec<String>>

Only the replicas with tags that match the given tag(s) are requested.

Each entry may be a regexp according to http://www.w3.org/TR/xmlschema-2/#regexs.

prefer_details: Option<bool>

This field is hint for the preferred type of return results.

It can be either true for QueryPointInTimeReplicaSuccessResult or false for QueryPointInTimeReplicaSummaryResult. If not set, VP may choose the appropriate type, as described in ReplicaQueryIntervalParam.