pub struct QueryReplicationPeerResult {
pub source_domain: Box<dyn FaultDomainIdTrait>,
pub target_domain: Option<Vec<Box<dyn FaultDomainIdTrait>>>,
pub error: Option<Vec<MethodFault>>,
pub warning: Option<Vec<MethodFault>>,
}Expand description
Information about the replication peers of a VASA provider.
This structure may be used only with operations rendered under /sms.
How to access
VasaProvider::query_replication_peer()
Fields
source_domain: Box<dyn FaultDomainIdTrait>Source fault domain id, must correspond to an id from the input.
target_domain: Option<Vec<Box<dyn FaultDomainIdTrait>>>Target fault domains for the given source, fault domain ID’s are globally unique.
There can be one or more target domains for a given source.
error: Option<Vec<MethodFault>>Error must be set when targetDomain field is not set.
warning: Option<Vec<MethodFault>>Optional warning messages.