ReplicationVmProgressInfo

Struct ReplicationVmProgressInfo 

pub struct ReplicationVmProgressInfo {
    pub progress: i32,
    pub bytes_transferred: i64,
    pub bytes_to_transfer: i64,
    pub checksum_total_bytes: Option<i64>,
    pub checksum_compared_bytes: Option<i64>,
}
A set of statistics related to the progress of the current operation (full sync or lwd).

Fields

progress: i32

An estimation of the operation progress as a percentage completed, from 0 to 100.

bytes_transferred: i64

Number of bytes transferred so far.

For sync operations, this value includes (i.e. counts multiple times) areas that were transferred multiple times (due to stopping and continuing the operation, or for some errors).

bytes_to_transfer: i64

The total number of bytes to be transferred.

For lwd operations, this is the total size of the disk images that are transferring. This is known from the start and will not change during a lwd operation.

For sync operations, this is the total size of the blocks that have been found not to match between the primary and secondary (by comparing checksums). It starts from 0 and grows as the checksum operations advance. The value includes (i.e. counts multiple times) areas that will end up being transferred more than once (due to stopping and continuing the operation, or for some errors).

checksum_total_bytes: Option<i64>

The total number of bytes to be checksummed, only present for sync tasks.

This is the total size of all disks.

checksum_compared_bytes: Option<i64>

The total number of bytes that were checksummed, only present for sync tasks.