ResourcePoolResourceUsage

Struct ResourcePoolResourceUsage 

pub struct ResourcePoolResourceUsage {
    pub reservation_used: i64,
    pub reservation_used_for_vm: i64,
    pub unreserved_for_pool: i64,
    pub unreserved_for_vm: i64,
    pub overall_usage: i64,
    pub max_usage: i64,
}
Specifies the resource usage for either memory or CPU.

For CPU the unit is MHz, for memory the unit is bytes.

In the typical case, where a resourcepool is in a consistent state, unreservedForVm will be equal to unreservedForPool. Hence, we can simply say talk about unreserved resources.

If the reservation on the resource pool is not expandable, then the following is true:

           reservation = reservationUsed + unreserved

If the reservation on the resource pool is expandable, then the following is true:

      reservation + parent.unreserved = reservationUsed + unreserved

How to access

  • ResourcePool::runtime.memory
  • ResourcePool::runtime.cpu
  • ResourcePool::summary.runtime.memory
  • ResourcePool::summary.runtime.cpu
  • VirtualApp::runtime.memory
  • VirtualApp::runtime.cpu
  • VirtualApp::summary.runtime.memory
  • VirtualApp::summary.runtime.cpu
  • EnvironmentBrowser::query_config_target().resource_pool?.memory
  • EnvironmentBrowser::query_config_target().resource_pool?.cpu

Fields

reservation_used: i64

Total amount of resources that have been used to satisfy the reservation requirements of all descendants of this resource pool (includes both resource pools and virtual machines).

reservation_used_for_vm: i64

Total amount of resources that have been used to satisfy the reservation requirements of running virtual machines in this resource pool or any of its child resource pools.

unreserved_for_pool: i64

Total amount of resources available to satisfy a reservation for a child resource pool.

In the undercommitted state, this is limited by the capacity at the root node. In the overcommitted case, this could be higher since we do not perform the dynamic capacity checks.

unreserved_for_vm: i64

Total amount of resources available to satisfy a reservation for a child virtual machine.

In general, this should be the same as ResourcePoolResourceUsage.unreservedForPool. However, in the overcommitted case, this is limited by the remaining available resources at the root node.

overall_usage: i64

Deprecated as of vSphere API 6.5. Use ResourcePoolQuickStats.overallCpuUsage and ResourcePoolQuickStats.hostMemoryUsage.

Close to real-time resource usage of all running child virtual machines, including virtual machines in child resource pools.

max_usage: i64

Current upper-bound on usage.

The upper-bound is based on the limit configured on this resource pool, as well as limits configured on any parent resource pool.