RunScriptAction

Struct RunScriptAction 

pub struct RunScriptAction {
    pub script: String,
}
This data object type specifies a script that is triggered by an alarm.

You can use any elements of the ActionParameter enumerated list as part of your script to provide information available at runtime.

How to access

  • ScheduledTask::reconfigure_scheduled_task(spec).action→RunScriptAction
  • ScheduledTaskManager::create_scheduled_task(spec).action→RunScriptAction
  • ScheduledTaskManager::create_object_scheduled_task(spec).action→RunScriptAction
  • Alarm::reconfigure_alarm(spec).action?→AlarmTriggeringAction.action→RunScriptAction
  • AlarmManager::create_alarm(spec).action?→AlarmTriggeringAction.action→RunScriptAction

Fields

script: String

The fully-qualified path to a shell script that runs on the VirtualCenter server as a result of an alarm.