pub struct SamlTokenAuthentication {
pub guest_authentication_: GuestAuthentication,
pub token: String,
pub username: Option<String>,
}Expand description
SAMLTokenAuthentication contains the information necessary to authenticate within a guest using a SAML bearer token.
SAML token authentication relies on a guest alias that associates a guest account with the subject and certificate encoded in a SAML token obtained from the VMware SSO Server.
- Use the GuestAliasManager. GuestAliasManager.AddGuestAlias method to create a guest alias.
- Use a SAMLTokenAuthentication object for the auth parameter to guest operations methods.
After you have created an alias, you can use SAML token authentication for guest operations methods. Do not use SAML token authentication for the GuestAuthManager.AcquireCredentialsInGuest and GuestAuthManager.ReleaseCredentialsInGuest methods.
How to access
GuestAliasManager::add_guest_alias(auth)→SamlTokenAuthenticationGuestAliasManager::list_guest_aliases(auth)→SamlTokenAuthenticationGuestAliasManager::list_guest_mapped_aliases(auth)→SamlTokenAuthenticationGuestAliasManager::remove_guest_alias(auth)→SamlTokenAuthenticationGuestAliasManager::remove_guest_alias_by_cert(auth)→SamlTokenAuthenticationGuestAuthManager::acquire_credentials_in_guest()→SamlTokenAuthenticationGuestAuthManager::acquire_credentials_in_guest(requested_auth)→SamlTokenAuthenticationGuestAuthManager::release_credentials_in_guest(auth)→SamlTokenAuthenticationGuestAuthManager::validate_credentials_in_guest(auth)→SamlTokenAuthenticationGuestFileManager::change_file_attributes_in_guest(auth)→SamlTokenAuthentication
(10 of 33 paths)
Fields
guest_authentication_: GuestAuthenticationtoken: StringThe SAML bearer token.
username: Option<String>This is the guest user to be associated with the authentication.
If none is specified, a guest dependent mapping will decide what user account is applied.