SessionManagerGenericServiceTicket

Struct SessionManagerGenericServiceTicket 

pub struct SessionManagerGenericServiceTicket {
    pub id: String,
    pub host_name: Option<String>,
    pub ssl_thumbprint: Option<String>,
    pub cert_thumbprint_list: Option<Vec<VirtualMachineCertThumbprint>>,
    pub ssl_certificate: Option<String>,
    pub ticket_type: Option<String>,
}
This data object represents a ticket which grants access to some service.

The ticket may be used only once and is valid only for the SessionManagerServiceRequestSpec with which it was acquired. For HTTP service requests (when spec is of type HttpServiceRequestSpec) the returned ticket must be used by setting SessionManagerGenericServiceTicket.id as the value of a special cookie in the HTTP request. For CGI requests the name of this cookie is ‘vmware_cgi_ticket’. The use of the returned ticket for other services is to be defined.

How to access

  • SessionManager::acquire_generic_service_ticket()

Fields

id: String

A unique string identifying the ticket.

host_name: Option<String>

The name of the host that the service is running on

ssl_thumbprint: Option<String>

The expected thumbprint of the SSL certificate of the host.

If it is empty, the host must be authenticated by name.

cert_thumbprint_list: Option<Vec<VirtualMachineCertThumbprint>>

List of expected thumbprints of the certificate of the host to which we are connecting.

The list can be configured on the host to include only certain hash types. The default configuration includes all hash types that are considered secure. See vmware.com for the current security standards.

Since: vSphere API Release 7.0.3.1

ssl_certificate: Option<String>

Supported only by vCenter.

The expected SSL certificate of the host to which we are connecting to, in PEM format. Note: SessionManagerGenericServiceTicket.sslThumbprint and SessionManagerGenericServiceTicket.sslCertificate parameters are mutually exclusive, and should never be used simultaneously.

Since: vSphere API Release 9.0.0.0

ticket_type: Option<String>

Type of the ticket See { @Vim::SessionManager::GenericServiceTicket::TicketType }

Since: vSphere API Release 7.0.2.0