pub struct SolutionsComplianceSpec {
pub desired_state: Option<Vec<SolutionsSolutionConfig>>,
pub solutions: Option<Vec<String>>,
pub hosts: Option<Vec<ManagedObjectReference>>,
pub deployment_units: Option<Vec<String>>,
}Expand description
Specification describing how to calculate compliance of a compute resource against a desired state.
This structure may be used only with operations rendered under /eam.
Fields
desired_state: Option<Vec<SolutionsSolutionConfig>>Desired state to be checked for compliance.
May be incomplete if exact solutions to be checked are provided. Empty desired state means all present solutions must be removed.
solutions: Option<Vec<String>>Specifies exact solutions to be checked for compliance instead of the complete desired state.
hosts: Option<Vec<ManagedObjectReference>>Specifies exact hosts to be checked for compliance of all solutions with SolutionsHostBoundSolutionConfig.
If omitted - the compliance is checked for all hosts in the cluster.
Refers instances of HostSystem.
deployment_units: Option<Vec<String>>Identifiers of the deployment units that to be checked for compliance of all solutions with SolutionsClusterBoundSolutionConfig.
The deployment unit represents a single VM instance deployment.
If omitted - the compliance is checked for all deployment units in the cluster.