pub struct SolutionsHostBoundSolutionConfig {
pub prefer_host_configuration: Option<bool>,
pub networks: Option<Vec<ManagedObjectReference>>,
pub datastores: Option<Vec<ManagedObjectReference>>,
pub vmci: Option<Vec<String>>,
}Expand description
Specifies host-bound solution configuration.
This structure may be used only with operations rendered under /eam.
Fields
prefer_host_configuration: Option<bool>If set to true - default network and datastore configured on host will take precedence over SolutionsHostBoundSolutionConfig.datastores and SolutionsHostBoundSolutionConfig.networks.
networks: Option<Vec<ManagedObjectReference>>networks to satisfy system Virtual Machine network adapter requirements.
If omitted - default configured network on the host will be used.
Refers instances of Network.
datastores: Option<Vec<ManagedObjectReference>>Datastores to be configured as a storage of the VMs.
The first available datastore on the host is used. The collection cannot contain duplicate elements. If omitted - default configured datastore on the host will be used.
Refers instances of Datastore.
vmci: Option<Vec<String>>VMCI to be allowed access from the system Virtual Machine.