StringExpression

Struct StringExpression 

pub struct StringExpression {
    pub negatable_expression_: NegatableExpression,
    pub value: Option<String>,
}
The string type of setting or configuration that may get a negated value.

How to access

  • DistributedVirtualPortgroup::config.default_port_config?.filter_policy?.filter_config?[*]⇒DvsTrafficFilterConfigTrait.traffic_ruleset?.rules?[*].qualifier?[*]→DvsSystemTrafficNetworkRuleQualifier.type_of_system_traffic?
  • VmwareDistributedVirtualSwitch::config.default_port_config.filter_policy?.filter_config?[*]⇒DvsTrafficFilterConfigTrait.traffic_ruleset?.rules?[*].qualifier?[*]→DvsSystemTrafficNetworkRuleQualifier.type_of_system_traffic?
  • DistributedVirtualSwitch::config.default_port_config.filter_policy?.filter_config?[*]⇒DvsTrafficFilterConfigTrait.traffic_ruleset?.rules?[*].qualifier?[*]→DvsSystemTrafficNetworkRuleQualifier.type_of_system_traffic?
  • DistributedVirtualPortgroup::reconfigure_dv_portgroup_task(spec).default_port_config?.filter_policy?.filter_config?[*]⇒DvsTrafficFilterConfigTrait.traffic_ruleset?.rules?[*].qualifier?[*]→DvsSystemTrafficNetworkRuleQualifier.type_of_system_traffic?
  • VmwareDistributedVirtualSwitch::create_dv_portgroup_task(spec).default_port_config?.filter_policy?.filter_config?[*]⇒DvsTrafficFilterConfigTrait.traffic_ruleset?.rules?[*].qualifier?[*]→DvsSystemTrafficNetworkRuleQualifier.type_of_system_traffic?
  • VmwareDistributedVirtualSwitch::add_dv_portgroup_task(spec).default_port_config?.filter_policy?.filter_config?[*]⇒DvsTrafficFilterConfigTrait.traffic_ruleset?.rules?[*].qualifier?[*]→DvsSystemTrafficNetworkRuleQualifier.type_of_system_traffic?
  • VmwareDistributedVirtualSwitch::reconfigure_dvs_task(spec).default_port_config?.filter_policy?.filter_config?[*]⇒DvsTrafficFilterConfigTrait.traffic_ruleset?.rules?[*].qualifier?[*]→DvsSystemTrafficNetworkRuleQualifier.type_of_system_traffic?
  • VmwareDistributedVirtualSwitch::reconfigure_dv_port_task(port).setting?.filter_policy?.filter_config?[*]⇒DvsTrafficFilterConfigTrait.traffic_ruleset?.rules?[*].qualifier?[*]→DvsSystemTrafficNetworkRuleQualifier.type_of_system_traffic?
  • Folder::create_dvs_task(spec).config_spec.default_port_config?.filter_policy?.filter_config?[*]⇒DvsTrafficFilterConfigTrait.traffic_ruleset?.rules?[*].qualifier?[*]→DvsSystemTrafficNetworkRuleQualifier.type_of_system_traffic?
  • StoragePod::create_dvs_task(spec).config_spec.default_port_config?.filter_policy?.filter_config?[*]⇒DvsTrafficFilterConfigTrait.traffic_ruleset?.rules?[*].qualifier?[*]→DvsSystemTrafficNetworkRuleQualifier.type_of_system_traffic?

(10 of 18 paths)

Fields

negatable_expression_: NegatableExpressionvalue: Option<String>

The String value that is either used as it is or negated.