pub struct SyncReplicationGroupSuccessResult {
pub group_operation_result_: GroupOperationResult,
pub time_stamp: String,
pub pit_id: Option<PointInTimeReplicaId>,
pub pit_name: Option<String>,
}Expand description
Result object for a replication group that was successfully synchronized.
This structure may be used only with operations rendered under /sms.
How to access
SmsStorageManager::query_replication_group_info()→SyncReplicationGroupSuccessResultVasaProvider::query_point_in_time_replica()→SyncReplicationGroupSuccessResultVasaProvider::query_replication_group()→SyncReplicationGroupSuccessResult
Fields
group_operation_result_: GroupOperationResulttime_stamp: StringCreation time of the PIT
pit_id: Option<PointInTimeReplicaId>PIT id.
If the VASA provider does not support PIT, this can be left unset.
A PIT created as a result of the syncReplicationGroup
may or may not have the same retention policy as other PITs. A VASA provider
can choose to delete such a PIT after a successful testFailoverStop
pit_name: Option<String>Trait Implementations
Sourceimpl GroupOperationResultTrait for SyncReplicationGroupSuccessResult
impl GroupOperationResultTrait for SyncReplicationGroupSuccessResult
Sourcefn get_group_operation_result(&self) -> &GroupOperationResult
fn get_group_operation_result(&self) -> &GroupOperationResult
Get a reference to the GroupOperationResult parent struct
Sourcefn get_group_operation_result_mut(&mut self) -> &mut GroupOperationResult
fn get_group_operation_result_mut(&mut self) -> &mut GroupOperationResult
Get a mutable reference to the GroupOperationResult parent struct
Sourceimpl VimObjectTrait for SyncReplicationGroupSuccessResult
impl VimObjectTrait for SyncReplicationGroupSuccessResult
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
impl DataObjectTrait for SyncReplicationGroupSuccessResult