TaskScheduler

Struct TaskScheduler 

pub struct TaskScheduler {
    pub active_time: Option<String>,
    pub expire_time: Option<String>,
}
The TaskScheduler data object is the base type for the scheduler objects.

The hierarchy of scheduler objects is as follows:

    TaskScheduler
        *AfterStartupTaskScheduler*
        *OnceTaskScheduler*
        *RecurrentTaskScheduler*
            *HourlyTaskScheduler*
                *DailyTaskScheduler*
                    *WeeklyTaskScheduler*
                    *MonthlyTaskScheduler*
                        *MonthlyByDayTaskScheduler*
                        *MonthlyByWeekdayTaskScheduler*

Use a scheduler object to set the time(s) for task execution. You can use two scheduling modes - single execution or recurring execution:

  • Use the AfterStartupTaskScheduler or the OnceTaskScheduler to schedule a single instance of task execution.
  • Use one of the recurrent task schedulers to schedule hourly, daily, weekly, or monthly task execution.

After you have established the task timing, use the scheduler object for the ScheduledTaskSpec ScheduledTaskSpec.scheduler property value.

How to access

  • ScheduledTask::reconfigure_scheduled_task(spec).scheduler
  • ScheduledTaskManager::create_scheduled_task(spec).scheduler
  • ScheduledTaskManager::create_object_scheduled_task(spec).scheduler

Fields

active_time: Option<String>

The time that the schedule for the task takes effect.

Task activation is distinct from task execution. When you activate a task, its schedule starts, and when the next execution time occurs, the task will run. If you do not set activeTime, the activation time defaults to the time that you create the scheduled task.

expire_time: Option<String>

The time the schedule for the task expires.

If you do not set expireTime, the schedule does not expire.