pub struct ToolsConfigInfoToolsLastInstallInfo {
pub counter: i32,
pub fault: Option<MethodFault>,
}Expand description
Describes status of last tools upgrade attempt
How to access
VirtualMachine::config.tools?.last_install_info?StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.tools?.last_install_info?StoragePod::pod_storage_drs_entry.action_history?[*].action→ClusterClusterInitialPlacementAction.config_spec?.tools?.last_install_info?ClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.tools?.last_install_info?ClusterComputeResource::recommendation.action?[*]→ClusterClusterInitialPlacementAction.config_spec?.tools?.last_install_info?VirtualMachineSnapshot::config.tools?.last_install_info?VirtualMachine::reconfig_vm_task(spec).tools?.last_install_info?VirtualMachine::clone_vm_task(spec).config?.tools?.last_install_info?HostSystem::query_memory_overhead_ex(vm_config_info).tools?.last_install_info?Folder::create_vm_task(config).tools?.last_install_info?
(10 of 26 paths)
Fields
counter: i32Number of attempts that have been made to upgrade the version of tools installed on this virtual machine.
fault: Option<MethodFault>Error that happened, if any, during last attempt to upgrade tools.