pub struct UserProfile {
pub apply_profile_: ApplyProfile,
pub key: String,
}Expand description
The UserProfile data object represents a user.
Use the ApplyProfile.policy list for access to configuration data for the user profile. Use the ApplyProfile.property list for access to subprofile configuration data, if any.
How to access
HostProfile::validation_failure_info.apply_profile?.user_account?[*]HostProfile::config→HostProfileConfigInfo.apply_profile?.user_account?[*]Profile::config→HostProfileConfigInfo.apply_profile?.user_account?[*]ClusterProfile::config→HostProfileConfigInfo.apply_profile?.user_account?[*]HostProfileManager::composite_host_profile_task(to_be_merged).user_account?[*]HostProfileManager::composite_host_profile_task(to_be_replaced_with).user_account?[*]HostProfileManager::composite_host_profile_task(to_be_deleted).user_account?[*]HostProfileManager::composite_host_profile_task(enable_status_to_be_copied).user_account?[*]HostProfileManager::create_default_profile()→UserProfileHostProfile::update_host_profile(config)→HostProfileCompleteConfigSpec.apply_profile?.user_account?[*]
(10 of 24 paths)
Fields
apply_profile_: ApplyProfilekey: StringLinkable identifier.