pub struct UserSearchResult {
pub principal: String,
pub full_name: Option<String>,
pub group: bool,
}Expand description
When searching for users, the search results in some additional information.
This object describes the additional information.
How to access
UserDirectory::retrieve_user_groups()
Fields
principal: StringLogin name of a user or the name of a group.
This key is the user within the searched domain.
full_name: Option<String>Full name of the user found by the search, or the description of a group, if available.
group: boolIf this is true, then the result is a group.
If this is false, then the result is a user.