VMwareDvsLagVlanConfig

Struct VMwareDvsLagVlanConfig 

pub struct VMwareDvsLagVlanConfig {
    pub vlan_id: Option<Vec<NumericRange>>,
}
This class defines the vlan configuration of the Link Aggregation Control Protocol group.

How to access

  • VmwareDistributedVirtualSwitch::config→VMwareDvsConfigInfo.lacp_group_config?[*].vlan?
  • DistributedVirtualSwitch::config→VMwareDvsConfigInfo.lacp_group_config?[*].vlan?
  • VmwareDistributedVirtualSwitch::update_dvs_lacp_group_config_task(lacp_group_spec).lacp_group_config.vlan?

Fields

vlan_id: Option<Vec<NumericRange>>

The VlanId range for the Uplink Ports in the Link Aggregation Control Protocol group.

The valid VlanId range is from 0 to 4094. Overlapping ranges are allowed. If set, this property will override the VLAN configuration of Uplink Ports in the Link Aggregation Control Protocol group. Thus they are no longer inheriting VLAN configuration from their Uplink Port Group. Setting this property would require VMwareDVSPortgroupPolicy.vlanOverrideAllowed of all the Uplink Port Groups to be true, otherwise ConflictingConfiguration fault will be raised.