VVolId

Struct VVolId 

pub struct VVolId {
    pub id: String,
}
Identity of a virtual volume for policy API purposes.

For the sake of brevity, let us use VVolId. This works because the class is defined as a part of the policy package.

WSDL names do not have this feature, but WSDL names are usually prefixed with the package name any way.

This structure may be used only with operations rendered under /sms.

How to access

  • VasaProvider::failover_replication_group_task(failover_param).policy_associations?[*].id→VVolId
  • SmsStorageManager::query_replication_group_info()→FailoverSuccessResult.recovered_device_info?[*].recovered_device_id?→VVolId
  • SmsStorageManager::query_replication_group_info()→FailoverSuccessResult.recovered_device_info?[*].source_device_id→VVolId
  • VasaProvider::query_point_in_time_replica()→FailoverSuccessResult.recovered_device_info?[*].recovered_device_id?→VVolId
  • VasaProvider::query_point_in_time_replica()→FailoverSuccessResult.recovered_device_info?[*].source_device_id→VVolId
  • VasaProvider::query_replication_group()→FailoverSuccessResult.recovered_device_info?[*].recovered_device_id?→VVolId
  • VasaProvider::query_replication_group()→FailoverSuccessResult.recovered_device_info?[*].source_device_id→VVolId
  • SmsStorageManager::query_replication_group_info()→QueryReplicationGroupSuccessResult.rg_info→TargetGroupInfo.devices?[*].source_id→VVolId
  • SmsStorageManager::query_replication_group_info()→QueryReplicationGroupSuccessResult.rg_info→SourceGroupInfo.member_info?[*].device_id→VVolId
  • SmsStorageManager::query_replication_group_info()→QueryReplicationGroupSuccessResult.rg_info→TargetGroupInfo.devices?[*]→RecoveredTargetGroupMemberInfo.recovered_device_id?→VVolId

(10 of 16 paths)

Fields

id: String