pub struct VasaProviderSpec {
pub sms_provider_spec_: SmsProviderSpec,
pub username: String,
pub password: String,
pub url: String,
pub certificate: Option<String>,
}Expand description
VASA(vStorage APIs for Storage Awareness) provider specification
This structure may be used only with operations rendered under /sms.
How to access
SmsStorageManager::register_provider_task(provider_spec)→VasaProviderSpec
Fields
sms_provider_spec_: SmsProviderSpecusername: StringUsername The maximum length of the username is 255 characters.
password: StringPassword The maximum length of the password is 255 characters.
url: StringURL
certificate: Option<String>Certificate