VibNotInstalled

Struct VibNotInstalled 

pub struct VibNotInstalled {
    pub vib_issue_: VibIssue,
}
Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs.

A VIB module is expected to be installed/removed on a host, but it has not been installed/removed.

Typically, a more specific issue (a subclass of this issue) indicates the particular reason why the VIB module operation failed.

This is an active remediable issue. To remediate, vSphere ESX Agent Manager attempts the VIB operation again. In case of unreachable host vSphere ESX Agent Manager will remediate the issue automatically when the host becomes reachable.

This structure may be used only with operations rendered under /eam.

Fields

vib_issue_: VibIssue