VimVsanHostDiskMapInfoEx

Struct VimVsanHostDiskMapInfoEx 

pub struct VimVsanHostDiskMapInfoEx {
    pub mapping: VsanHostDiskMapping,
    pub is_mounted: bool,
    pub unlocked_encrypted: Option<bool>,
    pub is_all_flash: bool,
    pub is_data_efficiency: Option<bool>,
    pub encryption_info: Option<VsanDataEncryptionConfig>,
    pub data_efficiency_config: Option<Box<dyn VsanDataEfficiencyConfigTrait>>,
    pub diskgroup_capability: Option<Vec<String>>,
}
DiskMapInfoEx is used to present information of a Virtual disk group.

It extended vim.vsan.host.DiskMapInfo, added fields all-flash and space efficiency settings on this disk group.

How to access

  • VimClusterVsanVcDiskManagementSystem::query_disk_mappings()
  • VimClusterVsanVcDiskManagementSystem::query_vsan_managed_disks().v_san_disk_map_info?[*]

Fields

mapping: VsanHostDiskMapping

The disk structure of this vSAN disk group.

is_mounted: bool

Whether this disk group is mounted to this host.

For an unmounted disk group, it cannot be used for vSAN I/O on this host. To make unmounted disk group contribute to vSAN I/O, please try vim.host.VsanSystem.InitializeDisks and vim.host.VsanSystem.AddDisks.

unlocked_encrypted: Option<bool>

Whether encryption keys for this disk group are loaded.

If vSAN encryption is on and the encryption keys are not loaded for the disk group, the disk group cannot be used for vSAN I/O on this host.

is_all_flash: bool

Whether this disk group is all flash disk group.

is_data_efficiency: Option<bool>

This field will be True if both vSAN deduplication and compression are enabled, or only compression is enabled on this disk group.

Check VimVsanHostDiskMapInfoEx.dataEfficiencyConfig for more details.

encryption_info: Option<VsanDataEncryptionConfig>

vSAN encryption metadata for the disk group.

data_efficiency_config: Option<Box<dyn VsanDataEfficiencyConfigTrait>>

The data efficiency configuration on this disk group.

dedupEnabled in dataEfficiencyConfig will be set when both vSAN deduplication and compression are enabled. compressionEnabled in dataEfficiencyConfig will be set when compression-only is enabled. dedupEnabled and compressionEnabled will not be set at the same time (i.e. mutually-exclusive True). For more details refer to VsanDataEfficiencyConfig

diskgroup_capability: Option<Vec<String>>

vSAN diskgroup capability.

See VsanDiskgroupCapability_enum for all supported values.

See also VsanDiskgroupCapability_enum.