VirtualController

Struct VirtualController 

pub struct VirtualController {
    pub virtual_device_: VirtualDevice,
    pub bus_number: i32,
    pub device: Option<Vec<i32>>,
}
VirtualController is the base data object type for a device controller in a virtual machine.

VirtualController extends VirtualDevice to inherit general information about a controller (such as name and description), and to allow controllers to appear in a generic list of virtual devices.

How to access

  • VirtualMachine::config.hardware.device?[*]⇒VirtualControllerTrait
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.device_change?[*].device⇒VirtualControllerTrait
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StorageMigrationAction.relocate_spec.device_change?[*].device⇒VirtualControllerTrait
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→PlacementAction.relocate_spec?.device_change?[*].device⇒VirtualControllerTrait
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device⇒VirtualControllerTrait
  • StoragePod::pod_storage_drs_entry.action_history?[*].action→StoragePlacementAction.relocate_spec.device_change?[*].device⇒VirtualControllerTrait
  • ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.device_change?[*].device⇒VirtualControllerTrait
  • ClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.device_change?[*].device⇒VirtualControllerTrait
  • ClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.device_change?[*].device⇒VirtualControllerTrait
  • ClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device⇒VirtualControllerTrait

(10 of 65 paths)

Fields

virtual_device_: VirtualDevicebus_number: i32

Bus number associated with this controller.

device: Option<Vec<i32>>

List of devices currently controlled by this controller.

Each entry contains the VirtualDevice.key property of the corresponding device object.