VirtualDeviceRemoteDeviceBackingInfo

Struct VirtualDeviceRemoteDeviceBackingInfo 

pub struct VirtualDeviceRemoteDeviceBackingInfo {
    pub device_name: String,
    pub use_auto_detect: Option<bool>,
}
VirtualDeviceRemoteDeviceBackingInfo is a data object type for information about a remote device backing used by a device in a virtual machine.

The primary difference between a remote device backing and a local device backing is that the VirtualCenter server cannot provide a list of remote host devices available for this virtual device backing.

How to access

  • VirtualMachine::config.hardware.device?[*].backing?⇒VirtualDeviceRemoteDeviceBackingInfoTrait
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDeviceRemoteDeviceBackingInfoTrait
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StorageMigrationAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDeviceRemoteDeviceBackingInfoTrait
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→PlacementAction.relocate_spec?.disk?[*].disk_backing_info?⇒VirtualDeviceRemoteDeviceBackingInfoTrait
  • StoragePod::pod_storage_drs_entry.action_history?[*].action→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDeviceRemoteDeviceBackingInfoTrait
  • StoragePod::pod_storage_drs_entry.action_history?[*].action→StorageMigrationAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDeviceRemoteDeviceBackingInfoTrait
  • ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDeviceRemoteDeviceBackingInfoTrait
  • ClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDeviceRemoteDeviceBackingInfoTrait
  • ClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.disk?[*].disk_backing_info?⇒VirtualDeviceRemoteDeviceBackingInfoTrait
  • ClusterComputeResource::recommendation.action?[*]→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDeviceRemoteDeviceBackingInfoTrait

(10 of 100 paths)

Fields

device_name: String

The name of the device on the remote system.

use_auto_detect: Option<bool>

Indicates whether the device should be auto detected instead of directly specified.

If this value is set to TRUE, deviceName is ignored.