VirtualDiskFlatVer1BackingInfo

Struct VirtualDiskFlatVer1BackingInfo 

pub struct VirtualDiskFlatVer1BackingInfo {
    pub virtual_device_file_backing_info_: VirtualDeviceFileBackingInfo,
    pub disk_mode: String,
    pub split: Option<bool>,
    pub write_through: Option<bool>,
    pub content_id: Option<String>,
    pub parent: Option<Box<VirtualDiskFlatVer1BackingInfo>>,
}
This data object type contains information about backing a virtual disk by using a virtual disk file on the host, in the flat file format used by GSX Server 2.x.

Flat disks are allocated when created, unlike sparse disks, which grow as needed.

How to access

  • VirtualMachine::config.hardware.device?[*].backing?→VirtualDiskFlatVer1BackingInfo
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?→VirtualDiskFlatVer1BackingInfo
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StorageMigrationAction.relocate_spec.disk?[*].disk_backing_info?→VirtualDiskFlatVer1BackingInfo
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→PlacementAction.relocate_spec?.disk?[*].disk_backing_info?→VirtualDiskFlatVer1BackingInfo
  • StoragePod::pod_storage_drs_entry.action_history?[*].action→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?→VirtualDiskFlatVer1BackingInfo
  • StoragePod::pod_storage_drs_entry.action_history?[*].action→StorageMigrationAction.relocate_spec.disk?[*].disk_backing_info?→VirtualDiskFlatVer1BackingInfo
  • ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?→VirtualDiskFlatVer1BackingInfo
  • ClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.disk?[*].disk_backing_info?→VirtualDiskFlatVer1BackingInfo
  • ClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.disk?[*].disk_backing_info?→VirtualDiskFlatVer1BackingInfo
  • ClusterComputeResource::recommendation.action?[*]→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?→VirtualDiskFlatVer1BackingInfo

(10 of 100 paths)

Fields

virtual_device_file_backing_info_: VirtualDeviceFileBackingInfodisk_mode: String

The disk persistence mode.

Valid modes are:

  • persistent
  • nonpersistent
  • undoable

See also VirtualDiskMode_enum.

split: Option<bool>

Flag to indicate the type of virtual disk file: split or monolithic.

If true, the virtual disk is stored in multiple files, each 2GB.

write_through: Option<bool>

Flag to indicate whether writes should go directly to the file system or should be buffered.

content_id: Option<String>

Content ID of the virtual disk file, if available.

A content ID indicates the logical contents of the disk backing and its parents.

This property is only guaranteed to be up to date if this disk backing is not currently being written to by any virtual machine.

The only supported operation is comparing if two content IDs are equal or not. The guarantee provided by the content ID is that if two disk backings have the same content ID and are not currently being written to, then reads issued from the guest operating system to those disk backings will return the same data.

parent: Option<Box<VirtualDiskFlatVer1BackingInfo>>

The parent of this virtual disk file, if this is a delta disk backing.

This will be unset if this is not a delta disk backing.

A delta disk backing is a way to preserve a virtual disk backing at some point in time. A delta disk backing is a file backing which in turn points to the original virtual disk backing (the parent). After a delta disk backing is added, all writes go to the delta disk backing. All reads first try the delta disk backing and then try the parent backing if needed.

A delta disk backing can be added to a disk either implicitly during snapshot operations, or explicitly during create or reconfigure of the virtual machine.

Note that the type of the backing is consistent throughout the chain; any new delta disk backing which is added is of the same type as the original disk . Also note that since the parent backing is not being written to, it is possible that the parent backing may be shared among multiple disks belonging to multiple virtual machines.

During virtual machine creation and reconfiguration this property is only checked if the VirtualDeviceConfigSpec specifies an add operation with a create file operation. In this case, a new delta disk backing is created which points to the parent disk backing. Only the fileName property is important; all other properties will be ignored. The parent backing is assumed to exist and will not be recursively created.

This property may only be set if deltaDiskBackingsSupported is true.