VirtualDiskRawDiskVer2BackingInfo

Struct VirtualDiskRawDiskVer2BackingInfo 

pub struct VirtualDiskRawDiskVer2BackingInfo {
    pub virtual_device_device_backing_info_: VirtualDeviceDeviceBackingInfo,
    pub descriptor_file_name: String,
    pub uuid: Option<String>,
    pub change_id: Option<String>,
    pub sharing: Option<String>,
}
This data object type contains information about backing a virtual disk by using a host device, as used by VMware Server.

How to access

  • VirtualMachine::config.hardware.device?[*].backing?⇒VirtualDiskRawDiskVer2BackingInfoTrait
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDiskRawDiskVer2BackingInfoTrait
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StorageMigrationAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDiskRawDiskVer2BackingInfoTrait
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→PlacementAction.relocate_spec?.disk?[*].disk_backing_info?⇒VirtualDiskRawDiskVer2BackingInfoTrait
  • StoragePod::pod_storage_drs_entry.action_history?[*].action→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDiskRawDiskVer2BackingInfoTrait
  • StoragePod::pod_storage_drs_entry.action_history?[*].action→StorageMigrationAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDiskRawDiskVer2BackingInfoTrait
  • ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDiskRawDiskVer2BackingInfoTrait
  • ClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDiskRawDiskVer2BackingInfoTrait
  • ClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.disk?[*].disk_backing_info?⇒VirtualDiskRawDiskVer2BackingInfoTrait
  • ClusterComputeResource::recommendation.action?[*]→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?⇒VirtualDiskRawDiskVer2BackingInfoTrait

(10 of 100 paths)

Fields

virtual_device_device_backing_info_: VirtualDeviceDeviceBackingInfodescriptor_file_name: String

The name of the raw disk descriptor file.

uuid: Option<String>

Disk UUID for the virtual disk, if available.

change_id: Option<String>

The change ID of the virtual disk for the corresponding snapshot or virtual machine.

This can be used to track incremental changes to a virtual disk. See VirtualMachine.QueryChangedDiskAreas.

sharing: Option<String>

The sharing mode of the virtual disk.

See VirtualDiskSharing_enum. The default value is no sharing.