VirtualMachineConnection

Struct VirtualMachineConnection 

pub struct VirtualMachineConnection {
    pub label: String,
    pub client: String,
    pub user_name: String,
}
The VirtualMachineConnection object describes a connection to the virtual machine.

Since: vSphere API Release 7.0.1.0

How to access

  • VirtualMachine::drop_connections(list_of_connections)
  • VirtualMachine::query_connections()

Fields

label: String

The unique identifier associated with the connection.

The label is a UTF-8 string which specifies a unique identifier for a connection.

client: String

The client identifer.

This identifier is a UTF-8 string which is semantically meaningful for the connection. Examples of the client identifier are an IP address (V4 or V6) with or without a port specification, a machine name that requires a DNS lookup, or any other network oriented identification scheme.

user_name: String

The name of the user authorizing the connection.

This is used for auditing.