VirtualMachineDefinedProfileSpec

Struct VirtualMachineDefinedProfileSpec 

pub struct VirtualMachineDefinedProfileSpec {
    pub profile_id: String,
    pub replication_spec: Option<ReplicationSpec>,
    pub profile_data: Option<VirtualMachineProfileRawData>,
    pub profile_params: Option<Vec<KeyValue>>,
}
Policy specification that carries a pre-defined Storage Policy to be associated with a Virtual Machine Home or a Virtual Disk object.

Such a pre-defined policy can be either be vSphere Storage Administrator defined or may come from a set of pre-defined policies from Storage Vendor.

Neither the association nor the policy data is persisted in Virtual Machine configuration. This data is managed by the an extension of Virtual Center (Storage Policy Based Management).

How to access

  • ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.perfsvc_config?.profile?→VirtualMachineDefinedProfileSpec
  • ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.iscsi_config?→VsanIscsiTargetServiceSpec.home_object_storage_policy?→VirtualMachineDefinedProfileSpec
  • ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.profile?[*]→VirtualMachineDefinedProfileSpec
  • ClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.profile?[*]→VirtualMachineDefinedProfileSpec
  • ClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.profile?[*]→VirtualMachineDefinedProfileSpec
  • ClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.vm_profile?[*]→VirtualMachineDefinedProfileSpec
  • ClusterComputeResource::recommendation.action?[*]→StoragePlacementAction.relocate_spec.profile?[*]→VirtualMachineDefinedProfileSpec
  • Folder::create_vm_task(config).vm_profile?[*]→VirtualMachineDefinedProfileSpec
  • Folder::create_vm_task(config).device_change?[*].profile?[*]→VirtualMachineDefinedProfileSpec
  • Folder::create_cluster_ex(spec).vsan_config?→VsanConfigInfoEx.perfsvc_config?.profile?→VirtualMachineDefinedProfileSpec

(10 of 100 paths)

Fields

profile_id: String

Storage Policy Profile identification - Should be pbm.profileId but for implementation reasons, could not be.

replication_spec: Option<ReplicationSpec>

Specification containing replication related parameters, sent to the Replication Data Service provider.

profile_data: Option<VirtualMachineProfileRawData>

Profile data sent to the Storage Backend by vSphere.

This data is provided by the SPBM component of the vSphere platform. This field should not be set by Virtual Center users.

profile_params: Option<Vec<KeyValue>>

Parameterized Storage Profiles Extra configuration that is not expressed as a capability in the Profile definition.