pub struct VirtualMachineFileLayoutSnapshotLayout {
pub key: ManagedObjectReference,
pub snapshot_file: Vec<String>,
}Expand description
Enumerates the set of files that make up a snapshot or redo-point
How to access
VirtualMachine::layout.snapshot?[*]
Fields
key: ManagedObjectReferenceIdentification of the snapshot
Refers instance of VirtualMachineSnapshot.
snapshot_file: Vec<String>A list of files that make up the snapshot state.
These are relative paths from the snapshotDirectory. A slash is always used as a separator.