VirtualMachineGuestIntegrityInfo

Struct VirtualMachineGuestIntegrityInfo 

pub struct VirtualMachineGuestIntegrityInfo {
    pub enabled: Option<bool>,
}
This data object describes the guest integrity platform configuration of this virtual machine.

How to access

  • VirtualMachine::config.guest_integrity_info?
  • VirtualMachineSnapshot::config.guest_integrity_info?
  • HostSystem::query_memory_overhead_ex(vm_config_info).guest_integrity_info?

Fields

enabled: Option<bool>

Flag to indicate whether guest integrity platform feature is enabled for this virtual machine.

Guest integrity adds capabilities in the virtual platform to detect attacks on the guest OS kernel