pub struct VirtualMachineMksTicket {
pub ticket: String,
pub cfg_file: String,
pub host: Option<String>,
pub port: Option<i32>,
pub ssl_thumbprint: Option<String>,
}Expand description
Deprecated as of vSphere API 4.1, use VirtualMachineTicket instead.
This data object contains the information needed to establish an MKS (mouse-keyboard-screen) connection to a running virtual machine.
How to access
VirtualMachine::acquire_mks_ticket()
Fields
ticket: StringThe ticket name.
This is used as the username and password for the MKS connection.
cfg_file: StringThe name of the configuration file for the virtual machine.
host: Option<String>The host with which to establish a connection.
If the host is not specified, it is assumed that the requesting entity knows the appropriate host with which to connect.
port: Option<i32>The port number to use.
If the port is not specified, it is assumed that the requesting entity knows the appropriate port to use when making a new connection.
ssl_thumbprint: Option<String>The expected thumbprint of the SSL cert of the host to which we are connecting.