VirtualMachineRuntimeInfoDasProtectionState

Struct VirtualMachineRuntimeInfoDasProtectionState 

pub struct VirtualMachineRuntimeInfoDasProtectionState {
    pub das_protected: bool,
}
The VirtualMachineRuntimeInfoDasProtectionState object describes the vSphere HA protection state of a virtual machine (VM).

How to access

  • VirtualMachine::runtime.das_vm_protection?
  • VirtualMachine::summary.runtime.das_vm_protection?
  • HostSystem::query_host_connection_info().vm?[*].runtime.das_vm_protection?
  • Datacenter::query_connection_info().vm?[*].runtime.das_vm_protection?
  • Datacenter::query_connection_info_via_spec().vm?[*].runtime.das_vm_protection?
  • EnvironmentBrowser::query_config_target().usb?[*].summary?.runtime.das_vm_protection?

Fields

das_protected: bool

Whether vSphere HA is protecting a virtual machine (VM).

If a VM is protected, vSphere HA will enforce any availability features that have been enabled for this VM. For example, if the VM is running on a host that fails and the VM is configured to be restarted on a failure, then vSphere HA will attempt to restart the VM on another host. Similarly, if you enable VM/Application Health Monitoring for this VM, vSphere HA will monitor the heartbeats of the VM and reset the VM when needed, as dictated by the configured policy settings.