VirtualMachineVmciDevice

Struct VirtualMachineVmciDevice 

pub struct VirtualMachineVmciDevice {
    pub virtual_device_: VirtualDevice,
    pub id: Option<i64>,
    pub allow_unrestricted_communication: Option<bool>,
    pub filter_enable: Option<bool>,
    pub filter_info: Option<VirtualMachineVmciDeviceFilterInfo>,
}
The VirtualMachineVMCIDevice data object represents a virtual communication device that supports the VMCI (Virtual Machine Communication Interface).

Each virtual machine has a VMCI device that handles interprocess socket-based communication. VMCI device information is available in the virtual machine hardware device list (VirtualMachine.VirtualMachine.config.VirtualMachineConfigInfo.hardware.VirtualHardware.device[]).

An application running on a virtual machine uses the VMCI Sockets API for communication with other virtual machines on the same host (communication between virtual machines is not supported on vSphere 5.1 and later platforms as described for VirtualVMCIDevice.VirtualMachineVMCIDevice.allowUnrestrictedCommunication), or for communication with the host. For information about using the vSphere VMCI Sockets API, see the VMCI Sockets Programming Guide.

How to access

  • VirtualMachine::config.hardware.device?[*]→VirtualMachineVmciDevice
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.device_change?[*].device→VirtualMachineVmciDevice
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StorageMigrationAction.relocate_spec.device_change?[*].device→VirtualMachineVmciDevice
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→PlacementAction.relocate_spec?.device_change?[*].device→VirtualMachineVmciDevice
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device→VirtualMachineVmciDevice
  • StoragePod::pod_storage_drs_entry.action_history?[*].action→StoragePlacementAction.relocate_spec.device_change?[*].device→VirtualMachineVmciDevice
  • ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.device_change?[*].device→VirtualMachineVmciDevice
  • ClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.device_change?[*].device→VirtualMachineVmciDevice
  • ClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.device_change?[*].device→VirtualMachineVmciDevice
  • ClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device→VirtualMachineVmciDevice

(10 of 65 paths)

Fields

virtual_device_: VirtualDeviceid: Option<i64>

Unique identifier for VMCI socket access to this virtual machine.

Use this value to identify this virtual machine in calls to the VMCI Sockets API. Applications running on other virtual machines on this host will use this value to connect to this virtual machine. You can cast this value to a 32-bit unsigned integer.

The vSphere Server sets this value when a virtual machine powers on. The Server may change this value after power operations such as vMotion or restoring a virtual machine from a snapshot. If you have saved a VMCI device identifier, check to see if the value is still valid after power operations.

allow_unrestricted_communication: Option<bool>

Deprecated as of vSphere API 5.1. On vSphere 5.1 and later platforms, the VMCI device does not support communication with other virtual machines. Therefore, this property has no effect on these platforms.

Determines the extent of VMCI communication with this virtual machine.

Set this property to true to allow VMCI communication with all virtual machines on the host and with trusted services. Set this property to false to allow VMCI communication only with trusted services such as the hypervisor on the host.

If unset, communication is restricted to trusted services only.

filter_enable: Option<bool>

Determines if filtering of VMCI communication is enabled for this virtual machine.

Set this property to enable or disable filter rules as specified in VirtualMachineVMCIDevice.filterInfo.

filter_info: Option<VirtualMachineVmciDeviceFilterInfo>

Specify a VirtualMachineVMCIDeviceFilterInfo data object that controls the extent of VMCI communication with this virtual machine.