VirtualMachineVmciDeviceOption

Struct VirtualMachineVmciDeviceOption 

pub struct VirtualMachineVmciDeviceOption {
    pub virtual_device_option_: VirtualDeviceOption,
    pub allow_unrestricted_communication: BoolOption,
    pub filter_spec_option: Option<VirtualMachineVmciDeviceOptionFilterSpecOption>,
    pub filter_supported: Option<BoolOption>,
}
The VirtualMachineVMCIDeviceOption data object contains the options for the virtual VMCI device (VirtualMachineVMCIDevice).

How to access

  • EnvironmentBrowser::query_config_option().hardware_options.virtual_device_option[*]→VirtualMachineVmciDeviceOption
  • EnvironmentBrowser::query_config_option_ex().hardware_options.virtual_device_option[*]→VirtualMachineVmciDeviceOption

Fields

virtual_device_option_: VirtualDeviceOptionallow_unrestricted_communication: BoolOption

Indicates support for VMCI communication and specifies the default operation.

If BoolOption.defaultValue is set to true, the virtual machine can participate in VMCI communication with all other virtual machines on the host. Otherwise, VMCI communication will be restricted to trusted services such as the hypervisor on the host. On vSphere 5.1 and later platforms, the VMCI device does not support communication with other virtual machines. Therefore, this property has no effect on these platforms.

filter_spec_option: Option<VirtualMachineVmciDeviceOptionFilterSpecOption>

Filter specification options.

filter_supported: Option<BoolOption>

Indicates support for VMCI firewall filters and specifies the default operation.

If BoolOption.supported is set to true, then firewall filtering can be used for this virtual machine to allow or deny traffic over VMCI.