pub struct VirtualPciPassthrough {
pub virtual_device_: VirtualDevice,
}Expand description
The VirtualPCIPassthrough data object type contains information about a PCI device on the virtual machine that is being backed by a generic PCI device on the host via passthrough.
How to access
VirtualMachine::config.hardware.device?[*]→VirtualPciPassthroughStoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.device_change?[*].device→VirtualPciPassthroughStoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StorageMigrationAction.relocate_spec.device_change?[*].device→VirtualPciPassthroughStoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→PlacementAction.relocate_spec?.device_change?[*].device→VirtualPciPassthroughStoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device→VirtualPciPassthroughStoragePod::pod_storage_drs_entry.action_history?[*].action→StoragePlacementAction.relocate_spec.device_change?[*].device→VirtualPciPassthroughClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.device_change?[*].device→VirtualPciPassthroughClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.device_change?[*].device→VirtualPciPassthroughClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.device_change?[*].device→VirtualPciPassthroughClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device→VirtualPciPassthrough
(10 of 65 paths)
Fields
virtual_device_: VirtualDeviceTrait Implementations
Sourceimpl Debug for VirtualPciPassthrough
impl Debug for VirtualPciPassthrough
Sourceimpl Deref for VirtualPciPassthrough
impl Deref for VirtualPciPassthrough
Sourceimpl DerefMut for VirtualPciPassthrough
impl DerefMut for VirtualPciPassthrough
Sourceimpl Deserialize for VirtualPciPassthrough
impl Deserialize for VirtualPciPassthrough
Sourceimpl VimObjectTrait for VirtualPciPassthrough
impl VimObjectTrait for VirtualPciPassthrough
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
Sourceimpl VirtualDeviceTrait for VirtualPciPassthrough
impl VirtualDeviceTrait for VirtualPciPassthrough
Sourcefn get_virtual_device(&self) -> &VirtualDevice
fn get_virtual_device(&self) -> &VirtualDevice
Get a reference to the VirtualDevice parent struct
Sourcefn get_virtual_device_mut(&mut self) -> &mut VirtualDevice
fn get_virtual_device_mut(&mut self) -> &mut VirtualDevice
Get a mutable reference to the VirtualDevice parent struct
impl DataObjectTrait for VirtualPciPassthrough