pub struct VirtualPciPassthroughDeviceBackingInfo {
pub virtual_device_device_backing_info_: VirtualDeviceDeviceBackingInfo,
pub id: String,
pub device_id: String,
pub system_id: String,
pub vendor_id: i16,
}Expand description
The VirtualPCIPassthrough.DeviceBackingInfo data object type contains information about the backing that maps the virtual device onto a physical device.
How to access
ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?→VirtualPciPassthroughDeviceBackingInfoClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.disk?[*].disk_backing_info?→VirtualPciPassthroughDeviceBackingInfoClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?→VirtualSriovEthernetCardSriovBackingInfo.physical_function_backing?ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?→VirtualSriovEthernetCardSriovBackingInfo.virtual_function_backing?ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.device_change?[*].device.backing?→VirtualPciPassthroughDeviceBackingInfo
(5 of 100 paths)
Fields
virtual_device_device_backing_info_: VirtualDeviceDeviceBackingInfoid: StringThe name ID of this PCI, composed of “bus:slot.function”.
device_id: StringThe device ID of this PCI.
You must use the device ID retrieved from the vSphere host (HostPciDevice.deviceId), converted as is to a string.
system_id: StringThe ID of the system the PCI device is attached to.
vendor_id: i16The vendor ID for this PCI device.
You must use the vendor ID retrieved from the vSphere host (HostPciDevice.vendorId).