VirtualPciPassthroughDvxBackingInfo

Struct VirtualPciPassthroughDvxBackingInfo 

pub struct VirtualPciPassthroughDvxBackingInfo {
    pub device_class: Option<String>,
    pub config_params: Option<Vec<Box<dyn OptionValueTrait>>>,
}
DVX Device specific information.

Since: vSphere API Release 8.0.0.1

How to access

  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?→VirtualPciPassthroughDvxBackingInfo
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StorageMigrationAction.relocate_spec.disk?[*].disk_backing_info?→VirtualPciPassthroughDvxBackingInfo
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→PlacementAction.relocate_spec?.disk?[*].disk_backing_info?→VirtualPciPassthroughDvxBackingInfo
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.device_change?[*].device→VirtualSriovEthernetCard.dvx_backing_info?
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.device_change?[*].device.backing?→VirtualPciPassthroughDvxBackingInfo
  • ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?→VirtualPciPassthroughDvxBackingInfo
  • ClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.disk?[*].disk_backing_info?→VirtualPciPassthroughDvxBackingInfo
  • ClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.disk?[*].disk_backing_info?→VirtualPciPassthroughDvxBackingInfo
  • ClusterComputeResource::recommendation.action?[*]→StoragePlacementAction.relocate_spec.disk?[*].disk_backing_info?→VirtualPciPassthroughDvxBackingInfo
  • ClusterComputeResource::recommendation.action?[*]→StorageMigrationAction.relocate_spec.disk?[*].disk_backing_info?→VirtualPciPassthroughDvxBackingInfo

(10 of 100 paths)

Fields

device_class: Option<String>

The device class that backs this DVX device.

During add operations, this value must be a non-empty string. During edit operations, if this value is not set or is an empty string, the current device class remains unchanged.

config_params: Option<Vec<Box<dyn OptionValueTrait>>>

The configuration parameters for this device class.

All required configuration parameters must be provided for both add and edit operations. The provided configuration parameters replace the previous ones. In particular, passing an empty array will unset all existing configuration parameters.