VirtualSioControllerOption

Struct VirtualSioControllerOption 

pub struct VirtualSioControllerOption {
    pub virtual_controller_option_: VirtualControllerOption,
    pub num_floppy_drives: IntOption,
    pub num_serial_ports: IntOption,
    pub num_parallel_ports: IntOption,
}
The VirtualSIOControllerOption data object type contains the options for a virtual Super IO Controller.

How to access

  • EnvironmentBrowser::query_config_option().hardware_options.virtual_device_option[*]→VirtualSioControllerOption
  • EnvironmentBrowser::query_config_option_ex().hardware_options.virtual_device_option[*]→VirtualSioControllerOption

Fields

virtual_controller_option_: VirtualControllerOptionnum_floppy_drives: IntOption

Three properties (numFloppyDrives.min, numFloppyDrives.max, and numFloppyDrives.defaultValue) define the minimum, maximum, and default number of floppy drives you can have at any given time in the Super IO Controller.

This is further constrained by the number of available slots in the Super IO Controller.

num_serial_ports: IntOption

Three properties (numSerialPorts.min, numSerialPorts.max, and numSerialPorts.defaultValue) define the minimum, maximum, and default number of serial ports you can have at any given time in the Super IO Controller.

This is further constrained by the number of available slots in the Super IO Controller.

num_parallel_ports: IntOption

Three properties (numParallelPorts.min, numParallelPorts.max, and numParallelPorts.defaultValue) define the minimum, maximum, and default number of parallel ports you can have at any given time in the Super IO controller.

This is further constrained by the number of available slots in the Super IO Controller.