VirtualSriovEthernetCard

Struct VirtualSriovEthernetCard 

pub struct VirtualSriovEthernetCard {
    pub virtual_ethernet_card_: VirtualEthernetCard,
    pub allow_guest_os_mtu_change: Option<bool>,
    pub sriov_backing: Option<VirtualSriovEthernetCardSriovBackingInfo>,
    pub dvx_backing_info: Option<VirtualPciPassthroughDvxBackingInfo>,
}
The VirtualSriovEthernetCard data object defines the properties of a SR-IOV enabled Ethernet card attached to a virtual machine.

How to access

  • VirtualMachine::config.hardware.device?[*]→VirtualSriovEthernetCard
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.device_change?[*].device→VirtualSriovEthernetCard
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StorageMigrationAction.relocate_spec.device_change?[*].device→VirtualSriovEthernetCard
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→PlacementAction.relocate_spec?.device_change?[*].device→VirtualSriovEthernetCard
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device→VirtualSriovEthernetCard
  • StoragePod::pod_storage_drs_entry.action_history?[*].action→StoragePlacementAction.relocate_spec.device_change?[*].device→VirtualSriovEthernetCard
  • ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.device_change?[*].device→VirtualSriovEthernetCard
  • ClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.device_change?[*].device→VirtualSriovEthernetCard
  • ClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.device_change?[*].device→VirtualSriovEthernetCard
  • ClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device→VirtualSriovEthernetCard

(10 of 65 paths)

Fields

virtual_ethernet_card_: VirtualEthernetCardallow_guest_os_mtu_change: Option<bool>

Indicates whether MTU can be changed from guest OS.

sriov_backing: Option<VirtualSriovEthernetCardSriovBackingInfo>

Information about SR-IOV passthrough backing of this VirtualSriovEthernetCard.

During an edit operation, if this value is unset, no changes to the SR-IOV backing will be made. During an add operation, if this is unset, an automatic physical function assignment scheme as described above will be used. This field is ignored and must be unset if this VirtualSriovEthernetCard is a DVX device, in which case the dvxBackingInfo field is set. In other words, sriovBacking and dvxBackingInfo cannot both be set at any time.

dvx_backing_info: Option<VirtualPciPassthroughDvxBackingInfo>

Information about DVX backing of this VirtualSriovEthernetCard.

This field is set if and only if this VirtualSriovEthernetCard is a DVX device.

Since: vSphere API Release 8.0.0.1