VirtualTpm

Struct VirtualTpm 

pub struct VirtualTpm {
    pub virtual_device_: VirtualDevice,
    pub endorsement_key_certificate_signing_request: Option<Vec<Vec<u8>>>,
    pub endorsement_key_certificate: Option<Vec<Vec<u8>>>,
}
This data object type represents a TPM 2.0 module in a virtual machine.

How to access

  • VirtualMachine::config.hardware.device?[*]→VirtualTpm
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.device_change?[*].device→VirtualTpm
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StorageMigrationAction.relocate_spec.device_change?[*].device→VirtualTpm
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→PlacementAction.relocate_spec?.device_change?[*].device→VirtualTpm
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device→VirtualTpm
  • StoragePod::pod_storage_drs_entry.action_history?[*].action→StoragePlacementAction.relocate_spec.device_change?[*].device→VirtualTpm
  • ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.device_change?[*].device→VirtualTpm
  • ClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.device_change?[*].device→VirtualTpm
  • ClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.device_change?[*].device→VirtualTpm
  • ClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device→VirtualTpm

(10 of 65 paths)

Fields

virtual_device_: VirtualDeviceendorsement_key_certificate_signing_request: Option<Vec<Vec<u8>>>

Endorsement Key Certificate Signing Request in DER format.

There may be more than one - one for RSA 2048, one for ECC NIST P256, and any number of other signing requests for other algorithms.

endorsement_key_certificate: Option<Vec<Vec<u8>>>

Endorsement Key Certificate in DER format.

There may be more than one. Indices in this array do not match indices in VirtualTPM.endorsementKeyCertificateSigningRequest array, entries must be matched by comparing fields in DER data between certificate signing requests and certificates.