VmConfigSpec

Struct VmConfigSpec 

pub struct VmConfigSpec {
    pub product: Option<Vec<VAppProductSpec>>,
    pub property: Option<Vec<VAppPropertySpec>>,
    pub ip_assignment: Option<VAppIpAssignmentInfo>,
    pub eula: Option<Vec<String>>,
    pub ovf_section: Option<Vec<VAppOvfSectionSpec>>,
    pub ovf_environment_transport: Option<Vec<String>>,
    pub install_boot_required: Option<bool>,
    pub install_boot_stop_delay: Option<i32>,
}
vApp related configuration of a VM.

How to access

  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.v_app_config?
  • StoragePod::pod_storage_drs_entry.action_history?[*].action→ClusterClusterInitialPlacementAction.config_spec?.v_app_config?
  • ClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.v_app_config?
  • ClusterComputeResource::recommendation.action?[*]→ClusterClusterInitialPlacementAction.config_spec?.v_app_config?
  • VirtualMachine::reconfig_vm_task(spec).v_app_config?
  • VirtualMachine::clone_vm_task(spec).config?.v_app_config?
  • Folder::create_vm_task(config).v_app_config?
  • ResourcePool::create_child_vm_task(config).v_app_config?
  • ResourcePool::import_v_app(spec)→VirtualMachineImportSpec.config_spec.v_app_config?
  • Datastore::datastore_enter_maintenance_mode().recommendations?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.v_app_config?

(10 of 23 paths)

Fields

product: Option<Vec<VAppProductSpec>>

Information about the product.

Reconfigure privilege: VApp.ApplicationConfig

property: Option<Vec<VAppPropertySpec>>

List of properties.

Adding and editing properties requires various privileges depending on which fields are affected. See VAppPropertyInfo for details.

Deleting properties requires the privilege VApp.ApplicationConfig.

ip_assignment: Option<VAppIpAssignmentInfo>

IP assignment policy and DHCP support configuration.

Reconfigure privilege: See VAppIPAssignmentInfo

eula: Option<Vec<String>>

End User Liceses Agreements.

If this list is set, it replaces all exiting licenses. An empty list will not make any changes to installed licenses. A list with a single element {“”} will remove all licenses and leave an empty list.

Reconfigure privilege: VApp.ApplicationConfig

ovf_section: Option<Vec<VAppOvfSectionSpec>>

List of uninterpreted OVF meta-data sections.

Reconfigure privilege: VApp.ApplicationConfig

ovf_environment_transport: Option<Vec<String>>

List the transports to use for properties.

Supported values are: iso and com.vmware.guestInfo.

If this list is set, it replaces all exiting entries. An empty list will not make any changes. A list with a single element {“”} will clear the list of transports.

Reconfigure privilege: VApp.ApplicationConfig

install_boot_required: Option<bool>

If this is on a VirtualMachine object, it specifies whether the VM needs an initial boot before the deployment is complete.

If this is on a vApp object, it indicates than one or more VMs needs an initial reboot. This flag is automatically reset once the reboot has happened.

Reconfigure privilege: VApp.ApplicationConfig

install_boot_stop_delay: Option<i32>

Specifies the delay in seconds to wait for the VM to power off after the initial boot (used only if installBootRequired is true).

A value of 0 means wait forever.

Reconfigure privilege: VApp.ApplicationConfig