pub struct VmDiskFileQueryFlags {
pub disk_type: bool,
pub capacity_kb: bool,
pub hardware_version: bool,
pub controller_type: Option<bool>,
pub disk_extents: Option<bool>,
pub thin: Option<bool>,
pub encryption: Option<bool>,
pub sector_format: Option<bool>,
}Expand description
Details for the virtual disk primary file.
How to access
HostDatastoreBrowser::supported_type→VmDiskFileQuery.details?HostDatastoreBrowser::search_datastore_task(search_spec).query?[*]→VmDiskFileQuery.details?HostDatastoreBrowser::search_datastore_sub_folders_task(search_spec).query?[*]→VmDiskFileQuery.details?
Fields
disk_type: boolThe flag to indicate whether the type of the physical disk backing the virtual disk is returned.
capacity_kb: boolThe flag to indicate whether the capacity of the virtual disk from the point of view of a virtual machine is returned.
hardware_version: boolThe flag to indicate whether the hardware version of the virtual disk file is returned.
controller_type: Option<bool>Deprecated as of vSphere API 5.0, this property is no longer relevant and should not be used. With the current state of emulation, we don’t care about the adapter type a disk is connected to, as disks may be shuffled around. For example, a disk may be unplugged from a buslogic controller and plugged into an lsilogic controller.
The flag to indicate whether or not the controller type of the virtual disk file is returned.
disk_extents: Option<bool>The flag to indicate whether or not the disk extents of the virtual disk are returned.
thin: Option<bool>The flag to indicate whether the thin-ness of the disk is returned.
encryption: Option<bool>The flag to indicate whether the encryption information of the virtual disk is returned.
sector_format: Option<bool>The flag to indicate whether or not the sector format of the virtual disk is returned.
Since: vSphere API Release 9.0.0.0