VmHookTimedout

Struct VmHookTimedout 

pub struct VmHookTimedout {
    pub vm_issue_: VmIssue,
}
The VM hook remediation timed out.

In order to remediate the issue: Resolve the issue via vLCM System VMs API and process the hook within the timeout configured for the System VM Solution this issue’s VM belongs to.

This structure may be used only with operations rendered under /eam.

Since: vEAM API 9.0

Fields

vm_issue_: VmIssue