pub struct VmSuspended {
pub vm_issue_: VmIssue,
}Expand description
An agent virtual machine is expected to be powered on, but the agent virtual machine is suspended.
This is an active remediable issue. To remediate, vSphere ESX Agent Manager powers on the agent virtual machine.
This structure may be used only with operations rendered under /eam.
Fields
vm_issue_: VmIssueTrait Implementations
Sourceimpl AgencyIssueTrait for VmSuspended
impl AgencyIssueTrait for VmSuspended
Sourcefn get_agency_issue(&self) -> &AgencyIssue
fn get_agency_issue(&self) -> &AgencyIssue
Get a reference to the AgencyIssue parent struct
Sourcefn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
fn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
Get a mutable reference to the AgencyIssue parent struct
Sourceimpl AgentIssueTrait for VmSuspended
impl AgentIssueTrait for VmSuspended
Sourcefn get_agent_issue(&self) -> &AgentIssue
fn get_agent_issue(&self) -> &AgentIssue
Get a reference to the AgentIssue parent struct
Sourcefn get_agent_issue_mut(&mut self) -> &mut AgentIssue
fn get_agent_issue_mut(&mut self) -> &mut AgentIssue
Get a mutable reference to the AgentIssue parent struct
Sourceimpl Debug for VmSuspended
impl Debug for VmSuspended
Sourceimpl Deref for VmSuspended
impl Deref for VmSuspended
Sourceimpl DerefMut for VmSuspended
impl DerefMut for VmSuspended
Sourceimpl Deserialize for VmSuspended
impl Deserialize for VmSuspended
Sourceimpl IssueTrait for VmSuspended
impl IssueTrait for VmSuspended
Sourceimpl VimObjectTrait for VmSuspended
impl VimObjectTrait for VmSuspended
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
Sourceimpl VmIssueTrait for VmSuspended
impl VmIssueTrait for VmSuspended
Sourcefn get_vm_issue(&self) -> &VmIssue
fn get_vm_issue(&self) -> &VmIssue
Get a reference to the VmIssue parent struct
Sourcefn get_vm_issue_mut(&mut self) -> &mut VmIssue
fn get_vm_issue_mut(&mut self) -> &mut VmIssue
Get a mutable reference to the VmIssue parent struct
impl DataObjectTrait for VmSuspended