pub struct VsanAttachToSrOperation {
pub task: Option<ManagedObjectReference>,
pub success: Option<bool>,
pub timestamp: Option<String>,
pub sr_number: String,
}Expand description
Class for the historical operation of attaching to Support Request (SR)
How to access
VsanVcClusterHealthSystem::vsan_query_attach_to_sr_history()
Fields
task: Option<ManagedObjectReference>The task associates with this test result
Refers instance of Task.
success: Option<bool>Indicate the attach to SR operation is successful or not The success value will be empty when the operation is not completed when the task is running
timestamp: Option<String>The time for attaching to SR operation The timestamp will be empty when the operation is not completed when the task is running
sr_number: StringThe SR number