VsanBurnInTestCheckResult

Struct VsanBurnInTestCheckResult 

pub struct VsanBurnInTestCheckResult {
    pub passed_tests: Option<Vec<VsanBurnInTest>>,
    pub not_performed_tests: Option<Vec<VsanBurnInTest>>,
    pub failed_tests: Option<Vec<VsanBurnInTest>>,
}
Deprecated as of vSphere API 6.7.

Checks that verify if all recommended vSAN burn in tests have been performed and passed.

This structure may be used only with operations rendered under /vsan.

How to access

  • VsanVcClusterHealthSystem::vsan_query_vc_cluster_health_summary().burn_in_test?
  • VsanVcClusterHealthSystem::vsan_query_cluster_historical_health().burn_in_test?
  • VsanResourceCheckSystem::vsan_get_resource_check_status().result?.health?.burn_in_test?

Fields

passed_tests: Option<Vec<VsanBurnInTest>>

Passed burn in tests.

not_performed_tests: Option<Vec<VsanBurnInTest>>

Burn in tests with issue: There are burn in tests that have not been performed.

It is recommended to perform all burn in tests.

failed_tests: Option<Vec<VsanBurnInTest>>

Burn in tests with issue: There are burn in tests that have failed.

It is recommended to perform and pass all burn in tests.