VsanClusterHealthConfigs

Struct VsanClusterHealthConfigs 

pub struct VsanClusterHealthConfigs {
    pub enable_vsan_telemetry: Option<bool>,
    pub vsan_telemetry_interval: Option<i32>,
    pub vsan_telemetry_proxy: Option<VsanClusterTelemetryProxyConfig>,
    pub configs: Option<Vec<VsanClusterHealthResultKeyValuePair>>,
}
How to access

  • VsanVcClusterHealthSystem::vsan_health_query_vsan_cluster_health_config()
  • VsanVcClusterHealthSystem::vsan_health_set_vsan_cluster_telemetry_config(vsan_cluster_health_config)

Fields

enable_vsan_telemetry: Option<bool>

Enable flag to vSAN telemetry collection.

The flag doesn’t take effect any more and the value will be ignored

vsan_telemetry_interval: Option<i32>

The periodical vSAN telemetry collection interval in minutes.

The smaller value will collect vSAN telemetry more frequently but increase the system overhead and vice versa. The default is one week.

vsan_telemetry_proxy: Option<VsanClusterTelemetryProxyConfig>

The proxy used for sending vSAN telemetry.

The proxy can be either user configured or auto-discovered and will be applied for collecting all of vSAN telemetry data

configs: Option<Vec<VsanClusterHealthResultKeyValuePair>>

Any other vSAN cluster health configurations.

Each of configuration is the key/value pair. Currently, no additional configuration will be supported