VsanClusterHealthResultTable

Struct VsanClusterHealthResultTable 

pub struct VsanClusterHealthResultTable {
    pub vsan_cluster_health_result_base_: VsanClusterHealthResultBase,
    pub columns: Option<Vec<VsanClusterHealthResultColumnInfo>>,
    pub rows: Option<Vec<VsanClusterHealthResultRow>>,
}
The class defines the generic vSAN cluster health finding table which is used in data driven UI to rendering the health finding.

This table class includes the column and row list handling in pair. In other words, each of column defines the column schema while the row with the same index in the list contains the value list for this column

How to access

  • VsanPerformanceManager::vsan_perf_query_cluster_health().group_details?[*]→VsanClusterHealthResultTable
  • VsanPerformanceManager::vsan_perf_query_cluster_health().group_tests?[*].test_details?[*]→VsanClusterHealthResultTable
  • VsanPerformanceManager::vsan_perf_query_cluster_health().group_details?[*]→VsanClusterHealthResultWithRemediation.issue_detail?[*]
  • VsanVcClusterHealthSystem::vsan_query_vc_cluster_health_summary().groups?[*].group_details?[*]→VsanClusterHealthResultTable
  • VsanVcClusterHealthSystem::vsan_query_cluster_historical_health().groups?[*].group_details?[*]→VsanClusterHealthResultTable
  • VsanClusterHealthSystem::vsan_query_cluster_create_vm_health_test().cluster_result.health_test?.test_details?[*]→VsanClusterHealthResultTable
  • VsanClusterHealthSystem::vsan_query_cluster_network_perf_test().cluster_result.health_test?.test_details?[*]→VsanClusterHealthResultTable
  • VsanPerformanceManager::vsan_perf_query_cluster_health().group_tests?[*].test_details?[*]→VsanClusterHealthResultWithRemediation.issue_detail?[*]
  • VsanPerformanceManager::vsan_perf_query_cluster_health().group_tests?[*].historical_results?[*].test_details?[*]→VsanClusterHealthResultTable
  • VsanVcClusterHealthSystem::vsan_query_vc_cluster_create_vm_health_history_test().cluster_result.health_test?.test_details?[*]→VsanClusterHealthResultTable

(10 of 52 paths)

Fields

vsan_cluster_health_result_base_: VsanClusterHealthResultBasecolumns: Option<Vec<VsanClusterHealthResultColumnInfo>>

The column list in the data driven UI table

rows: Option<Vec<VsanClusterHealthResultRow>>

The row list in the data driven UI table