VsanDataEfficiencyConfig

Struct VsanDataEfficiencyConfig 

pub struct VsanDataEfficiencyConfig {
    pub dedup_enabled: bool,
    pub compression_enabled: Option<bool>,
}
The data efficiency configuration of a vSAN cluster.

Data efficiency configurations work together as below.

dedupEnabled compressionEnabled Details State Transition
False False - Disable deduplication and compression. Or - Disable compression only - Deduplication and compression -> No data efficiency - Compression only -> No data efficiency
None 0 - Disable compression only if enabled - Throw exception if deduplication and compression is enabled - Compression only -> No data efficiency
None 1 - Enable compression only - Throw exception if deduplication and compression is enabled. - No data efficiency -> Compression only
0 None - Disable deduplication and compression - Throw exception if compression only is enabled - Deduplication and compression -> No data efficiency
1 1 - Enable deduplcation and compression - Disable compression only if already enabled - Get *VsanClusterConfigInfo* will return compressionEnabled flag as true - No data efficiency -> Deduplication and compression - Compression only -> Deduplication and compression
1 0 - Enable deduplication and compression - Disable compression only if already enabled - Get *VsanClusterConfigInfo* will return compressionEnabled flag as True - No data efficiency -> Deduplication and compression - Compression only -> Deduplication and compression
0 1 - Enable compression only - Disable deduplication and compression - Deduplication and compression -> Compression only - No data efficiency -> Compression only
1 None - Enable deduplication and compression - Disable compression only if already enabled - Get *VsanClusterConfigInfo* will return compression only flag as True - No data efficiency -> deduplication and compression - Compression only -> deduplication and compression

How to access

  • HostSystem::config.vsan_host_config?→VsanHostConfigInfoEx.data_efficiency_info?
  • ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.data_efficiency_config?
  • ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_host_config?[*]→VsanHostConfigInfoEx.data_efficiency_info?
  • ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.data_efficiency_config?
  • ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_host_config?[*]→VsanHostConfigInfoEx.data_efficiency_info?
  • HostVsanSystem::config→VsanHostConfigInfoEx.data_efficiency_info?
  • Folder::create_cluster_ex(spec).vsan_config?→VsanConfigInfoEx.data_efficiency_config?
  • Folder::create_cluster_ex(spec).vsan_host_config_spec?[*]→VsanHostConfigInfoEx.data_efficiency_info?
  • Folder::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.data_efficiency_config?
  • Folder::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*]→VsanHostConfigInfoEx.data_efficiency_info?

(10 of 49 paths)

Fields

dedup_enabled: bool

Enables data deduplication and compression on the vSAN cluster.

The behaviour of this flag is described in the table above.

compression_enabled: Option<bool>

Enables compression on the vSAN cluster.

The behaviour of this flag is described in the table above.