pub struct VsanDiagnosticsThreshold {
pub entity_type: String,
pub metric: String,
pub yellow: Option<i32>,
pub red: Option<i32>,
}Expand description
Define the threshold value for the alarms raised by VsanDiagnosticsSystem.
This structure may be used only with operations rendered under /vsan.
How to access
VsanDiagnosticsSystem::vsan_get_thresholds()VsanDiagnosticsSystem::vsan_set_thresholds(thresholds)
Fields
entity_type: StringThe “entityType” is used to identify the target entity to get/set the threshold value.
Current supported entity types and metrics:
| Entity Type | Metrics |
|---|---|
| 'vsan-pnic-net' | 'rxCrcErr', 'txCarErr', 'rxErr', 'txErr', 'pauseCount', 'rxMissErr', 'rxOvErr', 'rxFifoErr' |
| 'rdt-net' | 'checksumMismatchCount' |
metric: StringThe “metric” is used to identify the stats of an entity, e.g.: rxCrcErr (CRC error of physical NIC), txCarErr (Carrier error of physical NIC).
Current supported metrics:
See VsanDiagnosticsThreshold.entityType
yellow: Option<i32>The yellow value of threshold indicates light severe warnings.
The unit is the same as the metric.
red: Option<i32>The red value of threshold indicates severe warnings.
The unit is the same as the metric.