pub struct VsanFileServerHealthSummary {
pub domain_name: Option<String>,
pub file_server_ip: Option<String>,
pub nfsd_health: Option<String>,
pub network_health: Option<String>,
pub rootfs_health: Option<String>,
pub description: Option<String>,
pub smb_connections: Option<i32>,
pub smb_daemon_health: Option<String>,
pub ad_test_join_health: Option<String>,
pub dns_lookup_health: Option<String>,
}Expand description
This class defines file server health summary for this host.
This structure may be used only with operations rendered under /vsan.
How to access
HostVsanHealthSystem::vsan_host_query_file_service_health_summary().file_server_health?[*]VsanVcClusterHealthSystem::vsan_cluster_query_file_service_health_summary().host_results?[*].file_server_health?[*]VsanVcClusterHealthSystem::vsan_query_vc_cluster_health_summary().file_service_health?.host_results?[*].file_server_health?[*]VsanVcClusterHealthSystem::vsan_query_cluster_historical_health().file_service_health?.host_results?[*].file_server_health?[*]VsanResourceCheckSystem::vsan_get_resource_check_status().result?.health?.file_service_health?.host_results?[*].file_server_health?[*]
Fields
domain_name: Option<String>The domain name on which the file server is checked against.
file_server_ip: Option<String>The IP address of the file server.
nfsd_health: Option<String>Whether the NFS daemon of the file server is running or not.
network_health: Option<String>Whether the ip address of the file server is present or not.
rootfs_health: Option<String>Whether the root filesystem is responsive to the file server or not.
description: Option<String>The description of the health state.
smb_connections: Option<i32>The count of client connections to SMB daemon of the file service.
smb_daemon_health: Option<String>Whether the SMB daemon of the file server is running or not.
ad_test_join_health: Option<String>Whether File server AD join configuration and connectivity is correct or not.
dns_lookup_health: Option<String>Whether File server DNS configuration and connectivity is correct or not.