VsanFileServiceShareHealthSummary

Struct VsanFileServiceShareHealthSummary 

pub struct VsanFileServiceShareHealthSummary {
    pub overall_health: Option<String>,
    pub domain_name: Option<String>,
    pub share_uuid: Option<String>,
    pub share_name: Option<String>,
    pub object_health: Option<VsanObjectOverallHealth>,
    pub description: Option<String>,
    pub extensible: Option<bool>,
    pub spbm_profile_uuid: Option<String>,
    pub spbm_profile_generation_id: Option<String>,
    pub share_policy_mismatch: Option<bool>,
}
This class defines file service share health summary in cluster level.

This structure may be used only with operations rendered under /vsan.

How to access

  • HostVsanHealthSystem::vsan_host_query_file_service_health_summary().file_share_health?[*]
  • VsanVcClusterHealthSystem::vsan_cluster_query_file_service_health_summary().host_results?[*].file_share_health?[*]
  • VsanVcClusterHealthSystem::vsan_query_vc_cluster_health_summary().file_service_health?.host_results?[*].file_share_health?[*]
  • VsanVcClusterHealthSystem::vsan_query_cluster_historical_health().file_service_health?.host_results?[*].file_share_health?[*]
  • VsanResourceCheckSystem::vsan_get_resource_check_status().result?.health?.file_service_health?.host_results?[*].file_share_health?[*]

Fields

overall_health: Option<String>

Overall health state for this vSAN file service share.

The possible state of the file service share could be one of the following:

  • ‘green’ if the file server for this file share is running properly and all its backing vSAN objects are healthy.
  • ‘red’ if the file server for this file share is in error state or any of its backing vSAN objects are degraded.
domain_name: Option<String>

The name of the domain.

See VsanDirectoryServerConfig for more detailed information about vSAN file service domain.

share_uuid: Option<String>

The UUID of the file share.

share_name: Option<String>

The name of the file share.

object_health: Option<VsanObjectOverallHealth>

The health status of share’s backing vSAN objects.

If any object is not healthy the overall healthy will be ‘red’.

description: Option<String>

The description of the health status.

It includes the detail of the vSAN objects in error state and the status of file server.

extensible: Option<bool>

The extensibility of this file share.

The file share is backed by vSAN objects, and each vSAN object can provide 255GB in maximum. So if the file share needs to grow beyond this limit, more vSAN objects should be provisioned. This item is to check whether the storage policy of this file share can be met by the current cluster for provisioning more backing vSAN objects. If the storage policy cannot be met by the cluster, and the quota of the file share cannot be satisfied by current backing vSAN object, this field will be set to False to indicate this issue. Note: the provisioning of the vSAN object will be impacted by other facts, e.g., network partition. Check the network health and host state first before validating the extensibility of the file share.

spbm_profile_uuid: Option<String>

UUID of SPBM profile used for the policy of the object when it was applied to vSAN File Service share.

Not set if the share doesn’t use an SPBM managed policy.

spbm_profile_generation_id: Option<String>

Generation ID of SPBM profile used for the policy of the object when it was applied to vSAN File Service share.

Not set if the share doesn’t use a SPBM managed policy.

share_policy_mismatch: Option<bool>

This field is to check whether the storage policy of this file share mismatches latest version of the SPBM policy.

Whenever SPBM policy is changed, the change needs to be propagated to associated file shares.The mismatch status would be used as a health check when file share is queried.