pub struct VsanFileShareSmbOptions {
pub encryption: Option<String>,
pub access_based_enumeration: Option<bool>,
}Expand description
The protocol specific options for SMB file shares.
This structure may be used only with operations rendered under /vsan.
How to access
VsanFileServiceSystem::vsan_create_file_share(config).smb_options?VsanFileServiceSystem::vsan_reconfigure_file_share(config).smb_options?VsanFileServiceSystem::vsan_cluster_query_file_shares().file_shares?[*].config?.smb_options?
Fields
encryption: Option<String>This option controls whether a remote client is allowed or required to use SMB encryption.
Default value is ‘disabled’.
See also VsanFileShareSmbEncryptionType_enum.
access_based_enumeration: Option<bool>This option controls whether SMB clients can list entries which they don’t have permission to access.
Default value is ‘False’. Note: enabling this feature will slow down the listing of large directories for the first time.