VsanHealthActionBase

Struct VsanHealthActionBase 

pub struct VsanHealthActionBase {
    pub description: String,
}
This is the base class for vSAN health issue remediation or troubleshooting.

This structure may be used only with operations rendered under /vsan.

How to access

  • VsanPerformanceManager::vsan_perf_query_cluster_health().group_details?[*]→VsanClusterHealthResultWithRemediation.troubleshooting?.diagnostic_steps?[*]
  • VsanPerformanceManager::vsan_perf_query_cluster_health().group_details?[*]→VsanClusterHealthResultWithRemediation.troubleshooting?.remediations?[*]
  • VsanPerformanceManager::vsan_perf_query_cluster_health().group_tests?[*].test_details?[*]→VsanClusterHealthResultWithRemediation.troubleshooting?.diagnostic_steps?[*]
  • VsanPerformanceManager::vsan_perf_query_cluster_health().group_tests?[*].test_details?[*]→VsanClusterHealthResultWithRemediation.troubleshooting?.remediations?[*]
  • VsanVcClusterHealthSystem::vsan_query_vc_cluster_health_summary().groups?[*].group_details?[*]→VsanClusterHealthResultWithRemediation.troubleshooting?.diagnostic_steps?[*]
  • VsanVcClusterHealthSystem::vsan_query_vc_cluster_health_summary().groups?[*].group_details?[*]→VsanClusterHealthResultWithRemediation.troubleshooting?.remediations?[*]
  • VsanVcClusterHealthSystem::vsan_query_cluster_historical_health().groups?[*].group_details?[*]→VsanClusterHealthResultWithRemediation.troubleshooting?.diagnostic_steps?[*]
  • VsanVcClusterHealthSystem::vsan_query_cluster_historical_health().groups?[*].group_details?[*]→VsanClusterHealthResultWithRemediation.troubleshooting?.remediations?[*]
  • VsanClusterHealthSystem::vsan_query_cluster_create_vm_health_test().cluster_result.health_test?.test_details?[*]→VsanClusterHealthResultWithRemediation.troubleshooting?.diagnostic_steps?[*]
  • VsanClusterHealthSystem::vsan_query_cluster_create_vm_health_test().cluster_result.health_test?.test_details?[*]→VsanClusterHealthResultWithRemediation.troubleshooting?.remediations?[*]

(10 of 52 paths)

Fields

description: String

The descriptive message for explaining what the action it is.

Notice it can support the following mark up tags. 1. Hyperlink <tag.link>{link_content}</tag.link> 2. Host entity <tag.icon.host>${host_ip}</tag.icon.host>