pub struct VsanHealthThreshold {
pub yellow_value: i64,
pub red_value: i64,
pub target: Option<String>,
pub enabled: Option<bool>,
}Expand description
Define threshold values for the health status VsanHealthStatusType.red and VsanHealthStatusType.yellow for the given vSAN entity.
Each vSAN entity is independent to define the threshold values as per the requirement. Like a capacity system can have threshold in form of percentage of total capacity. Other systems, for example, congestion system can have threshold value as fixed numbers.
This structure may be used only with operations rendered under /vsan.
How to access
ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.vsan_health_config?.health_check_threshold_spec?[*]ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.vsan_health_config?.health_check_threshold_spec?[*]Folder::create_cluster_ex(spec).vsan_config?→VsanConfigInfoEx.vsan_health_config?.health_check_threshold_spec?[*]Folder::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.vsan_health_config?.health_check_threshold_spec?[*]Folder::batch_add_hosts_to_cluster_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.vsan_health_config?.health_check_threshold_spec?[*]Folder::batch_add_standalone_hosts_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.vsan_health_config?.health_check_threshold_spec?[*]StoragePod::create_cluster_ex(spec).vsan_config?→VsanConfigInfoEx.vsan_health_config?.health_check_threshold_spec?[*]StoragePod::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.vsan_health_config?.health_check_threshold_spec?[*]StoragePod::batch_add_hosts_to_cluster_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.vsan_health_config?.health_check_threshold_spec?[*]StoragePod::batch_add_standalone_hosts_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.vsan_health_config?.health_check_threshold_spec?[*]
(10 of 32 paths)
Fields
yellow_value: i64Entity beyond this threshold will be marked as VsanHealthStatusType.yellow.
red_value: i64Entity beyond this threshold will be marked as VsanHealthStatusType.red.
target: Option<String>This optional attribute is used as the target for the thresholds.
The definition of the targets: VsanHealthThresholdTarget_enum
See also VsanHealthThresholdTarget_enum.
enabled: Option<bool>As each target will have its own switch for threshold customization, this field is used to tell if the threshold takes effect.
If not given, the default value is False.