pub struct VsanHostAboutInfoEx {
pub name: Option<String>,
pub version: Option<String>,
pub build: Option<String>,
pub build_type: Option<String>,
pub api_version: Option<String>,
}Expand description
This data object type describes system information including the name, version, build type and build number.
This structure may be used only with operations rendered under /vsan.
How to access
VsanSystemEx::vsan_get_about_info_ex()
Fields
name: Option<String>Represents name of current product.
version: Option<String>Represents version of current product.
build: Option<String>Represents build number of current product.
build_type: Option<String>Represents build type of current product.
api_version: Option<String>Represents managment API verison for vSAN.