VsanHostComponentSyncState

Struct VsanHostComponentSyncState 

pub struct VsanHostComponentSyncState {
    pub uuid: String,
    pub disk_uuid: String,
    pub host_uuid: String,
    pub bytes_to_sync: i64,
    pub recovery_eta: Option<i64>,
    pub reasons: Option<Vec<String>>,
}
This data object type describes sync state for a vSAN component.

This structure may be used only with operations rendered under /vsan.

How to access

  • VsanObjectSystem::query_syncing_vsan_objects_summary().objects?[*].components[*]
  • VsanSystemEx::vsan_query_syncing_vsan_objects().objects?[*].components[*]

Fields

uuid: String

Represents the uuid of component.

disk_uuid: String

Represents the uuid of disk on which component resides.

host_uuid: String

Represents the uuid of host on which component resides.

bytes_to_sync: i64

Indicates how many bytes need to be synced for this component.

recovery_eta: Option<i64>

The estimated time in seconds to complete recovery.

This attribute will be not returned if no data has been synced.

reasons: Option<Vec<String>>

The list of reasons indicate why the component went into syncing state.

The API returns full list of reasons for background. However, sometimes it’s userful to generate an aggregate reason, in which case the following priorities could be used:

  • P0: “evacuate”
  • P1: “dying_evacuate”
  • P2: “rebalance”
  • P3: “repair”, “reconfigure”
  • P4: “stale”, “merge_concat”

See also VsanSyncReason_enum.