pub struct VsanHostConfigInfoClusterInfo {
pub uuid: Option<String>,
pub node_uuid: Option<String>,
}Expand description
Host-local VSAN cluster configuration.
This data object is used both for specifying and retrieving cluster configuration for a host participating in the VSAN service.
How to access
HostSystem::config.vsan_host_config?.cluster_info?ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_host_config?[*].cluster_info?ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_host_config?[*].cluster_info?HostVsanSystem::config.cluster_info?Folder::create_cluster_ex(spec).vsan_host_config_spec?[*].cluster_info?Folder::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*].cluster_info?Folder::batch_add_hosts_to_cluster_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*].cluster_info?Folder::batch_add_standalone_hosts_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*].cluster_info?StoragePod::create_cluster_ex(spec).vsan_host_config_spec?[*].cluster_info?StoragePod::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*].cluster_info?
(10 of 17 paths)
Fields
uuid: Option<String>VSAN service cluster UUID, in the string form “nnnnnnnn-nnnn-nnnn-nnnn-nnnnnnnnnnnn”, where n are hexadecimal digits.
If provided while enabling the VSAN service, this value will be used for the service cluster UUID. If omitted when enabling the VSAN service, a suitable UUID will be generated by the platform. This is a read-only value while the VSAN service is enabled.
node_uuid: Option<String>VSAN node UUID for this host.
This is a read-only value which is populated upon enabling of the VSAN service.