pub struct VsanHostIoInsightInfo {
pub host: ManagedObjectReference,
pub ioinsight_world_id: Option<i64>,
pub fault_message: Option<String>,
pub ioinsight_info: Option<VsanIoInsightInfo>,
}Expand description
This data object describes ioinsight information on the host.
This structure may be used only with operations rendered under /vsan.
How to access
VsanIoInsightManager::stop_io_insight(hosts_io_insight_infos)VsanIoInsightManager::query_io_insight_instances().hosts_io_insight_info?[*]
Fields
host: ManagedObjectReferenceESXi host on which the ioinsight tool is installed.
Refers instance of HostSystem.
ioinsight_world_id: Option<i64>The ESXi process identifier (aka.
worldId) of running ioinsight. For stopped ioinsight the worldId value is 0.
fault_message: Option<String>The error message when there is any issue found.
ioinsight_info: Option<VsanIoInsightInfo>The current ioinsight state, along with all monitored VMs if ioinsight is in running stauts, see VsanIoInsightInfo.