pub struct VsanHostVmdkLoadTestResult {
pub hostname: String,
pub issue_found: bool,
pub fault_message: Option<String>,
pub vmdk_results: Option<Vec<VsanVmdkLoadTestResult>>,
}Expand description
Deprecated as of vSphere API 6.7.
Class for preparing, running and cleaning up VMDK load test results on the host.
How to access
VsanVcClusterHealthSystem::vsan_query_vc_cluster_vmdk_load_history_test().host_results?[*]
Fields
hostname: StringThe host name.
issue_found: boolFalse either indicate one or more VMDK test result is failed in host VMDK load test or issues found in preparing VMDK or cleaning up VMDK.
fault_message: Option<String>The error message when there is any issue found
vmdk_results: Option<Vec<VsanVmdkLoadTestResult>>The VMDK load test result on the host