pub struct VsanHostVsanObjectSyncQueryResult {
pub total_objects_to_sync: Option<i64>,
pub total_bytes_to_sync: Option<i64>,
pub total_recovery_eta: Option<i64>,
pub objects: Option<Vec<VsanHostVsanObjectSyncState>>,
pub syncing_object_recovery_details: Option<VsanSyncingObjectRecoveryDetails>,
}Expand description
This data object type describes results being returned from querying syncing vSAN objects.
This structure may be used only with operations rendered under /vsan.
How to access
VsanObjectSystem::query_syncing_vsan_objects_summary()VsanSystemEx::vsan_query_syncing_vsan_objects()
Fields
total_objects_to_sync: Option<i64>Total number of vSAN objects that are syncing.
It’s returned only when summary data is needed.
total_bytes_to_sync: Option<i64>The amount of data to be re-synced.
It’s returned only when summary data is needed.
total_recovery_eta: Option<i64>The estimated time in seconds to recover all vSAN objects of specified types.
It’s returned only when summary data is needed.
objects: Option<Vec<VsanHostVsanObjectSyncState>>The retrieved objects.
syncing_object_recovery_details: Option<VsanSyncingObjectRecoveryDetails>Details returned from querying vSAN syncing objects for different sync status.