VsanInternalExtendedConfig

Struct VsanInternalExtendedConfig 

pub struct VsanInternalExtendedConfig {
    pub vc_max_disk_version: Option<i32>,
    pub stretched_client: Option<bool>,
}
vSAN internal extended configurations This contains vSAN host level extended configurations that can be configured for hosts internally by vCente server.

Unlike VsanExtendedConfig, this is not part of vSAN cluster reconfiguration spec VsanConfigInfoEx and it is not meant to be set by users.

This structure may be used only with operations rendered under /vsan.

How to access

  • HostSystem::config.vsan_host_config?→VsanHostConfigInfoEx.internal_extended_config?
  • ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_host_config?[*]→VsanHostConfigInfoEx.internal_extended_config?
  • ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_host_config?[*]→VsanHostConfigInfoEx.internal_extended_config?
  • HostVsanSystem::config→VsanHostConfigInfoEx.internal_extended_config?
  • Folder::create_cluster_ex(spec).vsan_host_config_spec?[*]→VsanHostConfigInfoEx.internal_extended_config?
  • Folder::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*]→VsanHostConfigInfoEx.internal_extended_config?
  • Folder::batch_add_hosts_to_cluster_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*]→VsanHostConfigInfoEx.internal_extended_config?
  • Folder::batch_add_standalone_hosts_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*]→VsanHostConfigInfoEx.internal_extended_config?
  • StoragePod::create_cluster_ex(spec).vsan_host_config_spec?[*]→VsanHostConfigInfoEx.internal_extended_config?
  • StoragePod::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*]→VsanHostConfigInfoEx.internal_extended_config?

(10 of 17 paths)

Fields

vc_max_disk_version: Option<i32>

This configuration is the highest disk version that vCenter server can understand and manage.

vCenter server passes this configuration to ESXi hosts so that ESXi hosts will not choose a higher disk version that vCenter server cannot understand when creating a disk group. The default value on ESXi host is 0 when it is unset, meaning that the host is not managed by any vCenter server. Note that older vCenter server before v6.7 update 3 won’t know this value hence will not set it.

stretched_client: Option<bool>

This configuration indicates if the host works in stretched compute only cluster.

This configuration only serves ESX reconfiguration purpose, but not returned via get API.