VsanIoDiagnosticsInstance

Struct VsanIoDiagnosticsInstance 

pub struct VsanIoDiagnosticsInstance {
    pub name: String,
    pub state: String,
    pub events: Option<Vec<VsanIoDiagnosticsInstanceEvent>>,
    pub targets: Option<Vec<VsanIoDiagnosticsTarget>>,
    pub start_time: String,
    pub end_time: String,
    pub recurrence_name: Option<String>,
}
This data object describes the diagnostics instance including the name and the diagnostics target and the running time range.

This structure may be used only with operations rendered under /vsan.

How to access

  • VsanDiagnosticsSystem::query_io_diagnostics_instances()

Fields

name: String

The instance name.

state: String

The state of the instance, can be “VsanIODiagnosticsInstanceRunning” or “VsanIODiagnosticsInstanceCompleted”.

See also VsanIODiagnosticsInstanceState_enum.

events: Option<Vec<VsanIoDiagnosticsInstanceEvent>>

The event which makes the instance stopped, if the event is unset, it means the IO diagnostic operation completed without any events.

targets: Option<Vec<VsanIoDiagnosticsTarget>>

The targets that the IO diagnostics run against.

start_time: String

The start time of the diagnostics.

end_time: String

The end time of the diagnostics.

recurrence_name: Option<String>

The name of the recurrence if the instance is triggered by a recurrence.

Since: 8.0.0.4