pub struct VsanIoDiagnosticsTarget {
pub type: String,
pub entity_id: String,
pub obj_uuids: Option<Vec<String>>,
}Expand description
This data object describes the spec of the target to run IO diagnostics against.
This structure may be used only with operations rendered under /vsan.
How to access
VsanDiagnosticsSystem::start_io_diagnostics_task(targets)VsanDiagnosticsSystem::create_io_trip_analyzer_recurrences().targets[*]VsanDiagnosticsSystem::create_io_trip_analyzer_recurrences(recurrences).targets[*]VsanDiagnosticsSystem::edit_io_trip_analyzer_recurrences().targets[*]VsanDiagnosticsSystem::edit_io_trip_analyzer_recurrences(recurrences).targets[*]
(5 of 10 paths)
Fields
type: StringThe type of the target to run IO diagnostics against.
See also VsanIODiagnosticsTargetType_enum.
entity_id: StringThe entity id of the target to run IO diagnostics against.
For virtual machine, the field is VM moRef.
obj_uuids: Option<Vec<String>>The vSAN object uuids involved to run IO diagnostics.
If not specified, it will list all the backing objects for the entity with the specified type and entityId.