VsanIoInsightInfo

Struct VsanIoInsightInfo 

pub struct VsanIoInsightInfo {
    pub state: Option<String>,
    pub monitored_v_ms: Option<Vec<ManagedObjectReference>>,
}
This data object describes ioinsight status on host.

It includes both ioinsight state (running or stopped), and all of the VMs under monitor by ioinsight in running status.

This structure may be used only with operations rendered under /vsan.

How to access

  • VsanIoInsightManager::stop_io_insight(hosts_io_insight_infos).ioinsight_info?
  • VsanIoInsightManager::query_io_insight_instances().hosts_io_insight_info?[*].ioinsight_info?

Fields

state: Option<String>

Current state of ioinsight, which should be either running or stopped in general, please refer to VsanIoInsightState_enum for more details.

See also VsanIoInsightState_enum.

monitored_v_ms: Option<Vec<ManagedObjectReference>>

One or more virtual machines monitored by the ioinsight tool.

Refers instances of VirtualMachine.