VsanIoInsightInstanceQuerySpec

Struct VsanIoInsightInstanceQuerySpec 

pub struct VsanIoInsightInstanceQuerySpec {
    pub state: Option<String>,
    pub entity_ref_id: Option<String>,
}
Describe specifications for ioinsight instance query operation.

This structure may be used only with operations rendered under /vsan.

How to access

  • VsanIoInsightManager::query_io_insight_instances(query_spec)

Fields

state: Option<String>

Indicate the state in which ioinsight instance will be returned.

If this attribute is not provided, ioinsight instance state will be skipped during the query operation.

See also VsanIoInsightInstanceState_enum.

entity_ref_id: Option<String>

The ‘entityRefId’ is a reference id of the target entity, which acts as filter condition for ioinsight instance query.

For example, if host entity is provided then the query operation will return all ioinsight instances containing the host. If this attribute is not provided, the query operation will return all ioinsight instances matching VsanIoInsightInstanceQuerySpec.state The reference id consists of entity type and ID, which is formated as <entity-type>:<entity-id> Below are the examples:

Entity Type Entity ID format EntityRefId Example
Host Host UUID 'host:xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx'
VM VM InstanceUUID 'vm:xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx'
runName IOInsight runName 'runName:xxxxxx'