pub struct VsanIscsiHomeObjectSpec {
pub storage_policy: Option<Box<dyn VirtualMachineProfileSpecTrait>>,
pub default_config: Option<VsanIscsiTargetServiceDefaultConfigSpec>,
}Expand description
Defines iSCSI home object specification for creating home object.
Fields
storage_policy: Option<Box<dyn VirtualMachineProfileSpecTrait>>Default storage policy for the home object, which acts as a descriptor for the targets.
If it is not specified, vSAN datastore vmnamespace policy should be used by default.
default_config: Option<VsanIscsiTargetServiceDefaultConfigSpec>iSCSI target service default configuration, the networkInterface property in this field is required when create home object.