VsanIscsiVipConfigSpec

Struct VsanIscsiVipConfigSpec 

pub struct VsanIscsiVipConfigSpec {
    pub enabled: Option<bool>,
    pub v_4_network_config: Option<VsanVipNetworkConfig>,
    pub v_6_network_config: Option<VsanVipNetworkConfig>,
    pub vswitch_config: Option<VsanIscsiVipVswitchConfig>,
    pub distributed_switch_config: Option<VsanIscsiVipDVswitchConfig>,
}
Define virtual IP (VIP) specification.

This structure may be used only with operations rendered under /vsan.

How to access

  • ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.iscsi_config?.vip_configs?[*]
  • ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.iscsi_config?.vip_configs?[*]
  • Folder::create_cluster_ex(spec).vsan_config?→VsanConfigInfoEx.iscsi_config?.vip_configs?[*]
  • Folder::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.iscsi_config?.vip_configs?[*]
  • Folder::batch_add_hosts_to_cluster_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.iscsi_config?.vip_configs?[*]
  • Folder::batch_add_standalone_hosts_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.iscsi_config?.vip_configs?[*]
  • StoragePod::create_cluster_ex(spec).vsan_config?→VsanConfigInfoEx.iscsi_config?.vip_configs?[*]
  • StoragePod::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.iscsi_config?.vip_configs?[*]
  • StoragePod::batch_add_hosts_to_cluster_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.iscsi_config?.vip_configs?[*]
  • StoragePod::batch_add_standalone_hosts_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.iscsi_config?.vip_configs?[*]

(10 of 20 paths)

Fields

enabled: Option<bool>

Whether virtual IP (VIP) is enabled or not, disabled if it is not specified.

v_4_network_config: Option<VsanVipNetworkConfig>

IPv4 network configurations for Virtual IP.

If provided, Virtual IP will use IPv4 network. At least one of v4NetworkConfig and v6NetworkConfig should be provided for Virtual IP enablement.

v_6_network_config: Option<VsanVipNetworkConfig>

IPv6 network configurations for Virtual IP.

If provided, Virtual IP will use IPv6 network. At least one of v4NetworkConfig and v6NetworkConfig should be provided for Virtual IP enablement.

vswitch_config: Option<VsanIscsiVipVswitchConfig>

The standard vSwitch configuration for Virtual IP vmkernal adapter.

You can specify this property only if you do no specify VsanIscsiVipConfigSpec.distributedSwitchConfig.

distributed_switch_config: Option<VsanIscsiVipDVswitchConfig>

The distributed vSwitch configuration for Virtual IP vmkernal adapter.

You can specify this property only if you do no specify VsanIscsiVipConfigSpec.vswitchConfig.