pub struct VsanPerfDiagnoseQuerySpec {
pub start_time: String,
pub end_time: String,
pub query_type: String,
pub context: Option<String>,
}Expand description
This data object specifies the query parameters for the vSAN Performance diagnostic query.
This structure may be used only with operations rendered under /vsan.
How to access
VsanPerformanceManager::vsan_perf_diagnose(perf_diagnose_query)VsanPerformanceManager::vsan_perf_diagnose_task(perf_diagnose_query)
Fields
start_time: StringThe start time of the period for which the cluster performance will be diagnosed.
This parameter must be specified.
end_time: StringThe end time of the period for which the cluster performance will be diagnosed.
This parameter must be specified.
query_type: StringThe query type for which the cluster performance will be diagnosed.
See also VsanPerfDiagnosticQueryType_enum.
context: Option<String>Any additional context that can be supplied as a hint to the diagnosis.
As an example, if for HCIBench workloads, the string ‘HCIBench’ can be supplied here.