pub struct VsanPerfHotspotEntitiesMetrics {
pub entity_ref_id: String,
pub start_time: String,
pub end_time: String,
pub metrics_value: Option<Vec<VsanPerfMetricSeriesCsv>>,
}Expand description
This data object type stores values and metadata for vSAN metrics associated with a specific entity.
This structure may be used only with operations rendered under /vsan.
How to access
VsanPerformanceManager::query_vsan_perf_hotspot_entities()
Fields
entity_ref_id: StringThe entity reference id in format <type>:<id> like managed object reference.
For supported entity types, metric groups, metrics, see VsanPerformanceManager.VsanPerfQueryPerf.
start_time: StringThe start time of the hotspot entities query.
end_time: StringThe end time of the hotspot entities query.
metrics_value: Option<Vec<VsanPerfMetricSeriesCsv>>The queried metrics value of the hotspot entities.