VsanPhysicalDiskHealthSummary

Struct VsanPhysicalDiskHealthSummary 

pub struct VsanPhysicalDiskHealthSummary {
    pub overall_health: String,
    pub heaps_with_issues: Option<Vec<VsanResourceHealth>>,
    pub slabs_with_issues: Option<Vec<VsanResourceHealth>>,
    pub disks: Option<Vec<VsanPhysicalDiskHealth>>,
    pub components_with_issues: Option<Vec<VsanResourceHealth>>,
    pub hostname: Option<String>,
    pub host_dedup_scope: Option<i32>,
    pub error: Option<MethodFault>,
}
This class encapsulates the vSAN physical disk health check result for all of disks in the host

How to access

  • HostVsanHealthSystem::vsan_host_query_physical_disk_health_summary()
  • VsanClusterHealthSystem::vsan_query_cluster_physical_disk_health_summary()
  • VsanVcClusterHealthSystem::vsan_query_vc_cluster_health_summary().physical_disks_health?[*]
  • VsanVcClusterHealthSystem::vsan_query_cluster_historical_health().physical_disks_health?[*]
  • VsanResourceCheckSystem::vsan_get_resource_check_status().result?.health?.physical_disks_health?[*]

Fields

overall_health: String

The overall health status.

It’s the aggregated health from all of disk’s health status. All of possible values are red, yellow and green.

heaps_with_issues: Option<Vec<VsanResourceHealth>>

It includes all of vSAN heaps whose usage health is not green.

The health status will be red if the percentage of used heap space is larger 95%, the health status will be yellow if the percentage is in between of 75% and 95%.

slabs_with_issues: Option<Vec<VsanResourceHealth>>

It includes all of vSAN slabs whose usage health is not green.

The health status will be red if the usage percentage is larger 95% and the health status will be yellow if the percentage is in between of 75% and 95%

disks: Option<Vec<VsanPhysicalDiskHealth>>

Per physical disk health result on the host

components_with_issues: Option<Vec<VsanResourceHealth>>

It includes all of vSAN components whose health status is not in green

hostname: Option<String>

The host name

host_dedup_scope: Option<i32>

The dedup scope configuration on the host.

The value 0 indicate there is no dedup enabled, 1 indicates the dedup scope is in disk wide and 2 indicates the dedup scope is in disk group wide.

error: Option<MethodFault>

If error is set, it means that collection of physical disk info failed on this host