pub struct VsanRemoteVcInfoStandalone {
pub vsan_remote_vc_info_: VsanRemoteVcInfo,
pub user: Option<String>,
pub password: Option<String>,
pub cert: Option<String>,
}Expand description
The information for communicating with a standalone remote vCenter.
It is an inherit class from VsanRemoteVcInfo, with adding specific information for a standalone remote vCenter.
This structure may be used only with operations rendered under /vsan.
How to access
VsanRemoteDatastoreSystem::vsan_query_hci_mesh_datastores(extra_vc_infos)→VsanRemoteVcInfoStandaloneVsanRemoteDatastoreSystem::vsan_create_datastore_source(datastore_source).vc_info→VsanRemoteVcInfoStandaloneVsanRemoteDatastoreSystem::vsan_destroy_datastore_source(datastore_source).vc_info→VsanRemoteVcInfoStandaloneVsanRemoteDatastoreSystem::vsan_precheck_datastore_source(datastore_source).vc_info→VsanRemoteVcInfoStandaloneVsanRemoteDatastoreSystem::vsan_query_datastore_source().vc_info→VsanRemoteVcInfoStandalone
(5 of 6 paths)
Fields
vsan_remote_vc_info_: VsanRemoteVcInfouser: Option<String>The user name for login into the standalone remote vCenter.
This information won’t be persisted in backend implementation.
password: Option<String>The password for login into the standalone remote vCenter.
This information won’t be persisted in backend implementation.
cert: Option<String>The single x509 certificate encoded in PEM format, which the remote vCenter is expected to have.