VsanResourceCheckDataPersistenceResult

Struct VsanResourceCheckDataPersistenceResult 

pub struct VsanResourceCheckDataPersistenceResult {
    pub vsan_resource_check_component_result_: VsanResourceCheckComponentResult,
    pub data_to_rebuild: Option<i64>,
    pub inaccessible_instances: Option<Vec<String>>,
    pub reduced_availability_instances: Option<Vec<String>>,
    pub rebuild_instances: Option<Vec<String>>,
}
The resource check component result for vSphere Data Persistence Platform.

This structure may be used only with operations rendered under /vsan.

How to access

  • VsanResourceCheckSystem::vsan_get_resource_check_status().result?→VsanResourceCheckDataPersistenceResult
  • VsanResourceCheckSystem::vsan_get_resource_check_status().component_results?[*]→VsanResourceCheckDataPersistenceResult

Fields

vsan_resource_check_component_result_: VsanResourceCheckComponentResultdata_to_rebuild: Option<i64>

Amount of data that will rebuild asynchronously after queried operation is performed.

inaccessible_instances: Option<Vec<String>>

Persistent service instances that are predicted to become inaccessible after queried operation is performed.

Instance names are constructed as follows service:namespace:instance where:

  • service: Name of the peristent service.
  • namespace: Name of the instance namespace.
  • instance: Instance name given to the respective service instance while creating it.
reduced_availability_instances: Option<Vec<String>>

Persistent service instances that are predicted to have reduced availability after queried operation is performed.

Instance names are constructed as follows service:namespace:instance where:

  • service: Name of the peristent service.
  • namespace: Name of the instance namespace.
  • instance: Instance name given to the respective service instance while creating it.
rebuild_instances: Option<Vec<String>>

Persistent service instances that will lead to rebuild on a different entity, these instances will have reduced availability as long as the data is rebuilt.

The data may be rebuilt syncronously or asyncronously depending on the service. Instance names are constructed as follows service:namespace:instance where:

  • service: Name of the peristent service.
  • namespace: Name of the instance namespace.
  • instance: Instance name given to the respective service instance while creating it.