pub struct VsanSharedWitnessCompatibilityResult {
pub witness_host_compatibility: VsanEntityCompatibilityResult,
pub robo_cluster_compatibility: Option<Vec<VsanEntityCompatibilityResult>>,
}Expand description
Data object to represent compatibility result of shared witness host.
This structure may be used only with operations rendered under /vsan.
How to access
VimClusterVsanVcStretchedClusterSystem::query_shared_witness_compatibility()
Fields
witness_host_compatibility: VsanEntityCompatibilityResultRepresent whether given shared witness host could be attached to all specified ROBO clusters.
robo_cluster_compatibility: Option<Vec<VsanEntityCompatibilityResult>>Represent whether each given ROBO cluster could support using target shared witness host as its witness.