VsanSpaceEfficiencyRatio

Struct VsanSpaceEfficiencyRatio 

pub struct VsanSpaceEfficiencyRatio {
    pub overall_ratio: Option<f32>,
    pub compression_ratio: Option<f32>,
    pub dedup_ratio: Option<f32>,
}
This class holds the vSAN space efficiency ratio.

This structure may be used only with operations rendered under /vsan.

Since: 8.0.0.4

How to access

  • VsanSpaceReportSystem::vsan_query_space_usage().space_efficiency_ratio?
  • VsanSpaceReportSystem::query_vsan_managed_storage_space_usage().space_usage?.space_efficiency_ratio?

Fields

overall_ratio: Option<f32>

The cluster level space efficiency ratio.

For vSAN ESA, it will exclude all the system overhead.

compression_ratio: Option<f32>

The cluster level space efficiency ratio for compression.

This attribute specifically quantifies the space efficiency achieved through compression, without considering other efficiency features. It is only exposed when compression is enabled within the cluster state. Compression Ratio = Space Usage Before Compression / Space Usage After Compression

dedup_ratio: Option<f32>

The cluster level space efficiency ratio for compression.

This attribute specifically quantifies the space efficiency achieved through deduplication, without considering other efficiency features. It is only exposed when deduplication is enabled within the cluster state. Deduplication Ratio = Space Usage Before Deduplication / Space Usage After Deduplication