VsanSpaceUsage

Struct VsanSpaceUsage 

pub struct VsanSpaceUsage {
    pub total_capacity_b: i64,
    pub free_capacity_b: Option<i64>,
    pub space_overview: Option<VsanObjectSpaceSummary>,
    pub space_detail: Option<VsanSpaceUsageDetailResult>,
    pub efficient_capacity: Option<VimVsanDataEfficiencyCapacityState>,
    pub whatif_capacities: Option<Vec<VsanWhatifCapacity>>,
    pub uncommitted_b: Option<i64>,
    pub capacity_health_threshold: Option<VsanHealthThreshold>,
    pub space_efficiency_ratio: Option<VsanSpaceEfficiencyRatio>,
}
Describes the vSAN space usage.

There are multiple ways to present the space usage. One way is presenting the overall vSAN cluster system space usage like total used space in which how much data is physically written into disk and how much is the over-reserved space size. A second is listing the space usage breakdown per vSAN object type defined in below enumerations: VsanObjectTypeEnum_enum, VsanObjectTypeEnum90_enum

How to access

  • VsanSpaceReportSystem::vsan_query_space_usage()
  • VsanSpaceReportSystem::query_vsan_managed_storage_space_usage().space_usage?

Fields

total_capacity_b: i64

The total vSAN capacity in byte, which is the total used and free capacity combined.

It’s the total of physical space which can be use for writing data including any of user data, metadata and the overhead data.

free_capacity_b: Option<i64>

The free vSAN capacity in byte.

It’s the total of free vSAN physical space which can be used for writing data including any of user data, metadata and the overhead data.

space_overview: Option<VsanObjectSpaceSummary>

The vSAN space usage overview including the vSAN physically written capacity, the reserved and over-reserved capacity and the total used capacity.

It shares the same data structure as the per vSAN object type space usage summary VsanObjectSpaceSummary without setting the object type.

space_detail: Option<VsanSpaceUsageDetailResult>

The vSAN space usage detail by breakdown the usage into different vSAN object type.

efficient_capacity: Option<VimVsanDataEfficiencyCapacityState>

The vSAN efficient capacity breakdown details when the vSAN cluster enables data efficiency.

whatif_capacities: Option<Vec<VsanWhatifCapacity>>

The vSAN capacity details if all objects are stored with the specified storage policy.

uncommitted_b: Option<i64>

Total additional storage space, in bytes, potentially used by all vSAN objects except for the virtual machine swap objects and namespace objects on this vSAN datastore.

It can be retrieved through VsanSpaceReportSystem.VsanQuerySpaceUsage by specifying whatifCapacityOnly as False.

capacity_health_threshold: Option<VsanHealthThreshold>

Indicates the yellow or red threshold, in bytes, for capacity usage based on current cluster capacityReservationInfo.

space_efficiency_ratio: Option<VsanSpaceEfficiencyRatio>

Indicates the vSAN space efficiency ratio, it exists only when vSAN efficiency feature is enabled, including dedup and compression.

Since: 8.0.0.4