pub struct VsanUnicastAddressInfo {
pub address: String,
pub port: Option<i32>,
pub nic_type: Option<String>,
}Expand description
Unicast address information of a cluster member.
When unicast is used for vSAN clustering, we need to tell each host about the addresses information of all hosts in the cluster. These information includes the IP address, port and the vmknic. Host uses such information to communicate with others (through others’ IP address). One such object represents one address information.
This structure may be used only with operations rendered under /vsan.
How to access
HostSystem::config.vsan_host_config?→VsanHostConfigInfoEx.unicast_config?.remote_unicast_config?[*].unicast_info?[*].unicast_spec?[*]ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_host_config?[*]→VsanHostConfigInfoEx.unicast_config?.remote_unicast_config?[*].unicast_info?[*].unicast_spec?[*]ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_host_config?[*]→VsanHostConfigInfoEx.unicast_config?.remote_unicast_config?[*].unicast_info?[*].unicast_spec?[*]HostVsanSystem::config→VsanHostConfigInfoEx.unicast_config?.remote_unicast_config?[*].unicast_info?[*].unicast_spec?[*]Folder::create_cluster_ex(spec).vsan_host_config_spec?[*]→VsanHostConfigInfoEx.unicast_config?.remote_unicast_config?[*].unicast_info?[*].unicast_spec?[*]Folder::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*]→VsanHostConfigInfoEx.unicast_config?.remote_unicast_config?[*].unicast_info?[*].unicast_spec?[*]Folder::batch_add_hosts_to_cluster_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*]→VsanHostConfigInfoEx.unicast_config?.remote_unicast_config?[*].unicast_info?[*].unicast_spec?[*]Folder::batch_add_standalone_hosts_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*]→VsanHostConfigInfoEx.unicast_config?.remote_unicast_config?[*].unicast_info?[*].unicast_spec?[*]StoragePod::create_cluster_ex(spec).vsan_host_config_spec?[*]→VsanHostConfigInfoEx.unicast_config?.remote_unicast_config?[*].unicast_info?[*].unicast_spec?[*]StoragePod::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*]→VsanHostConfigInfoEx.unicast_config?.remote_unicast_config?[*].unicast_info?[*].unicast_spec?[*]
(10 of 17 paths)
Fields
address: StringIP address of a cluster member.
It could be IPv4 or IPv6 address.
port: Option<i32>Port of a cluster member used for unicast traffic.
nic_type: Option<String>nictype of a cluster member for unicast traffic.