VsanUnmapConfig

Struct VsanUnmapConfig 

pub struct VsanUnmapConfig {
    pub enable: bool,
}
The configuration to support SCSI unmap command on vSAN datastore.

This structure may be used only with operations rendered under /vsan.

How to access

  • HostSystem::config.vsan_host_config?→VsanHostConfigInfoEx.unmap_config?
  • ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.unmap_config?
  • ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_host_config?[*]→VsanHostConfigInfoEx.unmap_config?
  • ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.unmap_config?
  • ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_host_config?[*]→VsanHostConfigInfoEx.unmap_config?
  • HostVsanSystem::config→VsanHostConfigInfoEx.unmap_config?
  • Folder::create_cluster_ex(spec).vsan_config?→VsanConfigInfoEx.unmap_config?
  • Folder::create_cluster_ex(spec).vsan_host_config_spec?[*]→VsanHostConfigInfoEx.unmap_config?
  • Folder::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.unmap_config?
  • Folder::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*]→VsanHostConfigInfoEx.unmap_config?

(10 of 42 paths)

Fields

enable: bool

Whether SCSI unmap command is supported on vSAN datastore.

If this setting is switched from disabled to enabled, for any unmap request to vSAN datastore from powered on VMs will take effect and succeed immediately; And if it is switched from enabled to disabled dynamically, running VMs reside on this vSAN datastore won’t know this change until VM rebooting happen. vSAN will fail any unmap request, and the failure will be handled by guest OS gracefully.