pub struct VsanVibScanResult {
pub host: ManagedObjectReference,
pub vib_name: String,
pub vib_version: String,
pub existing_version: Option<String>,
pub maintenance_mode_required: bool,
pub reboot_required: bool,
pub meets_system_req: bool,
pub pkg_deps_met_by_host: bool,
}Expand description
Information about a VIB based on a scan of a host.
This structure may be used only with operations rendered under /vsan.
How to access
VsanUpdateManager::vsan_vib_install_task(scan_results)VsanUpdateManager::vsan_vib_scan()
Fields
host: ManagedObjectReferenceHost for which this information is in reference to.
Refers instance of HostSystem.
vib_name: StringName of the VIB which uniquely identifies it among other VIBs in the host.
vib_version: StringVersion provided by this VIB.
existing_version: Option<String>Existing version on the host, if any.
maintenance_mode_required: boolTrue if install of this VIB will require maintenance mode.
reboot_required: boolTrue if install of this VIB will require a host reboot.
meets_system_req: boolTrue if system requirements are met.
pkg_deps_met_by_host: boolTrue if this vibs dependency is satisfied by the host vibs.