pub struct VsanXvcClientInfoSpec {
pub client_vc: String,
pub vc_uuid: Option<String>,
pub vc_version: Option<String>,
pub cluster: Option<ManagedObjectReference>,
pub cluster_name: Option<String>,
pub cluster_uuid: Option<String>,
pub vsan_format_version: Option<String>,
pub min_vsan_format_version: Option<String>,
pub datastore: Option<Vec<ManagedObjectReference>>,
}Expand description
The spec to present the client cluster’s mount request
This structure may be used only with operations rendered under /vsan.
Fields
client_vc: StringClient VC name which owns this client cluster
vc_uuid: Option<String>The uuid of the client vCenter
vc_version: Option<String>The API version of the client vCenter
cluster: Option<ManagedObjectReference>The client cluster which requests to mount specified the vSAN datastores.
Refers instance of ClusterComputeResource.
cluster_name: Option<String>The client cluster name which requests to mount specified the vSAN datastores.
cluster_uuid: Option<String>The uuid of the client cluster
vsan_format_version: Option<String>The client cluster vSAN format version.
This is passed to server side for vSAN version compatibility check.
min_vsan_format_version: Option<String>Minimum required cluster vSAN format version.
This is passed to server side for vSAN version compatibility check.
datastore: Option<Vec<ManagedObjectReference>>The server datastores requested to mount across VC
Refers instances of Datastore.