VsanXvcQuerySpec

Struct VsanXvcQuerySpec 

pub struct VsanXvcQuerySpec {
    pub object_model: Option<String>,
    pub properties: Option<Vec<String>>,
    pub filter: Option<VsanXvcQueryFilter>,
    pub offset: Option<i32>,
    pub limit: Option<i32>,
    pub return_total_count: Option<bool>,
}
A query which encapsulates a request for specific object model.

It supports filtering the object model’s data to return by conditions on target object model’s properties. Also, it allows for paging the final result set.

This structure may be used only with operations rendered under /vsan.

How to access

  • VsanRemoteDatastoreSystem::vsan_query_hci_mesh_datastores(query_specs)

Fields

object_model: Option<String>

Supported object models:

  • providerVcenter: The vCenters which the queried vCenter has configured as Datastore Sources.
  • clientVcenter: The vCenters which have added the queried vCenter as Datastore Source.
  • datastore: The vSAN local datastores on all provider vCenters and the local vCenter which are allowed to be mounted.
  • clientCluster: The clusters which mount the datastores on the queried vCenter.
properties: Option<Vec<String>>

Specifies the object model properties to be included in the result set for the query.

For providerVcenter, each properties are illustrated below:

  • name: The vCenter’s name (align with the Datastore Source configuration or specified remote vCenter information).

  • uuid: The vCenter’s uuid.

  • version: The vCenter’s API version.

  • linkType: The vCenter’s link type. See .

  • totalCapacity: The total capacity of the datastores which can be mounted on the vCenter.

  • usedCapacity: The used capacity of the datastores which can be mounted on the vCenter

  • status: The communication status of the vCenter. When the vCenter can be communicated, the status code is ‘OK’. When there is issue for communication, the status is in format of ‘code{info}’, as below:

    code: VsanSslVerifyCertFault, info: The expected certificate of the vCenter. This is the string of single x509 certificate encoded in PEM format. Caller needs to explicitly specify the certificate in passed parameter of VsanRemoteVcInfoStandalone and retry the related APIs.

    code: NotAuthenticated, info: Some detailed information about unauthentication.

    code: ERROR, info: The exception type of the error, with some detailed error information. Representing a generic error.

  • clientVcenter: The queried vCenter which configures the providerVcenter as a Datastore Source. This is for differentiating multiple queried vCenters which configures the same providerVcenter.

For clientVcenter, each properties are illustrated below:

  • name: The vCenter’s name.
  • uuid: The vCenter’s uuid.
  • providerVcenter: The queried vCenter which the clientVcenter configures as a Datastore Source. This is for differentiating multiple queried vCenters which has the same clientVcenter.

For datastore, each properties are illustrated below:

  • name: The datastore’s name.
  • moId: The datastore’s moId.
  • providerVcenter: The name (align with the Datastore Source configuration or specified remote vCenter information) of the vCenter which provides the datastore.
  • serverGuid: The uuid of the providerVcenter.
  • datacenter: The name of the datacenter which provides the datastore.
  • clusterName: The name of the cluster which provides the datastore.
  • clusterMoId: The moId of the cluster which provides the datastore.
  • totalCapacity: The total capacity of the datastore.
  • usedCapacity: The used capacity of the datastore.
  • vmCount: The count the VMs which are provisioned in the datastore.
  • aliasOf: The alias property of the datastore.
  • containerId: The containerId property of the datastore.
  • clusterType: The cluster type(OSA/ESA) which provides the datastore.
  • clusterVmCount: The count of cluster VMs which are provisioned in the datastore.

For clientCluster, each properties are illustrated below:

  • name: The name of the cluster.
  • moId: The moId of the cluster.
  • uuid: The uuid of the cluster.
  • vcenter: The name of the vCenter which provides the cluster.
  • serverGuid: The uuid of the vCenter which provides the cluster.
  • providerVcenter: The name (align with the Datastore Source configuration or specified remote vCenter information) of the vCenter which has datastore(s) mounted by the client.
  • datastores: The moIds list of the datastores on the providerVcenter which are mounted by the client cluster

For serverCluster, each properties are illustrated below:

  • name: The name of the cluster.
  • providerVcenter: The name (align with the Datastore Source configuration or specified remote vCenter information) of the vCenter which provides the cluster.
  • moId: The moId of the cluster.
  • serverGuid: The uuid of the vCenter which provides the cluster.
  • uuid: The uuid of the cluster.
  • types: The types indicators list of the server cluster which provides the datastore. It can be the combination of the following values:
  • OSA: The cluster is a vSAN OSA cluster.
  • ESA: The cluster is a vSAN ESA cluster.
  • Max: The cluster is a vSAN Max cluster. A vSAN Max cluster is also a special kind of vSAN ESA cluster.
  • Stretched: The cluster is a vSAN OSA cluster. Multiple values could be combined to reflect the accurate cluster type, Some valid combinations are below:
  • OSA,Stretched: The cluster is a vSAN OSA Stretched cluster.
  • ESA, Stretched: The cluster is a vSAN ESA Stretched cluster.
  • ESA, Max: The cluster is a vSAN Max cluster, while a vSAN Max cluster must also be a vSAN ESA cluster.
  • ESA, Max, Stretched: The cluster is a vSAN Max Stretched cluster.
  • faultDomains: The fault domain info configured for the cluster. It is a list of fault domain name and UUID pairs in format “name:UUID”
filter: Option<VsanXvcQueryFilter>

Restricts (filters) the set of resources to be returned for the query.

offset: Option<i32>

The offset into the result set.

Must be non-negative number. If unset, defaults to 0.

limit: Option<i32>

The maximum number of result items to return.

If used, the value should be a non-negative integer.

return_total_count: Option<bool>

Indicates whether the total number of objects that matched the query should be computed and returned.

This is meaningful only in cases where the number of objects that match the query could be more than the limit of the result items to be returned. If unset, defaults to false.