pub struct VslmCreateSpecDiskFileBackingSpec {
pub vslm_create_spec_backing_spec_: VslmCreateSpecBackingSpec,
pub provisioning_type: Option<String>,
}Expand description
Specification of the disk file backing of a virtual storage object.
How to access
HostVStorageObjectManager::host_create_disk_task(spec).backing_spec→VslmCreateSpecDiskFileBackingSpecVcenterVStorageObjectManager::create_disk_task(spec).backing_spec→VslmCreateSpecDiskFileBackingSpecVslmVStorageObjectManager::vslm_create_disk_task(spec).backing_spec→VslmCreateSpecDiskFileBackingSpec
Fields
vslm_create_spec_backing_spec_: VslmCreateSpecBackingSpecprovisioning_type: Option<String>Provisioning type.
See also BaseConfigInfoDiskFileBackingInfoProvisioningType_enum
If unset, system will first look up the provisioning type specified in the policy. If still not found, the default thin will be used..