pub struct VslmTaskReasonUser {
pub user_name: String,
}Expand description
Indicates that the task was queued by a specific user.
This structure may be used only with operations rendered under /vslm.
How to access
VslmTask::vslm_query_info().reason→VslmTaskReasonUser
Fields
user_name: StringName of the user that queued the task.