CnsBackingObjectDetailsTrait

Trait CnsBackingObjectDetailsTrait 

pub trait CnsBackingObjectDetailsTrait: DataObjectTrait {
    // Required methods
    fn get_cns_backing_object_details(&self) -> &CnsBackingObjectDetails;
    fn get_cns_backing_object_details_mut(
        &mut self,
    ) -> &mut CnsBackingObjectDetails;
}
Base class for providing additional option for creating backing for a container volume.

The child-classes of this class will be used at the time of volume creation to specify options that should be used to create volume, and will also be returned as part of query result to give more information about the volume, CnsVolume. Type of child-class will also serve as the volume type specification during creation.

Backing type specific fields would be there in the respective child classes.

E.g. BlockBackingDetails class will have details related to block type of backing object. One example of such property is ID of the block disk that backs the volume.

This structure may be used only with operations rendered under /vsan.

How to access

  • CnsVolumeManager::cns_create_volume(create_specs).backing_object_details
  • CnsVolumeManager::cns_query_volume().volumes?[*].backing_object_details?

Required Methods

fn get_cns_backing_object_details(&self) -> &CnsBackingObjectDetails

Get a reference to the CnsBackingObjectDetails parent struct

fn get_cns_backing_object_details_mut(&mut self) -> &mut CnsBackingObjectDetails

Get a mutable reference to the CnsBackingObjectDetails parent struct