CnsVolumeSourceTrait

Trait CnsVolumeSourceTrait 

pub trait CnsVolumeSourceTrait: DataObjectTrait { }
Base class for the source of volumes creation.

The source can be a volume snapshot or a volume.

This structure may be used only with operations rendered under /vsan.

How to access

  • CnsVolumeManager::cns_create_volume(create_specs).volume_source?