VirtualDeviceBusSlotInfoTrait

Trait VirtualDeviceBusSlotInfoTrait 

pub trait VirtualDeviceBusSlotInfoTrait: DataObjectTrait { }
VirtualDeviceBusSlotInfo is a base data object type for information about device connection to its bus.

This base type does not define any properties. It is used as a namespace for general-purpose subtypes. Specific devices types are represented by subtypes which define properties for device-specific backing information.

How to access

  • VirtualMachine::config.hardware.device?[*].slot_info?
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.device_change?[*].device.slot_info?
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StorageMigrationAction.relocate_spec.device_change?[*].device.slot_info?
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→PlacementAction.relocate_spec?.device_change?[*].device.slot_info?
  • StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device.slot_info?
  • StoragePod::pod_storage_drs_entry.action_history?[*].action→StoragePlacementAction.relocate_spec.device_change?[*].device.slot_info?
  • ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.device_change?[*].device.slot_info?
  • ClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.device_change?[*].device.slot_info?
  • ClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.device_change?[*].device.slot_info?
  • ClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device.slot_info?

(10 of 65 paths)