pub trait VirtualDeviceTrait: DataObjectTrait {
// Required methods
fn get_virtual_device(&self) -> &VirtualDevice;
fn get_virtual_device_mut(&mut self) -> &mut VirtualDevice;
}Expand description
VirtualDevice is the base data object type for devices in a virtual machine.
This type contains enough information about a virtual device to allow clients to display devices they do not recognize. For example, a client with an older version than the server to which it connects may see a device without knowing what it is.
How to access
VirtualMachine::config.hardware.device?[*]StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StoragePlacementAction.relocate_spec.device_change?[*].deviceStoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→StorageMigrationAction.relocate_spec.device_change?[*].deviceStoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→PlacementAction.relocate_spec?.device_change?[*].deviceStoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].deviceStoragePod::pod_storage_drs_entry.action_history?[*].action→StoragePlacementAction.relocate_spec.device_change?[*].deviceClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.device_change?[*].deviceClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.device_change?[*].deviceClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.device_change?[*].deviceClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device
(10 of 65 paths)
Required Methods
Sourcefn get_virtual_device(&self) -> &VirtualDevice
fn get_virtual_device(&self) -> &VirtualDevice
Get a reference to the VirtualDevice parent struct
Sourcefn get_virtual_device_mut(&mut self) -> &mut VirtualDevice
fn get_virtual_device_mut(&mut self) -> &mut VirtualDevice
Get a mutable reference to the VirtualDevice parent struct