VsanDiskResourceCheckResultTrait

Trait VsanDiskResourceCheckResultTrait 

pub trait VsanDiskResourceCheckResultTrait: EntityResourceCheckDetailsTrait {
    // Required methods
    fn get_vsan_disk_resource_check_result(
        &self,
    ) -> &VsanDiskResourceCheckResult;
    fn get_vsan_disk_resource_check_result_mut(
        &mut self,
    ) -> &mut VsanDiskResourceCheckResult;
}
The vSAN disk level resource check report.

It includes basic disk info, current disk usage and the predicted disk usage after the queried operation is performed EntityResourceCheckDetails. For example, if the queried resource check is for host enter maintenance mode operation, vSAN will simulate the disk usage after the queried host enters maintenance mode. This will provide user a sense of what the disk usage will look like if the queried operation is carried out. If EntityResourceCheckDetails.isNew is true, this is a new disk suggested to be added by vSAN simulation for more resources to make the operation succeed. In this case, currentUsage will be 0 and postOperationUsage will show how the new disk will be used assuming the queried operation is done from vSAN simulation. If EntityResourceCheckDetails.isNew is false, this is an existing disk in the current cluster. postOperationUsage will give the usage of the disk assuming the queried operation is done from vSAN simulation.

This structure may be used only with operations rendered under /vsan.

How to access

  • VsanResourceCheckSystem::vsan_get_resource_check_status().result?.fault_domains?[*].hosts?[*].disk_groups?[*].cache_tier_disk?
  • VsanResourceCheckSystem::vsan_get_resource_check_status().result?.fault_domains?[*].hosts?[*].disk_groups?[*].capacity_tier_disks?[*]

Required Methods

fn get_vsan_disk_resource_check_result(&self) -> &VsanDiskResourceCheckResult

Get a reference to the VsanDiskResourceCheckResult parent struct

fn get_vsan_disk_resource_check_result_mut( &mut self, ) -> &mut VsanDiskResourceCheckResult

Get a mutable reference to the VsanDiskResourceCheckResult parent struct