pub struct CustomizationSpecManager { /* private fields */ }Expand description
The CustomizationSpecManager managed object is used to manage customization specifications stored on the VirtualCenter server.
Implementations
Sourceimpl CustomizationSpecManager
impl CustomizationSpecManager
pub fn new(client: Arc<dyn VimClient>, mo_id: &str) -> Self
Sourcepub async fn check_customization_resources(&self, guest_os: &str) -> Result<()>
pub async fn check_customization_resources(&self, guest_os: &str) -> Result<()>
Deprecated as of vSphere 9.0, and there is no replacement for it.
Validate that required resources are available on the server to customize a particular guest operating system.
These would include sysprep for Windows and the debugfs and changefs volume editors for Linux guests.
Required privileges: System.View
Parameters:
guest_os
Short name from the guest OS descriptor list describing the OS we intend to customize.
Errors:
MissingLinuxCustResources:
MissingWindowsCustResources:
UncustomizableGuest:
Sourcepub async fn create_customization_spec(
&self,
item: &CustomizationSpecItem,
) -> Result<()>
pub async fn create_customization_spec( &self, item: &CustomizationSpecItem, ) -> Result<()>
Sourcepub async fn delete_customization_spec(&self, name: &str) -> Result<()>
pub async fn delete_customization_spec(&self, name: &str) -> Result<()>
Sourcepub async fn does_customization_spec_exist(&self, name: &str) -> Result<bool>
pub async fn does_customization_spec_exist(&self, name: &str) -> Result<bool>
Sourcepub async fn get_customization_spec(
&self,
name: &str,
) -> Result<CustomizationSpecItem>
pub async fn get_customization_spec( &self, name: &str, ) -> Result<CustomizationSpecItem>
Sourcepub async fn is_guest_os_customizable(&self, guest_id: &str) -> Result<bool>
pub async fn is_guest_os_customizable(&self, guest_id: &str) -> Result<bool>
Sourcepub async fn overwrite_customization_spec(
&self,
item: &CustomizationSpecItem,
) -> Result<()>
pub async fn overwrite_customization_spec( &self, item: &CustomizationSpecItem, ) -> Result<()>
Overwrites an existing specification, possibly after retrieving (by using ‘get’) and editing it.
If, based on the item’s changeVersion value, the overwrite process detects that the specification has changed since its retrieval, then the API uses the SpecModified exception to warn clients that they might overwrite another client’s change.
Required privileges: VirtualMachine.Provisioning.ModifyCustSpecs
Parameters:
item
Errors:
NotFound:
ConcurrentAccess:
CannotDecryptPasswords:
Sourcepub async fn customization_spec_item_to_xml(
&self,
item: &CustomizationSpecItem,
) -> Result<String>
pub async fn customization_spec_item_to_xml( &self, item: &CustomizationSpecItem, ) -> Result<String>
Sourcepub async fn xml_to_customization_spec_item(
&self,
spec_item_xml: &str,
) -> Result<CustomizationSpecItem>
pub async fn xml_to_customization_spec_item( &self, spec_item_xml: &str, ) -> Result<CustomizationSpecItem>