pub struct HostVFlashManager { /* private fields */ }Expand description
The VFlash Manager object is used to configure vFlash resource and vFlash cache on the ESX host.
Implementations
Sourceimpl HostVFlashManager
impl HostVFlashManager
pub fn new(client: Arc<dyn VimClient>, mo_id: &str) -> Self
Sourcepub async fn host_config_v_flash_cache(
&self,
spec: &HostVFlashManagerVFlashCacheConfigSpec,
) -> Result<()>
pub async fn host_config_v_flash_cache( &self, spec: &HostVFlashManagerVFlashCacheConfigSpec, ) -> Result<()>
Configure vFlash cache on the host.
Required privileges: Host.Config.AdvancedConfig
Parameters:
spec
Specification for host cache configuration.
Errors:
HostConfigFault: If the swap cache cannot be configured on the host.
InaccessibleVFlashSource: vFlash resource is not accessible.
ResourceInUse: The contained VFFS volume is being used.
Sourcepub async fn host_configure_v_flash_resource(
&self,
spec: &HostVFlashManagerVFlashResourceConfigSpec,
) -> Result<()>
pub async fn host_configure_v_flash_resource( &self, spec: &HostVFlashManagerVFlashResourceConfigSpec, ) -> Result<()>
Configure vFlash resource on the host by attaching to a backend VFFS volume.
Required privileges: Host.Config.Storage
Parameters:
spec
the vFlash resource specification.
Errors:
HostConfigFault: If vFlash resource cannot be configured on the host
ResourceInUse: The contained VFFS volume is being used.
Sourcepub async fn configure_v_flash_resource_ex_task(
&self,
device_path: Option<&[String]>,
) -> Result<ManagedObjectReference>
pub async fn configure_v_flash_resource_ex_task( &self, device_path: Option<&[String]>, ) -> Result<ManagedObjectReference>
Configure vFlash resource on a list of SSD disks.
If the host does not have a VFFS volume, host will format the volume first and then extend the volume on the rest of the SSDs; otherwise host will extend the existing VFFS volume on the passed SSDs. Finally host will configure the vFlash resource on the VFFS volume.
It will return HostVFlashResourceConfigurationResult describing success or failure associated with each device.
Required privileges: Host.Config.Storage
Parameters:
device_path
An array of device path names that identify disks. See ScsiDisk.
Returns:
This method returns a Task object with which to monitor the operation. The info.result property in the Task contains HostVFlashResourceConfigurationResult describing success or failure associated with each device.
Refers instance of Task.
Errors:
HostConfigFault: if batch operation fails on the host. Because the returned VFlashResourceConfigurationResult contains the configuration success or fault for each device, as of vSphere API 5.x, we won’t throw fault when batch operation fails.
Sourcepub async fn host_get_v_flash_module_default_config(
&self,
v_flash_module: &str,
) -> Result<VirtualDiskVFlashCacheConfigInfo>
pub async fn host_get_v_flash_module_default_config( &self, v_flash_module: &str, ) -> Result<VirtualDiskVFlashCacheConfigInfo>
Retrieve the default supported configuration for a given vFlash module
Required privileges: Host.Config.AdvancedConfig
Parameters:
v_flash_module
Name of the vFlash module
Returns:
The supported default vFlash cache configuration
Errors:
NotFound: If vFlash resource is not configured or the contained VFFS volume cannot be found on the host.
HostConfigFault: If the default vFlash module configuration option cannot be retrieved.
Sourcepub async fn host_remove_v_flash_resource(&self) -> Result<()>
pub async fn host_remove_v_flash_resource(&self) -> Result<()>
Remove vFlash resource on the host by destroying the contained VFFS volume.
Required privileges: Host.Config.Storage
Errors:
NotFound: If vFlash resource is not configured or the contained VFFS volume cannot be found on the host.
HostConfigFault: If vFlash resource or the contained VFFS volume cannot be removed from the host.
ResourceInUse: The contained VFFS volume is being used.
Sourcepub async fn v_flash_config_info(
&self,
) -> Result<Option<HostVFlashManagerVFlashConfigInfo>>
pub async fn v_flash_config_info( &self, ) -> Result<Option<HostVFlashManagerVFlashConfigInfo>>
Host vFlash configuration information.