pub enum VirtualMachineFaultToleranceStateEnum {
NotConfigured,
Disabled,
Enabled,
NeedSecondary,
Starting,
Running,
Other_(String),
}Expand description
The FaultToleranceState type defines a simple set of states for a fault tolerant virtual machine: disabled, starting, and enabled.
Possible values:
-
notConfigured: This state indicates that the virtual machine has not been configured for fault tolerance. -
disabled: For a virtual machine that is the primary in a fault tolerant group, this state indicates that the virtual machine has at least one registered secondary, but no secondary is enabled.For a virtual machine that is the secondary in a fault tolerant group, this state indicates that the secondary is disabled.
-
enabled: For a virtual machine that is the primary in a fault tolerant group, this state indicates that the virtual machine is not currently powered on, but has at least one enabled secondary For a virtual machine that is the secondary in a fault tolerant group, this state indicates that the secondary is enabled, but is not currently powered on. -
needSecondary: For a virtual machine that is the primary in a fault tolerant group, this state indicates that the virtual machine is powered on and has at least one enabled secondary, but no secondary is currently active.This state is not valid for a virtual machine that is a secondary in a fault tolerant group.
-
starting: For a virtual machine that is the primary in a fault tolerant group, this state indicates that the virtual machine is powered on and has at least one secondary that is synchronizing its state with the primary.For a virtual machine that is the secondary in a fault tolerant group, this state indicates that the secondary is powered on and is synchronizing its state with the primary virtual machine.
-
running: This state indicates that the virtual machine is running with fault tolerance protection.
How to access
VirtualMachine::runtime.fault_tolerance_stateVirtualMachine::summary.runtime.fault_tolerance_stateHostSystem::query_host_connection_info().vm?[*].runtime.fault_tolerance_stateDatacenter::query_connection_info().vm?[*].runtime.fault_tolerance_stateDatacenter::query_connection_info_via_spec().vm?[*].runtime.fault_tolerance_stateEnvironmentBrowser::query_config_target().usb?[*].summary?.runtime.fault_tolerance_state
Variants
NotConfigured
Disabled
Enabled
NeedSecondary
Starting
Running
Other_(String)
This variant handles values not known at compile time.
Implementations