pub enum VsanCapabilityTypeEnum {
Show 146 variants
Capability,
Allflash,
Stretchedcluster,
Dataefficiency,
Clusterconfig,
Upgrade,
Objectidentities,
Iscsitargets,
Witnessmanagement,
Perfsvcverbosemode,
Encryption,
Decomwhatif,
Throttleresync,
Unicastmode,
Device4Ksupport,
Nestedfd,
Complianceprecheck,
Vumintegration,
Firmwareupdate,
FullStackFw,
Configassist,
Umap,
Localdataprotection,
Archivaldataprotection,
Pr1741414Fixed,
Cloudhealth,
Perfanalysis,
Fcd,
Healthcheck2018Q2,
Enhancedresyncapi,
Genericnestedfd,
Hostaffinity,
Perfsvcautoconfig,
Unicasttest,
Vsanrdma,
Vumbaselinerecommendation,
Supportinsight,
Netperftest,
Masspropertycollector,
Whatifcapacity,
Historicalcapacity,
Policyassociation,
Policyhostapi,
Diagnosticmode,
Purgeinaccessiblevmswapobjects,
Recreatediskgroup,
Repairtimerinresyncstats,
Clusteradvancedoptions,
Updatevumreleasecatalogoffline,
Performanceforsupport,
Gethcllastupdateonvc,
Automaticrebalance,
Verbosemodeconfiguration,
Resyncetaimprovement,
Fileservices,
Fileservicekerberos,
Fileservicesmb,
Fileservicenfsv3,
Fileservicesc,
Fileservicesnapshot,
Fileserviceowe,
Fileservice80,
Fileservicescale,
Resourceprecheck,
Upgraderesourceprecheck,
Vitonlineresize,
Vitstretchedcluster,
Largecapacitydrive,
Nondatamovementdfc,
Cnsvolumes,
Filevolumes,
Diagnosticsfeedback,
Hostreservedcapacity,
Vmlevelcapacity,
Improvedcapacityscreen,
Slackspacecapacity,
Sharedwitness,
VsanCapabilityTypeUnknown,
SupportApiVersion,
Vsanmetadatanode,
Pmanintegration,
Wcpappplatform,
Diskresourceprecheck,
Metricsconfig,
Ioinsight,
Apidevversionenabled,
Nativelargeclustersupport,
Historicalhealth,
Dataintransitencryption,
Perfsvctwoyaxisgraph,
Compressiononly,
Remotedatastore,
Vsanmanagedvmfs,
Capacityreservation,
Securewipe,
Validateconfigspec,
Vsananalyticsevents,
Vsandefaultgatewaysupported,
Pspairgap,
Vsanmanagedpmem,
Capacityevaluationonvc,
Readlocalitytodrs,
Vsanencrkmx,
Vsan2Encr,
Dit4Sw,
Vsanclient,
Capacityoversubscription,
Vsandiagnostics,
Capacitycustomizablethresholds,
Hcimeshpolicy,
Topcontributors,
Vsandirectdiskdecom,
Diskmgmtredesign,
Datapersistresourcecheck,
Clusterpoweraction,
Clusterpowerselfcontain,
Duplicatepciidfix,
Healthcorrelation,
Volumerelocation,
Iodiagnostics,
Vsanrebuildtrim,
Elasticpolicy,
VsanEsaConfigure,
Hdcsintegration,
Vsanesasingletier,
Vsanperfhighresolution,
Cnsreconfigpolicy,
Vsanhostdomlatencysort,
Sha256Thumbprint,
Minrebalancethreshold,
Vsan2Hcimesh,
Dfcobjectsmanagement,
Healthremediation,
Hcimeshstretchedcluster,
Vsanxvchcimesh,
Vsan2Deeprekey,
Vsandsdefaultpolicy,
Vsanperfsvc80U2,
Vsankeyexpiration,
Vsanxvchcimeshv2,
Dhci,
Snapservice,
Vsan2Disableencryption,
Iodiagmultiplevms,
Vsanxvchcimeshv3,
Other_(String),
}Expand description
Represents a feature capability (for 8.x and previous releases).
Possible values:
-
capability: The current feature for retrieving Capabilities. -
allflash: Creating AllFlash disk groups. -
stretchedcluster: Creating a stretched cluster, adding and removing witness host. -
dataefficiency: Enabling/disabling Deduplication and Compression. -
clusterconfig: Create/Configure a vSAN cluster and related features with a single call. -
upgrade: Upgrade disk groups to a higher version. -
objectidentities: Retrieve a greater set of virtual objects. -
iscsitargets: iscsi feature provides iSCSI protocol on top of vSAN. -
witnessmanagement: The enable/disable vSAN operation and changing claiming policy. -
perfsvcverbosemode: Allow users to configure performance service to run in verbose mode, in which extra stats are collected for support cases and dev debugging. -
encryption: Software data at rest encryption for vSAN. -
decomwhatif: Query what-if result for decommissioning host or disk. -
throttleresync: Improve throttling options & resumable resync. -
unicastmode: Enforce unicast mode in vSAN. -
device4ksupport: 4k disks supporting status in vSAN -
nestedfd: Nested fault domains for stretched clusters. -
complianceprecheck: Calculate required additional capacity to make all vms compliant. -
vumintegration: vSAN upgrades through VUM integration. -
firmwareupdate: vSAN firmware/driver update feature that allow users to remediate outdated driver or firmware in an automated and simple fashion for supported hardware. -
fullStackFw: (deprecated since vSphere 8.0) allows users to update full stack of firmware for vSAN hosts. -
configassist: Configuration Assist UI provided in vSphere Web Client to help vSAN deployment. -
umap: TRIM/UNMAP for space reclamation on vSAN. -
localdataprotection: Support for data protection on a vSAN cluster. -
archivaldataprotection: Support for data protection to NFS datastores. -
pr1741414fixed: GetPreferredfaultDomain on stretched cluster and VmdkLoadTest work correctly operation are automatically performed by the VsanVcClusterConfig API. -
cloudhealth: Enable/Disable Cloud Connected Analytics -
perfanalysis: Enable/Disable Performance Analytics -
fcd: Enable/Disable First Class Disk Support in vSAN -
healthcheck2018q2: Enable/Disable suites of health group checks on 2018q2 releases -
enhancedresyncapi: Support VsanSystemEx.VsanQuerySyncingVsanObjects. -
genericnestedfd: Nested fault domain for non-stretched cluster. -
hostaffinity: Support for Host Affinity -
perfsvcautoconfig: The capability of enable/disable vSAN performance service automatically when configure vSAN. -
unicasttest: For unicast performance test capability.(Obsoleted, DO NOT USE)
-
vsanrdma -
vumbaselinerecommendation -
supportinsight -
netperftest: For network performance test capability. -
masspropertycollector: For vSAN mass property collector capability by extending property collector to collect multiple properties and APIs execution result as a batch mode -
whatifcapacity: For vSAN datastore What-If capacity report capability. -
historicalcapacity: For vSAN datastore historical capacity report capability. -
policyassociation: Support SPBM to use vSAN as source of truth for policy association. -
policyhostapi -
diagnosticmode: For vSAN diagnostic mode capability. -
purgeinaccessiblevmswapobjects: Support for purging inaccessible VM swap objects -
recreatediskgroup: Support for recreating disk groups -
repairtimerinresyncstats: Support for retrieving repair time runtime information -
clusteradvancedoptions: Support for cluster advanced options -
updatevumreleasecatalogoffline: Support for VUM release catalog offline update -
performanceforsupport: Capability of performance metrics collection for vSAN support -
gethcllastupdateonvc: Indicates if the cluster parameter is optional in the VsanVcClusterHealthSystem.VsanVcClusterGetHclInfo method. -
automaticrebalance -
verbosemodeconfiguration -
resyncetaimprovement -
fileservices -
fileservicekerberos -
fileservicesmb -
fileservicenfsv3 -
fileservicesc -
fileservicesnapshot -
fileserviceowe -
fileservice80 -
fileservicescale -
resourceprecheck -
upgraderesourceprecheck -
vitonlineresize -
vitstretchedcluster -
largecapacitydrive -
nondatamovementdfc -
cnsvolumes -
filevolumes -
diagnosticsfeedback -
hostreservedcapacity -
vmlevelcapacity -
improvedcapacityscreen -
slackspacecapacity -
sharedwitness -
VsanCapabilityType_Unknown -
supportApiVersion -
vsanmetadatanode -
pmanintegration -
wcpappplatform -
diskresourceprecheck -
metricsconfig -
ioinsight -
apidevversionenabled -
nativelargeclustersupport -
historicalhealth -
dataintransitencryption -
perfsvctwoyaxisgraph -
compressiononly -
remotedatastore -
vsanmanagedvmfs -
capacityreservation -
securewipe -
validateconfigspec -
vsananalyticsevents -
vsandefaultgatewaysupported -
pspairgap -
vsanmanagedpmem -
capacityevaluationonvc -
readlocalitytodrs -
vsanencrkmx -
vsan2encr -
dit4sw -
vsanclient -
capacityoversubscription -
vsandiagnostics -
capacitycustomizablethresholds -
hcimeshpolicy -
topcontributors -
vsandirectdiskdecom -
diskmgmtredesign -
datapersistresourcecheck -
clusterpoweraction -
clusterpowerselfcontain -
duplicatepciidfix -
healthcorrelation -
volumerelocation -
iodiagnostics -
vsanrebuildtrim -
elasticpolicy -
vsanEsaConfigure -
hdcsintegration -
vsanesasingletier -
vsanperfhighresolution -
cnsreconfigpolicy -
vsanhostdomlatencysort -
sha256thumbprint -
minrebalancethreshold -
vsan2hcimesh -
dfcobjectsmanagement -
healthremediation -
hcimeshstretchedcluster -
vsanxvchcimesh -
vsan2deeprekey -
vsandsdefaultpolicy -
vsanperfsvc80u2 -
vsankeyexpiration -
vsanxvchcimeshv2 -
dhci -
snapservice: Since: 8.0.0.4 -
vsan2disableencryption: Since: 8.0.0.4 -
iodiagmultiplevms: Since: 8.0.0.4 -
vsanxvchcimeshv3: Since: 8.0.0.4
Variants
Capability
Allflash
Stretchedcluster
Dataefficiency
Clusterconfig
Upgrade
Objectidentities
Iscsitargets
Witnessmanagement
Perfsvcverbosemode
Encryption
Decomwhatif
Throttleresync
Unicastmode
Device4Ksupport
Nestedfd
Complianceprecheck
Vumintegration
Firmwareupdate
FullStackFw
Configassist
Umap
Localdataprotection
Archivaldataprotection
Pr1741414Fixed
Cloudhealth
Perfanalysis
Fcd
Healthcheck2018Q2
Enhancedresyncapi
Genericnestedfd
Hostaffinity
Perfsvcautoconfig
Unicasttest
Vsanrdma
Vumbaselinerecommendation
Supportinsight
Netperftest
Masspropertycollector
Whatifcapacity
Historicalcapacity
Policyassociation
Policyhostapi
Diagnosticmode
Purgeinaccessiblevmswapobjects
Recreatediskgroup
Repairtimerinresyncstats
Clusteradvancedoptions
Updatevumreleasecatalogoffline
Performanceforsupport
Gethcllastupdateonvc
Automaticrebalance
Verbosemodeconfiguration
Resyncetaimprovement
Fileservices
Fileservicekerberos
Fileservicesmb
Fileservicenfsv3
Fileservicesc
Fileservicesnapshot
Fileserviceowe
Fileservice80
Fileservicescale
Resourceprecheck
Upgraderesourceprecheck
Vitonlineresize
Vitstretchedcluster
Largecapacitydrive
Nondatamovementdfc
Cnsvolumes
Filevolumes
Diagnosticsfeedback
Hostreservedcapacity
Vmlevelcapacity
Improvedcapacityscreen
Slackspacecapacity
VsanCapabilityTypeUnknown
SupportApiVersion
Vsanmetadatanode
Pmanintegration
Wcpappplatform
Diskresourceprecheck
Metricsconfig
Ioinsight
Apidevversionenabled
Nativelargeclustersupport
Historicalhealth
Dataintransitencryption
Perfsvctwoyaxisgraph
Compressiononly
Remotedatastore
Vsanmanagedvmfs
Capacityreservation
Securewipe
Validateconfigspec
Vsananalyticsevents
Vsandefaultgatewaysupported
Pspairgap
Vsanmanagedpmem
Capacityevaluationonvc
Readlocalitytodrs
Vsanencrkmx
Vsan2Encr
Dit4Sw
Vsanclient
Capacityoversubscription
Vsandiagnostics
Capacitycustomizablethresholds
Hcimeshpolicy
Topcontributors
Vsandirectdiskdecom
Diskmgmtredesign
Datapersistresourcecheck
Clusterpoweraction
Clusterpowerselfcontain
Duplicatepciidfix
Healthcorrelation
Volumerelocation
Iodiagnostics
Vsanrebuildtrim
Elasticpolicy
VsanEsaConfigure
Hdcsintegration
Vsanesasingletier
Vsanperfhighresolution
Cnsreconfigpolicy
Vsanhostdomlatencysort
Sha256Thumbprint
Minrebalancethreshold
Vsan2Hcimesh
Dfcobjectsmanagement
Healthremediation
Hcimeshstretchedcluster
Vsanxvchcimesh
Vsan2Deeprekey
Vsandsdefaultpolicy
Vsanperfsvc80U2
Vsankeyexpiration
Vsanxvchcimeshv2
Dhci
Snapservice
Vsan2Disableencryption
Iodiagmultiplevms
Vsanxvchcimeshv3
Other_(String)
This variant handles values not known at compile time.
Implementations