pub struct ClusterComputeResourceSummary {Show 15 fields
pub compute_resource_summary_: ComputeResourceSummary,
pub current_failover_level: i32,
pub admission_control_info: Option<Box<dyn ClusterDasAdmissionControlInfoTrait>>,
pub num_vmotions: i32,
pub target_balance: Option<i32>,
pub current_balance: Option<i32>,
pub drs_score: Option<i32>,
pub num_vms_per_drs_score_bucket: Option<Vec<i32>>,
pub usage_summary: Option<ClusterUsageSummary>,
pub current_evc_mode_key: Option<String>,
pub current_evc_graphics_mode_key: Option<String>,
pub das_data: Option<Box<dyn ClusterDasDataTrait>>,
pub cluster_maintenance_mode_status: Option<String>,
pub vcs_health_status: Option<String>,
pub vcs_slots: Option<Vec<ClusterComputeResourceVcsSlots>>,
}Expand description
The ClusterComputeResourceSummary data object encapsulates runtime properties of a ClusterComputeResource.
How to access
ComputeResource::summary→ClusterComputeResourceSummaryClusterComputeResource::summary_exClusterComputeResource::summary→ClusterComputeResourceSummary
Fields
compute_resource_summary_: ComputeResourceSummarycurrent_failover_level: i32Deprecated as of vSphere API 4.0, use ClusterFailoverLevelAdmissionControlInfo.currentFailoverLevel.
Current failover level.
This is the number of physical host failures that can be tolerated without impacting the ability to satisfy the minimums for all running virtual machines. This represents the current value, as opposed to desired value configured by the user.
admission_control_info: Option<Box<dyn ClusterDasAdmissionControlInfoTrait>>Information about the current amount of resources available for a vSphere HA cluster.
The actual type of admissionControlInfo will depend on what kind of ClusterDasAdmissionControlPolicy was used to configure the cluster.
num_vmotions: i32Total number of migrations with VMotion that have been done internal to this cluster.
target_balance: Option<i32>The target balance, in terms of standard deviation, for a DRS cluster.
Units are thousandths. For example, 12 represents 0.012.
current_balance: Option<i32>The current balance, in terms of standard deviation, for a DRS cluster.
Units are thousandths. For example, 12 represents 0.012.
drs_score: Option<i32>The DRS score of this cluster, in percentage.
num_vms_per_drs_score_bucket: Option<Vec<i32>>The number of VMs in this cluster corresponding to each DRS score bucket.
The buckets are defined as follows:
- 0% - 20%
- 21% - 40%
- 41% - 60%
- 61% - 80%
- 81% - 100%
usage_summary: Option<ClusterUsageSummary>The current usage summary for a DRS cluster.
current_evc_mode_key: Option<String>The Enhanced VMotion Compatibility mode that is currently in effect for all hosts in this cluster; unset if no EVC mode is active.
See also Capability.supportedEVCMode.
current_evc_graphics_mode_key: Option<String>The Enhanced VMotion Compatibility Graphics mode that is currently in effect for all hosts in this cluster; unset if no EVC mode is active.
See also Capability.supportedEVCGraphicsMode.
Since: vSphere API Release 7.0.1.0
das_data: Option<Box<dyn ClusterDasDataTrait>>Data pertaining to DAS.
cluster_maintenance_mode_status: Option<String>Configuration pertinent to state of the cluster maintenance mode.
Valid values are enumerated by the ClusterMaintenanceModeStatus type.
Since: vSphere API Release 7.0.0.2
vcs_health_status: Option<String>Deprecated as of vSphere 9.0 with no replacement. In a future release of vSphere, the vCLS functionality will be disabled, vCLS system VMs will be deleted, and vCLS APIs will be removed.
The health status of the vSphere Cluster Services in the cluster.
Supported values are enumerated by the VcsHealthStatus type.
Since: vSphere API Release 7.0.1.1
vcs_slots: Option<Vec<ClusterComputeResourceVcsSlots>>Deprecated as of vSphere 9.0 with no replacement. In a future release of vSphere, the vCLS functionality will be disabled, vCLS system VMs will be deleted, and vCLS APIs will be removed.
An array of hosts and number of resource slots on the host for vSphere Cluster Services in the cluster.
The number of resource slots on the host includes both following types: 1. Number of vCS VMs running on the host (resource reserved and occupied). 2. Number of reserved and unoccupied slots (reserved for new vCS VMs).
Since: vSphere API Release 7.0.1.1