pub struct ClusterDrsFaultsFaultsByVm {
pub vm: Option<ManagedObjectReference>,
pub fault: Vec<MethodFault>,
}Expand description
FaultsByVm is the faults generated by DRS when it tries to move a VM.
How to access
StoragePod::pod_storage_drs_entry.drs_fault?[*].faults_by_vm[*]ClusterComputeResource::drs_fault.faults_by_vm[*]Datastore::datastore_enter_maintenance_mode().drs_fault?.faults_by_vm[*]ClusterComputeResource::cluster_enter_maintenance_mode().fault?.faults_by_vm[*]ClusterComputeResource::place_vm().drs_fault?.faults_by_vm[*]StorageResourceManager::recommend_datastores().drs_fault?.faults_by_vm[*]
Fields
vm: Option<ManagedObjectReference>The VM that DRS was trying to migrate when it generated the faults.
If this property is NULL, the fault is not associated with a particular VM.
Refers instance of VirtualMachine.
fault: Vec<MethodFault>The faults generated by DRS when it was trying to move the given VM.