pub struct DistributedVirtualSwitchHostMember {
pub dynamic_property: Option<Vec<DynamicProperty>>,
pub runtime_state: Option<DistributedVirtualSwitchHostMemberRuntimeState>,
pub config: DistributedVirtualSwitchHostMemberConfigInfo,
pub product_info: Option<DistributedVirtualSwitchProductSpec>,
pub uplink_port_key: Option<Vec<String>>,
pub status: String,
pub status_detail: Option<String>,
}Expand description
The DistributedVirtualSwitchHostMember data object represents an ESXi host that is a member of a distributed virtual switch.
When you add a host to a switch (DistributedVirtualSwitchHostMemberConfigSpec.DistributedVirtualSwitchHostMemberConfigSpec.host), the Server creates a proxy switch (HostProxySwitch). The host member object contains information about the configuration and state of the proxy.
How to access
VmwareDistributedVirtualSwitch::config.host?[*]DistributedVirtualSwitch::config.host?[*]
Fields
dynamic_property: Option<Vec<DynamicProperty>>Set of dynamic properties.
This property is optional because only the properties of an object that are unknown to a client will be part of this set. This property is not readonly just in case we want to send such properties from a client in the future.
runtime_state: Option<DistributedVirtualSwitchHostMemberRuntimeState>Host member runtime state.
config: DistributedVirtualSwitchHostMemberConfigInfoHost member configuration.
product_info: Option<DistributedVirtualSwitchProductSpec>Vendor, product and version information for the proxy switch module.
uplink_port_key: Option<Vec<String>>Port keys of the uplink ports created for the host member.
These ports will be deleted after the host leaves the switch.
status: StringDeprecated as of vSphere API 5.1, use HostMemberRuntimeInfo.HostMemberRuntimeInfo.status instead.
The host DistributedVirtualSwitch component status.
See HostComponentState for valid values.
status_detail: Option<String>Deprecated as of vSphere API 5.1, use HostMemberRuntimeInfo.HostMemberRuntimeInfo.statusDetail instead.
Additional information regarding the host’s current status.