pub struct DpuStatusInfo {
pub host_hardware_element_info_: HostHardwareElementInfo,
pub dpu_id: String,
pub fru: Option<HostFru>,
pub sensors: Option<Vec<DpuStatusInfoOperationalInfo>>,
}Expand description
Data object describing the operational status of various DPU elements.
Since: vSphere API Release 8.0.0.1
How to access
HostSystem::runtime.health_system_runtime?.hardware_status_info?.dpu_status_info?[*]HostSystem::runtime.health_system_runtime?.hardware_status_info?.memory_status_info?[*]→DpuStatusInfoHostSystem::runtime.health_system_runtime?.hardware_status_info?.cpu_status_info?[*]→DpuStatusInfoHostSystem::summary.runtime?.health_system_runtime?.hardware_status_info?.dpu_status_info?[*]HostSystem::summary.runtime?.health_system_runtime?.hardware_status_info?.memory_status_info?[*]→DpuStatusInfoHostHealthStatusSystem::runtime.hardware_status_info?.dpu_status_info?[*]HostHealthStatusSystem::runtime.hardware_status_info?.memory_status_info?[*]→DpuStatusInfoHostHealthStatusSystem::runtime.hardware_status_info?.cpu_status_info?[*]→DpuStatusInfoDatacenter::query_connection_info().host.runtime?.health_system_runtime?.hardware_status_info?.dpu_status_info?[*]Datacenter::query_connection_info_via_spec().host.runtime?.health_system_runtime?.hardware_status_info?.dpu_status_info?[*]
(10 of 18 paths)
Fields
host_hardware_element_info_: HostHardwareElementInfodpu_id: StringUniquely identify this DPU.
Should be the VMware identifier which can be composed from pci and other identifying elements.
fru: Option<HostFru>The FRU this sensor monitors, if any.
sensors: Option<Vec<DpuStatusInfoOperationalInfo>>Trait Implementations
Sourceimpl Debug for DpuStatusInfo
impl Debug for DpuStatusInfo
Sourceimpl Deref for DpuStatusInfo
impl Deref for DpuStatusInfo
Sourceimpl DerefMut for DpuStatusInfo
impl DerefMut for DpuStatusInfo
Sourceimpl Deserialize for DpuStatusInfo
impl Deserialize for DpuStatusInfo
Sourceimpl HostHardwareElementInfoTrait for DpuStatusInfo
impl HostHardwareElementInfoTrait for DpuStatusInfo
Sourcefn get_host_hardware_element_info(&self) -> &HostHardwareElementInfo
fn get_host_hardware_element_info(&self) -> &HostHardwareElementInfo
Get a reference to the HostHardwareElementInfo parent struct
Sourcefn get_host_hardware_element_info_mut(&mut self) -> &mut HostHardwareElementInfo
fn get_host_hardware_element_info_mut(&mut self) -> &mut HostHardwareElementInfo
Get a mutable reference to the HostHardwareElementInfo parent struct
Sourceimpl VimObjectTrait for DpuStatusInfo
impl VimObjectTrait for DpuStatusInfo
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
impl DataObjectTrait for DpuStatusInfo