pub struct ExtendedElementDescription {
pub element_description_: ElementDescription,
pub message_catalog_key_prefix: String,
pub message_arg: Option<Vec<KeyAnyValue>>,
}Expand description
How to access
ClusterComputeResource::action_history.action→StoragePlacementAction.relocate_spec.device_change?[*].device.device_info?→ExtendedElementDescriptionClusterComputeResource::action_history.action→StorageMigrationAction.relocate_spec.device_change?[*].device.device_info?→ExtendedElementDescriptionClusterComputeResource::action_history.action→PlacementAction.relocate_spec?.device_change?[*].device.device_info?→ExtendedElementDescriptionClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_change?[*].device.device_info?→ExtendedElementDescriptionClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.device_groups?.device_group?[*].device_info?→ExtendedElementDescriptionAlarmManager::description.state_operator[*]→ExtendedElementDescriptionAlarmManager::description.metric_operator[*]→ExtendedElementDescriptionAlarmManager::description.host_system_connection_state[*]→ExtendedElementDescriptionAlarmManager::description.virtual_machine_power_state[*]→ExtendedElementDescriptionAlarmManager::description.datastore_connection_state[*]→ExtendedElementDescription
(10 of 100 paths)
Fields
element_description_: ElementDescriptionmessage_catalog_key_prefix: StringKey to the localized message string in the catalog.
If the localized string contains parameters, values to the parameters will be provided in #messageArg. E.g: If the message in the catalog is “IP address is {address}”, value for “address” will be provided by #messageArg. Both summary and label in ElementDescription will have a corresponding entry in the message catalog with the keys <messageCatalogKeyPrefix>.summary and <messageCatalogKeyPrefix>.label respectively. ElementDescription.summary and ElementDescription.label will contain the strings in server locale.
message_arg: Option<Vec<KeyAnyValue>>Provides named arguments that can be used to localize the message in the catalog.