pub struct FailoverNodeInfo {
pub cluster_ip_settings: CustomizationIpSettings,
pub failover_ip: Option<CustomizationIpSettings>,
pub bios_uuid: Option<String>,
}Expand description
How to access
FailoverClusterConfigurator::get_vcha_config().failover_node_info_1?FailoverClusterConfigurator::get_vcha_config().failover_node_info_2?
Fields
cluster_ip_settings: CustomizationIpSettingsVCHA Cluster network configuration of the node.
All cluster communication (state replication, heartbeat, cluster messages) happens over this network.
failover_ip: Option<CustomizationIpSettings>Failover IP address that this node will assume after the failover to serve client requests.
Each failover node can have a different failover IP address.
bios_uuid: Option<String>BIOS UUID for the node.
It is set only if the VCHA Cluster was formed using automatic provisioning by the deploy API.