pub struct FileQuery {}Expand description
The data object type that describes the base query specification.
Contains query filters and details that apply to every file. Querying only file details generally does not require opening files and so is an efficient query. Derived types add query parameters specific to the type of file.
How to access
HostDatastoreBrowser::supported_typeHostDatastoreBrowser::search_datastore_task(search_spec).query?[*]HostDatastoreBrowser::search_datastore_sub_folders_task(search_spec).query?[*]