pub struct HbrTargetSpecReplacement {
pub spec: Option<Vec<HbrTargetSpec>>,
}Expand description
Defines replace-all specs on source host operation.
This operation will remove all existing specs and will replace them with new ones. If specs is empty array, all existing specs will be removed and nothing new will be added.
Since: vSphere API Release 9.0.0.0
Fields
spec: Option<Vec<HbrTargetSpec>>Array of all new targets.
If this is empty array, nothing new will be configured and all existing ones will be deleted.