pub struct HostBootDeviceInfo {
pub boot_devices: Option<Vec<HostBootDevice>>,
pub current_boot_device_key: Option<String>,
}Expand description
This data object represents the boot device information of the host.
How to access
HostBootDeviceSystem::query_boot_devices()
Fields
boot_devices: Option<Vec<HostBootDevice>>The list of boot devices present on the host
current_boot_device_key: Option<String>The key of the current boot device that the host is configured to boot.
This property is unset if the current boot device is disabled.