pub struct HostDiskPartitionBlockRange {
pub partition: Option<i32>,
pub type: String,
pub start: HostDiskDimensionsLba,
pub end: HostDiskDimensionsLba,
}Expand description
A BlockRange data object type describes a contiguous set of blocks on a disk.
A BlockRange may describe either a partition or unpartitioned (primordial) blocks on the disk.
How to access
HostStorageSystem::compute_disk_partition_info_for_resize(block_range)HostStorageSystem::compute_disk_partition_info(layout).partition[*]HostDiagnosticSystem::query_partition_create_desc().layout.partition[*]HostStorageSystem::compute_disk_partition_info().layout.partition[*]HostStorageSystem::compute_disk_partition_info_for_resize().layout.partition[*]HostStorageSystem::retrieve_disk_partition_info().layout.partition[*]HostDatastoreSystem::query_vmfs_datastore_create_options().info⇒VmfsDatastoreSingleExtentOptionTrait.vmfs_extentHostDatastoreSystem::query_vmfs_datastore_create_options().info→VmfsDatastoreMultipleExtentOption.vmfs_extent[*]HostDatastoreSystem::query_vmfs_datastore_create_options().info.layout.partition[*]HostDatastoreSystem::query_vmfs_datastore_expand_options().info⇒VmfsDatastoreSingleExtentOptionTrait.vmfs_extent
(10 of 15 paths)
Fields
partition: Option<i32>Partition number.
This number is a hint from the server indicating what the partition number for this block range is if the range corresponds to a partition. The partition number should correlate to the one in the partition specification. If sent back to the server, this property is ignored.
type: StringThe type of data in the partition.
See also HostDiskPartitionAttributes.type.
start: HostDiskDimensionsLbaThe starting block address of the disk range.
The block numbers start from zero. The range is inclusive of the end address.
end: HostDiskDimensionsLbaThe end block address of the disk range.
The block numbers start from zero. The range is inclusive of the end address.