pub struct HostVmfsVolume {Show 16 fields
pub host_file_system_volume_: HostFileSystemVolume,
pub block_size_mb: i32,
pub block_size: Option<i32>,
pub unmap_granularity: Option<i32>,
pub unmap_priority: Option<String>,
pub unmap_bandwidth_spec: Option<VmfsUnmapBandwidthSpec>,
pub max_blocks: i32,
pub major_version: i32,
pub version: String,
pub uuid: String,
pub extent: Vec<HostScsiDiskPartition>,
pub vmfs_upgradable: bool,
pub force_mounted_info: Option<HostForceMountedInfo>,
pub ssd: Option<bool>,
pub local: Option<bool>,
pub scsi_disk_type: Option<String>,
}Expand description
The VMFS file system.
How to access
HostSystem::config.file_system_volume?.mount_info?[*].volume→HostVmfsVolumeDatastore::info→VmfsDatastoreInfo.vmfs?HostStorageSystem::file_system_volume_info.mount_info?[*].volume→HostVmfsVolumeHostStorageSystem::format_vmfs()HostStorageSystem::resolve_multiple_unresolved_vmfs_volumes().vmfs?
Fields
host_file_system_volume_: HostFileSystemVolumeblock_size_mb: i32Deprecated as of vSphere API 6.5, use HostVmfsVolume.blockSize instead.
Block size of VMFS.
Determines maximum file size. The maximum number of blocks is typically fixed with each specific version of VMFS. To increase the maximum size of a VMFS file, increase the block size.
The minimum block size is 1MB.
block_size: Option<i32>Block size of VMFS in KB.
Determines maximum file size. The maximum number of blocks is typically fixed with each specific version of VMFS. To increase the maximum size of a VMFS file, increase the block size.
The minimum block size is 1MB.
unmap_granularity: Option<i32>VMFS unmap reclaims unused storage space.
This property determines the granularity of unmap operations. The unit is KB. If not specified, the default value is the same as the block size of VMFS HostVmfsVolume.blockSize. This property cannot be changed after a VMFS volume is created.
unmap_priority: Option<String>VMFS unmap reclaims unused storage space.
This property determines the processing rate of unmaps. See HostVmfsVolumeUnmapPriority_enum for supported values. If not specified, the default value is low, which means unmap is processed at low rate. This property can be updated by calling HostStorageSystem.UpdateVmfsUnmapPriority.
unmap_bandwidth_spec: Option<VmfsUnmapBandwidthSpec>VMFS unmap bandwidth related specification.
See VmfsUnmapBandwidthSpec for detail.
max_blocks: i32Maximum number of blocks.
Determines maximum file size along with blockSize. See information about the blockSize.
major_version: i32Major version number of VMFS.
version: StringVersion string.
Contains major and minor version numbers.
uuid: StringThe universally unique identifier assigned to VMFS.
extent: Vec<HostScsiDiskPartition>The list of partition names that comprise this disk’s VMFS extents.
This property can be accessed via various enclosing objects. In VirtualCenter, where it can be accessed from multiple hosts, the value of this property may differ according to the context in which it is accessed. When accessed from the VmfsDatastoreInfo object, in VirtualCenter, this property reflects the extent information of any one of the hosts visible to the datastore.
For a VirtualCenter system which manages ESX Server 2.x and ESX Server 3.x hosts, this extent information is only correlatable across hosts if the extents are exposed on the same adapter on all hosts which can access them. To find the extent names for a specific host, this same property should be accessed via the host’s HostFileSystemVolume object, by correlating the uuid of the VMFS datastore in the VmfsDatastoreInfo object to the uuid in the FileSystemVolume object.
For a Virtual Center system which manages only ESX Server hosts with versions 4.0 onwards , this extent information is correlatable across hosts, irrespective of the adapters the extents are exposed on.
vmfs_upgradable: boolCan the filesystem be upgraded to a newer version.
See also HostStorageSystem.UpgradeVmfs.
force_mounted_info: Option<HostForceMountedInfo>Information about ‘forceMounted’ VmfsVolume.
When the system detects a copy of a VmfsVolume, it will not be auto-mounted on the host and it will be detected as ‘UnresolvedVmfsVolume’. If user decides to ‘forceMount’ the VmfsVolume on the host, forceMountedInfo will be populated. It will not be set for automounted VMFS volumes.
ssd: Option<bool>Indicates whether the volume is SSD backed.
If unset, the information whether the volume is SSD backed is unknown.
local: Option<bool>Indicates whether the volume is backed by local disk.
If unset, the information of the volume is local-disk backed is unknown.
scsi_disk_type: Option<String>The type of disk drives.
See ScsiDiskType_enum for supported types. If unset, the default disk drive type is native512.