pub struct HttpNfcLeaseManifestEntry {
pub key: String,
pub sha_1: String,
pub checksum: Option<String>,
pub checksum_type: Option<String>,
pub size: i64,
pub disk: bool,
pub capacity: Option<i64>,
pub populated_size: Option<i64>,
}Expand description
Provides a manifest for downloaded (exported) files and disks.
How to access
HttpNfcLease::http_nfc_lease_get_manifest()
Fields
key: StringKey used to match this entry with the corresponding HttpNfcLeaseDeviceUrl entry in HttpNfcLease.info.
sha_1: StringSHA-1 checksum of the data stream sent from the server.
This can be used to verify that the bytes received by the client match those sent by the HttpNfc server.
checksum: Option<String>Checksum of the data stream sent/recieved by host.
See HttpNfcLeaseManifestEntryChecksumType_enum for used algoritm.
checksum_type: Option<String>Algorithm used to produce checksum in respective property.
See HttpNfcLeaseManifestEntryChecksumType_enum for supported algorithms.
size: i64Size of the downloaded file.
disk: boolTrue if the downloaded file is a virtual disk backing.
capacity: Option<i64>The capacity of the disk, if the file is a virtual disk backing.
populated_size: Option<i64>The populated size of the disk, if the file is a virtual disk backing.