pub struct IncompatibleHostVersion {
pub vm_not_deployed_: VmNotDeployed,
}Expand description
Deprecated as of vSphere 9.0. Please refer to vLCM APIs.
An agent virtual machine is expected to be deployed on a host, but the agent could not be deployed because it was incompatible with the host.
This is an active remediable issue. To remediate, vSphere ESX Agent Manager redeployes the agent. However, the problem is likely to persist until either the host or the solution has been upgraded, so that the agent will become compatible with the host.
This structure may be used only with operations rendered under /eam.
Fields
vm_not_deployed_: VmNotDeployedTrait Implementations
Sourceimpl AgencyIssueTrait for IncompatibleHostVersion
impl AgencyIssueTrait for IncompatibleHostVersion
Sourcefn get_agency_issue(&self) -> &AgencyIssue
fn get_agency_issue(&self) -> &AgencyIssue
Get a reference to the AgencyIssue parent struct
Sourcefn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
fn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
Get a mutable reference to the AgencyIssue parent struct
Sourceimpl AgentIssueTrait for IncompatibleHostVersion
impl AgentIssueTrait for IncompatibleHostVersion
Sourcefn get_agent_issue(&self) -> &AgentIssue
fn get_agent_issue(&self) -> &AgentIssue
Get a reference to the AgentIssue parent struct
Sourcefn get_agent_issue_mut(&mut self) -> &mut AgentIssue
fn get_agent_issue_mut(&mut self) -> &mut AgentIssue
Get a mutable reference to the AgentIssue parent struct
Sourceimpl Debug for IncompatibleHostVersion
impl Debug for IncompatibleHostVersion
Sourceimpl Deref for IncompatibleHostVersion
impl Deref for IncompatibleHostVersion
Sourceimpl DerefMut for IncompatibleHostVersion
impl DerefMut for IncompatibleHostVersion
Sourceimpl IssueTrait for IncompatibleHostVersion
impl IssueTrait for IncompatibleHostVersion
Sourceimpl VimObjectTrait for IncompatibleHostVersion
impl VimObjectTrait for IncompatibleHostVersion
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
Sourceimpl VmNotDeployedTrait for IncompatibleHostVersion
impl VmNotDeployedTrait for IncompatibleHostVersion
Sourcefn get_vm_not_deployed(&self) -> &VmNotDeployed
fn get_vm_not_deployed(&self) -> &VmNotDeployed
Get a reference to the VmNotDeployed parent struct
Sourcefn get_vm_not_deployed_mut(&mut self) -> &mut VmNotDeployed
fn get_vm_not_deployed_mut(&mut self) -> &mut VmNotDeployed
Get a mutable reference to the VmNotDeployed parent struct
impl DataObjectTrait for IncompatibleHostVersion