pub struct IntegrityAgencyCannotDeleteSoftware {
pub integrity_agency_vum_issue_: IntegrityAgencyVumIssue,
}Expand description
Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs.
Cannot remove the Baseline associated with an Agency from VUM.
This is an active remediable issue. To remediate, vSphere ESX Agent Manager retries the delete operation. Note: In future this issue will denote also the removal of the Agency software (VIBs) from VUM software depot once VUM provides an API for that.
This structure may be used only with operations rendered under /eam.
Fields
integrity_agency_vum_issue_: IntegrityAgencyVumIssueTrait Implementations
Sourceimpl AgencyIssueTrait for IntegrityAgencyCannotDeleteSoftware
impl AgencyIssueTrait for IntegrityAgencyCannotDeleteSoftware
Sourcefn get_agency_issue(&self) -> &AgencyIssue
fn get_agency_issue(&self) -> &AgencyIssue
Get a reference to the AgencyIssue parent struct
Sourcefn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
fn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
Get a mutable reference to the AgencyIssue parent struct
Sourceimpl IntegrityAgencyVumIssueTrait for IntegrityAgencyCannotDeleteSoftware
impl IntegrityAgencyVumIssueTrait for IntegrityAgencyCannotDeleteSoftware
Sourcefn get_integrity_agency_vum_issue(&self) -> &IntegrityAgencyVumIssue
fn get_integrity_agency_vum_issue(&self) -> &IntegrityAgencyVumIssue
Get a reference to the IntegrityAgencyVumIssue parent struct
Sourcefn get_integrity_agency_vum_issue_mut(&mut self) -> &mut IntegrityAgencyVumIssue
fn get_integrity_agency_vum_issue_mut(&mut self) -> &mut IntegrityAgencyVumIssue
Get a mutable reference to the IntegrityAgencyVumIssue parent struct
Sourceimpl VimObjectTrait for IntegrityAgencyCannotDeleteSoftware
impl VimObjectTrait for IntegrityAgencyCannotDeleteSoftware
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
impl DataObjectTrait for IntegrityAgencyCannotDeleteSoftware