pub struct LicenseDiagnostics {
pub source_last_changed: String,
pub source_lost: String,
pub source_latency: f32,
pub license_requests: String,
pub license_request_failures: String,
pub license_feature_unknowns: String,
pub op_state: LicenseManagerStateEnum,
pub last_status_update: String,
pub op_failure_message: String,
}Expand description
Deprecated as of vSphere API 4.0, this is not used by the system.
This data object type provides summary status and diagnostic information for LicenseManager.
Counters in this property can be reset to zero. The property specified as a discontinuity is used to determine when this last occurred.
How to access
LicenseManager::diagnostics
Fields
source_last_changed: StringA timestamp of when sourceAvailable last changed state, expressed in UTC.
source_lost: StringCounter to track number of times connection to source was lost.
This value starts at zero and wraps at 2^32-1 to zero. Discontinuity: sourceLastChanged.
source_latency: f32Exponentially decaying average of the transaction time for license acquisition and routine communications with LicenseSource.
Units: milliseconds.
license_requests: StringCounter to track total number of licenses requested.
This value starts at zero and wraps at 2^32-1 to zero. Discontinuity: sourceLastChanged.
license_request_failures: StringCounter to track Total number of licenses requests that were not fulfilled (denied, timeout, or other).
This value starts at zero and wraps at 2^32-1 to zero. Discontinuity: sourceLastChanged.
license_feature_unknowns: StringCounter to track Total number of license features parsed from License source that are not recognized.
This value starts at zero and wraps at 2^32-1 to zero. Discontinuity: sourceLastChanged.
op_state: LicenseManagerStateEnumThe general state of the license subsystem.
last_status_update: StringA timestamp of when opState was last updated.
op_failure_message: StringA human readable reason when optState reports Fault condition.