pub struct OptionValue {
pub key: String,
pub value: Option<VimAny>,
}Expand description
Describes the key/value pair of a configured option.
How to access
ComputeResource::configuration_ex→ClusterConfigInfoEx.das_config.option?[*]ComputeResource::configuration_ex→ClusterConfigInfoEx.drs_config.option?[*]ComputeResource::configuration_ex→ClusterConfigInfoEx.dpm_config_info?.option?[*]ClusterComputeResource::configuration.das_config.option?[*]ClusterComputeResource::configuration.drs_config.option?[*]ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.das_config.option?[*]ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.drs_config.option?[*]ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.dpm_config_info?.option?[*]Datacenter::power_on_multi_vm_task(option)Datastore::datastore_enter_maintenance_mode().recommendations?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.extra_config?[*]
(10 of 100 paths)
Fields
key: StringThe name of the option using dot notation to reflect the option’s position in a hierarchy.
For example, you might have an option called “Ethernet” and another option that is a child of that called “Connection”. In this case, the key for the latter could be defined as “Ethernet.Connection”
value: Option<VimAny>The value of the option.
The Any data object type enables you to define any value for the option. Typically, however, the value of an option is of type String or Integer.