pub struct OrphanedAgency {
pub agency_issue_: AgencyIssue,
}Expand description
Deprecated eAM no longer raises this issue. If agecny is getting orphaned EAM simply destroys it.
The solution that created the agency is no longer registered with the vCenter server.
This is an active remediable issue. To remediate, vSphere ESX Agent Manager undeploys and removes the agency.
This structure may be used only with operations rendered under /eam.
Fields
agency_issue_: AgencyIssueTrait Implementations
Sourceimpl AgencyIssueTrait for OrphanedAgency
impl AgencyIssueTrait for OrphanedAgency
Sourcefn get_agency_issue(&self) -> &AgencyIssue
fn get_agency_issue(&self) -> &AgencyIssue
Get a reference to the AgencyIssue parent struct
Sourcefn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
fn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
Get a mutable reference to the AgencyIssue parent struct
Sourceimpl Debug for OrphanedAgency
impl Debug for OrphanedAgency
Sourceimpl Deref for OrphanedAgency
impl Deref for OrphanedAgency
Sourceimpl DerefMut for OrphanedAgency
impl DerefMut for OrphanedAgency
Sourceimpl Deserialize for OrphanedAgency
impl Deserialize for OrphanedAgency
Sourceimpl IssueTrait for OrphanedAgency
impl IssueTrait for OrphanedAgency
Sourceimpl VimObjectTrait for OrphanedAgency
impl VimObjectTrait for OrphanedAgency
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
impl DataObjectTrait for OrphanedAgency