pub struct PersonalityAgentPmIssue {
pub agent_issue_: AgentIssue,
}Expand description
Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs.
Base class for all issues which occurred during EAM communication with Personality Manager.
This structure may be used only with operations rendered under /eam.
Fields
agent_issue_: AgentIssueTrait Implementations
Sourceimpl AgencyIssueTrait for PersonalityAgentPmIssue
impl AgencyIssueTrait for PersonalityAgentPmIssue
Sourcefn get_agency_issue(&self) -> &AgencyIssue
fn get_agency_issue(&self) -> &AgencyIssue
Get a reference to the AgencyIssue parent struct
Sourcefn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
fn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
Get a mutable reference to the AgencyIssue parent struct
Sourceimpl AgentIssueTrait for PersonalityAgentPmIssue
impl AgentIssueTrait for PersonalityAgentPmIssue
Sourcefn get_agent_issue(&self) -> &AgentIssue
fn get_agent_issue(&self) -> &AgentIssue
Get a reference to the AgentIssue parent struct
Sourcefn get_agent_issue_mut(&mut self) -> &mut AgentIssue
fn get_agent_issue_mut(&mut self) -> &mut AgentIssue
Get a mutable reference to the AgentIssue parent struct
Sourceimpl Debug for PersonalityAgentPmIssue
impl Debug for PersonalityAgentPmIssue
Sourceimpl Deref for PersonalityAgentPmIssue
impl Deref for PersonalityAgentPmIssue
Sourceimpl DerefMut for PersonalityAgentPmIssue
impl DerefMut for PersonalityAgentPmIssue
Sourceimpl IssueTrait for PersonalityAgentPmIssue
impl IssueTrait for PersonalityAgentPmIssue
Sourceimpl PersonalityAgentPmIssueTrait for PersonalityAgentPmIssue
impl PersonalityAgentPmIssueTrait for PersonalityAgentPmIssue
Sourcefn get_personality_agent_pm_issue(&self) -> &PersonalityAgentPmIssue
fn get_personality_agent_pm_issue(&self) -> &PersonalityAgentPmIssue
Get a reference to the PersonalityAgentPmIssue parent struct
Sourcefn get_personality_agent_pm_issue_mut(&mut self) -> &mut PersonalityAgentPmIssue
fn get_personality_agent_pm_issue_mut(&mut self) -> &mut PersonalityAgentPmIssue
Get a mutable reference to the PersonalityAgentPmIssue parent struct
Sourceimpl VimObjectTrait for PersonalityAgentPmIssue
impl VimObjectTrait for PersonalityAgentPmIssue
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
impl DataObjectTrait for PersonalityAgentPmIssue