pub struct SoftwarePackage {Show 18 fields
pub name: String,
pub version: String,
pub type: String,
pub vendor: String,
pub acceptance_level: String,
pub summary: String,
pub description: String,
pub reference_url: Option<Vec<String>>,
pub creation_date: Option<String>,
pub depends: Option<Vec<Relation>>,
pub conflicts: Option<Vec<Relation>>,
pub replaces: Option<Vec<Relation>>,
pub provides: Option<Vec<String>>,
pub maintenance_mode_required: Option<bool>,
pub hardware_platforms_required: Option<Vec<String>>,
pub capability: SoftwarePackageCapability,
pub tag: Option<Vec<String>>,
pub payload: Option<Vec<String>>,
}Expand description
Software Packages provide discrete version and packaging.
This data is reported by CLI:: esxcli software vib get -n …
How to access
HostImageConfigManager::fetch_software_packages()
Fields
name: StringIdentifier that uniquely identifies the software package.
version: StringVersion string uniquely identifies this package.
type: StringType of vib installed.
See SoftwarePackageVibType_enum.
vendor: StringThe corporate entity that created this package.
acceptance_level: StringSee also HostImageAcceptanceLevel_enum.
summary: StringA brief description of the package contents.
description: StringA full account of the package contents.
reference_url: Option<Vec<String>>The list of SupportReference objects with in-depth support information.
creation_date: Option<String>The time when the package was installed.
On Autodeploy stateless installs there is no set value.
depends: Option<Vec<Relation>>A list of VIBs that must be installed at the same time as this VIB.
conflicts: Option<Vec<Relation>>A list of VIBs that cannot be installed at the same time as this VIB for a given version.
replaces: Option<Vec<Relation>>A list of SoftwareConstraint objects that identify VIBs that replace this VIB or make it obsolete.
VIBs automatically replace VIBs with the same name but lower versions.
provides: Option<Vec<String>>A list of virtual packages or interfaces this VIB provides.
maintenance_mode_required: Option<bool>True if hosts must be in maintenance mode for installation of this VIB.
hardware_platforms_required: Option<Vec<String>>A list of hardware platforms this package is supported on.
capability: SoftwarePackageCapabilityA set of optional attributes for this package.
tag: Option<Vec<String>>A list of string tags for this package defined by the vendor or publisher.
Tags can be used to identify characteristics of a package.
payload: Option<Vec<String>>A list of string tags to indicate one or more of what is contained: may be one of bootloader, upgrade, bootisobios, bootisoefi, vgz, tgz, boot or other values.