pub struct SolutionsApplySpec {
pub desired_state: Option<Vec<SolutionsSolutionConfig>>,
pub solutions: Option<Vec<String>>,
pub hosts: Option<Vec<ManagedObjectReference>>,
pub deployment_units: Option<Vec<String>>,
}Expand description
Specification describing a desired state to be applied.
This structure may be used only with operations rendered under /eam.
Fields
desired_state: Option<Vec<SolutionsSolutionConfig>>Complete desired state to be applied on the target entity.
the solutions member limits which parts of this desired state to be applied If the solutions member is omitted.
- Any solution described in this structure will be applied on the target entity
- Any solution already existing on the target entity, but missing from this structure, will be deleted from the target entity
solutions: Option<Vec<String>>If provided, limits the parts of the desiredState structure to be applied on the target entity.
- solutions that are also present in the desiredState structure will be applied on the target entity.
- solutions that are missing from the desiredState structure will be deleted from the target entity.
hosts: Option<Vec<ManagedObjectReference>>Specifies exact hosts to apply the desired state to, instead of every host in the cluster.
Applicable only to solutions with SolutionsHostBoundSolutionConfig.
Refers instances of HostSystem.
deployment_units: Option<Vec<String>>Deployment units on which solutions that are specified by the this structure need to be applied.
Applicable only to solutions with SolutionsClusterBoundSolutionConfig.
The deployment unit represents a single VM instance deployment. It is returned by the Solutions.Compliance operation.
If omitted - the configured solutions by SolutionsApplySpec.solutions are applied on all of the deployment units in the cluster.