pub struct TargetToSourceInfo {
pub source_group_id: ReplicationGroupId,
pub replication_agreement_description: Option<String>,
}Expand description
Information about each replication target.
This structure may be used only with operations rendered under /sms.
How to access
SmsStorageManager::query_replication_group_info()→QueryReplicationGroupSuccessResult.rg_info→TargetGroupInfo.source_infoVasaProvider::query_point_in_time_replica()→QueryReplicationGroupSuccessResult.rg_info→TargetGroupInfo.source_infoVasaProvider::query_replication_group()→QueryReplicationGroupSuccessResult.rg_info→TargetGroupInfo.source_info
Fields
source_group_id: ReplicationGroupIdId of the source CG id (including the fault domain ID).
replication_agreement_description: Option<String>Description of the replication agreement.
This could be used to describe the characteristics of the replication relationship between the source and the target (e.g. RPO, Replication Mode, and other such properties). It is expected that VASA provider will localize the string before sending to vSphere.