pub struct VAppCloneSpecResourceMap {
pub source: ManagedObjectReference,
pub parent: Option<ManagedObjectReference>,
pub resource_spec: Option<ResourceConfigSpec>,
pub location: Option<ManagedObjectReference>,
}Expand description
Maps source child entities to destination resource pools and resource settings.
If a mapping is not specified, a child is copied as a direct child of the parent.
How to access
VirtualApp::clone_v_app_task(spec).resource_mapping?[*]
Fields
source: ManagedObjectReferenceSource entity
Refers instance of ManagedEntity.
parent: Option<ManagedObjectReference>Resource pool to use for the cloned entity of source.
This must specify a resource pool that is not part of the vApp. If this is specified, a linked child (as opposed to a direct child) is created for the vApp.
Refers instance of ResourcePool.
resource_spec: Option<ResourceConfigSpec>An optional resource configuration for the cloned entity of the source.
If not specified, the same resource configuration as the source is used.
location: Option<ManagedObjectReference>A client can optionally specify a datastore in the resource map to override the default datastore location set in VAppCloneSpecResourceMap.location field.
This enables cloning to different compute resources that do not have shared datastores.
Refers instance of Datastore.