pub struct VasaProviderInfo {Show 24 fields
pub sms_provider_info_: SmsProviderInfo,
pub url: String,
pub certificate: Option<String>,
pub status: Option<String>,
pub status_fault: Option<MethodFault>,
pub vasa_version: Option<String>,
pub namespace: Option<String>,
pub last_sync_time: Option<String>,
pub supported_vendor_model_mapping: Option<Vec<SupportedVendorModelMapping>>,
pub supported_profile: Option<Vec<String>>,
pub supported_provider_profile: Option<Vec<String>>,
pub related_storage_array: Option<Vec<RelatedStorageArray>>,
pub provider_id: Option<String>,
pub certificate_expiry_date: Option<String>,
pub certificate_status: Option<String>,
pub service_location: Option<String>,
pub needs_explicit_activation: Option<bool>,
pub max_batch_size: Option<i64>,
pub retain_vasa_provider_certificate: Option<bool>,
pub array_independent_provider: Option<bool>,
pub type: Option<String>,
pub category: Option<String>,
pub priority: Option<i32>,
pub failover_group_id: Option<String>,
}Expand description
Information about VASA (vStorage APIs for Storage Awareness) providers.
This structure may be used only with operations rendered under /sms.
How to access
SmsProvider::query_provider_info()→VasaProviderInfoVasaProvider::query_provider_info()→VasaProviderInfoSmsStorageManager::query_storage_container().provider_info?[*]→VasaProviderInfo
Fields
sms_provider_info_: SmsProviderInfourl: StringProvider URL
certificate: Option<String>Provider certificate
status: Option<String>The operational state of VASA Provider.
status_fault: Option<MethodFault>A fault that describes the cause of the current operational status.
vasa_version: Option<String>Supported VASA(vStorage APIs for Storage Awareness) version
namespace: Option<String>Namespace to categorize storage capabilities provided by arrays managed by the provider
last_sync_time: Option<String>Time stamp to indicate when last sync operation was completed successfully.
supported_vendor_model_mapping: Option<Vec<SupportedVendorModelMapping>>List containing mapping between the supported vendorID and corresponding modelID
supported_profile: Option<Vec<String>>Deprecated as of SMS API 3.0, use StorageArray.supportedProfile.
List of supported profiles
supported_provider_profile: Option<Vec<String>>List of supported profiles at provider level.
Must be one of the string values from ProviderProfile_enum.
List containing mapping between storage arrays reported by the provider and information such as whether the provider is considered active for them.
provider_id: Option<String>Provider identifier reported by the provider which is unique within the provider namespace.
certificate_expiry_date: Option<String>Provider certificate expiry date.
certificate_status: Option<String>Provider certificate status This field holds values from VasaProviderCertificateStatus_enum
service_location: Option<String>Service location for the VASA endpoint that SMS is using to communicate with the provider.
needs_explicit_activation: Option<bool>Indicates the type of deployment supported by the provider.
If true, it is an active/passive deployment and the provider needs to be activated explicitly using activateProviderEx() VASA API. If false, it is an active/active deployment and provider does not need any explicit activation to respond to VASA calls.
max_batch_size: Option<i64>Maximum number of elements in batch APIs that the VASA Provider can support.
This value is common to all batch APIs supported by the provider. However, for each specific API, the provider may still throw or return TooMany fault in which a different value of maxBatchSize can be specified. If the value is not specified (zero) or invalid (negative), client will assume there’s no common limit for the number of elements that can be handled in all batch APIs.
retain_vasa_provider_certificate: Option<bool>Indicate whether the provider wants to retain its certificate after bootstrapping.
If true, SMS will not provision a VMCA signed certificate for the provider and all certificate life cycle management workflows are disabled for this provider certificate. If false, SMS will provision a VMCA signed certificate for the provider and all certificate life cycle management workflows are enabled for this provider certificate.
array_independent_provider: Option<bool>Indicates if this provider is independent of arrays.
Default value for this flag is false, which means this provider supports arrays. Arrays will be queried for this provider during sync. If this flag is set to true, arrays will not be synced for this provider and array related API will not be invoked on this provider.
type: Option<String>Type of this VASA provider.
This field will be equal to one of the values of VpType_enum.
category: Option<String>This field indicates the category of the provider and will be equal to one of the values of VpCategory_enum.
priority: Option<i32>Priority level of the provider within a VASA HA group.
For a stand-alone provider which does not participate in VASA HA, this field will be ignored.
The priority value is an integer with valid range from 0 to 255.
failover_group_id: Option<String>Unique identifier of a VASA HA group.
Providers should report this
identifier to utilize HA feature supported by vSphere. Different providers
reporting the same failoverGroupId will be treated as an HA
group. Failover/failback will be done within one group.