pub struct VibNotInstalled {
pub vib_issue_: VibIssue,
}Expand description
Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs.
A VIB module is expected to be installed/removed on a host, but it has not been installed/removed.
Typically, a more specific issue (a subclass of this issue) indicates the particular reason why the VIB module operation failed.
This is an active remediable issue. To remediate, vSphere ESX Agent Manager attempts the VIB operation again. In case of unreachable host vSphere ESX Agent Manager will remediate the issue automatically when the host becomes reachable.
This structure may be used only with operations rendered under /eam.
Fields
vib_issue_: VibIssueTrait Implementations
Sourceimpl AgencyIssueTrait for VibNotInstalled
impl AgencyIssueTrait for VibNotInstalled
Sourcefn get_agency_issue(&self) -> &AgencyIssue
fn get_agency_issue(&self) -> &AgencyIssue
Get a reference to the AgencyIssue parent struct
Sourcefn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
fn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
Get a mutable reference to the AgencyIssue parent struct
Sourceimpl AgentIssueTrait for VibNotInstalled
impl AgentIssueTrait for VibNotInstalled
Sourcefn get_agent_issue(&self) -> &AgentIssue
fn get_agent_issue(&self) -> &AgentIssue
Get a reference to the AgentIssue parent struct
Sourcefn get_agent_issue_mut(&mut self) -> &mut AgentIssue
fn get_agent_issue_mut(&mut self) -> &mut AgentIssue
Get a mutable reference to the AgentIssue parent struct
Sourceimpl Debug for VibNotInstalled
impl Debug for VibNotInstalled
Sourceimpl Deref for VibNotInstalled
impl Deref for VibNotInstalled
Sourceimpl DerefMut for VibNotInstalled
impl DerefMut for VibNotInstalled
Sourceimpl Deserialize for VibNotInstalled
impl Deserialize for VibNotInstalled
Sourceimpl IssueTrait for VibNotInstalled
impl IssueTrait for VibNotInstalled
Sourceimpl VibIssueTrait for VibNotInstalled
impl VibIssueTrait for VibNotInstalled
Sourcefn get_vib_issue(&self) -> &VibIssue
fn get_vib_issue(&self) -> &VibIssue
Get a reference to the VibIssue parent struct
Sourcefn get_vib_issue_mut(&mut self) -> &mut VibIssue
fn get_vib_issue_mut(&mut self) -> &mut VibIssue
Get a mutable reference to the VibIssue parent struct
Sourceimpl VibNotInstalledTrait for VibNotInstalled
impl VibNotInstalledTrait for VibNotInstalled
Sourcefn get_vib_not_installed(&self) -> &VibNotInstalled
fn get_vib_not_installed(&self) -> &VibNotInstalled
Get a reference to the VibNotInstalled parent struct
Sourcefn get_vib_not_installed_mut(&mut self) -> &mut VibNotInstalled
fn get_vib_not_installed_mut(&mut self) -> &mut VibNotInstalled
Get a mutable reference to the VibNotInstalled parent struct
Sourceimpl VimObjectTrait for VibNotInstalled
impl VimObjectTrait for VibNotInstalled
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
impl DataObjectTrait for VibNotInstalled