pub struct VirtualDiskSparseVer2BackingOption {
pub virtual_device_file_backing_option_: VirtualDeviceFileBackingOption,
pub disk_mode: ChoiceOption,
pub split: BoolOption,
pub write_through: BoolOption,
pub growable: bool,
pub hot_growable: bool,
pub uuid: bool,
pub virtual_disk_format: Option<ChoiceOption>,
}Expand description
This data object type contains the options available when backing a virtual disk using a host file with the sparse file format from VMware Server.
How to access
EnvironmentBrowser::query_config_option().hardware_options.virtual_device_option[*].backing_option?[*]→VirtualDiskSparseVer2BackingOptionEnvironmentBrowser::query_config_option_ex().hardware_options.virtual_device_option[*].backing_option?[*]→VirtualDiskSparseVer2BackingOption
Fields
virtual_device_file_backing_option_: VirtualDeviceFileBackingOptiondisk_mode: ChoiceOptionThe disk mode.
Valid disk modes are:
- persistent
- nonpersistent
- undoable
- independent_persistent
- independent_nonpersistent
- append
See also VirtualDiskMode_enum.
split: BoolOptionFlag to indicate whether or not the host supports allowing the client to select whether or not a sparse disk should be split.
write_through: BoolOptionFlag to indicate whether or not the host supports allowing the client to select “writethrough” as a mode for virtual disks.
Typically, this is available only for VMware Server Linux hosts.
growable: boolIndicates whether or not this disk backing can be extended to larger sizes through a reconfigure operation.
If set to true, reconfiguring this virtual disk with a VirtualDisk.capacityInKB value greater than its current value will grow the disk to the newly specified size.
hot_growable: boolIndicates whether or not this disk backing can be extended to larger sizes through a reconfigure operation while the virtual machine is powered on.
If set to true, reconfiguring this virtual disk with a VirtualDisk.capacityInKB value greater than its current value will grow the disk to the newly specified size while the virtual machine is powered on.
uuid: boolFlag to indicate whether this backing supports disk UUID property.
virtual_disk_format: Option<ChoiceOption>Virtual disk format.
See DatastoreSectorFormat_enum for the list of supported types.
Since: vSphere API Release 9.0.0.0