pub struct VirtualMachineVcpuConfig {
pub latency_sensitivity: Option<LatencySensitivity>,
}Expand description
Vcpu configuration.
How to access
VirtualMachine::config.vcpu_config?[*]StoragePod::pod_storage_drs_entry.recommendation?[*].action?[*]→ClusterClusterInitialPlacementAction.config_spec?.vcpu_config?[*]StoragePod::pod_storage_drs_entry.action_history?[*].action→ClusterClusterInitialPlacementAction.config_spec?.vcpu_config?[*]ClusterComputeResource::action_history.action→ClusterClusterInitialPlacementAction.config_spec?.vcpu_config?[*]ClusterComputeResource::recommendation.action?[*]→ClusterClusterInitialPlacementAction.config_spec?.vcpu_config?[*]VirtualMachineSnapshot::config.vcpu_config?[*]VirtualMachine::reconfig_vm_task(spec).vcpu_config?[*]VirtualMachine::clone_vm_task(spec).config?.vcpu_config?[*]HostSystem::query_memory_overhead_ex(vm_config_info).vcpu_config?[*]Folder::create_vm_task(config).vcpu_config?[*]
(10 of 26 paths)
Fields
latency_sensitivity: Option<LatencySensitivity>Latency sensitivity specification for this vcpu.
The latency sensitivity can be configured per-vcpu only when the VM latencySensitivity is configured to high in the same ConfigSpec. Setting latencySensitivity, but not setting the vcpu’s LatencySensitivity would apply the VM’s latency sensitivity level to all the vcpus of the VM. The latency sensitivity of the vcpu should not exceed the latency sensivity level of the VM. The only allowed levels for vcpu Latency sensitivity are high or normal