pub struct VmHookTimedout {
pub vm_issue_: VmIssue,
}Expand description
The VM hook remediation timed out.
In order to remediate the issue: Resolve the issue via vLCM System VMs API and process the hook within the timeout configured for the System VM Solution this issue’s VM belongs to.
This structure may be used only with operations rendered under /eam.
Since: vEAM API 9.0
Fields
vm_issue_: VmIssueTrait Implementations
Sourceimpl AgencyIssueTrait for VmHookTimedout
impl AgencyIssueTrait for VmHookTimedout
Sourcefn get_agency_issue(&self) -> &AgencyIssue
fn get_agency_issue(&self) -> &AgencyIssue
Get a reference to the AgencyIssue parent struct
Sourcefn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
fn get_agency_issue_mut(&mut self) -> &mut AgencyIssue
Get a mutable reference to the AgencyIssue parent struct
Sourceimpl AgentIssueTrait for VmHookTimedout
impl AgentIssueTrait for VmHookTimedout
Sourcefn get_agent_issue(&self) -> &AgentIssue
fn get_agent_issue(&self) -> &AgentIssue
Get a reference to the AgentIssue parent struct
Sourcefn get_agent_issue_mut(&mut self) -> &mut AgentIssue
fn get_agent_issue_mut(&mut self) -> &mut AgentIssue
Get a mutable reference to the AgentIssue parent struct
Sourceimpl Debug for VmHookTimedout
impl Debug for VmHookTimedout
Sourceimpl Deref for VmHookTimedout
impl Deref for VmHookTimedout
Sourceimpl DerefMut for VmHookTimedout
impl DerefMut for VmHookTimedout
Sourceimpl Deserialize for VmHookTimedout
impl Deserialize for VmHookTimedout
Sourceimpl IssueTrait for VmHookTimedout
impl IssueTrait for VmHookTimedout
Sourceimpl VimObjectTrait for VmHookTimedout
impl VimObjectTrait for VmHookTimedout
fn as_vim_object_ref<'a>(&'a self) -> &'a dyn VimObjectTrait
fn data_type(&self) -> StructType
Sourceimpl VmIssueTrait for VmHookTimedout
impl VmIssueTrait for VmHookTimedout
Sourcefn get_vm_issue(&self) -> &VmIssue
fn get_vm_issue(&self) -> &VmIssue
Get a reference to the VmIssue parent struct
Sourcefn get_vm_issue_mut(&mut self) -> &mut VmIssue
fn get_vm_issue_mut(&mut self) -> &mut VmIssue
Get a mutable reference to the VmIssue parent struct
impl DataObjectTrait for VmHookTimedout