pub struct VsanClusterEncryptionHealthSummary {
pub overall_health: Option<String>,
pub config_health: Option<String>,
pub kms_health: Option<String>,
pub vc_kms_result: Option<VsanVcKmipServersHealth>,
pub host_results: Option<Vec<VsanEncryptionHealthSummary>>,
pub aesni_health: Option<String>,
}Expand description
This class defines encryption health summary in cluster level.
The encryption health summary is aggregated from each health check result from all hosts across the cluster and checked configuration consistency against cluster configuration on vCenter side.
This structure may be used only with operations rendered under /vsan.
How to access
VsanVcClusterHealthSystem::vsan_query_vc_cluster_health_summary().encryption_health?VsanVcClusterHealthSystem::vsan_query_cluster_historical_health().encryption_health?VsanResourceCheckSystem::vsan_get_resource_check_status().result?.health?.encryption_health?
Fields
overall_health: Option<String>Overall health state for encryption configuration and Key Management Server connection on vCenter and across all hosts in the cluster.
config_health: Option<String>Encryption configuration consistency health across all hosts in the cluster.
kms_health: Option<String>Key Management Server connection health on vCenter and across all hosts in the cluster.
vc_kms_result: Option<VsanVcKmipServersHealth>Key Management Servers connection health result on vCenter side.
host_results: Option<Vec<VsanEncryptionHealthSummary>>Encryption health results on all of vSAN hosts in the cluster.
aesni_health: Option<String>AES-NI configuration consistency health across all hosts in the cluster.
Valid value can be [‘green’ , ‘yellow’, ‘red’, ‘unknown’]