pub struct VsanClusterVMsHealthSummaryResult {
pub num_v_ms: i32,
pub state: Option<String>,
pub health: String,
pub vm_instance_uuids: Option<Vec<String>>,
}Expand description
Captures how many (and which) VM share a given health status.
The VM considered may be a subset of the total VM, as specified by the query API.
How to access
VsanVcClusterHealthSystem::vsan_query_vc_cluster_health_summary().vm_health?.health_state_list?[*]VsanVcClusterHealthSystem::vsan_query_cluster_historical_health().vm_health?.health_state_list?[*]VsanResourceCheckSystem::vsan_get_resource_check_status().result?.health?.vm_health?.health_state_list?[*]
Fields
num_v_ms: i32Number of VMs that have this health status.
state: Option<String>The VM health state.
All of possible state include ‘green’, ‘yellow’, ‘red’ and ‘info’
health: StringThe VM state in vSAN cluster.
The VM state is computed by fetching the most severe state of virtual disk in this VM. All of possible states with severity order include ‘inaccessible’, ‘reduced-availability-with-no-rebuild’, ‘reduced-availability-with-no-rebuild-delay-timer’, ‘reduced-availability-with-active-rebuild’, ‘data-move’, ‘non-availability-related-reconfig’, ‘non-availability-related-incompliance’ and ‘healthy’
vm_instance_uuids: Option<Vec<String>>instanceUuids of VM that have this health status.
Only included if query API requested it due to size.