pub struct VsanDataDrivenApiAction {
pub action_id: String,
pub action_label: LocalizableMessage,
pub action_description: LocalizableMessage,
pub enabled: bool,
pub parameters: Option<Vec<KeyValue>>,
}Expand description
The vSAN Cluster health action is a set of instructions that guide vSphere and storage administrators on how to address potential health problems detected by the vSAN health service.
The data-driven API action, in this case, refers to the action button in the user interface, which is defined by vSAN remediation rules and does not require any code changes from the UI side. This approach offers flexibility as it allows administrators to invoke any APIs provided by the vSAN service using the button in the UI.
This structure may be used only with operations rendered under /vsan.
How to access
VsanPerformanceManager::vsan_perf_query_cluster_health().group_details?[*]→VsanClusterHealthResultTable.rows?[*].actions?[*].api_actionVsanPerformanceManager::vsan_perf_query_cluster_health().group_tests?[*].test_details?[*]→VsanClusterHealthResultTable.rows?[*].actions?[*].api_actionVsanPerformanceManager::vsan_perf_query_cluster_health().group_details?[*]→VsanClusterHealthResultWithRemediation.issue_detail?[*].rows?[*].actions?[*].api_actionVsanPerformanceManager::vsan_perf_query_cluster_health().group_details?[*]→VsanClusterHealthResultWithRemediation.troubleshooting?.diagnostic_steps?[*]→VsanHealthDataDrivenAction.api_actionVsanPerformanceManager::vsan_perf_query_cluster_health().group_details?[*]→VsanClusterHealthResultWithRemediation.troubleshooting?.remediations?[*]→VsanHealthDataDrivenAction.api_actionVsanVcClusterHealthSystem::vsan_query_vc_cluster_health_summary().groups?[*].group_details?[*]→VsanClusterHealthResultTable.rows?[*].actions?[*].api_actionVsanVcClusterHealthSystem::vsan_query_cluster_historical_health().groups?[*].group_details?[*]→VsanClusterHealthResultTable.rows?[*].actions?[*].api_actionVsanClusterHealthSystem::vsan_query_cluster_create_vm_health_test().cluster_result.health_test?.test_details?[*]→VsanClusterHealthResultTable.rows?[*].actions?[*].api_actionVsanClusterHealthSystem::vsan_query_cluster_network_perf_test().cluster_result.health_test?.test_details?[*]→VsanClusterHealthResultTable.rows?[*].actions?[*].api_actionVsanVcClusterHealthSystem::vsan_query_vc_cluster_create_vm_health_history_test().cluster_result.health_test?.test_details?[*]→VsanClusterHealthResultTable.rows?[*].actions?[*].api_action
(10 of 100 paths)
Fields
action_id: StringThe unique action ID
action_label: LocalizableMessageThe localized label for the action that is displayed in the UI.
action_description: LocalizableMessageThe localized description for the action that is displayed in the UI.
enabled: boolTrue indicates the action will be enabled from UI.
In the data-driven action use case, it is not possible for it to be False.
parameters: Option<Vec<KeyValue>>The action parameters which can be used as the parameters for this action API when calling from UI.