pub struct VsanHostCreateNativeKeyProviderSpec {
pub provider: String,
pub key_id: Option<String>,
pub key_derivation_key: Option<String>,
pub tpm_required: Option<bool>,
}Expand description
Specifies parameters needed to create native key provider.
This structure may be used only with operations rendered under /vsan.
How to access
VsanVcsaDeployerSystem::vsan_post_config_for_vcsa(spec).create_native_key_provider_spec?VsanVcsaDeployerSystem::vsan_prepare_vsan_for_vcsa(spec).create_native_key_provider_spec?
Fields
provider: StringProvider identifier.
A unique string provided by the client.
key_id: Option<String>Key identifier for the provider.
The key identifier is required to be a 128-bit UUID represented as a hexadecimal string in “12345678-abcd-1234-cdef-123456789abc” format. If unset, the key identifier will be generated automatically.
key_derivation_key: Option<String>Key used to derive data encryption keys.
Base64 encoded. If unset, the key derivation key will be generated automatically.
tpm_required: Option<bool>TPM Required or Not.
When TPM is required, user won’t be able to create native key provider on hosts without TPM. If unset, there’s no TPM constraints on host.