pub struct VsanHwToVcgInfoMappingSpec {
pub entity: String,
pub vsan_hw_to_vcg_info_mappings: Vec<VsanHwToVcgInfoMapping>,
}Expand description
This class defines the mappings from the hardware indentifiers to the vSAN VCG entries under one entity.
An entity can be one vSAN cluster, one host, one controller or one NVMe disk. If the entity is a cluster or a host, it means applying to all the corresponding hardware devices under the cluster or the host. For example: if the entity is a host, and the host has 2 NVMe disks who have the same hardware identifier, then it means that the 2 NVMe disks are assumed to be the same device and be mapping to the same vSAN VCG entry.
This structure may be used only with operations rendered under /vsan.
How to access
VsanVcClusterHealthSystem::set_vsan_vcg_mapping_for_hw_devices(spec)
Fields
entity: StringThe MOID string of the entity.
vsan_hw_to_vcg_info_mappings: Vec<VsanHwToVcgInfoMapping>Refer to (@link vim.host.VsanHwToVcgInfoMapping).