pub struct VsanIoTripAnalyzerConfig {
pub recurrences: Option<Vec<VsanIoTripAnalyzerRecurrence>>,
}Expand description
The spec for vSAN IO trip analyzer configuration.
This structure may be used only with operations rendered under /vsan.
How to access
VsanDiagnosticsSystem::get_io_trip_analyzer_scheduler_config()
Fields
recurrences: Option<Vec<VsanIoTripAnalyzerRecurrence>>The spec defining the recurrence settings for all entities to be diagnosed by IO trip analyzer.
Currently it only supports diagnosing for one entity. If not specified, it will remove the current recurrence settings.