pub struct VsanIoTripAnalyzerRecurrence {
pub name: Option<String>,
pub targets: Vec<VsanIoDiagnosticsTarget>,
pub start_time: String,
pub end_time: Option<String>,
pub duration: i64,
pub interval: i64,
pub status: String,
}Expand description
The spec for vSAN IO trip analyzer scheduler recurrence settings.
This structure may be used only with operations rendered under /vsan.
How to access
VsanDiagnosticsSystem::create_io_trip_analyzer_recurrences()VsanDiagnosticsSystem::create_io_trip_analyzer_recurrences(recurrences)VsanDiagnosticsSystem::edit_io_trip_analyzer_recurrences()VsanDiagnosticsSystem::edit_io_trip_analyzer_recurrences(recurrences)VsanDiagnosticsSystem::get_io_trip_analyzer_scheduler_config().recurrences?[*]
Fields
name: Option<String>The unique name for this recurrence setting.
If not given, it will generate the name automatically.
targets: Vec<VsanIoDiagnosticsTarget>The target entity list to run the IO trip analyzer diagnosis.
Currently it supports only one entity to be given.
start_time: StringThe start time for the IO trip analyzer recurrence.
end_time: Option<String>The end time for the IO trip analyzer recurrence.
If not set, the recurrence will not end.
duration: i64The diagnostic duration for each IO trip analyzer occurence.
The unit is second.
interval: i64The time interval between two IO trip analyzer tasks.
If the value is set to 0, it means it is one-time IO trip analyzer scheduling, no recurrence needed. Unit is second.
status: StringThe recurrence status.
If the status is set as enabled, the scheduler with this recurrence setting is up and running. Diagnostic tasks will be triggered based on the setting. If the status is set as disabled, the scheduler with this recurrence setting is not runninig. No diagnostic task will be triggered.
See also VsanIOTripAnalyzerRecurrenceStatus_enum.