pub struct VsanMetricProfile {
pub auth_token: String,
}Expand description
The vSAN metrics configuration per monitor client.
In pull mode, when vSAN metrics query happens, all authTokens configured to vSAN node will be used for authentication and identify the monitor client.
This structure may be used only with operations rendered under /vsan.
How to access
HostSystem::config.vsan_host_config?→VsanHostConfigInfoEx.metrics_config?.profiles?[*]ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.metrics_config?.profiles?[*]ComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_host_config?[*]→VsanHostConfigInfoEx.metrics_config?.profiles?[*]ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_config_info?→VsanConfigInfoEx.metrics_config?.profiles?[*]ClusterComputeResource::configuration_ex→ClusterConfigInfoEx.vsan_host_config?[*]→VsanHostConfigInfoEx.metrics_config?.profiles?[*]HostVsanSystem::config→VsanHostConfigInfoEx.metrics_config?.profiles?[*]Folder::create_cluster_ex(spec).vsan_config?→VsanConfigInfoEx.metrics_config?.profiles?[*]Folder::create_cluster_ex(spec).vsan_host_config_spec?[*]→VsanHostConfigInfoEx.metrics_config?.profiles?[*]Folder::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_config?→VsanConfigInfoEx.metrics_config?.profiles?[*]Folder::add_standalone_host_task(comp_res_spec)→ClusterConfigSpecEx.vsan_host_config_spec?[*]→VsanHostConfigInfoEx.metrics_config?.profiles?[*]
(10 of 42 paths)
Fields
auth_token: StringThe credential used for authentication between monitor and vSAN metrics provider.
The length of this token should not exceed 30.