pub struct VsanObjectDetail {
pub uuid: String,
pub object_path: Option<String>,
pub snapshots: Option<Vec<VsanSnapshotDetail>>,
}Expand description
The information related to vSAN object.
This structure may be used only with operations rendered under /vsan.
Since: 8.0.0.4
Fields
uuid: StringvSAN object uuid.
Its format is like ‘e3d10064-ae3c-9323-568d-b02628350470’.
object_path: Option<String>Vmdk descriptor file that points to the object running point.
It is a full path in the format like “/vmfs/volume/vsan:522116b0018397a0-faf6eef653793842/2e661d64-20a3-afb9-80f6-e4434ba16432/foo.vmdk” It is set when the field includeDescriptorPath of VsanSnapshotQuerySpec is True.
snapshots: Option<Vec<VsanSnapshotDetail>>A list of snapshots information of vSAN object.