pub struct VsanStretchedClusterConfig {
pub cluster: ManagedObjectReference,
pub preferred_fd_name: Option<String>,
pub fault_domain_config: Option<VimClusterVsanStretchedClusterFaultDomainConfig>,
}Expand description
Config spec of single vSAN stretched cluster
This structure may be used only with operations rendered under /vsan.
How to access
VimClusterVsanVcStretchedClusterSystem::vsan_vc_add_witness_host_for_clusters(config_spec).clusters[*]VimClusterVsanVcStretchedClusterSystem::vsan_vc_replace_witness_host_for_clusters(config_spec).clusters[*]
Fields
cluster: ManagedObjectReferenceThe target vSAN cluster to add/replace witness host.
Refers instance of ClusterComputeResource.
preferred_fd_name: Option<String>User friendly name of preferred Fault Domain configured in target cluster.
fault_domain_config: Option<VimClusterVsanStretchedClusterFaultDomainConfig>The mapping between Fault Domain and vSAN hosts reside in target cluster, to decide how to configure vSAN cluster into two sites.