pub struct VslmCloneSpec {
pub vslm_migrate_spec_: VslmMigrateSpec,
pub name: String,
pub keep_after_delete_vm: Option<bool>,
pub metadata: Option<Vec<KeyValue>>,
}Expand description
Specification of cloning a virtual storage object.
How to access
HostVStorageObjectManager::host_clone_v_storage_object_task(spec)VcenterVStorageObjectManager::clone_v_storage_object_task(spec)VslmVStorageObjectManager::vslm_clone_v_storage_object_task(spec)
Fields
vslm_migrate_spec_: VslmMigrateSpecname: StringDescriptive name of the cloned virtual storage object.
keep_after_delete_vm: Option<bool>Choice of the deletion behavior of this virtual storage object.
If not set, the default value is false.
metadata: Option<Vec<KeyValue>>The metadata KV pairs that are supposed to be updated on the destination virtual storage object.
The clone task is atomic by design. That being said, failing to update the specified metadata pairs leads to the failure of the clone task. If unset, no metadata will be updated. An empty string value is indicative of a vcenter tag.