Skip to main content Module traits Copy item path Source ActionTrait This data object type defines the action initiated by a scheduled task or alarm. AgencyIssueTrait Base class for all agency issues. AgencyScopeTrait Deprecated as of vSphere 9.0. Please refer to vLCM APIs. AgentIssueTrait Base class for all agent issues. AgentSslTrustTrait Deprecated as of vSphere 9.0. Please refer to vLCM APIs. AgentStoragePolicyTrait Deprecated as of vSphere 9.0. Please refer to vLCM APIs. AlarmActionTrait Action invoked by triggered alarm. AlarmExpressionTrait Base type for the expressions specifying the conditions that define
the status of an alarm. AlarmSpecTrait Parameters for alarm creation. AnswerFileCreateSpecTrait Base class for host-specific answer file options. ApplyProfileTrait The ApplyProfile data object is the base class for all data objects
that define profile configuration data. ArrayUpdateSpecTrait An ArrayUpdateSpec data object type is a common superclass
for supporting incremental updates to arrays. BaseConfigInfoBackingInfoTrait The data object type is a base type of backing of a virtual
storage object. BaseConfigInfoFileBackingInfoTrait Information for file backing of a virtual storage
object. BaseConfigInfoTrait This data object type contains the basic configuration for
a virtual storage object or a virtual storage object snapshot. ClusterActionTrait Base class for all action recommendations in VirtualCenter. ClusterAgentAgentIssueTrait Base class for all cluster bound agents. ClusterAgentVmIssueTrait Base class for all cluster bound Virtual Machines. ClusterAgentVmNotDeployedTrait A cluster agent Virtual Machine is expected to be deployed on a cluster, but
the cluster agent Virtual Machine has not been deployed or has been exlicitly
deleted from the cluster. ClusterAgentVmPoweredOffTrait A cluster agent Virtual Machine is expected to be powered on, but the agent
Virtual Machine is powered off. ClusterComputeResourceValidationResultBaseTrait Describes the validation results. ClusterDasAdmissionControlInfoTrait Base class for admission control related information of a vSphere HA cluster. ClusterDasAdmissionControlPolicyTrait Base class for specifying how admission control should be done for vSphere HA. ClusterDasAdvancedRuntimeInfoTrait Base class for advanced runtime information related to the high
availability service for a cluster. ClusterDasDataTrait Base class for DAS data for high availability service for a cluster. ClusterDasHostInfoTrait HA specific advanced information pertaining to the hosts in the cluster. ClusterDrsFaultsFaultsByVmTrait FaultsByVm is the faults generated by DRS when it tries to
move a VM. ClusterGroupInfoTrait ClusterGroupInfo is the base type for all virtual machine
and host groups.ClusterProfileConfigSpecTrait DataObject which is a baseclass for other configuration
specifications. ClusterProfileCreateSpecTrait Base class for Cluster CreateSpecs ClusterRuleInfoTrait The ClusterRuleInfo data object is the base type for affinity
and anti-affinity rules. ClusterSlotPolicyTrait The base class ClusterSlotPolicy is used for specifying how
the slot size is to be computed for the failover level HA admission control
policy. CnsAccessControlSpecTrait This class defines general access control list spec. CnsBackingObjectDetailsTrait Base class for providing additional option for creating backing for a
container volume. CnsBaseCreateSpecTrait Base specification for volume creation. CnsEntityMetadataTrait Base data object that represents the metadata associated with an entity
in container orchestrators like Kubernetes, Docker swarm etc. CnsFileBackingDetailsTrait Details for a file type backing for container volume. CnsFileCreateSpecTrait Specification for file volume creation. CnsQueryFilterTrait Filter object to query matching volumes. CnsVolumeOperationResultTrait Base class for returning result of operation invoked on a specific volume. CnsVolumeRelocateSpecTrait Base class for the volume relocation spec. CnsVolumeSourceTrait Base class for the source of volumes creation. ComputeResourceConfigInfoTrait Configuration of the compute resource; applies to both standalone hosts
and clusters. ComputeResourceConfigSpecTrait Changes to apply to the compute resource configuration. ComputeResourceSummaryTrait This data object type encapsulates a typical set of ComputeResource information
that is useful for list views and summary pages. CryptoManagerKmipCryptoKeyStatusKeyInfoTrait Base class of key information. CryptoSpecNoOpTrait This data object type indicates that the encryption settings of the
virtual machine or disk should not be modified by the operation. CryptoSpecTrait This data object type encapsulates virtual machine or disk encryption
settings. CustomFieldValueTrait Base type for storing values. CustomizationIdentitySettingsTrait Base type for sysprep, sysprepText, or linuxPrep object type. CustomizationIpGeneratorTrait Base type for the various IP specification possibilities. CustomizationIpV6GeneratorTrait Base type for the various IpV6 specification possibilities CustomizationNameTrait A base object type for a virtual machine name that can be either fixed or
auto-generated. CustomizationOptionsTrait Base object type for optional operations supported by the customization process. DailyTaskSchedulerTrait The DailyTaskScheduler data object sets the time for daily
task execution. DataObjectTrait This is the built-in base interface implemented by all
data objects. DatastoreInfoTrait Detailed information about a datastore. DescriptionTrait Static strings used for describing an object or property. DeviceIdTrait Base class that represents a replicated device. DirectPathProfileManagerCapacityQuerySpecTrait Base specification describing information about a DirectPath profile
for which capacity needs to be queried using
DirectPathProfileManager.DirectPathProfileManagerQueryCapacity . DirectPathProfileManagerCapacityResultTrait Base specification for capacity query result returned from
DirectPathProfileManager.DirectPathProfileManagerQueryCapacity . DirectPathProfileManagerDirectPathConfigTrait Base configuration of a DirectPath device. DirectPathProfileManagerTargetEntityTrait Base specification describing the target entity against which the
capacity of a DirectPath profile can be queried using
DirectPathProfileManager.DirectPathProfileManagerQueryCapacity . DistributedVirtualSwitchHostMemberBackingTrait Base class. DistributedVirtualSwitchManagerHostDvsFilterSpecTrait Base class for filters to check host compatibility. DvPortSettingTrait The DVPortSetting data object
describes the network configuration of a DistributedVirtualPort . DvPortgroupPolicyTrait The DistributedVirtualPortgroup policies. DvsConfigInfoTrait Configuration of a DistributedVirtualSwitch . DvsConfigSpecTrait The DVSConfigSpec
data object contains configuration data for a
DistributedVirtualSwitch . DvsFeatureCapabilityTrait The DVSFeatureCapability data object
represents the capabilities supported by a
DistributedVirtualSwitch . DvsFilterConfigTrait This class defines Network Filter configuration. DvsFilterSpecConnecteeSpecTrait Base class for connectee filters. DvsFilterSpecVlanSpecTrait Base class for VlanSpec filters. DvsHealthCheckCapabilityTrait Health check capabilities of health check supported by the
vSphere Distributed Switch DvsHealthCheckConfigTrait The DVSHealthCheckConfig data object
defines vSphere Distributed Switch health check configuration. DvsIpPortTrait Base class for specifying Ports. DvsNetworkRuleActionTrait This class is the base class for network rule action. DvsNetworkRuleQualifierTrait This class is the base class for identifying network traffic. DvsTrafficFilterConfigTrait This class defines Traffic Filter configuration. DvsUplinkPortPolicyTrait The base class for uplink port policy. DvsVNicProfileTrait The DvsVNicProfile data object is the base object
for host and service console Virtual NIC subprofiles. EamObjectRuntimeInfoTrait Deprecated as of vSphere 9.0. Please refer to vLCM APIs. ElementDescriptionTrait Static strings used for describing an object model string or enumeration. EntityEventArgumentTrait The event argument is a managed entity object. EntityResourceCheckDetailsTrait Details about the resource check result for a given entity. EventArgumentTrait This is the base type for event argument types. EventManagerEventViewSpecTrait BaseClass allowing different views on filtered set. FailoverParamTrait Input to the failover or testFailover methods. FaultDomainIdTrait Represents the identity of a replication fault domain. FaultToleranceConfigInfoTrait FaultToleranceConfigInfo is a data object type containing Fault Tolerance
settings for this virtual machine. FileBackedVirtualDiskSpecTrait Specification used to create a file based virtual disk FileInfoTrait This data object type contains rudimentary information about a file in a
datastore. FileQueryTrait The data object type that describes the base query specification. GroupInfoTrait Replication group information. GroupOperationResultTrait The base class for any operation on a replication group. GuestAuthSubjectTrait A Subject. GuestAuthenticationTrait GuestAuthentication is an abstract base class for authentication
in the guest. GuestFileAttributesTrait Different attributes for a guest file. GuestProgramSpecTrait This describes the arguments to GuestProcessManager.StartProgramInGuest . GuestRegValueDataSpecTrait This describes the registry value data. HbrReplicationTargetSpecTrait The base data type for all different spec operations. HostAccountSpecTrait This data object type contains common parameters
for local account creation. HostAuthenticationStoreInfoTrait The HostAuthenticationStoreInfo base class defines status information
for local and host Active Directory authentication. HostConnectInfoNetworkInfoTrait The base data object type for information about networks on the host. HostDataTransportConnectionInfoTrait DataTransportConnectionInfo contains common information about data transport
connections on a host. HostDatastoreConnectInfoTrait The base data object type for information about datastores on the host. HostDeviceTrait This data object type defines a device on the host. HostDigestInfoTrait This data object type describes the digest information HostDirectoryStoreInfoTrait HostDirectoryStoreInfo is a base class for objects that
provide information about directory-based authentication stores.HostDnsConfigTrait This data object type describes the DNS configuration. HostFibreChannelHbaTrait This data object type describes the Fibre Channel host bus adapter. HostFibreChannelTargetTransportTrait Fibre Channel transport information about a SCSI target. HostFileSystemVolumeTrait Detailed information about a file system. HostHardwareElementInfoTrait Data object describing the operational status of a physical
element. HostHbaCreateSpecTrait A data object which specifies the parameters needed
to create a software host bus adapter of a specific kind. HostHostBusAdapterTrait This data object type describes the bus adapter for
the host. HostIpConfigTrait The IP configuration. HostIpRouteConfigTrait IP Route Configuration. HostIssueTrait Deprecated all host issues were removed. HostMemberHealthCheckResultTrait This class defines healthcheck result of the vSphere Distributed Switch. HostMemberUplinkHealthCheckResultTrait This class defines healthcheck result of a specified Uplink port
in vSphere Distributed Switch. HostMultipathInfoLogicalUnitPolicyTrait The HostMultipathInfoLogicalUnitPolicy data object
describes a path selection policy for a device. HostNvmeSpecTrait Specifies the main parameters needed when connecting to
an NVMe over Fabrics controller or Discovery Service. HostNvmeTransportParametersTrait This data object represents the transport specific parameters
necessary to establish an NVM Express over Fabrics connection. HostPciPassthruConfigTrait This data object provides information about the state of PciPassthru
for all pci devices. HostPciPassthruInfoTrait This data object provides information about the state of PciPassthru
for all pci devices. HostProfileConfigSpecTrait HostProfileConfigSpec is the base data object
for all HostProfile configuration specifications.HostProfilesEntityCustomizationsTrait Data type used to contain a representation of host or cluster customization
data in a HostProfilesCustomizationData object. HostRdmaDeviceBackingTrait This data object represents the physical
backing of an RDMA device. HostSriovDevicePoolInfoTrait How to access HostSystemSwapConfigurationSystemSwapOptionTrait Base class for all system swap options. HostTargetTransportTrait Transport information about a SCSI target. HostTpmBootSecurityOptionEventDetailsTrait Details of a Trusted Platform Module (TPM) event recording kernel security
option passed at boot time and currently in effect. HostTpmEventDetailsTrait This is a base data object for describing an event generated by
Trusted Platform Module (TPM). HostVirtualSwitchBridgeTrait A bridge connects a virtual switch to a physical network adapter. HourlyTaskSchedulerTrait The HourlyTaskScheduler data object sets the time for hourly
task execution. ImportSpecTrait An ImportSpec is used when importing VMs or vApps. InheritablePolicyTrait The base class for any type of setting or configuration that may get a
inherited value. IntegrityAgencyVumIssueTrait Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs. IoFilterInfoTrait Information about an IO Filter. IoFilterManagerSslTrustTrait Specifies an SSL trust policy. IpAddressTrait This is the abstract base class for IP address. IssueTrait An issue represents a problem encountered while deploying and configurating agents
in a vCenter installation. KmipClusterInfoKeyInfoTrait Base class of key information. KmipServerSpecKeySpecTrait Base class of key specification. LicenseSourceTrait Deprecated as of vSphere API 4.0, this is not used by the system. MacAddressTrait Base class for specifying MAC addresses. MonthlyTaskSchedulerTrait The MonthlyTaskScheduler data object is the base type for
the monthly schedulers (MonthlyByDayTaskScheduler and
MonthlyByWeekdayTaskScheduler ). NegatableExpressionTrait The base class for any type of setting or configuration to which negation
can be applied. NetBiosConfigInfoTrait This data object type describes the NetBIOS configuration of
an operating system. NetworkSummaryTrait General information about a network. NoAgentVmDatastoreTrait An agent virtual machine is expected to be deployed on a host, but the agent cannot be
deployed because the agent datastore has not been configured on the host. NoAgentVmNetworkTrait An agent virtual machine is expected to be deployed on a host, but the agent cannot be
deployed because the agent network has not been configured on the host. NodeDeploymentSpecTrait The NodeDeploymentSpec class defines location
specification of the nodes the VCHA Cluster along with Management
vCenter Server information that manages node VM. NodeNetworkSpecTrait The NodeNetworkSpec class defines network specification of a node
in the VCHA Cluster. OptionTypeTrait The base data object type for all options. OptionValueTrait Describes the key/value pair of a configured option. OvfCreateImportSpecParamsTrait Parameters for deploying an OVF. OvfManagerCommonParamsTrait A common super-class for basic OVF descriptor parameters PbmCapabilityConstraintsTrait The PbmCapabilityConstraints data object is the base
object for capability subprofile constraints. PbmCapabilityProfileTrait The PbmCapabilityProfile data object defines
capability-based profiles. PbmCapabilityTypeInfoTrait The PbmCapabilityTypeInfo data object defines the datatype for a requirement
or capability property. PbmLineOfServiceInfoTrait Describes Line of Service of a capability provider. PbmPlacementMatchingResourcesTrait Describes the collection of resources (for example, hosts) that satisfy a
policy, for a specific datastore. PbmPlacementRequirementTrait Defines a constraint for placing objects onto PbmPlacementHub s. PbmProfileTrait The PbmProfile data object is the base object
for storage capability profiles. PerfEntityMetricBaseTrait Base type for the various PerfEntityMetric
encodings. PerfMetricSeriesTrait This is a generic data object type that stores values for a specific
performance metric. PersonalityAgencyDepotIssueTrait Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs. PersonalityAgencyPmIssueTrait Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs. PersonalityAgentPmIssueTrait Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs. PhysicalNicHintTrait This data object type describes each network of a physical
network adapter’s network hint. PolicyOptionTrait The PolicyOption data object represents one or more configuration
values. PortGroupProfileTrait PortGroupProfile is the base class for the different port group
subprofile objects.ProfileConfigInfoTrait How to access ProfileCreateSpecTrait Specification describing the parameters during Profile creation ProfileExecuteResultTrait The ProfileExecuteResult data object contains the results from a
HostProfile .HostProfile.ExecuteHostProfile
operation. ProfileExpressionTrait How to access ProfilePolicyOptionMetadataTrait The ProfilePolicyOptionMetadata data object contains the metadata information
for a PolicyOption . ProfileSerializedCreateSpecTrait The ProfileSerializedCreateSpec data object
defines a string that contains a serialized representation of a host profile. RecurrentTaskSchedulerTrait The RecurrentTaskScheduler data object is the base type for
the hierarchy that includes hourly, daily, weekly, and monthly task schedulers. ResourcePoolSummaryTrait This data object type encapsulates a typical set of resource
pool information that is useful for list views and summary pages. ScheduledTaskSpecTrait Parameters for scheduled task creation. ScsiLunTrait The ScsiLun data object describes a SCSI logical unit. SddcBaseTrait An empty data object which can be used as the base class for data objects
outside VIM namespace which have to be proxied through vCenter opaquely. SelectionSetTrait Base class for selecting entities SelectionSpecTrait The SelectionSpec is the base type for data
object types that specify what additional objects to filter. ServiceLocatorCredentialTrait The data object type is a base type of credential for authentication such
as username/password or SAML token. SessionManagerServiceRequestSpecTrait This data object type describes a request to a service. SmsProviderInfoTrait Information about Storage Monitoring Service (SMS)
providers. SmsProviderSpecTrait Specification for Storage Monitoring Service (SMS)
providers. SolutionsHookAcknowledgeConfigTrait Specifies the acknowledgement type of a configured System Virtual
Machine’s lifecycle hook. SolutionsStoragePolicyTrait Storage policy to be applied during system Virtual Machine creation. SolutionsTypeSpecificSolutionConfigTrait Specifies the specific solution configuration based on its type. SolutionsVmSourceTrait Specifies how to find the files of the system Virtual Machine to be
created. StoragePortTrait This data object represents the storage port. TargetGroupMemberInfoTrait Information about member virtual volumes in a ReplicationGroup
on the target when the state is TARGET . TaskManagerTaskViewSpecTrait TaskManagerTaskViewSpec provides the specifications
for returning the set of tasks in the
Task Console.TaskReasonTrait Base type for all task reasons. TaskSchedulerTrait The TaskScheduler data object is the base type for the scheduler objects. TypeDescriptionTrait Static strings used for describing an object type. UserSearchResultTrait When searching for users, the search results in
some additional information. VMwareDvsHealthCheckConfigTrait This class defines health check configuration for
VMware vSphere Distributed Switch. VibIssueTrait Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs. VibNotInstalledTrait Deprecated as of vSphere 9.0. Please refer to vLCM Image APIs. VibVibServicesSslTrustTrait This structure may be used only with operations rendered under /eam. VimClusterVsanFaultDomainSpecTrait Describes a fault domain structure. VirtualControllerOptionTrait The VirtualControllerOption data object type contains information about
a virtual controller type. VirtualControllerTrait VirtualController is the base data object type for a device controller in
a virtual machine. VirtualDeviceBackingInfoTrait VirtualDeviceBackingInfo is a base data object type
for information about the backing of a device in a virtual machine.VirtualDeviceBackingOptionTrait The VirtualDeviceBackingOption data class
defines options for device-specific virtual backing objects. VirtualDeviceBusSlotInfoTrait VirtualDeviceBusSlotInfo is a base data object type
for information about device connection to its bus.VirtualDeviceConfigSpecTrait The VirtualDeviceSpec data object type encapsulates change
specifications for an individual virtual device. VirtualDeviceDeviceBackingInfoTrait The VirtualDeviceDeviceBackingInfo data object type
defines information about a host device or resource that backs a device
in a virtual machine. VirtualDeviceDeviceBackingOptionTrait The DeviceBackingOption data class contains device-specific backing options. VirtualDeviceFileBackingInfoTrait VirtualDeviceFileBackingInfo is a data object type
for information about file backing for a device in a virtual machine.VirtualDeviceFileBackingOptionTrait The FileBackingOption data class contains file-specific backing options. VirtualDeviceOptionTrait The VirtualDeviceOption data object type contains information about
a virtual device type, the options for configuring the virtual device,
and the relationship between this virtual device and other devices. VirtualDevicePciBusSlotInfoTrait The VirtualDevicePciBusSlotInfo data object type
defines information about a pci bus slot of pci device in a virtual machine. VirtualDevicePipeBackingInfoTrait The VirtualDevicePipeBackingInfo data object type
defines information for using a named pipe as backing for a device
in a virtual machine. VirtualDevicePipeBackingOptionTrait The VirtualDevicePipeBackingOption data object type contains options
specific to pipe backings. VirtualDeviceRemoteDeviceBackingInfoTrait VirtualDeviceRemoteDeviceBackingInfo is a data object type
for information
about a remote device backing used by a device in a virtual machine.VirtualDeviceRemoteDeviceBackingOptionTrait VirtualDeviceOption.RemoteDeviceBackingOption describes the options
for a remote device backing. VirtualDeviceTrait VirtualDevice is the base data object type for devices in a virtual machine. VirtualDeviceUriBackingInfoTrait The VirtualDeviceURIBackingInfo data object type
defines information for using a network socket as backing for a virtual device. VirtualDeviceUriBackingOptionTrait The VirtualDeviceURIBackingOption data object type describes network communication
options for virtual devices. VirtualDiskRawDiskVer2BackingInfoTrait This data object type contains information about backing a virtual disk by
using a host device, as used by VMware Server. VirtualDiskRawDiskVer2BackingOptionTrait The VirtualDiskOption.RawDiskVer2BackingOption object type
contains the available options when backing a virtual disk
using a host device on VMware Server. VirtualDiskSpecTrait Specification used to create or clone a virtual disk VirtualEthernetCardOptionTrait This data object type contains the options for the
virtual ethernet card data object type. VirtualEthernetCardTrait The VirtualEthernetCard data object contains the properties
of an Ethernet adapter attached to a virtual machine. VirtualMachineBaseIndependentFilterSpecTrait The BaseIndependentFilterSpec is base class for two different types
of independent filter specs VirtualMachineIndependentFilterSpec
and VirtualMachineEmptyIndependentFilterSpec which are used to specify
independent filters to be attached/removed on VMs virtual disk. VirtualMachineBootOptionsBootableDeviceTrait Bootable device. VirtualMachineConnectionTrait The VirtualMachineConnection object describes a connection to the virtual
machine. VirtualMachineDeviceRuntimeInfoDeviceRuntimeStateTrait Runtime state of a device. VirtualMachineDiskDeviceInfoTrait The DiskDeviceInfo class contains basic information about a specific disk hardware
device. VirtualMachineGuestQuiesceSpecTrait This data object type encapsulates configuration settings
when creating a virtual machine quiesced snapshot. VirtualMachineIdTrait Abstracts the identity of a virtual machine. VirtualMachinePciPassthroughInfoTrait Description of a generic PCI device that can be attached to a virtual machine. VirtualMachineProfileSpecTrait The ProfileSpec data object is used to specify the Storage Policy to be
associated with a Virtual Machine Home or a Virtual Disk. VirtualMachineSriovDevicePoolInfoTrait How to access VirtualMachineTargetInfoTrait The TargetInfo specified a value that can be used in the device backings to
connect the virtual machine to a physical (or logical) host device. VirtualMachineVirtualDeviceGroupsDeviceGroupTrait Base device group type. VirtualPciPassthroughPluginBackingInfoTrait The VirtualPCIPassthrough.PluginBackingInfo is a base data object type
for encoding plugin-specific information. VirtualPciPassthroughPluginBackingOptionTrait This data object type describes the options for the
VirtualPCIPassthroughPluginBackingInfo data object type. VirtualSataControllerOptionTrait The VirtualSATAControllerOption data object type contains the options
for a virtual SATA controller defined by the
VirtualSATAController
data object type. VirtualSataControllerTrait The VirtualSATAController data object type represents
a SATA controller in a virtual machine. VirtualScsiControllerOptionTrait The VirtualSCSIControllerOption data object type contains the options
for a virtual SCSI controller defined by the
VirtualSCSIController
data object type. VirtualScsiControllerTrait The VirtualSCSIController data object type represents
a SCSI controller in a virtual machine. VirtualSoundCardOptionTrait The VirtualSoundCardOption data class contains the options for the
virtual sound card class. VirtualSoundCardTrait This data object type represents a sound card in
a virtual machine. VirtualVmxnet3OptionTrait The VirtualVmxnet3Option data object type contains the options for the
VirtualVmxnet3 data object type. VirtualVmxnet3Trait The VirtualVmxnet3 data object type represents an instance
of the Vmxnet3 virtual Ethernet adapter attached to a virtual machine. VirtualVmxnetOptionTrait The VirtualVmxnetOption data object type contains the options for the
VirtualVmxnet data object type. VirtualVmxnetTrait The VirtualVmxnet data object type represents an instance
of the Vmxnet virtual Ethernet adapter attached to a virtual machine. VmConfigFileInfoTrait This data object type describes a virtual machine configuration file. VmConfigFileQueryTrait This data object type describes query specification for the virtual machine
configuration file. VmConfigInfoTrait VM Configuration. VmConfigSpecTrait vApp related configuration of a VM. VmDeployedTrait An agent virtual machine is expected to be removed from a host, but the agent virtual machine has not
been removed. VmIssueTrait Base class for all issues related to the deployed virtual machine for a
particular agent. VmNotDeployedTrait An agent virtual machine is expected to be deployed on a host, but the agent virtual machine has not
been deployed. VmPoweredOffTrait An agent virtual machine is expected to be powered on, but the agent virtual machine is powered off. VmfsDatastoreBaseOptionTrait Base class that describes a VMFS datastore provisioning option. VmfsDatastoreSingleExtentOptionTrait Datastore addition policy to use a single extent on the disk for a VMFS
datastore. VmfsDatastoreSpecTrait Base class for VMFS datastore addition specification. VmwareDistributedVirtualSwitchVlanSpecTrait Base class for Vlan Specifiation for ports. VsanClusterConfigInfoTrait The VsanClusterConfigInfo data object contains configuration
data for the VSAN service in a cluster. VsanClusterHealthLinkBaseTrait Defines a link in the context of a ResultTable cell, which
will be consumed by vSAN UI for UI navigation VsanClusterHealthResultBaseTrait The base class for vSAN health summary test result VsanComparatorTrait Defines the base criteria for data Comparator. VsanConfigBaseIssueTrait Base class for all vSAN configuration issues. VsanDataEfficiencyConfigTrait The data efficiency configuration of a vSAN cluster. VsanDatastoreConfigTrait The datastore configuration of a vSAN cluster. VsanDatastoreSpecTrait The configuration information of a vSAN datastore. VsanDirectoryServerConfigTrait The directory server configuration which can be used to communicate and
authenticate with a directory server. VsanDiskResourceCheckResultTrait The vSAN disk level resource check report. VsanHclCommonDeviceInfoTrait Captures all common HCL related information about particular device, e.g physical NIC VsanHealthActionBaseTrait This is the base class for vSAN health issue remediation or troubleshooting. VsanHostConfigInfoNetworkInfoPortConfigTrait A PortConfig represents a virtual network adapter and its
configuration for use by the VSAN service. VsanHostConfigInfoTrait The VsanHostConfigInfo data object contains host-specific settings
for the VSAN service. VsanHostDiskResultTrait A DiskResult represents the result of VSAN configuration operation
on a HostScsiDisk , and its current eligibility state for use by
the VSAN service. VsanHostIpConfigTrait An VsanHostIpConfig is a pair of multicast IP addresses for use by the VSAN
service. VsanIscsiLunCommonInfoTrait Specifies common properties for iSCSI LUN. VsanIscsiTargetBasicInfoTrait Specifies the basic properties for iSCSI target. VsanIscsiTargetCommonInfoTrait Specifies the common properties for vSAN iSCSI target. VsanIscsiTargetServiceConfigTrait Specified common properties for vSAN iSCSI target service. VsanIscsiVipConfigSpecTrait Define virtual IP (VIP) specification. VsanMountPrecheckItemTrait Precheck result for mounting a remote vSAN datastore. VsanMountPrecheckResultTrait Result for all types of remote vSAN mounting prechecks. VsanNetworkConfigBaseIssueTrait Base class for all vSAN network configuration issues. VsanRemoteVcInfoTrait The basic information for communicating with a remote vCenter. VsanResourceCheckComponentResultTrait The resource check result for different components,
e.g., regular vSAN or vSphere data persistence platform. VsanResourceCheckResultTrait The resource check result for the queried spec
VsanResourceCheckSpec . VsanResourceCheckTaskDetailsTrait The detailed information of a running task that is related to resource check. VsanResourceConstraintTrait Defines the base criteria for matching resources based on their types. VsanUpgradeSystemPreflightCheckIssueTrait Base class for a pre-flight check issue. VsanUpgradeSystemPreflightCheckResultTrait Captures the result of a VSAN upgrade pre-flight check. VsanUpgradeSystemUpgradeHistoryItemTrait Captures one “log entry” of an upgrade process. VsanUpgradeSystemUpgradeStatusTrait Captures the status of a VSAN cluster on-disk format upgrade. VslmCreateSpecBackingSpecTrait Specification of the backing of a virtual
storage object. VslmMigrateSpecTrait Base specification of moving or copying a virtual storage object. VslmTaskReasonTrait Base type for all task reasons.