pub trait ClusterAgentVmNotDeployedTrait: ClusterAgentAgentIssueTrait {
// Required methods
fn get_cluster_agent_vm_not_deployed(&self) -> &ClusterAgentVmNotDeployed;
fn get_cluster_agent_vm_not_deployed_mut(
&mut self,
) -> &mut ClusterAgentVmNotDeployed;
}Expand description
A cluster agent Virtual Machine is expected to be deployed on a cluster, but the cluster agent Virtual Machine has not been deployed or has been exlicitly deleted from the cluster.
Typically more specific issue (a subclass of this issue) indicates the particular reason why vSphere ESX Agent Manager was unable to deploy the cluster agent Virtual Machine.
This is an active remediable issue. To remediate, vSphere ESX Agent Manager redeploys the cluster agent Virtual Machine.
This structure may be used only with operations rendered under /eam.
Required Methods
Sourcefn get_cluster_agent_vm_not_deployed(&self) -> &ClusterAgentVmNotDeployed
fn get_cluster_agent_vm_not_deployed(&self) -> &ClusterAgentVmNotDeployed
Get a reference to the ClusterAgentVmNotDeployed parent struct
Sourcefn get_cluster_agent_vm_not_deployed_mut(
&mut self,
) -> &mut ClusterAgentVmNotDeployed
fn get_cluster_agent_vm_not_deployed_mut( &mut self, ) -> &mut ClusterAgentVmNotDeployed
Get a mutable reference to the ClusterAgentVmNotDeployed parent struct