pub trait VmNotDeployedTrait: AgentIssueTrait {
// Required methods
fn get_vm_not_deployed(&self) -> &VmNotDeployed;
fn get_vm_not_deployed_mut(&mut self) -> &mut VmNotDeployed;
}Expand description
An agent virtual machine is expected to be deployed on a host, but the agent virtual machine has not been deployed.
Typically, a more specific issue (a subclass of this issue) indicates the particular reason why vSphere ESX Agent Manager was unable to deploy the agent, such as being unable to access the OVF package for the agent or a missing host configuration. This issue can also happen if the agent virtual machine is explicitly deleted from the host.
This is an active remediable issue. To remediate, vSphere ESX Agent Manager redeploys the agent virtual machine.
This structure may be used only with operations rendered under /eam.
Required Methods
Sourcefn get_vm_not_deployed(&self) -> &VmNotDeployed
fn get_vm_not_deployed(&self) -> &VmNotDeployed
Get a reference to the VmNotDeployed parent struct
Sourcefn get_vm_not_deployed_mut(&mut self) -> &mut VmNotDeployed
fn get_vm_not_deployed_mut(&mut self) -> &mut VmNotDeployed
Get a mutable reference to the VmNotDeployed parent struct